/* ------------------------------------------------------------
name: "gods_cab"
Code generated with Faust 2.22.5 (https://faust.grame.fr)
Compilation options: -lang cpp -scal -ftz 0
------------------------------------------------------------ */

#ifndef  __gods_cab_H__
#define  __gods_cab_H__

/************************************************************************
 ************************************************************************
    FAUST Architecture File
    Copyright (C) 2009-2016 Albert Graef <aggraef@gmail.com>
    ---------------------------------------------------------------------
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as
    published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with the GNU C Library; if not, write to the Free
    Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
    02111-1307 USA.
 ************************************************************************
 ************************************************************************/

/* LV2 architecture for Faust synths. */

/* NOTE: This requires one of the Boost headers (boost/circular_buffer.hpp),
   so to compile Faust programs created with this architecture you need to
   have at least the Boost headers installed somewhere on your include path
   (the Boost libraries aren't needed). */

#include <stdlib.h>
#include <string.h>
#include <math.h>
#include <list>
#include <map>
#include <set>

// generic Faust dsp and UI classes
/************************** BEGIN dsp.h **************************/
/************************************************************************
 FAUST Architecture File
 Copyright (C) 2003-2017 GRAME, Centre National de Creation Musicale
 ---------------------------------------------------------------------
 This Architecture section is free software; you can redistribute it
 and/or modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 3 of
 the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; If not, see <http://www.gnu.org/licenses/>.
 
 EXCEPTION : As a special exception, you may create a larger work
 that contains this FAUST architecture section and distribute
 that work under terms of your choice, so long as this FAUST
 architecture section is not modified.
 ************************************************************************/

#ifndef __dsp__
#define __dsp__

#include <string>
#include <vector>

#ifndef FAUSTFLOAT
#define FAUSTFLOAT float
#endif

struct UI;
struct Meta;

/**
 * DSP memory manager.
 */

struct dsp_memory_manager {
    
    virtual ~dsp_memory_manager() {}
    
    virtual void* allocate(size_t size) = 0;
    virtual void destroy(void* ptr) = 0;
    
};

/**
* Signal processor definition.
*/

class dsp {

    public:

        dsp() {}
        virtual ~dsp() {}

        /* Return instance number of audio inputs */
        virtual int getNumInputs() = 0;
    
        /* Return instance number of audio outputs */
        virtual int getNumOutputs() = 0;
    
        /**
         * Trigger the ui_interface parameter with instance specific calls
         * to 'addBtton', 'addVerticalSlider'... in order to build the UI.
         *
         * @param ui_interface - the user interface builder
         */
        virtual void buildUserInterface(UI* ui_interface) = 0;
    
        /* Returns the sample rate currently used by the instance */
        virtual int getSampleRate() = 0;
    
        /**
         * Global init, calls the following methods:
         * - static class 'classInit': static tables initialization
         * - 'instanceInit': constants and instance state initialization
         *
         * @param sample_rate - the sampling rate in Hertz
         */
        virtual void init(int sample_rate) = 0;

        /**
         * Init instance state
         *
         * @param sample_rate - the sampling rate in Hertz
         */
        virtual void instanceInit(int sample_rate) = 0;

        /**
         * Init instance constant state
         *
         * @param sample_rate - the sampling rate in Hertz
         */
        virtual void instanceConstants(int sample_rate) = 0;
    
        /* Init default control parameters values */
        virtual void instanceResetUserInterface() = 0;
    
        /* Init instance state (delay lines...) */
        virtual void instanceClear() = 0;
 
        /**
         * Return a clone of the instance.
         *
         * @return a copy of the instance on success, otherwise a null pointer.
         */
        virtual dsp* clone() = 0;
    
        /**
         * Trigger the Meta* parameter with instance specific calls to 'declare' (key, value) metadata.
         *
         * @param m - the Meta* meta user
         */
        virtual void metadata(Meta* m) = 0;
    
        /**
         * DSP instance computation, to be called with successive in/out audio buffers.
         *
         * @param count - the number of frames to compute
         * @param inputs - the input audio buffers as an array of non-interleaved FAUSTFLOAT samples (eiher float, double or quad)
         * @param outputs - the output audio buffers as an array of non-interleaved FAUSTFLOAT samples (eiher float, double or quad)
         *
         */
        virtual void compute(int count, FAUSTFLOAT** inputs, FAUSTFLOAT** outputs) = 0;
    
        /**
         * DSP instance computation: alternative method to be used by subclasses.
         *
         * @param date_usec - the timestamp in microsec given by audio driver.
         * @param count - the number of frames to compute
         * @param inputs - the input audio buffers as an array of non-interleaved FAUSTFLOAT samples (either float, double or quad)
         * @param outputs - the output audio buffers as an array of non-interleaved FAUSTFLOAT samples (either float, double or quad)
         *
         */
        virtual void compute(double /*date_usec*/, int count, FAUSTFLOAT** inputs, FAUSTFLOAT** outputs) { compute(count, inputs, outputs); }
       
};

/**
 * Generic DSP decorator.
 */

class decorator_dsp : public dsp {

    protected:

        dsp* fDSP;

    public:

        decorator_dsp(dsp* dsp = nullptr):fDSP(dsp) {}
        virtual ~decorator_dsp() { delete fDSP; }

        virtual int getNumInputs() { return fDSP->getNumInputs(); }
        virtual int getNumOutputs() { return fDSP->getNumOutputs(); }
        virtual void buildUserInterface(UI* ui_interface) { fDSP->buildUserInterface(ui_interface); }
        virtual int getSampleRate() { return fDSP->getSampleRate(); }
        virtual void init(int sample_rate) { fDSP->init(sample_rate); }
        virtual void instanceInit(int sample_rate) { fDSP->instanceInit(sample_rate); }
        virtual void instanceConstants(int sample_rate) { fDSP->instanceConstants(sample_rate); }
        virtual void instanceResetUserInterface() { fDSP->instanceResetUserInterface(); }
        virtual void instanceClear() { fDSP->instanceClear(); }
        virtual decorator_dsp* clone() { return new decorator_dsp(fDSP->clone()); }
        virtual void metadata(Meta* m) { fDSP->metadata(m); }
        // Beware: subclasses usually have to overload the two 'compute' methods
        virtual void compute(int count, FAUSTFLOAT** inputs, FAUSTFLOAT** outputs) { fDSP->compute(count, inputs, outputs); }
        virtual void compute(double date_usec, int count, FAUSTFLOAT** inputs, FAUSTFLOAT** outputs) { fDSP->compute(date_usec, count, inputs, outputs); }
    
};

/**
 * DSP factory class.
 */

class dsp_factory {
    
    protected:
    
        // So that to force sub-classes to use deleteDSPFactory(dsp_factory* factory);
        virtual ~dsp_factory() {}
    
    public:
    
        virtual std::string getName() = 0;
        virtual std::string getSHAKey() = 0;
        virtual std::string getDSPCode() = 0;
        virtual std::string getCompileOptions() = 0;
        virtual std::vector<std::string> getLibraryList() = 0;
        virtual std::vector<std::string> getIncludePathnames() = 0;
    
        virtual dsp* createDSPInstance() = 0;
    
        virtual void setMemoryManager(dsp_memory_manager* manager) = 0;
        virtual dsp_memory_manager* getMemoryManager() = 0;
    
};

/**
 * On Intel set FZ (Flush to Zero) and DAZ (Denormals Are Zero)
 * flags to avoid costly denormals.
 */

#ifdef __SSE__
    #include <xmmintrin.h>
    #ifdef __SSE2__
        #define AVOIDDENORMALS _mm_setcsr(_mm_getcsr() | 0x8040)
    #else
        #define AVOIDDENORMALS _mm_setcsr(_mm_getcsr() | 0x8000)
    #endif
#else
    #define AVOIDDENORMALS
#endif

#endif
/**************************  END  dsp.h **************************/
/************************** BEGIN UI.h **************************/
/************************************************************************
 FAUST Architecture File
 Copyright (C) 2003-2020 GRAME, Centre National de Creation Musicale
 ---------------------------------------------------------------------
 This Architecture section is free software; you can redistribute it
 and/or modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 3 of
 the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; If not, see <http://www.gnu.org/licenses/>.
 
 EXCEPTION : As a special exception, you may create a larger work
 that contains this FAUST architecture section and distribute
 that work under terms of your choice, so long as this FAUST
 architecture section is not modified.
 ************************************************************************/

#ifndef __UI_H__
#define __UI_H__

#ifndef FAUSTFLOAT
#define FAUSTFLOAT float
#endif

/*******************************************************************************
 * UI : Faust DSP User Interface
 * User Interface as expected by the buildUserInterface() method of a DSP.
 * This abstract class contains only the method that the Faust compiler can
 * generate to describe a DSP user interface.
 ******************************************************************************/

struct Soundfile;

template <typename REAL>
struct UIReal
{
    UIReal() {}
    virtual ~UIReal() {}
    
    // -- widget's layouts
    
    virtual void openTabBox(const char* label) = 0;
    virtual void openHorizontalBox(const char* label) = 0;
    virtual void openVerticalBox(const char* label) = 0;
    virtual void closeBox() = 0;
    
    // -- active widgets
    
    virtual void addButton(const char* label, REAL* zone) = 0;
    virtual void addCheckButton(const char* label, REAL* zone) = 0;
    virtual void addVerticalSlider(const char* label, REAL* zone, REAL init, REAL min, REAL max, REAL step) = 0;
    virtual void addHorizontalSlider(const char* label, REAL* zone, REAL init, REAL min, REAL max, REAL step) = 0;
    virtual void addNumEntry(const char* label, REAL* zone, REAL init, REAL min, REAL max, REAL step) = 0;
    
    // -- passive widgets
    
    virtual void addHorizontalBargraph(const char* label, REAL* zone, REAL min, REAL max) = 0;
    virtual void addVerticalBargraph(const char* label, REAL* zone, REAL min, REAL max) = 0;
    
    // -- soundfiles
    
    virtual void addSoundfile(const char* label, const char* filename, Soundfile** sf_zone) = 0;
    
    // -- metadata declarations
    
    virtual void declare(REAL* zone, const char* key, const char* val) {}
};

struct UI : public UIReal<FAUSTFLOAT>
{
    UI() {}
    virtual ~UI() {}
};

#endif
/**************************  END  UI.h **************************/

using namespace std;

typedef pair<const char*,const char*> strpair;

struct Meta : std::map<const char*, const char*>
{
  void declare(const char *key, const char *value)
  {
    (*this)[key] = value;
  }
  const char* get(const char *key, const char *def)
  {
    if (this->find(key) != this->end())
      return (*this)[key];
    else
      return def;
  }
};

/******************************************************************************
*******************************************************************************

		       VECTOR INTRINSICS

*******************************************************************************
*******************************************************************************/


/***************************************************************************
   LV2 UI interface
 ***************************************************************************/

enum ui_elem_type_t {
  UI_BUTTON, UI_CHECK_BUTTON,
  UI_V_SLIDER, UI_H_SLIDER, UI_NUM_ENTRY,
  UI_V_BARGRAPH, UI_H_BARGRAPH,
  UI_END_GROUP, UI_V_GROUP, UI_H_GROUP, UI_T_GROUP
};

struct ui_elem_t {
  ui_elem_type_t type;
  const char *label;
  int port;
  float *zone;
  void *ref;
  float init, min, max, step;
};

class LV2UI : public UI
{
public:
  bool is_instr;
  int nelems, nports;
  ui_elem_t *elems;
  map< int, list<strpair> > metadata;

  LV2UI(int maxvoices = 0);
  virtual ~LV2UI();

protected:
  void add_elem(ui_elem_type_t type, const char *label = NULL);
  void add_elem(ui_elem_type_t type, const char *label, float *zone);
  void add_elem(ui_elem_type_t type, const char *label, float *zone,
		float init, float min, float max, float step);
  void add_elem(ui_elem_type_t type, const char *label, float *zone,
		float min, float max);

  bool have_freq, have_gain, have_gate;
  bool is_voice_ctrl(const char *label);

public:
  virtual void addButton(const char* label, float* zone);
  virtual void addCheckButton(const char* label, float* zone);
  virtual void addVerticalSlider(const char* label, float* zone, float init, float min, float max, float step);
  virtual void addHorizontalSlider(const char* label, float* zone, float init, float min, float max, float step);
  virtual void addNumEntry(const char* label, float* zone, float init, float min, float max, float step);

  virtual void addHorizontalBargraph(const char* label, float* zone, float min, float max);
  virtual void addVerticalBargraph(const char* label, float* zone, float min, float max);
    
  virtual void addSoundfile(const char* label, const char* filename, Soundfile** sf_zone) {}

  virtual void openTabBox(const char* label);
  virtual void openHorizontalBox(const char* label);
  virtual void openVerticalBox(const char* label);
  virtual void closeBox();

  virtual void run();

  virtual void declare(float* zone, const char* key, const char* value);
};

LV2UI::LV2UI(int maxvoices)
{
  is_instr = maxvoices>0;
  have_freq = have_gain = have_gate = false;
  nelems = nports = 0;
  elems = NULL;
}

LV2UI::~LV2UI()
{
  if (elems) free(elems);
}

void LV2UI::declare(float* zone, const char* key, const char* value)
{
  map< int, list<strpair> >::iterator it = metadata.find(nelems);
  if (it != metadata.end())
    it->second.push_back(strpair(key, value));
  else
    metadata[nelems] = list<strpair>(1, strpair(key, value));
}

inline void LV2UI::add_elem(ui_elem_type_t type, const char *label)
{
  ui_elem_t *elems1 = (ui_elem_t*)realloc(elems, (nelems+1)*sizeof(ui_elem_t));
  if (elems1)
    elems = elems1;
  else
    return;
  elems[nelems].type = type;
  elems[nelems].label = label;
  elems[nelems].port = -1;
  elems[nelems].zone = NULL;
  elems[nelems].ref = NULL;
  elems[nelems].init = 0.0;
  elems[nelems].min = 0.0;
  elems[nelems].max = 0.0;
  elems[nelems].step = 0.0;
  nelems++;
}

#define portno(label) (is_voice_ctrl(label)?-1:nports++)

inline void LV2UI::add_elem(ui_elem_type_t type, const char *label, float *zone)
{
  ui_elem_t *elems1 = (ui_elem_t*)realloc(elems, (nelems+1)*sizeof(ui_elem_t));
  if (elems1)
    elems = elems1;
  else
    return;
  elems[nelems].type = type;
  elems[nelems].label = label;
  elems[nelems].port = portno(label);
  elems[nelems].zone = zone;
  elems[nelems].ref = NULL;
  elems[nelems].init = 0.0;
  elems[nelems].min = 0.0;
  elems[nelems].max = 0.0;
  elems[nelems].step = 0.0;
  nelems++;
}

inline void LV2UI::add_elem(ui_elem_type_t type, const char *label, float *zone,
			     float init, float min, float max, float step)
{
  ui_elem_t *elems1 = (ui_elem_t*)realloc(elems, (nelems+1)*sizeof(ui_elem_t));
  if (elems1)
    elems = elems1;
  else
    return;
  elems[nelems].type = type;
  elems[nelems].label = label;
  elems[nelems].port = portno(label);
  elems[nelems].zone = zone;
  elems[nelems].ref = NULL;
  elems[nelems].init = init;
  elems[nelems].min = min;
  elems[nelems].max = max;
  elems[nelems].step = step;
  nelems++;
}

inline void LV2UI::add_elem(ui_elem_type_t type, const char *label, float *zone,
			     float min, float max)
{
  ui_elem_t *elems1 = (ui_elem_t*)realloc(elems, (nelems+1)*sizeof(ui_elem_t));
  if (elems1)
    elems = elems1;
  else
    return;
  elems[nelems].type = type;
  elems[nelems].label = label;
  elems[nelems].port = portno(label);
  elems[nelems].zone = zone;
  elems[nelems].ref = NULL;
  elems[nelems].init = 0.0;
  elems[nelems].min = min;
  elems[nelems].max = max;
  elems[nelems].step = 0.0;
  nelems++;
}

inline bool LV2UI::is_voice_ctrl(const char *label)
{
  if (!is_instr)
    return false;
  else if (!have_freq && !strcmp(label, "freq"))
    return (have_freq = true);
  else if (!have_gain && !strcmp(label, "gain"))
    return (have_gain = true);
  else if (!have_gate && !strcmp(label, "gate"))
    return (have_gate = true);
  else
    return false;
}

void LV2UI::addButton(const char* label, float* zone)
{ add_elem(UI_BUTTON, label, zone); }
void LV2UI::addCheckButton(const char* label, float* zone)
{ add_elem(UI_CHECK_BUTTON, label, zone); }
void LV2UI::addVerticalSlider(const char* label, float* zone, float init, float min, float max, float step)
{ add_elem(UI_V_SLIDER, label, zone, init, min, max, step); }
void LV2UI::addHorizontalSlider(const char* label, float* zone, float init, float min, float max, float step)
{ add_elem(UI_H_SLIDER, label, zone, init, min, max, step); }
void LV2UI::addNumEntry(const char* label, float* zone, float init, float min, float max, float step)
{ add_elem(UI_NUM_ENTRY, label, zone, init, min, max, step); }

void LV2UI::addHorizontalBargraph(const char* label, float* zone, float min, float max)
{ add_elem(UI_H_BARGRAPH, label, zone, min, max); }
void LV2UI::addVerticalBargraph(const char* label, float* zone, float min, float max)
{ add_elem(UI_V_BARGRAPH, label, zone, min, max); }

void LV2UI::openTabBox(const char* label)
{ add_elem(UI_T_GROUP, label); }
void LV2UI::openHorizontalBox(const char* label)
{ add_elem(UI_H_GROUP, label); }
void LV2UI::openVerticalBox(const char* label)
{ add_elem(UI_V_GROUP, label); }
void LV2UI::closeBox()
{ add_elem(UI_END_GROUP); }

void LV2UI::run() {}

//----------------------------------------------------------------------------
//  FAUST generated signal processor
//----------------------------------------------------------------------------

#ifndef FAUSTFLOAT
#define FAUSTFLOAT float
#endif 

#include <algorithm>
#include <cmath>


#ifndef FAUSTCLASS 
#define FAUSTCLASS gods_cab
#endif

#ifdef __APPLE__ 
#define exp10f __exp10f
#define exp10 __exp10
#endif

class gods_cab : public dsp {
	
 private:
	
	FAUSTFLOAT fEntry0;
	int IOTA;
	float fVec0[512];
	float fVec1[512];
	float fVec2[512];
	float fVec3[512];
	float fVec4[512];
	float fVec5[512];
	float fVec6[512];
	float fVec7[512];
	float fVec8[512];
	float fVec9[512];
	float fVec10[512];
	float fVec11[512];
	float fVec12[512];
	float fVec13[512];
	float fVec14[512];
	float fVec15[512];
	float fVec16[512];
	float fVec17[512];
	float fVec18[512];
	float fVec19[512];
	float fVec20[512];
	float fVec21[512];
	float fVec22[512];
	float fVec23[512];
	float fVec24[512];
	float fVec25[512];
	float fVec26[512];
	float fVec27[512];
	float fVec28[512];
	float fVec29[512];
	float fVec30[512];
	float fVec31[512];
	float fVec32[512];
	float fVec33[512];
	float fVec34[512];
	float fVec35[512];
	float fVec36[512];
	float fVec37[512];
	float fVec38[512];
	float fVec39[512];
	float fVec40[512];
	float fVec41[512];
	float fVec42[512];
	float fVec43[512];
	float fVec44[512];
	float fVec45[512];
	float fVec46[512];
	float fVec47[512];
	float fVec48[512];
	float fVec49[512];
	float fVec50[512];
	float fVec51[512];
	float fVec52[512];
	float fVec53[512];
	float fVec54[512];
	float fVec55[512];
	float fVec56[512];
	float fVec57[512];
	int fSampleRate;
	
 public:
	
	void metadata(Meta* m) { 
		m->declare("basics.lib/name", "Faust Basic Element Library");
		m->declare("basics.lib/version", "0.1");
		m->declare("filename", "gods_cab.dsp");
		m->declare("filters.lib/fir:author", "Julius O. Smith III");
		m->declare("filters.lib/fir:copyright", "Copyright (C) 2003-2019 by Julius O. Smith III <jos@ccrma.stanford.edu>");
		m->declare("filters.lib/fir:license", "MIT-style STK-4.3 license");
		m->declare("filters.lib/lowpass0_highpass1", "Copyright (C) 2003-2019 by Julius O. Smith III <jos@ccrma.stanford.edu>");
		m->declare("filters.lib/name", "Faust Filters Library");
		m->declare("name", "gods_cab");
	}

	virtual int getNumInputs() {
		return 1;
	}
	virtual int getNumOutputs() {
		return 1;
	}
	virtual int getInputRate(int channel) {
		int rate;
		switch ((channel)) {
			case 0: {
				rate = 1;
				break;
			}
			default: {
				rate = -1;
				break;
			}
		}
		return rate;
	}
	virtual int getOutputRate(int channel) {
		int rate;
		switch ((channel)) {
			case 0: {
				rate = 1;
				break;
			}
			default: {
				rate = -1;
				break;
			}
		}
		return rate;
	}
	
	static void classInit(int sample_rate) {
	}
	
	virtual void instanceConstants(int sample_rate) {
		fSampleRate = sample_rate;
	}
	
	virtual void instanceResetUserInterface() {
		fEntry0 = FAUSTFLOAT(0.0f);
	}
	
	virtual void instanceClear() {
		IOTA = 0;
		for (int l0 = 0; (l0 < 512); l0 = (l0 + 1)) {
			fVec0[l0] = 0.0f;
		}
		for (int l1 = 0; (l1 < 512); l1 = (l1 + 1)) {
			fVec1[l1] = 0.0f;
		}
		for (int l2 = 0; (l2 < 512); l2 = (l2 + 1)) {
			fVec2[l2] = 0.0f;
		}
		for (int l3 = 0; (l3 < 512); l3 = (l3 + 1)) {
			fVec3[l3] = 0.0f;
		}
		for (int l4 = 0; (l4 < 512); l4 = (l4 + 1)) {
			fVec4[l4] = 0.0f;
		}
		for (int l5 = 0; (l5 < 512); l5 = (l5 + 1)) {
			fVec5[l5] = 0.0f;
		}
		for (int l6 = 0; (l6 < 512); l6 = (l6 + 1)) {
			fVec6[l6] = 0.0f;
		}
		for (int l7 = 0; (l7 < 512); l7 = (l7 + 1)) {
			fVec7[l7] = 0.0f;
		}
		for (int l8 = 0; (l8 < 512); l8 = (l8 + 1)) {
			fVec8[l8] = 0.0f;
		}
		for (int l9 = 0; (l9 < 512); l9 = (l9 + 1)) {
			fVec9[l9] = 0.0f;
		}
		for (int l10 = 0; (l10 < 512); l10 = (l10 + 1)) {
			fVec10[l10] = 0.0f;
		}
		for (int l11 = 0; (l11 < 512); l11 = (l11 + 1)) {
			fVec11[l11] = 0.0f;
		}
		for (int l12 = 0; (l12 < 512); l12 = (l12 + 1)) {
			fVec12[l12] = 0.0f;
		}
		for (int l13 = 0; (l13 < 512); l13 = (l13 + 1)) {
			fVec13[l13] = 0.0f;
		}
		for (int l14 = 0; (l14 < 512); l14 = (l14 + 1)) {
			fVec14[l14] = 0.0f;
		}
		for (int l15 = 0; (l15 < 512); l15 = (l15 + 1)) {
			fVec15[l15] = 0.0f;
		}
		for (int l16 = 0; (l16 < 512); l16 = (l16 + 1)) {
			fVec16[l16] = 0.0f;
		}
		for (int l17 = 0; (l17 < 512); l17 = (l17 + 1)) {
			fVec17[l17] = 0.0f;
		}
		for (int l18 = 0; (l18 < 512); l18 = (l18 + 1)) {
			fVec18[l18] = 0.0f;
		}
		for (int l19 = 0; (l19 < 512); l19 = (l19 + 1)) {
			fVec19[l19] = 0.0f;
		}
		for (int l20 = 0; (l20 < 512); l20 = (l20 + 1)) {
			fVec20[l20] = 0.0f;
		}
		for (int l21 = 0; (l21 < 512); l21 = (l21 + 1)) {
			fVec21[l21] = 0.0f;
		}
		for (int l22 = 0; (l22 < 512); l22 = (l22 + 1)) {
			fVec22[l22] = 0.0f;
		}
		for (int l23 = 0; (l23 < 512); l23 = (l23 + 1)) {
			fVec23[l23] = 0.0f;
		}
		for (int l24 = 0; (l24 < 512); l24 = (l24 + 1)) {
			fVec24[l24] = 0.0f;
		}
		for (int l25 = 0; (l25 < 512); l25 = (l25 + 1)) {
			fVec25[l25] = 0.0f;
		}
		for (int l26 = 0; (l26 < 512); l26 = (l26 + 1)) {
			fVec26[l26] = 0.0f;
		}
		for (int l27 = 0; (l27 < 512); l27 = (l27 + 1)) {
			fVec27[l27] = 0.0f;
		}
		for (int l28 = 0; (l28 < 512); l28 = (l28 + 1)) {
			fVec28[l28] = 0.0f;
		}
		for (int l29 = 0; (l29 < 512); l29 = (l29 + 1)) {
			fVec29[l29] = 0.0f;
		}
		for (int l30 = 0; (l30 < 512); l30 = (l30 + 1)) {
			fVec30[l30] = 0.0f;
		}
		for (int l31 = 0; (l31 < 512); l31 = (l31 + 1)) {
			fVec31[l31] = 0.0f;
		}
		for (int l32 = 0; (l32 < 512); l32 = (l32 + 1)) {
			fVec32[l32] = 0.0f;
		}
		for (int l33 = 0; (l33 < 512); l33 = (l33 + 1)) {
			fVec33[l33] = 0.0f;
		}
		for (int l34 = 0; (l34 < 512); l34 = (l34 + 1)) {
			fVec34[l34] = 0.0f;
		}
		for (int l35 = 0; (l35 < 512); l35 = (l35 + 1)) {
			fVec35[l35] = 0.0f;
		}
		for (int l36 = 0; (l36 < 512); l36 = (l36 + 1)) {
			fVec36[l36] = 0.0f;
		}
		for (int l37 = 0; (l37 < 512); l37 = (l37 + 1)) {
			fVec37[l37] = 0.0f;
		}
		for (int l38 = 0; (l38 < 512); l38 = (l38 + 1)) {
			fVec38[l38] = 0.0f;
		}
		for (int l39 = 0; (l39 < 512); l39 = (l39 + 1)) {
			fVec39[l39] = 0.0f;
		}
		for (int l40 = 0; (l40 < 512); l40 = (l40 + 1)) {
			fVec40[l40] = 0.0f;
		}
		for (int l41 = 0; (l41 < 512); l41 = (l41 + 1)) {
			fVec41[l41] = 0.0f;
		}
		for (int l42 = 0; (l42 < 512); l42 = (l42 + 1)) {
			fVec42[l42] = 0.0f;
		}
		for (int l43 = 0; (l43 < 512); l43 = (l43 + 1)) {
			fVec43[l43] = 0.0f;
		}
		for (int l44 = 0; (l44 < 512); l44 = (l44 + 1)) {
			fVec44[l44] = 0.0f;
		}
		for (int l45 = 0; (l45 < 512); l45 = (l45 + 1)) {
			fVec45[l45] = 0.0f;
		}
		for (int l46 = 0; (l46 < 512); l46 = (l46 + 1)) {
			fVec46[l46] = 0.0f;
		}
		for (int l47 = 0; (l47 < 512); l47 = (l47 + 1)) {
			fVec47[l47] = 0.0f;
		}
		for (int l48 = 0; (l48 < 512); l48 = (l48 + 1)) {
			fVec48[l48] = 0.0f;
		}
		for (int l49 = 0; (l49 < 512); l49 = (l49 + 1)) {
			fVec49[l49] = 0.0f;
		}
		for (int l50 = 0; (l50 < 512); l50 = (l50 + 1)) {
			fVec50[l50] = 0.0f;
		}
		for (int l51 = 0; (l51 < 512); l51 = (l51 + 1)) {
			fVec51[l51] = 0.0f;
		}
		for (int l52 = 0; (l52 < 512); l52 = (l52 + 1)) {
			fVec52[l52] = 0.0f;
		}
		for (int l53 = 0; (l53 < 512); l53 = (l53 + 1)) {
			fVec53[l53] = 0.0f;
		}
		for (int l54 = 0; (l54 < 512); l54 = (l54 + 1)) {
			fVec54[l54] = 0.0f;
		}
		for (int l55 = 0; (l55 < 512); l55 = (l55 + 1)) {
			fVec55[l55] = 0.0f;
		}
		for (int l56 = 0; (l56 < 512); l56 = (l56 + 1)) {
			fVec56[l56] = 0.0f;
		}
		for (int l57 = 0; (l57 < 512); l57 = (l57 + 1)) {
			fVec57[l57] = 0.0f;
		}
	}
	
	virtual void init(int sample_rate) {
		classInit(sample_rate);
		instanceInit(sample_rate);
	}
	virtual void instanceInit(int sample_rate) {
		instanceConstants(sample_rate);
		instanceResetUserInterface();
		instanceClear();
	}
	
	virtual gods_cab* clone() {
		return new gods_cab();
	}
	
	virtual int getSampleRate() {
		return fSampleRate;
	}
	
	virtual void buildUserInterface(UI* ui_interface) {
		ui_interface->openVerticalBox("gods_cab");
		ui_interface->declare(&fEntry0, "name", "Impulse Response");
		ui_interface->declare(&fEntry0, "style", "menu{'None':0;'57 1 inch cap':1;'57 1 inch cone far':2;'57 1 inch cone near':3;'57 1 inch edge':4;'57 2 inch cap':5;'57 2 inch cone far':6;'57 2 inch cone near':7;'57 2 inch edge':8;'57 grill cap':9;'57 grill cone far':10;'57 grill cone near':11;'57 grill edge':12;'C414 1 foot':13;'C414 1 inch cap':14;'C414 1 inch cone far':15;'C414 1 inch cone near':16;'C414 1 inch edge':17;'C414 2 foot':18;'C414 2 inch cap':19;'C414 2 inch cone far':20;'C414 2 inch cone near':21;'C414 2 inch edge':22;'C414 4 foot':23;'C414 grill cap':24;'C414 grill cone far':25;'C414 grill cone near':26;'C414 grill edge':27;'MD421 1 inch cap':28;'MD421 1 inch cone far':29;'MD421 1 inch cone near':30;'MD421 1 inch edge':31;'MD421 2 inch cap':32;'MD421 2 inch cone far':33;'MD421 2 inch cone near':34;'MD421 2 inch edge':35;'MD421 grill cap':36;'MD421 grill cone far':37;'MD421 grill cone near':38;'MD421 grill edge':39;'SM7B 1 inch cap':40;'SM7B 1 inch cone far':41;'SM7B 1 inch cone near':42;'SM7B 1 inch edge':43;'SM7B 2 inch cap':44;'SM7B 2 inch cone far':45;'SM7B 2 inch cone near':46;'SM7B 2 inch edge':47;'SM7B grill cap':48;'SM7B grill cone far':49;'SM7B grill cone near':50;'SM7B grill edge':51;'U87 1 foot':52;'U87 2 foot':53;'U87 4 foot':54;'U87 grill cap':55;'U87 grill cone far':56;'U87 grill cone near':57;'U87 grill edge':58}");
		ui_interface->addNumEntry("ir", &fEntry0, 0.0f, 0.0f, 58.0f, 1.0f);
		ui_interface->closeBox();
	}
	
	virtual void compute(int count, FAUSTFLOAT** inputs, FAUSTFLOAT** outputs) {
		FAUSTFLOAT* input0 = inputs[0];
		FAUSTFLOAT* output0 = outputs[0];
		float fSlow0 = float(fEntry0);
		int iSlow1 = (fSlow0 >= 30.0f);
		int iSlow2 = (fSlow0 >= 15.0f);
		int iSlow3 = (fSlow0 >= 8.0f);
		int iSlow4 = (fSlow0 >= 4.0f);
		int iSlow5 = (fSlow0 >= 2.0f);
		int iSlow6 = (fSlow0 >= 1.0f);
		float fSlow7 = float((fSlow0 == 0.0f));
		float fSlow8 = float((fSlow0 == 1.0f));
		float fSlow9 = (0.075029999f * fSlow8);
		int iSlow10 = (fSlow0 >= 3.0f);
		float fSlow11 = float((fSlow0 == 2.0f));
		float fSlow12 = (0.079135634f * fSlow11);
		float fSlow13 = float((fSlow0 == 3.0f));
		float fSlow14 = (0.0720063299f * fSlow13);
		int iSlow15 = (fSlow0 >= 6.0f);
		int iSlow16 = (fSlow0 >= 5.0f);
		float fSlow17 = float((fSlow0 == 4.0f));
		float fSlow18 = (0.07247141f * fSlow17);
		float fSlow19 = float((fSlow0 == 5.0f));
		float fSlow20 = (0.0722749233f * fSlow19);
		int iSlow21 = (fSlow0 >= 7.0f);
		float fSlow22 = float((fSlow0 == 6.0f));
		float fSlow23 = (0.0805635005f * fSlow22);
		float fSlow24 = float((fSlow0 == 7.0f));
		float fSlow25 = (0.0714812577f * fSlow24);
		int iSlow26 = (fSlow0 >= 12.0f);
		int iSlow27 = (fSlow0 >= 10.0f);
		int iSlow28 = (fSlow0 >= 9.0f);
		float fSlow29 = float((fSlow0 == 8.0f));
		float fSlow30 = (0.070688121f * fSlow29);
		float fSlow31 = float((fSlow0 == 9.0f));
		float fSlow32 = (0.0740756914f * fSlow31);
		int iSlow33 = (fSlow0 >= 11.0f);
		float fSlow34 = float((fSlow0 == 10.0f));
		float fSlow35 = (0.0757743791f * fSlow34);
		float fSlow36 = float((fSlow0 == 11.0f));
		float fSlow37 = (0.0733819231f * fSlow36);
		int iSlow38 = (fSlow0 >= 14.0f);
		int iSlow39 = (fSlow0 >= 13.0f);
		float fSlow40 = float((fSlow0 == 12.0f));
		float fSlow41 = (0.0863632262f * fSlow40);
		float fSlow42 = float((fSlow0 == 13.0f));
		float fSlow43 = (0.132770136f * fSlow42);
		float fSlow44 = float((fSlow0 == 14.0f));
		float fSlow45 = (0.142014638f * fSlow44);
		int iSlow46 = (fSlow0 >= 23.0f);
		int iSlow47 = (fSlow0 >= 19.0f);
		int iSlow48 = (fSlow0 >= 17.0f);
		int iSlow49 = (fSlow0 >= 16.0f);
		float fSlow50 = float((fSlow0 == 15.0f));
		float fSlow51 = (0.131569535f * fSlow50);
		float fSlow52 = float((fSlow0 == 16.0f));
		float fSlow53 = (0.13896957f * fSlow52);
		int iSlow54 = (fSlow0 >= 18.0f);
		float fSlow55 = float((fSlow0 == 17.0f));
		float fSlow56 = (0.154357821f * fSlow55);
		float fSlow57 = float((fSlow0 == 18.0f));
		float fSlow58 = (0.130345806f * fSlow57);
		int iSlow59 = (fSlow0 >= 21.0f);
		int iSlow60 = (fSlow0 >= 20.0f);
		float fSlow61 = float((fSlow0 == 19.0f));
		float fSlow62 = (0.12886335f * fSlow61);
		float fSlow63 = float((fSlow0 == 20.0f));
		float fSlow64 = (0.127791658f * fSlow63);
		int iSlow65 = (fSlow0 >= 22.0f);
		float fSlow66 = float((fSlow0 == 21.0f));
		float fSlow67 = (0.145597592f * fSlow66);
		float fSlow68 = float((fSlow0 == 22.0f));
		float fSlow69 = (0.150506809f * fSlow68);
		int iSlow70 = (fSlow0 >= 27.0f);
		int iSlow71 = (fSlow0 >= 25.0f);
		int iSlow72 = (fSlow0 >= 24.0f);
		float fSlow73 = float((fSlow0 == 23.0f));
		float fSlow74 = (0.113947123f * fSlow73);
		float fSlow75 = float((fSlow0 == 24.0f));
		float fSlow76 = (0.15087001f * fSlow75);
		int iSlow77 = (fSlow0 >= 26.0f);
		float fSlow78 = float((fSlow0 == 25.0f));
		float fSlow79 = (0.143684044f * fSlow78);
		float fSlow80 = float((fSlow0 == 26.0f));
		float fSlow81 = (0.129116058f * fSlow80);
		int iSlow82 = (fSlow0 >= 29.0f);
		int iSlow83 = (fSlow0 >= 28.0f);
		float fSlow84 = float((fSlow0 == 27.0f));
		float fSlow85 = (0.167096883f * fSlow84);
		float fSlow86 = float((fSlow0 == 28.0f));
		float fSlow87 = (0.0965634882f * fSlow86);
		float fSlow88 = float((fSlow0 == 29.0f));
		float fSlow89 = (0.0934382156f * fSlow88);
		int iSlow90 = (fSlow0 >= 45.0f);
		int iSlow91 = (fSlow0 >= 38.0f);
		int iSlow92 = (fSlow0 >= 34.0f);
		int iSlow93 = (fSlow0 >= 32.0f);
		int iSlow94 = (fSlow0 >= 31.0f);
		float fSlow95 = float((fSlow0 == 30.0f));
		float fSlow96 = (0.0920995325f * fSlow95);
		float fSlow97 = float((fSlow0 == 31.0f));
		float fSlow98 = (0.105454676f * fSlow97);
		int iSlow99 = (fSlow0 >= 33.0f);
		float fSlow100 = float((fSlow0 == 32.0f));
		float fSlow101 = (0.0957473963f * fSlow100);
		float fSlow102 = float((fSlow0 == 33.0f));
		float fSlow103 = (0.0863705873f * fSlow102);
		int iSlow104 = (fSlow0 >= 36.0f);
		int iSlow105 = (fSlow0 >= 35.0f);
		float fSlow106 = float((fSlow0 == 34.0f));
		float fSlow107 = (0.0849584267f * fSlow106);
		float fSlow108 = float((fSlow0 == 35.0f));
		float fSlow109 = (0.0991597176f * fSlow108);
		int iSlow110 = (fSlow0 >= 37.0f);
		float fSlow111 = float((fSlow0 == 36.0f));
		float fSlow112 = (0.103464596f * fSlow111);
		float fSlow113 = float((fSlow0 == 37.0f));
		float fSlow114 = (0.0948219076f * fSlow113);
		int iSlow115 = (fSlow0 >= 42.0f);
		int iSlow116 = (fSlow0 >= 40.0f);
		int iSlow117 = (fSlow0 >= 39.0f);
		float fSlow118 = float((fSlow0 == 38.0f));
		float fSlow119 = (0.104219057f * fSlow118);
		float fSlow120 = float((fSlow0 == 39.0f));
		float fSlow121 = (0.120152824f * fSlow120);
		int iSlow122 = (fSlow0 >= 41.0f);
		float fSlow123 = float((fSlow0 == 40.0f));
		float fSlow124 = (0.0880305767f * fSlow123);
		float fSlow125 = float((fSlow0 == 41.0f));
		float fSlow126 = (0.0773857534f * fSlow125);
		int iSlow127 = (fSlow0 >= 44.0f);
		int iSlow128 = (fSlow0 >= 43.0f);
		float fSlow129 = float((fSlow0 == 42.0f));
		float fSlow130 = (0.0869700313f * fSlow129);
		float fSlow131 = float((fSlow0 == 43.0f));
		float fSlow132 = (0.0866100863f * fSlow131);
		float fSlow133 = float((fSlow0 == 44.0f));
		float fSlow134 = (0.0833290815f * fSlow133);
		int iSlow135 = (fSlow0 >= 52.0f);
		int iSlow136 = (fSlow0 >= 49.0f);
		int iSlow137 = (fSlow0 >= 47.0f);
		int iSlow138 = (fSlow0 >= 46.0f);
		float fSlow139 = float((fSlow0 == 45.0f));
		float fSlow140 = (0.080790557f * fSlow139);
		float fSlow141 = float((fSlow0 == 46.0f));
		float fSlow142 = (0.0855487213f * fSlow141);
		int iSlow143 = (fSlow0 >= 48.0f);
		float fSlow144 = float((fSlow0 == 47.0f));
		float fSlow145 = (0.0939839333f * fSlow144);
		float fSlow146 = float((fSlow0 == 48.0f));
		float fSlow147 = (0.0923918784f * fSlow146);
		int iSlow148 = (fSlow0 >= 51.0f);
		int iSlow149 = (fSlow0 >= 50.0f);
		float fSlow150 = float((fSlow0 == 49.0f));
		float fSlow151 = (0.0911576673f * fSlow150);
		float fSlow152 = float((fSlow0 == 50.0f));
		float fSlow153 = (0.0795364454f * fSlow152);
		float fSlow154 = float((fSlow0 == 51.0f));
		float fSlow155 = (0.0940233916f * fSlow154);
		int iSlow156 = (fSlow0 >= 56.0f);
		int iSlow157 = (fSlow0 >= 54.0f);
		int iSlow158 = (fSlow0 >= 53.0f);
		float fSlow159 = float((fSlow0 == 52.0f));
		float fSlow160 = (0.0644430444f * fSlow159);
		float fSlow161 = float((fSlow0 == 53.0f));
		float fSlow162 = (0.0536024533f * fSlow161);
		int iSlow163 = (fSlow0 >= 55.0f);
		float fSlow164 = float((fSlow0 == 54.0f));
		float fSlow165 = (0.0539697222f * fSlow164);
		float fSlow166 = float((fSlow0 == 55.0f));
		float fSlow167 = (0.0713672265f * fSlow166);
		int iSlow168 = (fSlow0 >= 58.0f);
		int iSlow169 = (fSlow0 >= 57.0f);
		float fSlow170 = float((fSlow0 == 56.0f));
		float fSlow171 = (0.0601004772f * fSlow170);
		float fSlow172 = float((fSlow0 == 57.0f));
		float fSlow173 = (0.0577411391f * fSlow172);
		float fSlow174 = float((fSlow0 == 58.0f));
		float fSlow175 = (0.0781783611f * fSlow174);
		for (int i = 0; (i < count); i = (i + 1)) {
			float fTemp0 = float(input0[i]);
			float fTemp1 = (fSlow8 * fTemp0);
			fVec0[(IOTA & 511)] = fTemp1;
			float fTemp2 = (fSlow11 * fTemp0);
			fVec1[(IOTA & 511)] = fTemp2;
			float fTemp3 = (fSlow13 * fTemp0);
			fVec2[(IOTA & 511)] = fTemp3;
			float fTemp4 = (fSlow17 * fTemp0);
			fVec3[(IOTA & 511)] = fTemp4;
			float fTemp5 = (fSlow19 * fTemp0);
			fVec4[(IOTA & 511)] = fTemp5;
			float fTemp6 = (fSlow22 * fTemp0);
			fVec5[(IOTA & 511)] = fTemp6;
			float fTemp7 = (fSlow24 * fTemp0);
			fVec6[(IOTA & 511)] = fTemp7;
			float fTemp8 = (fSlow29 * fTemp0);
			fVec7[(IOTA & 511)] = fTemp8;
			float fTemp9 = (fSlow31 * fTemp0);
			fVec8[(IOTA & 511)] = fTemp9;
			float fTemp10 = (fSlow34 * fTemp0);
			fVec9[(IOTA & 511)] = fTemp10;
			float fTemp11 = (fSlow36 * fTemp0);
			fVec10[(IOTA & 511)] = fTemp11;
			float fTemp12 = (fSlow40 * fTemp0);
			fVec11[(IOTA & 511)] = fTemp12;
			float fTemp13 = (fSlow42 * fTemp0);
			fVec12[(IOTA & 511)] = fTemp13;
			float fTemp14 = (fSlow44 * fTemp0);
			fVec13[(IOTA & 511)] = fTemp14;
			float fTemp15 = (fSlow50 * fTemp0);
			fVec14[(IOTA & 511)] = fTemp15;
			float fTemp16 = (fSlow52 * fTemp0);
			fVec15[(IOTA & 511)] = fTemp16;
			float fTemp17 = (fSlow55 * fTemp0);
			fVec16[(IOTA & 511)] = fTemp17;
			float fTemp18 = (fSlow57 * fTemp0);
			fVec17[(IOTA & 511)] = fTemp18;
			float fTemp19 = (fSlow61 * fTemp0);
			fVec18[(IOTA & 511)] = fTemp19;
			float fTemp20 = (fSlow63 * fTemp0);
			fVec19[(IOTA & 511)] = fTemp20;
			float fTemp21 = (fSlow66 * fTemp0);
			fVec20[(IOTA & 511)] = fTemp21;
			float fTemp22 = (fSlow68 * fTemp0);
			fVec21[(IOTA & 511)] = fTemp22;
			float fTemp23 = (fSlow73 * fTemp0);
			fVec22[(IOTA & 511)] = fTemp23;
			float fTemp24 = (fSlow75 * fTemp0);
			fVec23[(IOTA & 511)] = fTemp24;
			float fTemp25 = (fSlow78 * fTemp0);
			fVec24[(IOTA & 511)] = fTemp25;
			float fTemp26 = (fSlow80 * fTemp0);
			fVec25[(IOTA & 511)] = fTemp26;
			float fTemp27 = (fSlow84 * fTemp0);
			fVec26[(IOTA & 511)] = fTemp27;
			float fTemp28 = (fSlow86 * fTemp0);
			fVec27[(IOTA & 511)] = fTemp28;
			float fTemp29 = (fSlow88 * fTemp0);
			fVec28[(IOTA & 511)] = fTemp29;
			float fTemp30 = (fSlow95 * fTemp0);
			fVec29[(IOTA & 511)] = fTemp30;
			float fTemp31 = (fSlow97 * fTemp0);
			fVec30[(IOTA & 511)] = fTemp31;
			float fTemp32 = (fSlow100 * fTemp0);
			fVec31[(IOTA & 511)] = fTemp32;
			float fTemp33 = (fSlow102 * fTemp0);
			fVec32[(IOTA & 511)] = fTemp33;
			float fTemp34 = (fSlow106 * fTemp0);
			fVec33[(IOTA & 511)] = fTemp34;
			float fTemp35 = (fSlow108 * fTemp0);
			fVec34[(IOTA & 511)] = fTemp35;
			float fTemp36 = (fSlow111 * fTemp0);
			fVec35[(IOTA & 511)] = fTemp36;
			float fTemp37 = (fSlow113 * fTemp0);
			fVec36[(IOTA & 511)] = fTemp37;
			float fTemp38 = (fSlow118 * fTemp0);
			fVec37[(IOTA & 511)] = fTemp38;
			float fTemp39 = (fSlow120 * fTemp0);
			fVec38[(IOTA & 511)] = fTemp39;
			float fTemp40 = (fSlow123 * fTemp0);
			fVec39[(IOTA & 511)] = fTemp40;
			float fTemp41 = (fSlow125 * fTemp0);
			fVec40[(IOTA & 511)] = fTemp41;
			float fTemp42 = (fSlow129 * fTemp0);
			fVec41[(IOTA & 511)] = fTemp42;
			float fTemp43 = (fSlow131 * fTemp0);
			fVec42[(IOTA & 511)] = fTemp43;
			float fTemp44 = (fSlow133 * fTemp0);
			fVec43[(IOTA & 511)] = fTemp44;
			float fTemp45 = (fSlow139 * fTemp0);
			fVec44[(IOTA & 511)] = fTemp45;
			float fTemp46 = (fSlow141 * fTemp0);
			fVec45[(IOTA & 511)] = fTemp46;
			float fTemp47 = (fSlow144 * fTemp0);
			fVec46[(IOTA & 511)] = fTemp47;
			float fTemp48 = (fSlow146 * fTemp0);
			fVec47[(IOTA & 511)] = fTemp48;
			float fTemp49 = (fSlow150 * fTemp0);
			fVec48[(IOTA & 511)] = fTemp49;
			float fTemp50 = (fSlow152 * fTemp0);
			fVec49[(IOTA & 511)] = fTemp50;
			float fTemp51 = (fSlow154 * fTemp0);
			fVec50[(IOTA & 511)] = fTemp51;
			float fTemp52 = (fSlow159 * fTemp0);
			fVec51[(IOTA & 511)] = fTemp52;
			float fTemp53 = (fSlow161 * fTemp0);
			fVec52[(IOTA & 511)] = fTemp53;
			float fTemp54 = (fSlow164 * fTemp0);
			fVec53[(IOTA & 511)] = fTemp54;
			float fTemp55 = (fSlow166 * fTemp0);
			fVec54[(IOTA & 511)] = fTemp55;
			float fTemp56 = (fSlow170 * fTemp0);
			fVec55[(IOTA & 511)] = fTemp56;
			float fTemp57 = (fSlow172 * fTemp0);
			fVec56[(IOTA & 511)] = fTemp57;
			float fTemp58 = (fSlow174 * fTemp0);
			fVec57[(IOTA & 511)] = fTemp58;
			output0[i] = FAUSTFLOAT((iSlow1 ? (iSlow90 ? (iSlow135 ? (iSlow156 ? (iSlow168 ? ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.000570027158f * fVec57[((IOTA - 123) & 511)]) + ((0.000919971615f * fVec57[((IOTA - 122) & 511)]) + ((0.00300163031f * fVec57[((IOTA - 112) & 511)]) + ((0.0101668434f * fVec57[((IOTA - 111) & 511)]) + ((0.0142103322f * fVec57[((IOTA - 110) & 511)]) + ((0.0129606863f * fVec57[((IOTA - 109) & 511)]) + ((0.00492720772f * fVec57[((IOTA - 108) & 511)]) + ((((((((((((((((((((0.011785375f * fVec57[((IOTA - 52) & 511)]) + ((0.0109688155f * fVec57[((IOTA - 51) & 511)]) + ((0.00180584984f * fVec57[((IOTA - 50) & 511)]) + ((0.00915495679f * fVec57[((IOTA - 38) & 511)]) + ((0.010153152f * fVec57[((IOTA - 37) & 511)]) + ((0.000387561042f * fVec57[((IOTA - 36) & 511)]) + ((0.0315142758f * (fVec57[((IOTA - 24) & 511)] - fVec57[((IOTA - 30) & 511)])) + ((0.000703711063f * fVec57[((IOTA - 27) & 511)]) + ((0.0206926037f * fVec57[((IOTA - 26) & 511)]) + ((0.0373430811f * fVec57[((IOTA - 25) & 511)]) + ((0.00898817554f * fVec57[((IOTA - 23) & 511)]) + ((0.00947080832f * fVec57[((IOTA - 19) & 511)]) + ((0.0240511224f * fVec57[((IOTA - 18) & 511)]) + ((0.0244262237f * fVec57[((IOTA - 17) & 511)]) + ((0.0132726496f * fVec57[((IOTA - 16) & 511)]) + ((0.00380888581f * fVec57[((IOTA - 15) & 511)]) + ((0.0122920992f * fVec57[((IOTA - 14) & 511)]) + ((0.0487147421f * fVec57[((IOTA - 13) & 511)]) + ((0.0732584298f * fVec57[((IOTA - 12) & 511)]) + ((0.0405960605f * fVec57[((IOTA - 11) & 511)]) + ((0.0419504493f * fVec57[((IOTA - 5) & 511)]) + ((0.197948352f * fVec57[((IOTA - 4) & 511)]) + ((0.269275635f * fVec57[((IOTA - 3) & 511)]) + ((0.262636095f * fVec57[((IOTA - 2) & 511)]) + ((0.202849686f * fVec57[((IOTA - 1) & 511)]) + ((fSlow175 * fTemp0) + (0.0025909408f * fVec57[((IOTA - 53) & 511)]))))))))))))))))))))))))))) + (0.00163800502f * fVec57[((IOTA - 60) & 511)])) + (0.0105104074f * fVec57[((IOTA - 61) & 511)])) + (0.0113657471f * fVec57[((IOTA - 62) & 511)])) + (0.0101500619f * fVec57[((IOTA - 63) & 511)])) + (0.00459703431f * fVec57[((IOTA - 64) & 511)])) + (0.00940926559f * fVec57[((IOTA - 74) & 511)])) + (0.0137142092f * fVec57[((IOTA - 75) & 511)])) + (0.011748556f * fVec57[((IOTA - 76) & 511)])) + (0.00499905087f * fVec57[((IOTA - 77) & 511)])) + (0.00360621652f * fVec57[((IOTA - 95) & 511)])) + (0.00930492394f * fVec57[((IOTA - 96) & 511)])) + (0.0126973055f * fVec57[((IOTA - 97) & 511)])) + (0.01480598f * fVec57[((IOTA - 98) & 511)])) + (0.0154688517f * fVec57[((IOTA - 99) & 511)])) + (0.0109805129f * fVec57[((IOTA - 100) & 511)])) + (0.00128420535f * fVec57[((IOTA - 101) & 511)])) + (0.00369749917f * fVec57[((IOTA - 130) & 511)])) + (0.0087153241f * fVec57[((IOTA - 131) & 511)]))))))))) + (0.0113371033f * fVec57[((IOTA - 132) & 511)])) + (0.0109618045f * fVec57[((IOTA - 133) & 511)])) + (0.00786603242f * fVec57[((IOTA - 134) & 511)])) + (0.00378263416f * fVec57[((IOTA - 135) & 511)])) + (0.000485921744f * fVec57[((IOTA - 136) & 511)])) + (2.95415521e-05f * fVec57[((IOTA - 146) & 511)])) + (0.00482605537f * fVec57[((IOTA - 147) & 511)])) + (0.00822514948f * fVec57[((IOTA - 148) & 511)])) + (0.00922221504f * fVec57[((IOTA - 149) & 511)])) + (0.00818364508f * fVec57[((IOTA - 150) & 511)])) + (0.00582258916f * fVec57[((IOTA - 151) & 511)])) + (0.00356006017f * fVec57[((IOTA - 152) & 511)])) + (0.00259443f * fVec57[((IOTA - 153) & 511)])) + (0.00246470049f * fVec57[((IOTA - 154) & 511)])) + (0.00285674771f * fVec57[((IOTA - 155) & 511)])) + (0.00322932191f * fVec57[((IOTA - 156) & 511)])) + (0.00254564872f * fVec57[((IOTA - 157) & 511)])) + (0.000307277776f * fVec57[((IOTA - 158) & 511)])) + (0.00393609051f * fVec57[((IOTA - 170) & 511)])) + (0.00802444015f * fVec57[((IOTA - 171) & 511)])) + (0.010120986f * fVec57[((IOTA - 172) & 511)])) + (0.00925993081f * fVec57[((IOTA - 173) & 511)])) + (0.00550879864f * fVec57[((IOTA - 174) & 511)])) + (0.000716238748f * fVec57[((IOTA - 175) & 511)])) + (0.0010686093f * fVec57[((IOTA - 181) & 511)])) + (0.00580770196f * fVec57[((IOTA - 182) & 511)])) + (0.00971574616f * fVec57[((IOTA - 183) & 511)])) + (0.0115142185f * fVec57[((IOTA - 184) & 511)])) + (0.0107159354f * fVec57[((IOTA - 185) & 511)])) + (0.00806508027f * fVec57[((IOTA - 186) & 511)])) + (0.00460896408f * fVec57[((IOTA - 187) & 511)])) + (0.0019736276f * fVec57[((IOTA - 188) & 511)])) + (0.00117082475f * fVec57[((IOTA - 189) & 511)])) + (0.00165634789f * fVec57[((IOTA - 190) & 511)])) + (0.00295590563f * fVec57[((IOTA - 191) & 511)])) + (0.00472271023f * fVec57[((IOTA - 192) & 511)])) + (0.00590928597f * fVec57[((IOTA - 193) & 511)])) + (0.00606616493f * fVec57[((IOTA - 194) & 511)])) + (0.00561324041f * fVec57[((IOTA - 195) & 511)])) + (0.00468466198f * fVec57[((IOTA - 196) & 511)])) + (0.00351054734f * fVec57[((IOTA - 197) & 511)])) + (0.00276220823f * fVec57[((IOTA - 198) & 511)])) + (0.00242475793f * fVec57[((IOTA - 199) & 511)])) + (0.00239338866f * fVec57[((IOTA - 200) & 511)])) + (0.00265354617f * fVec57[((IOTA - 201) & 511)])) + (0.00286585279f * fVec57[((IOTA - 202) & 511)])) + (0.0027379836f * fVec57[((IOTA - 203) & 511)])) + (0.00210727891f * fVec57[((IOTA - 204) & 511)])) + (0.00124452915f * fVec57[((IOTA - 205) & 511)])) + (0.000733152963f * fVec57[((IOTA - 206) & 511)])) + (0.000756447203f * fVec57[((IOTA - 207) & 511)])) + (0.00108372932f * fVec57[((IOTA - 208) & 511)])) + (0.00144580286f * fVec57[((IOTA - 209) & 511)])) + (0.00174454041f * fVec57[((IOTA - 210) & 511)])) + (0.0021592835f * fVec57[((IOTA - 211) & 511)])) + (0.00293377461f * fVec57[((IOTA - 212) & 511)])) + (0.00400677044f * fVec57[((IOTA - 213) & 511)])) + (0.00462993234f * fVec57[((IOTA - 214) & 511)])) + (0.0040349164f * fVec57[((IOTA - 215) & 511)])) + (0.00237803673f * fVec57[((IOTA - 216) & 511)])) + (0.000496223103f * fVec57[((IOTA - 217) & 511)])) + (0.000245270319f * fVec57[((IOTA - 219) & 511)])) + (0.00314199366f * fVec57[((IOTA - 220) & 511)])) + (0.00685285125f * fVec57[((IOTA - 221) & 511)])) + (0.00921091624f * fVec57[((IOTA - 222) & 511)])) + (0.00961392932f * fVec57[((IOTA - 223) & 511)])) + (0.00814217422f * fVec57[((IOTA - 224) & 511)])) + (0.0053923605f * fVec57[((IOTA - 225) & 511)])) + (0.00287944358f * fVec57[((IOTA - 226) & 511)])) + (0.0017143013f * fVec57[((IOTA - 227) & 511)])) + (0.00215915078f * fVec57[((IOTA - 228) & 511)])) + (0.00383978989f * fVec57[((IOTA - 229) & 511)])) + (0.00563307852f * fVec57[((IOTA - 230) & 511)])) + (0.00667872606f * fVec57[((IOTA - 231) & 511)])) + (0.0068402905f * fVec57[((IOTA - 232) & 511)])) + (0.00610667234f * fVec57[((IOTA - 233) & 511)])) + (0.00492594484f * fVec57[((IOTA - 234) & 511)])) + (0.00380101055f * fVec57[((IOTA - 235) & 511)])) + (0.0028081988f * fVec57[((IOTA - 236) & 511)])) + (0.00220042234f * fVec57[((IOTA - 237) & 511)])) + (0.00214894908f * fVec57[((IOTA - 238) & 511)])) + (0.0025102254f * fVec57[((IOTA - 239) & 511)])) + (0.0032104142f * fVec57[((IOTA - 240) & 511)])) + (0.00368620083f * fVec57[((IOTA - 241) & 511)])) + (0.00403475016f * fVec57[((IOTA - 242) & 511)])) + (0.00447820406f * fVec57[((IOTA - 243) & 511)])) + (0.00406807987f * fVec57[((IOTA - 244) & 511)])) + (0.0026323786f * fVec57[((IOTA - 245) & 511)])) + (0.000738935079f * fVec57[((IOTA - 246) & 511)])) + (0.000172197819f * fVec57[((IOTA - 249) & 511)])) + (0.0021849703f * fVec57[((IOTA - 250) & 511)])) + (0.00451385975f * fVec57[((IOTA - 251) & 511)])) + (0.00641301926f * fVec57[((IOTA - 252) & 511)])) + (0.00744819921f * fVec57[((IOTA - 253) & 511)])) + (0.00780179957f * fVec57[((IOTA - 254) & 511)])) + (0.00746169081f * fVec57[((IOTA - 255) & 511)])) + (0.00685424684f * fVec57[((IOTA - 256) & 511)])) + (0.00640457869f * fVec57[((IOTA - 257) & 511)])) + (0.00589094311f * fVec57[((IOTA - 258) & 511)])) + (0.00569900684f * fVec57[((IOTA - 259) & 511)])) + (0.00605563074f * fVec57[((IOTA - 260) & 511)])) + (0.00615518773f * fVec57[((IOTA - 261) & 511)])) + (0.00574529637f * fVec57[((IOTA - 262) & 511)])) + (0.00518570328f * fVec57[((IOTA - 263) & 511)])) + (0.00461391546f * fVec57[((IOTA - 264) & 511)])) + (0.0041786693f * fVec57[((IOTA - 265) & 511)])) + (0.00415610615f * fVec57[((IOTA - 266) & 511)])) + (0.00492920121f * fVec57[((IOTA - 267) & 511)])) + (0.00639640447f * fVec57[((IOTA - 268) & 511)])) + (0.00762790721f * fVec57[((IOTA - 269) & 511)])) + (0.00784775615f * fVec57[((IOTA - 270) & 511)])) + (0.00669756765f * fVec57[((IOTA - 271) & 511)])) + (0.00441274093f * fVec57[((IOTA - 272) & 511)])) + (0.002068765f * fVec57[((IOTA - 273) & 511)])) + (0.000370613765f * fVec57[((IOTA - 274) & 511)])) + (0.000644196291f * fVec57[((IOTA - 277) & 511)])) + (0.00126649393f * fVec57[((IOTA - 278) & 511)])) + (0.00159905944f * fVec57[((IOTA - 279) & 511)])) + (0.00166771282f * fVec57[((IOTA - 280) & 511)])) + (0.00146451127f * fVec57[((IOTA - 281) & 511)])) + (0.00144158257f * fVec57[((IOTA - 282) & 511)])) + (0.00164292287f * fVec57[((IOTA - 283) & 511)])) + (0.00168884685f * fVec57[((IOTA - 284) & 511)])) + (0.00139094004f * fVec57[((IOTA - 285) & 511)])) + (0.000816227868f * fVec57[((IOTA - 286) & 511)])) + (0.000382576603f * fVec57[((IOTA - 287) & 511)])) + (0.000747873913f * fVec57[((IOTA - 288) & 511)])) + (0.00198618881f * fVec57[((IOTA - 289) & 511)])) + (0.00374342315f * fVec57[((IOTA - 290) & 511)])) + (0.00562188029f * fVec57[((IOTA - 291) & 511)])) + (0.00678044325f * fVec57[((IOTA - 292) & 511)])) + (0.00675608544f * fVec57[((IOTA - 293) & 511)])) + (0.00589104276f * fVec57[((IOTA - 294) & 511)])) + (0.00507398415f * fVec57[((IOTA - 295) & 511)])) + (0.00512220105f * fVec57[((IOTA - 296) & 511)])) + (0.00602243422f * fVec57[((IOTA - 297) & 511)])) + (0.00725928694f * fVec57[((IOTA - 298) & 511)])) + (0.00840987451f * fVec57[((IOTA - 299) & 511)])) + (0.00888792053f * fVec57[((IOTA - 300) & 511)])) + (0.00828197226f * fVec57[((IOTA - 301) & 511)])) + (0.00701541221f * fVec57[((IOTA - 302) & 511)])) + (0.00590656139f * fVec57[((IOTA - 303) & 511)])) + (0.00553740934f * fVec57[((IOTA - 304) & 511)])) + (0.00584186241f * fVec57[((IOTA - 305) & 511)])) + (0.00625451235f * fVec57[((IOTA - 306) & 511)])) + (0.00672571314f * fVec57[((IOTA - 307) & 511)])) + (0.00699165277f * fVec57[((IOTA - 308) & 511)])) + (0.00637168111f * fVec57[((IOTA - 309) & 511)])) + (0.00501672924f * fVec57[((IOTA - 310) & 511)])) + (0.0032701618f * fVec57[((IOTA - 311) & 511)])) + (0.00174520491f * fVec57[((IOTA - 312) & 511)])) + (0.00123389531f * fVec57[((IOTA - 313) & 511)])) + (0.00128712971f * fVec57[((IOTA - 314) & 511)])) + (0.00149817346f * fVec57[((IOTA - 315) & 511)])) + (0.00182379363f * fVec57[((IOTA - 316) & 511)])) + (0.00156200817f * fVec57[((IOTA - 317) & 511)])) + (0.000697397627f * fVec57[((IOTA - 318) & 511)])) + (0.000437638722f * fVec57[((IOTA - 327) & 511)])) + (0.00140765496f * fVec57[((IOTA - 328) & 511)])) + (0.00195591617f * fVec57[((IOTA - 329) & 511)])) + (0.00207321811f * fVec57[((IOTA - 330) & 511)])) + (0.00143413898f * fVec57[((IOTA - 331) & 511)])) + (0.000659714453f * fVec57[((IOTA - 332) & 511)])) + (0.000494628213f * fVec57[((IOTA - 333) & 511)])) + (0.000956458505f * fVec57[((IOTA - 334) & 511)])) + (0.00195229426f * fVec57[((IOTA - 335) & 511)])) + (0.00319349999f * fVec57[((IOTA - 336) & 511)])) + (0.0043157097f * fVec57[((IOTA - 337) & 511)])) + (0.00525186444f * fVec57[((IOTA - 338) & 511)])) + (0.00561284134f * fVec57[((IOTA - 339) & 511)])) + (0.00538770854f * fVec57[((IOTA - 340) & 511)])) + (0.00479349028f * fVec57[((IOTA - 341) & 511)])) + (0.00357783819f * fVec57[((IOTA - 342) & 511)])) + (0.00199761987f * fVec57[((IOTA - 343) & 511)])) + (0.000846965704f * fVec57[((IOTA - 344) & 511)])) + (0.000436774921f * fVec57[((IOTA - 345) & 511)])) + (0.000699690543f * fVec57[((IOTA - 346) & 511)])) + (0.0015321346f * fVec57[((IOTA - 347) & 511)])) + (0.00247752713f * fVec57[((IOTA - 348) & 511)])) + (0.00313219102f * fVec57[((IOTA - 349) & 511)])) + (0.00320207328f * fVec57[((IOTA - 350) & 511)])) + (0.00259326724f * fVec57[((IOTA - 351) & 511)])) + (0.00186486589f * fVec57[((IOTA - 352) & 511)])) + (0.00106016919f * fVec57[((IOTA - 353) & 511)])) + (8.00844282e-06f * fVec57[((IOTA - 360) & 511)])) + (3.72175127e-05f * fVec57[((IOTA - 361) & 511)])) + (9.42070037e-05f * fVec57[((IOTA - 365) & 511)])) + (6.10766001e-05f * fVec57[((IOTA - 366) & 511)])) + (0.000458806287f * fVec57[((IOTA - 375) & 511)])) + (0.00121854292f * fVec57[((IOTA - 376) & 511)])) + (0.00124708749f * fVec57[((IOTA - 377) & 511)])) + (0.000807920471f * fVec57[((IOTA - 378) & 511)])) + (8.1546139e-05f * fVec57[((IOTA - 379) & 511)])) + (0.000589931849f * fVec57[((IOTA - 384) & 511)])) + (0.000925221946f * fVec57[((IOTA - 385) & 511)])) + (0.00102720503f * fVec57[((IOTA - 386) & 511)])) + (0.000799512956f * fVec57[((IOTA - 387) & 511)])) + (0.000376362819f * fVec57[((IOTA - 388) & 511)])) + (0.000104375184f * fVec57[((IOTA - 389) & 511)])) + (0.000319074374f * fVec57[((IOTA - 401) & 511)])) + (0.000620303676f * fVec57[((IOTA - 402) & 511)])) + (0.00112078059f * fVec57[((IOTA - 409) & 511)])) + (0.00135415467f * fVec57[((IOTA - 410) & 511)])) + (0.000492401887f * fVec57[((IOTA - 411) & 511)])) + (0.000135844108f * fVec57[((IOTA - 422) & 511)])) + (0.00088278763f * fVec57[((IOTA - 423) & 511)])) + (0.00138333067f * fVec57[((IOTA - 424) & 511)])) + (0.00161062367f * fVec57[((IOTA - 425) & 511)])) + (0.00155051053f * fVec57[((IOTA - 426) & 511)])) + (0.00107439142f * fVec57[((IOTA - 427) & 511)])) + (0.000435312744f * fVec57[((IOTA - 428) & 511)])) + (0.000374767464f * fVec57[((IOTA - 451) & 511)])) + (0.000136542134f * fVec57[((IOTA - 452) & 511)])) + (3.01729888e-05f * fVec57[((IOTA - 470) & 511)])) + (0.000656591263f * fVec57[((IOTA - 493) & 511)])) + (0.00202629715f * fVec57[((IOTA - 494) & 511)])) + (0.00251926389f * fVec57[((IOTA - 495) & 511)])) + (0.00216606259f * fVec57[((IOTA - 496) & 511)])) + (0.00086800009f * fVec57[((IOTA - 497) & 511)])) - (((((((((((((((((((((((((0.0024502119f * fVec57[((IOTA - 482) & 511)]) + ((0.00221707067f * fVec57[((IOTA - 481) & 511)]) + ((0.00204171613f * fVec57[((IOTA - 480) & 511)]) + ((0.00215094304f * fVec57[((IOTA - 479) & 511)]) + ((0.00219882745f * fVec57[((IOTA - 478) & 511)]) + ((0.00211864337f * fVec57[((IOTA - 477) & 511)]) + ((0.00222697295f * fVec57[((IOTA - 476) & 511)]) + ((0.00219081901f * fVec57[((IOTA - 475) & 511)]) + ((0.00188899087f * fVec57[((IOTA - 474) & 511)]) + ((0.00144723197f * fVec57[((IOTA - 473) & 511)]) + ((0.000768443104f * fVec57[((IOTA - 472) & 511)]) + ((0.000151495449f * fVec57[((IOTA - 471) & 511)]) + ((0.000525366049f * fVec57[((IOTA - 469) & 511)]) + ((0.00181731395f * fVec57[((IOTA - 468) & 511)]) + ((0.00336672785f * fVec57[((IOTA - 467) & 511)]) + ((0.0046535586f * fVec57[((IOTA - 466) & 511)]) + ((0.0050547109f * fVec57[((IOTA - 465) & 511)]) + ((0.00409303559f * fVec57[((IOTA - 464) & 511)]) + ((0.00236241845f * fVec57[((IOTA - 463) & 511)]) + ((0.00108452654f * fVec57[((IOTA - 462) & 511)]) + ((0.000747707672f * fVec57[((IOTA - 461) & 511)]) + ((0.00144919241f * fVec57[((IOTA - 460) & 511)]) + ((0.002978303f * fVec57[((IOTA - 459) & 511)]) + ((0.00444341218f * fVec57[((IOTA - 458) & 511)]) + ((0.0053810291f * fVec57[((IOTA - 457) & 511)]) + ((0.00555359246f * fVec57[((IOTA - 456) & 511)]) + ((0.00450435607f * fVec57[((IOTA - 455) & 511)]) + ((0.00268498203f * fVec57[((IOTA - 454) & 511)]) + ((0.00100281416f * fVec57[((IOTA - 453) & 511)]) + ((0.000170934945f * fVec57[((IOTA - 450) & 511)]) + ((0.00100504048f * fVec57[((IOTA - 449) & 511)]) + ((0.00205218326f * fVec57[((IOTA - 448) & 511)]) + ((0.00289599225f * fVec57[((IOTA - 447) & 511)]) + ((0.00321307266f * fVec57[((IOTA - 446) & 511)]) + ((0.00336799072f * fVec57[((IOTA - 445) & 511)]) + ((0.00365852052f * fVec57[((IOTA - 444) & 511)]) + ((0.00443836115f * fVec57[((IOTA - 443) & 511)]) + ((0.00575938588f * fVec57[((IOTA - 442) & 511)]) + ((0.00697756326f * fVec57[((IOTA - 441) & 511)]) + ((0.00778099755f * fVec57[((IOTA - 440) & 511)]) + ((0.00773533946f * fVec57[((IOTA - 439) & 511)]) + ((0.00652882596f * fVec57[((IOTA - 438) & 511)]) + ((0.00487443851f * fVec57[((IOTA - 437) & 511)]) + ((0.00333951274f * fVec57[((IOTA - 436) & 511)]) + ((0.00192461349f * fVec57[((IOTA - 434) & 511)]) + ((0.00204689987f * fVec57[((IOTA - 433) & 511)]) + ((0.00223567942f * fVec57[((IOTA - 432) & 511)]) + ((0.00213745143f * fVec57[((IOTA - 431) & 511)]) + ((0.0013554506f * fVec57[((IOTA - 430) & 511)]) + ((0.000322696287f * fVec57[((IOTA - 429) & 511)]) + ((0.000450399239f * fVec57[((IOTA - 421) & 511)]) + ((0.000751728658f * fVec57[((IOTA - 420) & 511)]) + ((0.000715773553f * fVec57[((IOTA - 419) & 511)]) + ((0.000656723976f * fVec57[((IOTA - 418) & 511)]) + ((0.00125762168f * fVec57[((IOTA - 417) & 511)]) + ((0.00202583196f * fVec57[((IOTA - 416) & 511)]) + ((0.00231749145f * fVec57[((IOTA - 415) & 511)]) + ((0.00237358361f * fVec57[((IOTA - 414) & 511)]) + ((0.00188958924f * fVec57[((IOTA - 413) & 511)]) + ((0.000754552893f * fVec57[((IOTA - 412) & 511)]) + ((0.000188746024f * fVec57[((IOTA - 408) & 511)]) + ((0.00147783663f * fVec57[((IOTA - 407) & 511)]) + ((0.00209119543f * fVec57[((IOTA - 406) & 511)]) + ((0.0020058942f * fVec57[((IOTA - 405) & 511)]) + ((0.00120139634f * fVec57[((IOTA - 404) & 511)]) + ((5.94817102e-05f * fVec57[((IOTA - 403) & 511)]) + ((0.00100823073f * fVec57[((IOTA - 400) & 511)]) + ((0.00286738109f * fVec57[((IOTA - 399) & 511)]) + ((0.00445178617f * fVec57[((IOTA - 398) & 511)]) + ((0.00530453399f * fVec57[((IOTA - 397) & 511)]) + ((0.00517736282f * fVec57[((IOTA - 396) & 511)]) + ((0.00413131621f * fVec57[((IOTA - 395) & 511)]) + ((0.00267753843f * fVec57[((IOTA - 394) & 511)]) + ((0.0013977522f * fVec57[((IOTA - 393) & 511)]) + ((0.000774790067f * fVec57[((IOTA - 392) & 511)]) + ((0.00059837196f * fVec57[((IOTA - 391) & 511)]) + ((0.00026962813f * fVec57[((IOTA - 390) & 511)]) + ((0.000143453944f * fVec57[((IOTA - 383) & 511)]) + ((0.000694572926f * fVec57[((IOTA - 382) & 511)]) + ((0.000729131978f * fVec57[((IOTA - 381) & 511)]) + ((0.000689256005f * fVec57[((IOTA - 374) & 511)]) + ((0.00184828416f * fVec57[((IOTA - 373) & 511)]) + ((0.00276659476f * fVec57[((IOTA - 372) & 511)]) + ((0.00280480925f * fVec57[((IOTA - 371) & 511)]) + ((0.00221996149f * fVec57[((IOTA - 370) & 511)]) + ((0.00165920565f * fVec57[((IOTA - 369) & 511)]) + ((0.000970215537f * fVec57[((IOTA - 368) & 511)]) + ((0.000279530417f * fVec57[((IOTA - 367) & 511)]) + ((0.000142922159f * fVec57[((IOTA - 364) & 511)]) + ((0.000287937932f * fVec57[((IOTA - 363) & 511)]) + ((0.000104740728f * fVec57[((IOTA - 362) & 511)]) + ((1.02017075e-05f * fVec57[((IOTA - 359) & 511)]) + ((0.000216692686f * fVec57[((IOTA - 358) & 511)]) + ((0.000644462183f * fVec57[((IOTA - 357) & 511)]) + ((0.0010188641f * fVec57[((IOTA - 356) & 511)]) + ((0.00101530878f * fVec57[((IOTA - 355) & 511)]) + ((0.000170835294f * fVec57[((IOTA - 354) & 511)]) + ((0.000500841998f * fVec57[((IOTA - 380) & 511)]) + ((0.000876374077f * fVec57[((IOTA - 326) & 511)]) + ((0.00200350164f * fVec57[((IOTA - 325) & 511)]) + ((0.00283272238f * fVec57[((IOTA - 324) & 511)]) + (((0.00285565108f * fVec57[((IOTA - 322) & 511)]) + ((0.00249088556f * fVec57[((IOTA - 321) & 511)]) + ((0.00171018066f * fVec57[((IOTA - 320) & 511)]) + ((0.000448338687f * fVec57[((IOTA - 319) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0165462997f * fVec57[((IOTA - 49) & 511)]) + ((0.0304714534f * fVec57[((IOTA - 48) & 511)]) + ((0.0282536857f * fVec57[((IOTA - 47) & 511)]) + ((0.0176868849f * fVec57[((IOTA - 46) & 511)]) + ((0.00939268433f * fVec57[((IOTA - 45) & 511)]) + ((0.0054150233f * fVec57[((IOTA - 44) & 511)]) + ((0.00849996135f * fVec57[((IOTA - 43) & 511)]) + ((0.0177421477f * fVec57[((IOTA - 42) & 511)]) + ((0.0239673834f * fVec57[((IOTA - 41) & 511)]) + ((0.0187807493f * fVec57[((IOTA - 40) & 511)]) + ((0.0034006224f * fVec57[((IOTA - 39) & 511)]) + ((0.0139442943f * fVec57[((IOTA - 35) & 511)]) + ((0.0230635628f * fVec57[((IOTA - 34) & 511)]) + ((0.0295058899f * fVec57[((IOTA - 33) & 511)]) + ((0.0357408971f * fVec57[((IOTA - 32) & 511)]) + ((0.0351998471f * fVec57[((IOTA - 31) & 511)]) + ((0.0230168067f * fVec57[((IOTA - 29) & 511)]) + ((0.0115106627f * fVec57[((IOTA - 28) & 511)]) + ((0.0133571532f * fVec57[((IOTA - 22) & 511)]) + ((0.0186199509f * fVec57[((IOTA - 21) & 511)]) + ((0.00770181045f * fVec57[((IOTA - 20) & 511)]) + ((0.0432631001f * fVec57[((IOTA - 10) & 511)]) + ((0.14859055f * fVec57[((IOTA - 9) & 511)]) + ((0.226749703f * fVec57[((IOTA - 8) & 511)]) + ((0.21296142f * fVec57[((IOTA - 7) & 511)]) + ((0.110423103f * fVec57[((IOTA - 6) & 511)]) + (0.0159885678f * fVec57[((IOTA - 54) & 511)]))))))))))))))))))))))))))) + (0.0332578868f * fVec57[((IOTA - 55) & 511)])) + (0.0435470827f * fVec57[((IOTA - 56) & 511)])) + (0.0404014997f * fVec57[((IOTA - 57) & 511)])) + (0.0282884091f * fVec57[((IOTA - 58) & 511)])) + (0.0142546613f * fVec57[((IOTA - 59) & 511)])) + (0.00670929765f * fVec57[((IOTA - 65) & 511)])) + (0.0207290892f * fVec57[((IOTA - 66) & 511)])) + (0.0321843587f * fVec57[((IOTA - 67) & 511)])) + (0.0372502021f * fVec57[((IOTA - 68) & 511)])) + (0.0374457277f * fVec57[((IOTA - 69) & 511)])) + (0.0326512381f * fVec57[((IOTA - 70) & 511)])) + (0.0234842207f * fVec57[((IOTA - 71) & 511)])) + (0.0124975275f * fVec57[((IOTA - 72) & 511)])) + (0.000880095642f * fVec57[((IOTA - 73) & 511)])) + (0.00239485083f * fVec57[((IOTA - 78) & 511)])) + (0.00507066119f * fVec57[((IOTA - 79) & 511)])) + (0.00540299434f * fVec57[((IOTA - 80) & 511)])) + (0.00554807624f * fVec57[((IOTA - 81) & 511)])) + (0.00478993449f * fVec57[((IOTA - 82) & 511)])) + (0.00611607637f * fVec57[((IOTA - 83) & 511)])) + (0.00786360726f * fVec57[((IOTA - 84) & 511)])) + (0.00911564566f * fVec57[((IOTA - 85) & 511)])) + (0.0117114391f * fVec57[((IOTA - 86) & 511)])) + (0.015308883f * fVec57[((IOTA - 87) & 511)])) + (0.0200802423f * fVec57[((IOTA - 88) & 511)])) + (0.0252402574f * fVec57[((IOTA - 89) & 511)])) + (0.0271008052f * fVec57[((IOTA - 90) & 511)])) + (0.0245318953f * fVec57[((IOTA - 91) & 511)])) + (0.0205168165f * fVec57[((IOTA - 92) & 511)])) + (0.0136055471f * fVec57[((IOTA - 93) & 511)])) + (0.00430231774f * fVec57[((IOTA - 94) & 511)])) + (0.0109862946f * fVec57[((IOTA - 102) & 511)])) + (0.0221552532f * fVec57[((IOTA - 103) & 511)])) + (0.0287750624f * fVec57[((IOTA - 104) & 511)])) + (0.0283922218f * fVec57[((IOTA - 105) & 511)])) + (0.0197352804f * fVec57[((IOTA - 106) & 511)])) + (0.00701391697f * fVec57[((IOTA - 107) & 511)])) + (0.00557795027f * fVec57[((IOTA - 113) & 511)])) + (0.0134885442f * fVec57[((IOTA - 114) & 511)])) + (0.0198443756f * fVec57[((IOTA - 115) & 511)])) + (0.0233229883f * fVec57[((IOTA - 116) & 511)])) + (0.0227389708f * fVec57[((IOTA - 117) & 511)])) + (0.0184780248f * fVec57[((IOTA - 118) & 511)])) + (0.0122900717f * fVec57[((IOTA - 119) & 511)])) + (0.00613731006f * fVec57[((IOTA - 120) & 511)])) + (0.00148597779f * fVec57[((IOTA - 121) & 511)])) + (0.00350453286f * fVec57[((IOTA - 124) & 511)])) + (0.00866125897f * fVec57[((IOTA - 125) & 511)])) + (0.0108686602f * fVec57[((IOTA - 126) & 511)])) + (0.00994190946f * fVec57[((IOTA - 127) & 511)])) + (0.00691745011f * fVec57[((IOTA - 128) & 511)])) + (0.00211532041f * fVec57[((IOTA - 129) & 511)])) + (0.00183133688f * fVec57[((IOTA - 137) & 511)])) + (0.00346741499f * fVec57[((IOTA - 138) & 511)])) + (0.00459427619f * fVec57[((IOTA - 139) & 511)])) + (0.00565364771f * fVec57[((IOTA - 140) & 511)])) + (0.00705352705f * fVec57[((IOTA - 141) & 511)])) + (0.00843479671f * fVec57[((IOTA - 142) & 511)])) + (0.00876350887f * fVec57[((IOTA - 143) & 511)])) + (0.00744012464f * fVec57[((IOTA - 144) & 511)])) + (0.00437957747f * fVec57[((IOTA - 145) & 511)])) + (0.00304363295f * fVec57[((IOTA - 159) & 511)])) + (0.00565580791f * fVec57[((IOTA - 160) & 511)])) + (0.00591174513f * fVec57[((IOTA - 161) & 511)])) + (0.00433551474f * fVec57[((IOTA - 162) & 511)])) + (0.00240076566f * fVec57[((IOTA - 163) & 511)])) + (0.00136292726f * fVec57[((IOTA - 164) & 511)])) + (0.00184293417f * fVec57[((IOTA - 165) & 511)])) + (0.00335303741f * fVec57[((IOTA - 166) & 511)])) + (0.00444091996f * fVec57[((IOTA - 167) & 511)])) + (0.00374714471f * fVec57[((IOTA - 168) & 511)])) + (0.000660412479f * fVec57[((IOTA - 169) & 511)])) + (0.00336998468f * fVec57[((IOTA - 176) & 511)])) + (0.00584857492f * fVec57[((IOTA - 177) & 511)])) + (0.00649061147f * fVec57[((IOTA - 178) & 511)])) + (0.00575652812f * fVec57[((IOTA - 179) & 511)])) + (0.00325401174f * fVec57[((IOTA - 180) & 511)])) + (0.000519517343f * fVec57[((IOTA - 218) & 511)])) + (0.000879331492f * fVec57[((IOTA - 247) & 511)])) + (0.00109147187f * fVec57[((IOTA - 248) & 511)])) + (0.00046226196f * fVec57[((IOTA - 275) & 511)])) + (0.000213934574f * fVec57[((IOTA - 276) & 511)])) + (0.00312461425f * fVec57[((IOTA - 323) & 511)])) + (0.00224265782f * fVec57[((IOTA - 435) & 511)])))))) + (0.00257721683f * fVec57[((IOTA - 483) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00232579885f * fVec57[((IOTA - 484) & 511)])) + (0.00152153382f * fVec57[((IOTA - 485) & 511)])) + (0.000757809728f * fVec57[((IOTA - 486) & 511)])) + (0.000231214333f * fVec57[((IOTA - 487) & 511)])) + (9.72310081e-05f * fVec57[((IOTA - 488) & 511)])) + (0.000739100855f * fVec57[((IOTA - 489) & 511)])) + (0.00150395557f * fVec57[((IOTA - 490) & 511)])) + (0.00164820673f * fVec57[((IOTA - 491) & 511)])) + (0.000908906106f * fVec57[((IOTA - 492) & 511)])) + (0.000787749887f * fVec57[((IOTA - 498) & 511)])) + (0.00199705502f * fVec57[((IOTA - 499) & 511)])) + (0.00266032526f * fVec57[((IOTA - 500) & 511)])) + (0.00282654166f * fVec57[((IOTA - 501) & 511)])) + (0.00294985808f * fVec57[((IOTA - 502) & 511)])) + (0.00349728856f * fVec57[((IOTA - 503) & 511)])) + (0.00411091326f * fVec57[((IOTA - 504) & 511)])) + (0.00467236666f * fVec57[((IOTA - 505) & 511)])) + (0.00522936741f * fVec57[((IOTA - 506) & 511)])) + (0.00543682231f * fVec57[((IOTA - 507) & 511)])) + (0.00526399305f * fVec57[((IOTA - 508) & 511)])) + (0.0048732087f * fVec57[((IOTA - 509) & 511)])) + (0.00430790056f * fVec57[((IOTA - 510) & 511)])) + (0.00398181472f * fVec57[((IOTA - 511) & 511)]))) : (iSlow169 ? (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((3.16980295e-05f * fVec56[((IOTA - 319) & 511)]) + ((0.00182665372f * fVec56[((IOTA - 318) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0490132719f * fVec56[((IOTA - 6) & 511)]) + ((0.177655026f * fVec56[((IOTA - 5) & 511)]) + ((0.259027183f * fVec56[((IOTA - 4) & 511)]) + ((0.26130414f * fVec56[((IOTA - 3) & 511)]) + ((0.220370084f * fVec56[((IOTA - 2) & 511)]) + ((0.154509753f * fVec56[((IOTA - 1) & 511)]) + ((fSlow173 * fTemp0) + ((0.00143976277f * fVec56[((IOTA - 19) & 511)]) + ((0.000234301202f * fVec56[((IOTA - 18) & 511)]) + (((0.0120860562f * fVec56[((IOTA - 12) & 511)]) + ((0.0400138907f * fVec56[((IOTA - 15) & 511)]) + ((((0.0522584692f * fVec56[((IOTA - 13) & 511)]) + (0.0495195054f * fVec56[((IOTA - 14) & 511)])) + (0.0248208754f * fVec56[((IOTA - 16) & 511)])) + (0.00636334671f * fVec56[((IOTA - 17) & 511)])))) + (0.00741950795f * fVec56[((IOTA - 20) & 511)]))))))))))) + (0.00686609792f * fVec56[((IOTA - 21) & 511)])) + (0.00747945393f * fVec56[((IOTA - 22) & 511)])) + (0.0156330485f * fVec56[((IOTA - 23) & 511)])) + (0.0188248139f * fVec56[((IOTA - 24) & 511)])) + (0.0225731842f * fVec56[((IOTA - 25) & 511)])) + (0.0208222121f * fVec56[((IOTA - 26) & 511)])) + (0.010336021f * fVec56[((IOTA - 27) & 511)])) + (0.00186405936f * fVec56[((IOTA - 28) & 511)])) + (0.00565812085f * fVec56[((IOTA - 41) & 511)])) + (0.0195647366f * fVec56[((IOTA - 42) & 511)])) + (0.0259073172f * fVec56[((IOTA - 43) & 511)])) + (0.0160376746f * fVec56[((IOTA - 44) & 511)])) + (0.000787646975f * fVec56[((IOTA - 53) & 511)])) + (0.012391719f * fVec56[((IOTA - 65) & 511)])) + (0.0135080516f * fVec56[((IOTA - 66) & 511)])) + (0.0134895751f * fVec56[((IOTA - 74) & 511)])) + (0.0173997246f * fVec56[((IOTA - 75) & 511)])) + (0.00618902314f * fVec56[((IOTA - 76) & 511)])) + (0.00195944356f * fVec56[((IOTA - 81) & 511)])) + (0.0125435991f * fVec56[((IOTA - 82) & 511)])) + (0.0125346985f * fVec56[((IOTA - 83) & 511)])) + (0.00287855836f * fVec56[((IOTA - 84) & 511)])) + (0.00668229442f * fVec56[((IOTA - 97) & 511)])) + (0.0162664615f * fVec56[((IOTA - 98) & 511)])) + (0.0186617784f * fVec56[((IOTA - 99) & 511)])) + (0.0147686228f * fVec56[((IOTA - 100) & 511)])) + (0.00954260118f * fVec56[((IOTA - 101) & 511)])) + (0.0054497458f * fVec56[((IOTA - 102) & 511)])) + (0.00096980622f * fVec56[((IOTA - 103) & 511)])) + (0.0020186156f * fVec56[((IOTA - 111) & 511)])) + (0.00790832937f * fVec56[((IOTA - 112) & 511)])) + (0.00882989541f * fVec56[((IOTA - 113) & 511)])) + (0.00473726494f * fVec56[((IOTA - 114) & 511)])) + (0.00242372509f * fVec56[((IOTA - 123) & 511)])) + (0.00438736053f * fVec56[((IOTA - 124) & 511)])) + (0.000845787115f * fVec56[((IOTA - 125) & 511)])) + (0.0101056211f * fVec56[((IOTA - 132) & 511)])) + (0.0164910238f * fVec56[((IOTA - 133) & 511)])) + (0.0189634729f * fVec56[((IOTA - 134) & 511)])) + (0.0179982465f * fVec56[((IOTA - 135) & 511)])) + (0.014466282f * fVec56[((IOTA - 136) & 511)])) + (0.00905490853f * fVec56[((IOTA - 137) & 511)])) + (0.00240444206f * fVec56[((IOTA - 138) & 511)])) + (0.000222692732f * fVec56[((IOTA - 146) & 511)])) + (0.0062426487f * fVec56[((IOTA - 147) & 511)])) + (0.0104671661f * fVec56[((IOTA - 148) & 511)])) + (0.0122782122f * fVec56[((IOTA - 149) & 511)])) + (0.0118493699f * fVec56[((IOTA - 150) & 511)])) + (0.00920595042f * fVec56[((IOTA - 151) & 511)])) + (0.00494293123f * fVec56[((IOTA - 152) & 511)])) + (0.00114493538f * fVec56[((IOTA - 153) & 511)])) + (0.0014605294f * fVec56[((IOTA - 156) & 511)])) + (0.00347563019f * fVec56[((IOTA - 157) & 511)])) + (0.00399421435f * fVec56[((IOTA - 158) & 511)])) + (0.00184035813f * fVec56[((IOTA - 159) & 511)])) + (0.00277846633f * fVec56[((IOTA - 170) & 511)])) + (0.00798536558f * fVec56[((IOTA - 171) & 511)])) + (0.0123358369f * fVec56[((IOTA - 172) & 511)])) + (0.0136781512f * fVec56[((IOTA - 173) & 511)])) + (0.0113663524f * fVec56[((IOTA - 174) & 511)])) + (0.00674675452f * fVec56[((IOTA - 175) & 511)])) + (0.0013288036f * fVec56[((IOTA - 176) & 511)])) + (0.000289861578f * fVec56[((IOTA - 182) & 511)])) + (0.0056455452f * fVec56[((IOTA - 183) & 511)])) + (0.0104923509f * fVec56[((IOTA - 184) & 511)])) + (0.0128509384f * fVec56[((IOTA - 185) & 511)])) + (0.012536183f * fVec56[((IOTA - 186) & 511)])) + (0.0100680869f * fVec56[((IOTA - 187) & 511)])) + (0.00677361572f * fVec56[((IOTA - 188) & 511)])) + (0.00426605018f * fVec56[((IOTA - 189) & 511)])) + (0.00336937886f * fVec56[((IOTA - 190) & 511)])) + (0.00480340188f * fVec56[((IOTA - 191) & 511)])) + (0.00748483883f * fVec56[((IOTA - 192) & 511)])) + (0.00922894198f * fVec56[((IOTA - 193) & 511)])) + (0.00940684415f * fVec56[((IOTA - 194) & 511)])) + (0.00823208131f * fVec56[((IOTA - 195) & 511)])) + (0.00648981659f * fVec56[((IOTA - 196) & 511)])) + (0.00535655394f * fVec56[((IOTA - 197) & 511)])) + (0.00515056495f * fVec56[((IOTA - 198) & 511)])) + (0.00510000298f * fVec56[((IOTA - 199) & 511)])) + (0.00459950883f * fVec56[((IOTA - 200) & 511)])) + (0.00346479518f * fVec56[((IOTA - 201) & 511)])) + (0.00199488224f * fVec56[((IOTA - 202) & 511)])) + (0.000835726038f * fVec56[((IOTA - 203) & 511)])) + (0.000165584497f * fVec56[((IOTA - 204) & 511)])) + (0.000655792188f * fVec56[((IOTA - 206) & 511)])) + (0.00174016925f * fVec56[((IOTA - 207) & 511)])) + (0.00243385043f * fVec56[((IOTA - 208) & 511)])) + (0.0028948104f * fVec56[((IOTA - 209) & 511)])) + (0.00357714156f * fVec56[((IOTA - 210) & 511)])) + (0.00487963203f * fVec56[((IOTA - 211) & 511)])) + (0.00706402538f * fVec56[((IOTA - 212) & 511)])) + (0.00935508963f * fVec56[((IOTA - 213) & 511)])) + (0.0103377616f * fVec56[((IOTA - 214) & 511)])) + (0.00950551778f * fVec56[((IOTA - 215) & 511)])) + (0.00682482263f * fVec56[((IOTA - 216) & 511)])) + (0.0028296411f * fVec56[((IOTA - 217) & 511)])) + (0.00028383173f * fVec56[((IOTA - 221) & 511)])) + (0.00483503565f * fVec56[((IOTA - 222) & 511)])) + (0.00879239291f * fVec56[((IOTA - 223) & 511)])) + (0.0108073f * fVec56[((IOTA - 224) & 511)])) + (0.0102816531f * fVec56[((IOTA - 225) & 511)])) + (0.00810712762f * fVec56[((IOTA - 226) & 511)])) + (0.0055807298f * fVec56[((IOTA - 227) & 511)])) + (0.00403407076f * fVec56[((IOTA - 228) & 511)])) + (0.00434950367f * fVec56[((IOTA - 229) & 511)])) + (0.00627260562f * fVec56[((IOTA - 230) & 511)])) + (0.00887865108f * fVec56[((IOTA - 231) & 511)])) + (0.0105748046f * fVec56[((IOTA - 232) & 511)])) + (0.0102607254f * fVec56[((IOTA - 233) & 511)])) + (0.00880000181f * fVec56[((IOTA - 234) & 511)])) + (0.00725040864f * fVec56[((IOTA - 235) & 511)])) + (0.00585359801f * fVec56[((IOTA - 236) & 511)])) + (0.00523098698f * fVec56[((IOTA - 237) & 511)])) + (0.00543949148f * fVec56[((IOTA - 238) & 511)])) + (0.00567043899f * fVec56[((IOTA - 239) & 511)])) + (0.00573241618f * fVec56[((IOTA - 240) & 511)])) + (0.00558363227f * fVec56[((IOTA - 241) & 511)])) + (0.00530583085f * fVec56[((IOTA - 242) & 511)])) + (0.00506682135f * fVec56[((IOTA - 243) & 511)])) + (0.00442383112f * fVec56[((IOTA - 244) & 511)])) + (0.00319166947f * fVec56[((IOTA - 245) & 511)])) + (0.0016434947f * fVec56[((IOTA - 246) & 511)])) + (0.00272097113f * fVec56[((IOTA - 251) & 511)])) + (0.00677113282f * fVec56[((IOTA - 252) & 511)])) + (0.0103381816f * fVec56[((IOTA - 253) & 511)])) + (0.0122146867f * fVec56[((IOTA - 254) & 511)])) + (0.0118907094f * fVec56[((IOTA - 255) & 511)])) + (0.00969799608f * fVec56[((IOTA - 256) & 511)])) + (0.00707602082f * fVec56[((IOTA - 257) & 511)])) + (0.00529886549f * fVec56[((IOTA - 258) & 511)])) + (0.00495776488f * fVec56[((IOTA - 259) & 511)])) + (0.00612043543f * fVec56[((IOTA - 260) & 511)])) + (0.007791501f * fVec56[((IOTA - 261) & 511)])) + (0.00881186873f * fVec56[((IOTA - 262) & 511)])) + (0.00857456867f * fVec56[((IOTA - 263) & 511)])) + (0.00721754972f * fVec56[((IOTA - 264) & 511)])) + (0.00589606632f * fVec56[((IOTA - 265) & 511)])) + (0.00550598325f * fVec56[((IOTA - 266) & 511)])) + (0.00627470156f * fVec56[((IOTA - 267) & 511)])) + (0.00811093207f * fVec56[((IOTA - 268) & 511)])) + (0.0100534465f * fVec56[((IOTA - 269) & 511)])) + (0.0110792965f * fVec56[((IOTA - 270) & 511)])) + (0.0107680233f * fVec56[((IOTA - 271) & 511)])) + (0.00916103087f * fVec56[((IOTA - 272) & 511)])) + (0.00700017763f * fVec56[((IOTA - 273) & 511)])) + (0.00480839983f * fVec56[((IOTA - 274) & 511)])) + (0.00268450053f * fVec56[((IOTA - 275) & 511)])) + (0.00118276011f * fVec56[((IOTA - 276) & 511)])) + (0.000837015919f * fVec56[((IOTA - 277) & 511)])) + (0.0012211334f * fVec56[((IOTA - 278) & 511)])) + (0.00152769871f * fVec56[((IOTA - 279) & 511)])) + (0.00148261804f * fVec56[((IOTA - 280) & 511)])) + (0.00120562268f * fVec56[((IOTA - 281) & 511)])) + (0.00103071937f * fVec56[((IOTA - 282) & 511)])) + (0.000943525229f * fVec56[((IOTA - 283) & 511)])) + (0.00091105327f * fVec56[((IOTA - 284) & 511)])) + (0.00137385167f * fVec56[((IOTA - 285) & 511)])) + (0.00224150158f * fVec56[((IOTA - 286) & 511)])) + (0.0031561018f * fVec56[((IOTA - 287) & 511)])) + (0.00415873481f * fVec56[((IOTA - 288) & 511)])) + (0.00528754713f * fVec56[((IOTA - 289) & 511)])) + (0.00642651692f * fVec56[((IOTA - 290) & 511)])) + (0.00728900731f * fVec56[((IOTA - 291) & 511)])) + (0.00747248856f * fVec56[((IOTA - 292) & 511)])) + (0.00683356123f * fVec56[((IOTA - 293) & 511)])) + (0.00574699184f * fVec56[((IOTA - 294) & 511)])) + (0.00483100442f * fVec56[((IOTA - 295) & 511)])) + (0.00457858108f * fVec56[((IOTA - 296) & 511)])) + (0.00505476119f * fVec56[((IOTA - 297) & 511)])) + (0.00626235129f * fVec56[((IOTA - 298) & 511)])) + (0.00802248064f * fVec56[((IOTA - 299) & 511)])) + (0.00959516317f * fVec56[((IOTA - 300) & 511)])) + (0.0109124547f * fVec56[((IOTA - 301) & 511)])) + (0.011966778f * fVec56[((IOTA - 302) & 511)])) + (0.0121687688f * fVec56[((IOTA - 303) & 511)])) + (0.0116223879f * fVec56[((IOTA - 304) & 511)])) + (0.0105971182f * fVec56[((IOTA - 305) & 511)])) + (0.00898093637f * fVec56[((IOTA - 306) & 511)])) + (0.00730396993f * fVec56[((IOTA - 307) & 511)])) + (0.00608847942f * fVec56[((IOTA - 308) & 511)])) + (0.00543113984f * fVec56[((IOTA - 309) & 511)])) + (0.00542552862f * fVec56[((IOTA - 310) & 511)])) + (0.00554848369f * fVec56[((IOTA - 311) & 511)])) + (0.00546686864f * fVec56[((IOTA - 312) & 511)])) + (0.00575527921f * fVec56[((IOTA - 313) & 511)])) + (0.00606010295f * fVec56[((IOTA - 314) & 511)])) + (0.0057219686f * fVec56[((IOTA - 315) & 511)])) + (0.00489440095f * fVec56[((IOTA - 316) & 511)])) + (0.000220919028f * fVec56[((IOTA - 328) & 511)])) + (0.00125118671f * fVec56[((IOTA - 329) & 511)])) + (0.00158013077f * fVec56[((IOTA - 330) & 511)])) + (0.00118514663f * fVec56[((IOTA - 331) & 511)])) + (0.000932948664f * fVec56[((IOTA - 332) & 511)])) + (0.0012749522f * fVec56[((IOTA - 333) & 511)])) + (0.00170376291f * fVec56[((IOTA - 334) & 511)])) + (0.00213799113f * fVec56[((IOTA - 335) & 511)])))) + (0.00277785351f * fVec56[((IOTA - 336) & 511)])) + (0.00371415587f * fVec56[((IOTA - 337) & 511)])) + (0.00523679145f * fVec56[((IOTA - 338) & 511)])) + (0.00682962732f * fVec56[((IOTA - 339) & 511)])) + (0.00762572279f * fVec56[((IOTA - 340) & 511)])) + (0.00741051137f * fVec56[((IOTA - 341) & 511)])) + (0.0060621989f * fVec56[((IOTA - 342) & 511)])) + (0.0037502069f * fVec56[((IOTA - 343) & 511)])) + (0.00152698904f * fVec56[((IOTA - 344) & 511)])) + (0.000342229381f * fVec56[((IOTA - 345) & 511)])) + (0.000645795837f * fVec56[((IOTA - 346) & 511)])) + (0.00237729028f * fVec56[((IOTA - 347) & 511)])) + (0.00466609746f * fVec56[((IOTA - 348) & 511)])) + (0.00642442098f * fVec56[((IOTA - 349) & 511)])) + (0.0066311839f * fVec56[((IOTA - 350) & 511)])) + (0.00466158288f * fVec56[((IOTA - 351) & 511)])) + (0.00127940252f * fVec56[((IOTA - 352) & 511)])) + (0.000658436213f * fVec56[((IOTA - 357) & 511)])) + (0.00235023582f * fVec56[((IOTA - 358) & 511)])) + (0.00280061923f * fVec56[((IOTA - 359) & 511)])) + (0.00215456542f * fVec56[((IOTA - 360) & 511)])) + (0.00128320744f * fVec56[((IOTA - 361) & 511)])) + (0.00075285323f * fVec56[((IOTA - 362) & 511)])) + (0.000830051024f * fVec56[((IOTA - 363) & 511)])) + (0.00151131721f * fVec56[((IOTA - 364) & 511)])) + (0.00215137331f * fVec56[((IOTA - 365) & 511)])) + (0.00208875118f * fVec56[((IOTA - 366) & 511)])) + (0.00106806029f * fVec56[((IOTA - 367) & 511)])) + (0.000154459383f * fVec56[((IOTA - 375) & 511)])) + (0.00130890775f * fVec56[((IOTA - 376) & 511)])) + (0.00140061602f * fVec56[((IOTA - 377) & 511)])) + (0.0010053413f * fVec56[((IOTA - 378) & 511)])) + (0.000214502215f * fVec56[((IOTA - 379) & 511)])) + (6.19129278e-05f * fVec56[((IOTA - 385) & 511)])) + (0.00055157207f * fVec56[((IOTA - 386) & 511)])) + (0.000573983416f * fVec56[((IOTA - 387) & 511)])) + (0.000114957802f * fVec56[((IOTA - 392) & 511)])) + (0.000563019421f * fVec56[((IOTA - 393) & 511)])) + (6.53630123e-05f * fVec56[((IOTA - 394) & 511)])) + (0.00111981574f * fVec56[((IOTA - 407) & 511)])) + (0.00204628287f * fVec56[((IOTA - 408) & 511)])) + (0.00245974399f * fVec56[((IOTA - 409) & 511)])) + (0.00146865565f * fVec56[((IOTA - 410) & 511)])) + (0.00027609244f * fVec56[((IOTA - 419) & 511)])) + (0.000680170022f * fVec56[((IOTA - 420) & 511)])) + (0.000773394015f * fVec56[((IOTA - 421) & 511)])) + (0.000523291994f * fVec56[((IOTA - 422) & 511)])) + (0.000160844531f * fVec56[((IOTA - 423) & 511)])) + (8.12625512e-06f * fVec56[((IOTA - 426) & 511)])) + (0.000434453599f * fVec56[((IOTA - 427) & 511)])) + (0.000833920203f * fVec56[((IOTA - 428) & 511)])) + (0.000890673604f * fVec56[((IOTA - 429) & 511)])) + (5.65601513e-05f * fVec56[((IOTA - 430) & 511)])) + (0.000292828307f * fVec56[((IOTA - 471) & 511)])) + (0.000279446132f * fVec56[((IOTA - 472) & 511)])) + (0.000284669921f * fVec56[((IOTA - 486) & 511)])) + (0.000620482489f * fVec56[((IOTA - 493) & 511)])) + (0.00216923747f * fVec56[((IOTA - 494) & 511)])) + (0.00305662211f * fVec56[((IOTA - 495) & 511)])) + (0.00292328419f * fVec56[((IOTA - 496) & 511)])) + (0.00172817335f * fVec56[((IOTA - 497) & 511)])) + (0.000252875034f * fVec56[((IOTA - 498) & 511)])) - (((((((((((((0.000613291282f * fVec56[((IOTA - 499) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((0.00346511789f * fVec56[((IOTA - 449) & 511)]) + ((0.00336699234f * fVec56[((IOTA - 448) & 511)]) + ((0.00335870543f * fVec56[((IOTA - 447) & 511)]) + ((0.0040347157f * fVec56[((IOTA - 446) & 511)]) + ((0.00558492215f * fVec56[((IOTA - 445) & 511)]) + ((0.0074811629f * fVec56[((IOTA - 444) & 511)]) + ((0.00926412269f * fVec56[((IOTA - 443) & 511)]) + ((0.0105085373f * fVec56[((IOTA - 442) & 511)]) + ((0.0106155956f * fVec56[((IOTA - 441) & 511)]) + ((0.009645015f * fVec56[((IOTA - 440) & 511)]) + ((0.00785608962f * fVec56[((IOTA - 439) & 511)]) + ((0.00563016348f * fVec56[((IOTA - 438) & 511)]) + ((0.00390315102f * fVec56[((IOTA - 437) & 511)]) + ((0.00299100112f * fVec56[((IOTA - 436) & 511)]) + ((0.00269501284f * fVec56[((IOTA - 435) & 511)]) + ((0.00287188357f * fVec56[((IOTA - 434) & 511)]) + ((0.00284076575f * fVec56[((IOTA - 433) & 511)]) + ((0.00224295259f * fVec56[((IOTA - 432) & 511)]) + ((0.00124722067f * fVec56[((IOTA - 431) & 511)]) + ((0.000328299124f * fVec56[((IOTA - 425) & 511)]) + ((0.000237461179f * fVec56[((IOTA - 424) & 511)]) + ((0.00044058077f * fVec56[((IOTA - 418) & 511)]) + ((0.00175506668f * fVec56[((IOTA - 417) & 511)]) + ((0.00312427478f * fVec56[((IOTA - 416) & 511)]) + ((0.00398186408f * fVec56[((IOTA - 415) & 511)]) + ((0.00441464083f * fVec56[((IOTA - 414) & 511)]) + ((0.00401272392f * fVec56[((IOTA - 413) & 511)]) + ((0.00260136975f * fVec56[((IOTA - 412) & 511)]) + ((0.000591880176f * fVec56[((IOTA - 411) & 511)]) + ((2.49906443e-05f * fVec56[((IOTA - 406) & 511)]) + ((0.00138797564f * fVec56[((IOTA - 405) & 511)]) + ((0.0024145674f * fVec56[((IOTA - 404) & 511)]) + ((0.00300054625f * fVec56[((IOTA - 403) & 511)]) + ((0.00346927764f * fVec56[((IOTA - 402) & 511)]) + ((0.00417730864f * fVec56[((IOTA - 401) & 511)]) + ((0.00629424304f * fVec56[((IOTA - 399) & 511)]) + ((0.00654492527f * fVec56[((IOTA - 398) & 511)]) + ((0.00574908778f * fVec56[((IOTA - 397) & 511)]) + ((0.00380163966f * fVec56[((IOTA - 396) & 511)]) + ((0.00149983773f * fVec56[((IOTA - 395) & 511)]) + ((0.000608164351f * fVec56[((IOTA - 391) & 511)]) + ((0.000794225372f * fVec56[((IOTA - 390) & 511)]) + ((0.000541607849f * fVec56[((IOTA - 389) & 511)]) + ((2.71191821e-05f * fVec56[((IOTA - 388) & 511)]) + ((0.000367058907f * fVec56[((IOTA - 384) & 511)]) + ((0.000789517071f * fVec56[((IOTA - 383) & 511)]) + ((0.00103139644f * fVec56[((IOTA - 382) & 511)]) + ((0.000983671751f * fVec56[((IOTA - 381) & 511)]) + ((0.000593943521f * fVec56[((IOTA - 380) & 511)]) + ((0.00220071012f * fVec56[((IOTA - 374) & 511)]) + ((0.00488685537f * fVec56[((IOTA - 373) & 511)]) + ((0.00689657079f * fVec56[((IOTA - 372) & 511)]) + ((0.00722893281f * fVec56[((IOTA - 371) & 511)]) + ((0.00584611669f * fVec56[((IOTA - 370) & 511)]) + ((0.00359274866f * fVec56[((IOTA - 369) & 511)]) + ((0.00102804275f * fVec56[((IOTA - 368) & 511)]) + ((0.00159309385f * fVec56[((IOTA - 356) & 511)]) + ((0.00348552968f * fVec56[((IOTA - 355) & 511)]) + ((0.00379186915f * fVec56[((IOTA - 354) & 511)]) + ((0.00195931457f * fVec56[((IOTA - 353) & 511)]) + ((0.00168815581f * fVec56[((IOTA - 320) & 511)]) + ((0.00354189612f * (fVec56[((IOTA - 219) & 511)] - fVec56[((IOTA - 317) & 511)])) + ((0.00335599668f * fVec56[((IOTA - 324) & 511)]) + ((0.00340494653f * fVec56[((IOTA - 323) & 511)]) + ((0.0031287251f * fVec56[((IOTA - 322) & 511)]) + (((0.00112897344f * fVec56[((IOTA - 327) & 511)]) + ((0.00223179534f * fVec56[((IOTA - 326) & 511)]) + ((0.00289645512f * fVec56[((IOTA - 325) & 511)]) + (((0.000247748103f * fVec56[((IOTA - 250) & 511)]) + ((0.00151489675f * fVec56[((IOTA - 249) & 511)]) + ((0.00134447543f * fVec56[((IOTA - 248) & 511)]) + ((5.83655201e-05f * fVec56[((IOTA - 247) & 511)]) + ((0.00311547192f * fVec56[((IOTA - 220) & 511)]) + ((4.44985926e-06f * fVec56[((IOTA - 205) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.163030833f * fVec56[((IOTA - 8) & 511)]) + ((0.138384953f * fVec56[((IOTA - 10) & 511)]) + ((0.0808642507f * fVec56[((IOTA - 7) & 511)]) + ((0.177965462f * fVec56[((IOTA - 9) & 511)]) + (0.0651572272f * fVec56[((IOTA - 11) & 511)]))))) + (0.00863902923f * fVec56[((IOTA - 29) & 511)])) + (0.0162473395f * fVec56[((IOTA - 30) & 511)])) + (0.0230995715f * fVec56[((IOTA - 31) & 511)])) + (0.039095968f * fVec56[((IOTA - 32) & 511)])) + (0.0492968783f * fVec56[((IOTA - 33) & 511)])) + (0.0476103015f * fVec56[((IOTA - 34) & 511)])) + (0.0435261205f * fVec56[((IOTA - 35) & 511)])) + (0.0368793942f * fVec56[((IOTA - 36) & 511)])) + (0.0253886357f * fVec56[((IOTA - 37) & 511)])) + (0.0182764344f * fVec56[((IOTA - 38) & 511)])) + (0.0152671495f * fVec56[((IOTA - 39) & 511)])) + (0.00719039841f * fVec56[((IOTA - 40) & 511)])) + (0.00299274269f * fVec56[((IOTA - 45) & 511)])) + (0.0293623731f * fVec56[((IOTA - 46) & 511)])) + (0.0570106655f * fVec56[((IOTA - 47) & 511)])) + (0.0661663115f * fVec56[((IOTA - 48) & 511)])) + (0.0552365743f * fVec56[((IOTA - 49) & 511)])) + (0.0376625918f * fVec56[((IOTA - 50) & 511)])) + (0.0188906938f * fVec56[((IOTA - 51) & 511)])) + (0.0038364334f * fVec56[((IOTA - 52) & 511)])) + (0.00244903844f * fVec56[((IOTA - 54) & 511)])) + (0.00471304776f * fVec56[((IOTA - 55) & 511)])) + (0.0039845081f * fVec56[((IOTA - 56) & 511)])) + (0.00310731353f * fVec56[((IOTA - 57) & 511)])) + (0.00927976239f * fVec56[((IOTA - 58) & 511)])) + (0.0245476216f * fVec56[((IOTA - 59) & 511)])) + (0.0385858677f * fVec56[((IOTA - 60) & 511)])) + (0.0459065065f * fVec56[((IOTA - 61) & 511)])) + (0.0438870527f * fVec56[((IOTA - 62) & 511)])) + (0.0267385934f * fVec56[((IOTA - 63) & 511)])) + (0.00357823772f * fVec56[((IOTA - 64) & 511)])) + (0.00341304019f * fVec56[((IOTA - 67) & 511)])) + (0.0276150461f * fVec56[((IOTA - 68) & 511)])) + (0.0469154604f * fVec56[((IOTA - 69) & 511)])) + (0.0545557924f * fVec56[((IOTA - 70) & 511)])) + (0.0453651249f * fVec56[((IOTA - 71) & 511)])) + (0.0252645202f * fVec56[((IOTA - 72) & 511)])) + (0.00348172477f * fVec56[((IOTA - 73) & 511)])) + (0.011897061f * fVec56[((IOTA - 77) & 511)])) + (0.0227057151f * fVec56[((IOTA - 78) & 511)])) + (0.0215303078f * fVec56[((IOTA - 79) & 511)])) + (0.0121697355f * fVec56[((IOTA - 80) & 511)])) + (0.0110891964f * fVec56[((IOTA - 85) & 511)])) + (0.0216928273f * fVec56[((IOTA - 86) & 511)])) + (0.0238139555f * fVec56[((IOTA - 87) & 511)])) + (0.0198071636f * fVec56[((IOTA - 88) & 511)])) + (0.016029967f * fVec56[((IOTA - 89) & 511)])) + (0.0160942655f * fVec56[((IOTA - 90) & 511)])) + (0.0211476404f * fVec56[((IOTA - 91) & 511)])) + (0.0301200636f * fVec56[((IOTA - 92) & 511)])) + (0.0358828567f * fVec56[((IOTA - 93) & 511)])) + (0.0329118483f * fVec56[((IOTA - 94) & 511)])) + (0.0222210549f * fVec56[((IOTA - 95) & 511)])) + (0.00750386436f * fVec56[((IOTA - 96) & 511)])) + (0.00545300264f * fVec56[((IOTA - 104) & 511)])) + (0.0143008903f * fVec56[((IOTA - 105) & 511)])) + (0.0230036713f * fVec56[((IOTA - 106) & 511)])) + (0.0283731222f * fVec56[((IOTA - 107) & 511)])) + (0.0273437575f * fVec56[((IOTA - 108) & 511)])) + (0.0193152148f * fVec56[((IOTA - 109) & 511)])) + (0.00811970327f * fVec56[((IOTA - 110) & 511)])) + (0.00415944401f * fVec56[((IOTA - 115) & 511)])) + (0.0143702198f * fVec56[((IOTA - 116) & 511)])) + (0.0227132924f * fVec56[((IOTA - 117) & 511)])) + (0.0280216709f * fVec56[((IOTA - 118) & 511)])) + (0.0290487148f * fVec56[((IOTA - 119) & 511)])) + (0.0246723816f * fVec56[((IOTA - 120) & 511)])) + (0.0156835131f * fVec56[((IOTA - 121) & 511)])) + (0.00536268065f * fVec56[((IOTA - 122) & 511)])) + (0.00588000752f * fVec56[((IOTA - 126) & 511)])) + (0.0137771796f * fVec56[((IOTA - 127) & 511)])) + (0.018920714f * fVec56[((IOTA - 128) & 511)])) + (0.0182929114f * fVec56[((IOTA - 129) & 511)])) + (0.0112565542f * fVec56[((IOTA - 130) & 511)])) + (0.000115763862f * fVec56[((IOTA - 131) & 511)])) + (0.0045274063f * fVec56[((IOTA - 139) & 511)])) + (0.0108693093f * fVec56[((IOTA - 140) & 511)])) + (0.0154745579f * fVec56[((IOTA - 141) & 511)])) + (0.0172426514f * fVec56[((IOTA - 142) & 511)])) + (0.015809048f * fVec56[((IOTA - 143) & 511)])) + (0.0117780082f * fVec56[((IOTA - 144) & 511)])) + (0.00617254572f * fVec56[((IOTA - 145) & 511)])) + (0.000645763241f * fVec56[((IOTA - 154) & 511)])) + (0.000359191094f * fVec56[((IOTA - 155) & 511)])) + (0.00175913004f * fVec56[((IOTA - 160) & 511)])) + (0.00465797121f * fVec56[((IOTA - 161) & 511)])) + (0.00622326881f * fVec56[((IOTA - 162) & 511)])) + (0.00616777316f * fVec56[((IOTA - 163) & 511)])) + (0.00491468376f * fVec56[((IOTA - 164) & 511)])) + (0.0041074953f * fVec56[((IOTA - 165) & 511)])) + (0.00445195008f * fVec56[((IOTA - 166) & 511)])) + (0.00510683889f * fVec56[((IOTA - 167) & 511)])) + (0.0043651755f * fVec56[((IOTA - 168) & 511)])) + (0.00156400772f * fVec56[((IOTA - 169) & 511)])) + (0.00378909614f * fVec56[((IOTA - 177) & 511)])) + (0.00708695268f * fVec56[((IOTA - 178) & 511)])) + (0.00815546419f * fVec56[((IOTA - 179) & 511)])) + (0.00728939427f * fVec56[((IOTA - 180) & 511)])) + (0.00423038611f * fVec56[((IOTA - 181) & 511)])) + (0.0010642875f * fVec56[((IOTA - 218) & 511)])) + (0.0027467683f * fVec56[((IOTA - 321) & 511)])))))))) + (0.00530315423f * fVec56[((IOTA - 400) & 511)]))))) + (0.00326074101f * fVec56[((IOTA - 450) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00268724142f * fVec56[((IOTA - 451) & 511)])) + (0.00214363402f * fVec56[((IOTA - 452) & 511)])) + (0.00190352835f * fVec56[((IOTA - 453) & 511)])) + (0.00216775434f * fVec56[((IOTA - 454) & 511)])) + (0.00339653017f * fVec56[((IOTA - 455) & 511)])) + (0.00509587536f * fVec56[((IOTA - 456) & 511)])) + (0.00595949451f * fVec56[((IOTA - 457) & 511)])) + (0.0057052006f * fVec56[((IOTA - 458) & 511)])) + (0.00460618362f * fVec56[((IOTA - 459) & 511)])) + (0.00306223333f * fVec56[((IOTA - 460) & 511)])) + (0.00201580999f * fVec56[((IOTA - 461) & 511)])) + (0.0020860103f * fVec56[((IOTA - 462) & 511)])) + (0.0032539051f * fVec56[((IOTA - 463) & 511)])) + (0.00503989588f * fVec56[((IOTA - 464) & 511)])) + (0.00659206929f * fVec56[((IOTA - 465) & 511)])) + (0.00743005285f * fVec56[((IOTA - 466) & 511)])) + (0.00712042395f * fVec56[((IOTA - 467) & 511)])) + (0.00535223307f * fVec56[((IOTA - 468) & 511)])) + (0.00289174728f * fVec56[((IOTA - 469) & 511)])) + (0.000807058997f * fVec56[((IOTA - 470) & 511)])) + (0.000380441081f * fVec56[((IOTA - 473) & 511)])) + (0.00107212365f * fVec56[((IOTA - 474) & 511)])) + (0.00154714286f * fVec56[((IOTA - 475) & 511)])) + (0.00164604234f * fVec56[((IOTA - 476) & 511)])) + (0.00159057882f * fVec56[((IOTA - 477) & 511)])) + (0.0021154834f * fVec56[((IOTA - 478) & 511)])) + (0.00341065414f * fVec56[((IOTA - 479) & 511)])) + (0.00496069901f * fVec56[((IOTA - 480) & 511)])) + (0.00584834162f * fVec56[((IOTA - 481) & 511)])) + (0.00544932671f * fVec56[((IOTA - 482) & 511)])) + (0.00405451469f * fVec56[((IOTA - 483) & 511)])) + (0.00214766478f * fVec56[((IOTA - 484) & 511)])) + (0.00036512455f * fVec56[((IOTA - 485) & 511)])) + (0.000317657832f * fVec56[((IOTA - 487) & 511)])) + (0.00162662985f * fVec56[((IOTA - 488) & 511)])) + (0.00292912079f * fVec56[((IOTA - 489) & 511)])) + (0.00328840828f * fVec56[((IOTA - 490) & 511)])) + (0.00248531532f * fVec56[((IOTA - 491) & 511)])) + (0.0010478422f * fVec56[((IOTA - 492) & 511)])) + (0.000973095186f * fVec56[((IOTA - 500) & 511)]))) + (0.00126405293f * fVec56[((IOTA - 501) & 511)])) + (0.00179714803f * fVec56[((IOTA - 502) & 511)])) + (0.00293431245f * fVec56[((IOTA - 503) & 511)])) + (0.00459802523f * fVec56[((IOTA - 504) & 511)])) + (0.00651645195f * fVec56[((IOTA - 505) & 511)])) + (0.0082245674f * fVec56[((IOTA - 506) & 511)])) + (0.00898848195f * fVec56[((IOTA - 507) & 511)])) + (0.00865328219f * fVec56[((IOTA - 508) & 511)])) + (0.00754139898f * fVec56[((IOTA - 509) & 511)])) + (0.00604636595f * fVec56[((IOTA - 510) & 511)])) + (0.00490591256f * fVec56[((IOTA - 511) & 511)]))) : ((((((((((((((((0.000286517665f * fVec55[((IOTA - 419) & 511)]) + ((4.34443355e-05f * fVec55[((IOTA - 408) & 511)]) + ((0.00011087209f * fVec55[((IOTA - 407) & 511)]) + ((0.000520417467f * fVec55[((IOTA - 394) & 511)]) + ((0.00125684543f * fVec55[((IOTA - 393) & 511)]) + ((0.00132338842f * fVec55[((IOTA - 392) & 511)]) + ((0.000757527538f * fVec55[((IOTA - 391) & 511)]) + ((0.000119161326f * fVec55[((IOTA - 390) & 511)]) + ((0.000450532418f * fVec55[((IOTA - 387) & 511)]) + ((0.000992835965f * fVec55[((IOTA - 386) & 511)]) + ((0.000918364152f * fVec55[((IOTA - 385) & 511)]) + ((0.000137640163f * fVec55[((IOTA - 384) & 511)]) + ((0.000575460494f * fVec55[((IOTA - 368) & 511)]) + ((0.00250268215f * fVec55[((IOTA - 367) & 511)]) + ((0.00464247447f * fVec55[((IOTA - 365) & 511)]) + ((0.00445142994f * fVec55[((IOTA - 364) & 511)]) + ((0.00365458569f * fVec55[((IOTA - 363) & 511)]) + ((0.00271397457f * fVec55[((IOTA - 362) & 511)]) + ((0.00159100164f * fVec55[((IOTA - 361) & 511)]) + ((0.000529689714f * fVec55[((IOTA - 360) & 511)]) + ((7.97137618e-05f * fVec55[((IOTA - 359) & 511)]) + ((0.000348473899f * fVec55[((IOTA - 358) & 511)]) + ((0.000648064539f * fVec55[((IOTA - 357) & 511)]) + ((0.000191667117f * fVec55[((IOTA - 356) & 511)]) + ((0.000363971107f * fVec55[((IOTA - 353) & 511)]) + ((0.00199586153f * fVec55[((IOTA - 352) & 511)]) + ((0.00350823067f * fVec55[((IOTA - 351) & 511)]) + ((0.00386987533f * fVec55[((IOTA - 366) & 511)]) + ((0.00452796556f * fVec55[((IOTA - 350) & 511)]) + ((0.00469466671f * fVec55[((IOTA - 349) & 511)]) + ((0.00408418244f * fVec55[((IOTA - 348) & 511)]) + ((0.00345734879f * fVec55[((IOTA - 347) & 511)]) + ((0.00359564368f * fVec55[((IOTA - 346) & 511)]) + ((0.00474970974f * fVec55[((IOTA - 345) & 511)]) + ((0.00674924115f * fVec55[((IOTA - 344) & 511)]) + ((0.00887910649f * fVec55[((IOTA - 343) & 511)]) + ((0.00999087375f * fVec55[((IOTA - 342) & 511)]) + ((0.00917044003f * fVec55[((IOTA - 341) & 511)]) + ((0.00706092129f * fVec55[((IOTA - 340) & 511)]) + ((0.00517914258f * fVec55[((IOTA - 339) & 511)]) + ((0.00415711431f * fVec55[((IOTA - 338) & 511)]) + ((0.0037754178f * fVec55[((IOTA - 337) & 511)]) + ((0.00324818585f * fVec55[((IOTA - 336) & 511)]) + ((0.00195228588f * fVec55[((IOTA - 335) & 511)]) + ((0.000225446653f * fVec55[((IOTA - 334) & 511)]) + ((0.00045990292f * fVec55[((IOTA - 330) & 511)]) + ((0.0024215267f * fVec55[((IOTA - 329) & 511)]) + ((0.00323491637f * fVec55[((IOTA - 328) & 511)]) + ((0.00226619421f * fVec55[((IOTA - 327) & 511)]) + ((0.000758805312f * fVec55[((IOTA - 319) & 511)]) + ((0.00202459516f * fVec55[((IOTA - 318) & 511)]) + ((0.00717267813f * fVec55[((IOTA - 316) & 511)]) + ((0.00969256088f * fVec55[((IOTA - 315) & 511)]) + ((0.0115638562f * fVec55[((IOTA - 314) & 511)]) + ((0.0121665746f * fVec55[((IOTA - 313) & 511)]) + ((0.0114312936f * fVec55[((IOTA - 312) & 511)]) + ((0.0098104123f * fVec55[((IOTA - 311) & 511)]) + ((0.0080069378f * fVec55[((IOTA - 310) & 511)]) + ((0.00735474564f * fVec55[((IOTA - 309) & 511)]) + ((0.00853269547f * fVec55[((IOTA - 308) & 511)]) + ((0.0108414181f * fVec55[((IOTA - 307) & 511)]) + ((0.0133644138f * fVec55[((IOTA - 306) & 511)]) + ((0.0152299739f * fVec55[((IOTA - 305) & 511)]) + (((0.0158632956f * fVec55[((IOTA - 304) & 511)]) + ((0.0153493322f * fVec55[((IOTA - 303) & 511)]) + ((0.0137814619f * fVec55[((IOTA - 302) & 511)]) + ((0.0111127663f * fVec55[((IOTA - 301) & 511)]) + ((0.00782483816f * fVec55[((IOTA - 300) & 511)]) + ((0.00502374489f * fVec55[((IOTA - 299) & 511)]) + ((0.00364207011f * fVec55[((IOTA - 298) & 511)]) + ((0.00397943705f * fVec55[((IOTA - 297) & 511)]) + ((0.00546857622f * fVec55[((IOTA - 296) & 511)]) + ((0.00723614125f * fVec55[((IOTA - 295) & 511)]) + ((0.00903076865f * fVec55[((IOTA - 294) & 511)]) + ((0.0104906829f * fVec55[((IOTA - 293) & 511)]) + ((0.0111825522f * fVec55[((IOTA - 292) & 511)]) + ((0.011044912f * fVec55[((IOTA - 291) & 511)]) + ((0.00999064464f * fVec55[((IOTA - 290) & 511)]) + ((0.00833581947f * fVec55[((IOTA - 289) & 511)]) + ((0.00637793075f * fVec55[((IOTA - 288) & 511)]) + ((0.00405770913f * fVec55[((IOTA - 287) & 511)]) + ((0.00174299208f * fVec55[((IOTA - 286) & 511)]) + ((6.56908378e-05f * fVec55[((IOTA - 285) & 511)]) + ((0.000871643424f * fVec55[((IOTA - 283) & 511)]) + ((0.00246474193f * fVec55[((IOTA - 282) & 511)]) + ((0.00339401653f * fVec55[((IOTA - 281) & 511)]) + ((0.00351665076f * fVec55[((IOTA - 280) & 511)]) + ((0.00321964873f * fVec55[((IOTA - 279) & 511)]) + ((0.00351134315f * fVec55[((IOTA - 278) & 511)]) + ((0.00514958985f * fVec55[((IOTA - 277) & 511)]) + ((0.00776078505f * fVec55[((IOTA - 276) & 511)]) + ((0.0105801281f * fVec55[((IOTA - 275) & 511)]) + ((0.0124641676f * fVec55[((IOTA - 274) & 511)]) + ((0.012416332f * fVec55[((IOTA - 273) & 511)]) + ((0.0106981751f * fVec55[((IOTA - 272) & 511)]) + ((0.00850121025f * fVec55[((IOTA - 271) & 511)]) + ((0.00691187941f * fVec55[((IOTA - 270) & 511)]) + ((0.00675651431f * fVec55[((IOTA - 269) & 511)]) + ((0.00843316037f * fVec55[((IOTA - 268) & 511)]) + ((0.0113519076f * fVec55[((IOTA - 267) & 511)]) + ((0.0137658324f * fVec55[((IOTA - 266) & 511)]) + ((0.0140557913f * fVec55[((IOTA - 265) & 511)]) + ((0.0126743782f * fVec55[((IOTA - 264) & 511)]) + ((0.0111421216f * fVec55[((IOTA - 263) & 511)]) + ((0.0102237249f * fVec55[((IOTA - 262) & 511)]) + ((0.00994336605f * fVec55[((IOTA - 261) & 511)]) + ((0.00981467124f * fVec55[((IOTA - 260) & 511)]) + ((0.00975133851f * fVec55[((IOTA - 259) & 511)]) + ((0.00994756073f * fVec55[((IOTA - 258) & 511)]) + ((0.00982820243f * fVec55[((IOTA - 257) & 511)]) + ((0.00867374334f * fVec55[((IOTA - 256) & 511)]) + ((0.00649417611f * fVec55[((IOTA - 255) & 511)]) + ((0.00390611216f * fVec55[((IOTA - 254) & 511)]) + ((0.0020183702f * fVec55[((IOTA - 253) & 511)]) + ((0.00136637408f * fVec55[((IOTA - 252) & 511)]) + ((0.00174423726f * fVec55[((IOTA - 251) & 511)]) + ((0.00317889079f * fVec55[((IOTA - 250) & 511)]) + ((0.00511810416f * fVec55[((IOTA - 249) & 511)]) + ((0.00636692205f * fVec55[((IOTA - 248) & 511)]) + ((0.00616208417f * fVec55[((IOTA - 247) & 511)]) + ((0.00470570801f * fVec55[((IOTA - 246) & 511)]) + ((0.00291373441f * fVec55[((IOTA - 245) & 511)]) + ((0.00216334919f * fVec55[((IOTA - 244) & 511)]) + ((0.00328219449f * fVec55[((IOTA - 243) & 511)]) + ((0.0062582125f * fVec55[((IOTA - 242) & 511)]) + ((0.0102019701f * fVec55[((IOTA - 241) & 511)]) + ((0.0127591714f * fVec55[((IOTA - 240) & 511)]) + ((0.0125055797f * fVec55[((IOTA - 239) & 511)]) + ((0.0108808f * fVec55[((IOTA - 238) & 511)]) + ((0.00927751139f * fVec55[((IOTA - 237) & 511)]) + ((0.00836491399f * fVec55[((IOTA - 236) & 511)]) + ((0.00893745758f * fVec55[((IOTA - 235) & 511)]) + ((0.0112415925f * fVec55[((IOTA - 234) & 511)]) + ((0.0147542786f * fVec55[((IOTA - 233) & 511)]) + ((0.0178551599f * fVec55[((IOTA - 232) & 511)]) + ((0.0184634477f * fVec55[((IOTA - 231) & 511)]) + ((0.0154983401f * fVec55[((IOTA - 230) & 511)]) + ((0.00975186378f * fVec55[((IOTA - 229) & 511)]) + ((0.003817847f * fVec55[((IOTA - 228) & 511)]) + ((0.000264271162f * fVec55[((IOTA - 227) & 511)]) + ((0.0011907611f * fVec55[((IOTA - 225) & 511)]) + ((0.00304626347f * fVec55[((IOTA - 224) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00626460137f * fVec55[((IOTA - 44) & 511)]) + ((0.00650701951f * fVec55[((IOTA - 43) & 511)]) + ((0.00262210565f * fVec55[((IOTA - 29) & 511)]) + ((0.0227553844f * fVec55[((IOTA - 28) & 511)]) + ((0.0289255287f * fVec55[((IOTA - 27) & 511)]) + ((0.02466272f * fVec55[((IOTA - 26) & 511)]) + ((0.0150693664f * fVec55[((IOTA - 25) & 511)]) + ((0.00696374429f * fVec55[((IOTA - 24) & 511)]) + ((0.0019840668f * fVec55[((IOTA - 23) & 511)]) + ((0.00520810578f * fVec55[((IOTA - 22) & 511)]) + ((0.0098753497f * fVec55[((IOTA - 21) & 511)]) + ((0.00689772563f * fVec55[((IOTA - 20) & 511)]) + ((0.00533997919f * fVec55[((IOTA - 19) & 511)]) + ((0.0093579134f * fVec55[((IOTA - 18) & 511)]) + ((0.0191451609f * fVec55[((IOTA - 17) & 511)]) + ((0.0366726182f * fVec55[((IOTA - 16) & 511)]) + ((0.0420473292f * fVec55[((IOTA - 15) & 511)]) + ((0.0407234468f * fVec55[((IOTA - 14) & 511)]) + ((0.0325890593f * fVec55[((IOTA - 13) & 511)]) + ((0.0920437351f * fVec55[((IOTA - 6) & 511)]) + ((0.197927698f * fVec55[((IOTA - 5) & 511)]) + ((0.257799715f * fVec55[((IOTA - 4) & 511)]) + ((0.265496582f * fVec55[((IOTA - 3) & 511)]) + ((0.233000472f * fVec55[((IOTA - 2) & 511)]) + ((0.163784832f * fVec55[((IOTA - 1) & 511)]) + ((fSlow171 * fTemp0) + (0.014582729f * fVec55[((IOTA - 55) & 511)]))))))))))))))))))))))))))) + (0.026080206f * fVec55[((IOTA - 56) & 511)])) + (0.0230453108f * fVec55[((IOTA - 57) & 511)])) + (0.00512885023f * fVec55[((IOTA - 58) & 511)])) + (0.00192247098f * fVec55[((IOTA - 74) & 511)])) + (0.0043492401f * fVec55[((IOTA - 75) & 511)])) + (0.000739802606f * fVec55[((IOTA - 99) & 511)])) + (0.00748272007f * fVec55[((IOTA - 100) & 511)])) + (0.0111728543f * fVec55[((IOTA - 101) & 511)])) + (0.0107373931f * fVec55[((IOTA - 102) & 511)])) + (0.00661153533f * fVec55[((IOTA - 103) & 511)])) + (0.000991066918f * fVec55[((IOTA - 104) & 511)])) + (0.00148307811f * fVec55[((IOTA - 128) & 511)])) + (0.00441509485f * fVec55[((IOTA - 129) & 511)])) + (0.0051701325f * fVec55[((IOTA - 130) & 511)])) + (0.00551303662f * fVec55[((IOTA - 131) & 511)])) + (0.0049541546f * fVec55[((IOTA - 132) & 511)])) + (0.00500982022f * fVec55[((IOTA - 133) & 511)])) + (0.00758409081f * fVec55[((IOTA - 134) & 511)])) + (0.0112716369f * fVec55[((IOTA - 135) & 511)])) + (0.0140638836f * fVec55[((IOTA - 136) & 511)])) + (0.0134022553f * fVec55[((IOTA - 137) & 511)])) + (0.00789914653f * fVec55[((IOTA - 138) & 511)])) + (0.00235763751f * fVec55[((IOTA - 146) & 511)])) + (0.00367175369f * fVec55[((IOTA - 147) & 511)])) + (0.00336777279f * fVec55[((IOTA - 148) & 511)])) + (0.0022394266f * fVec55[((IOTA - 149) & 511)])) + (0.00152108399f * fVec55[((IOTA - 150) & 511)])) + (0.0013640807f * fVec55[((IOTA - 151) & 511)])) + (0.00166114839f * fVec55[((IOTA - 152) & 511)])) + (0.00261925533f * fVec55[((IOTA - 153) & 511)])) + (0.00410033483f * fVec55[((IOTA - 154) & 511)])) + (0.00598037709f * fVec55[((IOTA - 155) & 511)])) + (0.0071182251f * fVec55[((IOTA - 156) & 511)])) + (0.00600475306f * fVec55[((IOTA - 157) & 511)])) + (0.00259740185f * fVec55[((IOTA - 158) & 511)])) + (0.0021516527f * fVec55[((IOTA - 168) & 511)])) + (0.00637979852f * fVec55[((IOTA - 169) & 511)])) + (0.0101650124f * fVec55[((IOTA - 170) & 511)])) + (0.0124345813f * fVec55[((IOTA - 171) & 511)])) + (0.0121718831f * fVec55[((IOTA - 172) & 511)])) + (0.00940899178f * fVec55[((IOTA - 173) & 511)])) + (0.00547332736f * fVec55[((IOTA - 174) & 511)])) + (0.00201440603f * fVec55[((IOTA - 175) & 511)])) + (0.00226580119f * fVec55[((IOTA - 183) & 511)])) + (0.00874045026f * fVec55[((IOTA - 184) & 511)])) + (0.0131793972f * fVec55[((IOTA - 185) & 511)])) + (0.0146071045f * fVec55[((IOTA - 186) & 511)])) + (0.0137619013f * fVec55[((IOTA - 187) & 511)])) + (0.0119020082f * fVec55[((IOTA - 188) & 511)])) + (0.0104255816f * fVec55[((IOTA - 189) & 511)])) + (0.0101408008f * fVec55[((IOTA - 190) & 511)])) + (0.0103524206f * fVec55[((IOTA - 191) & 511)])) + (0.00998418964f * fVec55[((IOTA - 192) & 511)])) + (0.00862607174f * fVec55[((IOTA - 193) & 511)])) + (0.00720878365f * fVec55[((IOTA - 194) & 511)])) + (0.00662110234f * fVec55[((IOTA - 195) & 511)])) + (0.00639116718f * fVec55[((IOTA - 196) & 511)])) + (0.0064314995f * fVec55[((IOTA - 197) & 511)])) + (0.00678062858f * fVec55[((IOTA - 198) & 511)])) + (0.00623255875f * fVec55[((IOTA - 199) & 511)])) + (0.00480262283f * fVec55[((IOTA - 200) & 511)])) + (0.0034414581f * fVec55[((IOTA - 201) & 511)])) + (0.00242555654f * fVec55[((IOTA - 202) & 511)])) + (0.00248983875f * fVec55[((IOTA - 203) & 511)])) + (0.00361579331f * fVec55[((IOTA - 204) & 511)])) + (0.00495792273f * fVec55[((IOTA - 205) & 511)])) + (0.00592045253f * fVec55[((IOTA - 206) & 511)])) + (0.00623517949f * fVec55[((IOTA - 207) & 511)])) + (0.00607254123f * fVec55[((IOTA - 208) & 511)])) + (0.00599823333f * fVec55[((IOTA - 209) & 511)])) + (0.00583628239f * fVec55[((IOTA - 210) & 511)])) + (0.00535315042f * fVec55[((IOTA - 211) & 511)])) + (0.00537628122f * fVec55[((IOTA - 212) & 511)])) + (0.00661681034f * fVec55[((IOTA - 213) & 511)])) + (0.00856926013f * fVec55[((IOTA - 214) & 511)])) + (0.0105270185f * fVec55[((IOTA - 215) & 511)])) + (0.0111182053f * fVec55[((IOTA - 216) & 511)])) + (0.00941996835f * fVec55[((IOTA - 217) & 511)])) + (0.00648827851f * fVec55[((IOTA - 218) & 511)])) + (0.00400315784f * fVec55[((IOTA - 219) & 511)])) + (0.00321332505f * fVec55[((IOTA - 220) & 511)])) + (0.00403369358f * fVec55[((IOTA - 221) & 511)])) + (0.00469699316f * fVec55[((IOTA - 222) & 511)])) + (0.0042945575f * fVec55[((IOTA - 223) & 511)])) + (0.00434933836f * fVec55[((IOTA - 317) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00135326851f * fVec55[((IOTA - 420) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00198514806f * fVec55[((IOTA - 421) & 511)])) + (0.0016323491f * fVec55[((IOTA - 422) & 511)])) + (4.16426919e-05f * fVec55[((IOTA - 423) & 511)])) + (0.000293562189f * fVec55[((IOTA - 428) & 511)])) + (0.000709332526f * fVec55[((IOTA - 429) & 511)])) + (0.000577950384f * fVec55[((IOTA - 430) & 511)])) + (0.000126729719f * fVec55[((IOTA - 471) & 511)])) + (0.000681614503f * fVec55[((IOTA - 493) & 511)])) + (0.000595871825f * fVec55[((IOTA - 494) & 511)])) + (6.61499798e-05f * fVec55[((IOTA - 495) & 511)])) + (0.000605209731f * fVec55[((IOTA - 499) & 511)])) + (0.0012428551f * fVec55[((IOTA - 500) & 511)])) + (0.00116530387f * fVec55[((IOTA - 501) & 511)])) - ((((((((((((((((((((((((((((((((((((0.00308223767f * fVec55[((IOTA - 469) & 511)]) + ((0.00584470294f * fVec55[((IOTA - 468) & 511)]) + ((0.00793571025f * fVec55[((IOTA - 467) & 511)]) + ((0.0085617248f * fVec55[((IOTA - 466) & 511)]) + ((0.00769250561f * fVec55[((IOTA - 465) & 511)]) + ((0.00596494554f * fVec55[((IOTA - 464) & 511)]) + ((0.00452193711f * fVec55[((IOTA - 463) & 511)]) + ((0.00446414202f * fVec55[((IOTA - 462) & 511)]) + ((0.00572462426f * fVec55[((IOTA - 461) & 511)]) + ((0.00701347971f * fVec55[((IOTA - 460) & 511)]) + ((0.00699369051f * fVec55[((IOTA - 459) & 511)]) + ((0.00553685566f * fVec55[((IOTA - 458) & 511)]) + ((0.00370939914f * fVec55[((IOTA - 457) & 511)]) + ((0.00260847574f * fVec55[((IOTA - 456) & 511)]) + ((0.00281662308f * fVec55[((IOTA - 455) & 511)]) + ((0.00423040614f * fVec55[((IOTA - 454) & 511)]) + ((0.00622089487f * fVec55[((IOTA - 453) & 511)]) + ((0.00785845332f * fVec55[((IOTA - 452) & 511)]) + ((0.00842195563f * fVec55[((IOTA - 451) & 511)]) + ((0.00785422698f * fVec55[((IOTA - 450) & 511)]) + ((0.00646645809f * fVec55[((IOTA - 449) & 511)]) + ((0.00496968487f * fVec55[((IOTA - 448) & 511)]) + ((0.00430169981f * fVec55[((IOTA - 447) & 511)]) + ((0.00523110572f * fVec55[((IOTA - 446) & 511)]) + ((0.0075130919f * fVec55[((IOTA - 445) & 511)]) + ((0.00981879979f * fVec55[((IOTA - 444) & 511)]) + ((0.0112795327f * fVec55[((IOTA - 443) & 511)]) + ((0.0115408553f * fVec55[((IOTA - 442) & 511)]) + ((0.0105930697f * fVec55[((IOTA - 441) & 511)]) + ((0.00920104142f * fVec55[((IOTA - 440) & 511)]) + ((0.00772766117f * fVec55[((IOTA - 439) & 511)]) + ((0.00630752183f * fVec55[((IOTA - 438) & 511)]) + ((0.00558288861f * fVec55[((IOTA - 437) & 511)]) + ((0.00555471191f * fVec55[((IOTA - 436) & 511)]) + ((0.0054791919f * fVec55[((IOTA - 435) & 511)]) + ((0.00486503774f * fVec55[((IOTA - 434) & 511)]) + ((0.00330067286f * fVec55[((IOTA - 433) & 511)]) + ((0.00133367628f * fVec55[((IOTA - 432) & 511)]) + ((6.03832304e-05f * fVec55[((IOTA - 431) & 511)]) + ((0.000400207471f * fVec55[((IOTA - 427) & 511)]) + ((0.00134966476f * fVec55[((IOTA - 426) & 511)]) + ((0.00213586073f * fVec55[((IOTA - 425) & 511)]) + ((0.00169571396f * fVec55[((IOTA - 424) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0265051499f * fVec55[((IOTA - 124) & 511)]) + ((0.0297148712f * fVec55[((IOTA - 123) & 511)]) + ((0.0292260051f * fVec55[((IOTA - 122) & 511)]) + ((0.0264311023f * fVec55[((IOTA - 121) & 511)]) + ((0.0223082602f * fVec55[((IOTA - 120) & 511)]) + ((0.0178578459f * fVec55[((IOTA - 119) & 511)]) + ((0.0135814063f * fVec55[((IOTA - 118) & 511)]) + ((0.00878491066f * fVec55[((IOTA - 117) & 511)]) + ((0.00511512253f * fVec55[((IOTA - 116) & 511)]) + ((0.0034747133f * fVec55[((IOTA - 115) & 511)]) + ((0.00419626664f * fVec55[((IOTA - 114) & 511)]) + ((0.00737155322f * fVec55[((IOTA - 113) & 511)]) + ((0.0113286125f * fVec55[((IOTA - 112) & 511)]) + ((0.0161325131f * fVec55[((IOTA - 111) & 511)]) + ((0.0209309105f * fVec55[((IOTA - 110) & 511)]) + ((0.0235275906f * fVec55[((IOTA - 109) & 511)]) + ((0.0231369827f * fVec55[((IOTA - 108) & 511)]) + ((0.0182005856f * fVec55[((IOTA - 107) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((0.0218546148f * fVec55[((IOTA - 53) & 511)]) + ((0.0426571891f * fVec55[((IOTA - 52) & 511)]) + ((0.0601570271f * fVec55[((IOTA - 51) & 511)]) + ((0.0685204044f * fVec55[((IOTA - 50) & 511)]) + ((0.0648173913f * fVec55[((IOTA - 49) & 511)]) + ((0.0551102497f * fVec55[((IOTA - 48) & 511)]) + ((0.039790798f * fVec55[((IOTA - 47) & 511)]) + ((0.0182067454f * fVec55[((IOTA - 46) & 511)]) + ((0.00142931286f * fVec55[((IOTA - 45) & 511)]) + ((0.00370582798f * fVec55[((IOTA - 42) & 511)]) + ((0.0152940266f * fVec55[((IOTA - 41) & 511)]) + ((0.0204971842f * fVec55[((IOTA - 40) & 511)]) + ((0.0239201002f * fVec55[((IOTA - 39) & 511)]) + ((0.0233347453f * fVec55[((IOTA - 38) & 511)]) + ((0.01934053f * fVec55[((IOTA - 37) & 511)]) + ((0.0247222185f * fVec55[((IOTA - 36) & 511)]) + ((0.0380774885f * fVec55[((IOTA - 35) & 511)]) + ((0.0581497625f * fVec55[((IOTA - 34) & 511)]) + ((0.073305428f * fVec55[((IOTA - 33) & 511)]) + ((0.0691016614f * fVec55[((IOTA - 32) & 511)]) + ((0.0522387139f * fVec55[((IOTA - 31) & 511)]) + ((0.0272925906f * fVec55[((IOTA - 30) & 511)]) + ((0.000874133315f * fVec55[((IOTA - 12) & 511)]) + ((0.0475528948f * fVec55[((IOTA - 11) & 511)]) + ((0.0889145136f * fVec55[((IOTA - 10) & 511)]) + ((0.112593994f * fVec55[((IOTA - 9) & 511)]) + ((0.101977207f * fVec55[((IOTA - 8) & 511)]) + ((0.0303393118f * fVec55[((IOTA - 7) & 511)]) + (0.0021557156f * fVec55[((IOTA - 54) & 511)]))))))))))))))))))))))))))))) + (0.0175357144f * fVec55[((IOTA - 59) & 511)])) + (0.0415695347f * fVec55[((IOTA - 60) & 511)])) + (0.0619714111f * fVec55[((IOTA - 61) & 511)])) + (0.0708987415f * fVec55[((IOTA - 62) & 511)])) + (0.0636238456f * fVec55[((IOTA - 63) & 511)])) + (0.0452028885f * fVec55[((IOTA - 64) & 511)])) + (0.0247589126f * fVec55[((IOTA - 65) & 511)])) + (0.00960944034f * fVec55[((IOTA - 66) & 511)])) + (0.0093968045f * fVec55[((IOTA - 67) & 511)])) + (0.0219417997f * fVec55[((IOTA - 68) & 511)])) + (0.0346822627f * fVec55[((IOTA - 69) & 511)])) + (0.0410275906f * fVec55[((IOTA - 70) & 511)])) + (0.0392759517f * fVec55[((IOTA - 71) & 511)])) + (0.0272743404f * fVec55[((IOTA - 72) & 511)])) + (0.0104410788f * fVec55[((IOTA - 73) & 511)])) + (0.0036163833f * fVec55[((IOTA - 76) & 511)])) + (0.0164887197f * fVec55[((IOTA - 77) & 511)])) + (0.0222114772f * fVec55[((IOTA - 78) & 511)])) + (0.0185322855f * fVec55[((IOTA - 79) & 511)])) + (0.0113599021f * fVec55[((IOTA - 80) & 511)])) + (0.00449644681f * fVec55[((IOTA - 81) & 511)])) + (0.000966166612f * fVec55[((IOTA - 82) & 511)])) + (0.00193007244f * fVec55[((IOTA - 83) & 511)])) + (0.0060267048f * fVec55[((IOTA - 84) & 511)])) + (0.0116234198f * fVec55[((IOTA - 85) & 511)])) + (0.0154974237f * fVec55[((IOTA - 86) & 511)])) + (0.0171870757f * fVec55[((IOTA - 87) & 511)])) + (0.0174030866f * fVec55[((IOTA - 88) & 511)])) + (0.0171225648f * fVec55[((IOTA - 89) & 511)])) + (0.0171577856f * fVec55[((IOTA - 90) & 511)])) + (0.0192749705f * fVec55[((IOTA - 91) & 511)])) + (0.0243755784f * fVec55[((IOTA - 92) & 511)])) + (0.0295733958f * fVec55[((IOTA - 93) & 511)])) + (0.0319945961f * fVec55[((IOTA - 94) & 511)])) + (0.0301342458f * fVec55[((IOTA - 95) & 511)])) + (0.0249854736f * fVec55[((IOTA - 96) & 511)])) + (0.0178041458f * fVec55[((IOTA - 97) & 511)])) + (0.00838624313f * fVec55[((IOTA - 98) & 511)])) + (0.00420822529f * fVec55[((IOTA - 105) & 511)])) + (0.0105346516f * fVec55[((IOTA - 106) & 511)])) + (0.0197303519f * fVec55[((IOTA - 125) & 511)])))))))))))))))))))) + (0.0113921091f * fVec55[((IOTA - 126) & 511)])) + (0.00406150986f * fVec55[((IOTA - 127) & 511)])) + (0.000273674726f * fVec55[((IOTA - 139) & 511)])) + (0.00820751674f * fVec55[((IOTA - 140) & 511)])) + (0.0133875441f * fVec55[((IOTA - 141) & 511)])) + (0.014471136f * fVec55[((IOTA - 142) & 511)])) + (0.0113219945f * fVec55[((IOTA - 143) & 511)])) + (0.00569340028f * fVec55[((IOTA - 144) & 511)])) + (0.000686103012f * fVec55[((IOTA - 145) & 511)])) + (0.00158661138f * fVec55[((IOTA - 159) & 511)])) + (0.00499094836f * fVec55[((IOTA - 160) & 511)])) + (0.00692626275f * fVec55[((IOTA - 161) & 511)])) + (0.00763290888f * fVec55[((IOTA - 162) & 511)])) + (0.00774342055f * fVec55[((IOTA - 163) & 511)])) + (0.0071533476f * fVec55[((IOTA - 164) & 511)])) + (0.00557784317f * fVec55[((IOTA - 165) & 511)])) + (0.00359112257f * fVec55[((IOTA - 166) & 511)])) + (0.00129494956f * fVec55[((IOTA - 167) & 511)])) + (0.000249003526f * fVec55[((IOTA - 176) & 511)])) + (0.00177549338f * fVec55[((IOTA - 177) & 511)])) + (0.00278045237f * fVec55[((IOTA - 178) & 511)])) + (0.00386722153f * fVec55[((IOTA - 179) & 511)])) + (0.00494442414f * fVec55[((IOTA - 180) & 511)])) + (0.0050239414f * fVec55[((IOTA - 181) & 511)])) + (0.00294577749f * fVec55[((IOTA - 182) & 511)])) + (0.000260601752f * fVec55[((IOTA - 226) & 511)])) + (0.000290089287f * fVec55[((IOTA - 284) & 511)])) + (7.80755654e-05f * fVec55[((IOTA - 320) & 511)])) + (0.00106439181f * fVec55[((IOTA - 321) & 511)])) + (0.00239862502f * fVec55[((IOTA - 322) & 511)])) + (0.00387036707f * fVec55[((IOTA - 323) & 511)])) + (0.00417359406f * fVec55[((IOTA - 324) & 511)])) + (0.00262321951f * fVec55[((IOTA - 325) & 511)])) + (7.33905472e-05f * fVec55[((IOTA - 326) & 511)])) + (0.00156026939f * fVec55[((IOTA - 331) & 511)])) + (0.00239567598f * fVec55[((IOTA - 332) & 511)])) + (0.00152573641f * fVec55[((IOTA - 333) & 511)])) + (0.000810309779f * fVec55[((IOTA - 354) & 511)])) + (0.000724403653f * fVec55[((IOTA - 355) & 511)])) + (0.00180229405f * fVec55[((IOTA - 369) & 511)])) + (0.00422873534f * fVec55[((IOTA - 370) & 511)])) + (0.00661045406f * fVec55[((IOTA - 371) & 511)])) + (0.00840439368f * fVec55[((IOTA - 372) & 511)])) + (0.00883205794f * fVec55[((IOTA - 373) & 511)])) + (0.00783696026f * fVec55[((IOTA - 374) & 511)])) + (0.00568026211f * fVec55[((IOTA - 375) & 511)])) + (0.00326378131f * fVec55[((IOTA - 376) & 511)])) + (0.00208107987f * fVec55[((IOTA - 377) & 511)])) + (0.00247312943f * fVec55[((IOTA - 378) & 511)])) + (0.00326686073f * fVec55[((IOTA - 379) & 511)])) + (0.00360321207f * fVec55[((IOTA - 380) & 511)])) + (0.00325198611f * fVec55[((IOTA - 381) & 511)])) + (0.00231337408f * fVec55[((IOTA - 382) & 511)])) + (0.00108041335f * fVec55[((IOTA - 383) & 511)])) + (0.000160869211f * fVec55[((IOTA - 388) & 511)])) + (0.000261224341f * fVec55[((IOTA - 389) & 511)])) + (0.000660055783f * fVec55[((IOTA - 395) & 511)])) + (0.00227438519f * fVec55[((IOTA - 396) & 511)])) + (0.00422709715f * fVec55[((IOTA - 397) & 511)])) + (0.00639398489f * fVec55[((IOTA - 398) & 511)])) + (0.00835691951f * fVec55[((IOTA - 399) & 511)])) + (0.00910363533f * fVec55[((IOTA - 400) & 511)])) + (0.00852139294f * fVec55[((IOTA - 401) & 511)])) + (0.00735618686f * fVec55[((IOTA - 402) & 511)])) + (0.00587631995f * fVec55[((IOTA - 403) & 511)])) + (0.00408234773f * fVec55[((IOTA - 404) & 511)])) + (0.00206682784f * fVec55[((IOTA - 405) & 511)])) + (0.000451122411f * fVec55[((IOTA - 406) & 511)])) + (0.000100748148f * fVec55[((IOTA - 409) & 511)])) + (0.00025594933f * fVec55[((IOTA - 410) & 511)])) + (0.000571397599f * fVec55[((IOTA - 411) & 511)])) + (0.00127463602f * fVec55[((IOTA - 412) & 511)])) + (0.00239312043f * fVec55[((IOTA - 413) & 511)])) + (0.00341773732f * fVec55[((IOTA - 414) & 511)])) + (0.00407812092f * fVec55[((IOTA - 415) & 511)])) + (0.00409676367f * fVec55[((IOTA - 416) & 511)])) + (0.00298676454f * fVec55[((IOTA - 417) & 511)])) + (0.00121657876f * fVec55[((IOTA - 418) & 511)])) + (0.000836979598f * fVec55[((IOTA - 470) & 511)]))))))))))))))))))))))))))))))))))))))))))))) + (0.000289499294f * fVec55[((IOTA - 472) & 511)])) + (0.00147976913f * fVec55[((IOTA - 473) & 511)])) + (0.00244983425f * fVec55[((IOTA - 474) & 511)])) + (0.00291475048f * fVec55[((IOTA - 475) & 511)])) + (0.00327754207f * fVec55[((IOTA - 476) & 511)])) + (0.00384572847f * fVec55[((IOTA - 477) & 511)])) + (0.00461478904f * fVec55[((IOTA - 478) & 511)])) + (0.00539715169f * fVec55[((IOTA - 479) & 511)])) + (0.0059823757f * fVec55[((IOTA - 480) & 511)])) + (0.00603656657f * fVec55[((IOTA - 481) & 511)])) + (0.00545884576f * fVec55[((IOTA - 482) & 511)])) + (0.00439311052f * fVec55[((IOTA - 483) & 511)])) + (0.0030519315f * fVec55[((IOTA - 484) & 511)])) + (0.00193167757f * fVec55[((IOTA - 485) & 511)])) + (0.00136322901f * fVec55[((IOTA - 486) & 511)])) + (0.00118987635f * fVec55[((IOTA - 487) & 511)])) + (0.00146751525f * fVec55[((IOTA - 488) & 511)])) + (0.00210119691f * fVec55[((IOTA - 489) & 511)])) + (0.00216737902f * fVec55[((IOTA - 490) & 511)])) + (0.00139763067f * fVec55[((IOTA - 491) & 511)])) + (0.000185868237f * fVec55[((IOTA - 492) & 511)])) + (0.000257915352f * fVec55[((IOTA - 496) & 511)])) + (0.000267907977f * fVec55[((IOTA - 497) & 511)])) + (3.57115641e-06f * fVec55[((IOTA - 498) & 511)])) + (0.000255752821f * fVec55[((IOTA - 502) & 511)])) + (0.00307539012f * fVec55[((IOTA - 503) & 511)])) + (0.00643975567f * fVec55[((IOTA - 504) & 511)])) + (0.0094603654f * fVec55[((IOTA - 505) & 511)])) + (0.0115792211f * fVec55[((IOTA - 506) & 511)])) + (0.0120352581f * fVec55[((IOTA - 507) & 511)])) + (0.0107818209f * fVec55[((IOTA - 508) & 511)])) + (0.00865968782f * fVec55[((IOTA - 509) & 511)])) + (0.00662424788f * fVec55[((IOTA - 510) & 511)])) + (0.00568904309f * fVec55[((IOTA - 511) & 511)]))))) : (iSlow157 ? (iSlow163 ? ((((((((((((((0.000546779018f * (fVec54[((IOTA - 414) & 511)] + fVec54[((IOTA - 425) & 511)])) + ((0.00040223496f * fVec54[((IOTA - 424) & 511)]) + ((0.000155799557f * fVec54[((IOTA - 423) & 511)]) + ((2.11615115e-05f * fVec54[((IOTA - 416) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00113259023f * fVec54[((IOTA - 287) & 511)]) + ((0.00178412395f * fVec54[((IOTA - 286) & 511)]) + ((0.00204573153f * fVec54[((IOTA - 285) & 511)]) + ((0.00205382751f * fVec54[((IOTA - 284) & 511)]) + ((0.00215914194f * fVec54[((IOTA - 283) & 511)]) + ((0.00219445489f * fVec54[((IOTA - 282) & 511)]) + ((0.00170138618f * fVec54[((IOTA - 281) & 511)]) + ((0.000438305084f * fVec54[((IOTA - 280) & 511)]) + ((0.00260972278f * fVec54[((IOTA - 275) & 511)]) + ((0.00491248677f * fVec54[((IOTA - 274) & 511)]) + ((0.00566074532f * fVec54[((IOTA - 273) & 511)]) + ((0.00476669241f * fVec54[((IOTA - 272) & 511)]) + ((0.00283170538f * fVec54[((IOTA - 271) & 511)]) + ((0.00102395192f * fVec54[((IOTA - 270) & 511)]) + ((0.000499913935f * fVec54[((IOTA - 269) & 511)]) + ((0.00130606256f * fVec54[((IOTA - 268) & 511)]) + ((0.00293833623f * fVec54[((IOTA - 267) & 511)]) + ((0.00465459842f * fVec54[((IOTA - 266) & 511)]) + ((0.00546308374f * fVec54[((IOTA - 265) & 511)]) + ((0.00508885551f * fVec54[((IOTA - 264) & 511)]) + ((0.00421876134f * fVec54[((IOTA - 263) & 511)]) + ((0.00382511597f * fVec54[((IOTA - 262) & 511)]) + ((0.00456244824f * fVec54[((IOTA - 261) & 511)]) + ((0.00619001593f * fVec54[((IOTA - 260) & 511)]) + ((0.007770258f * fVec54[((IOTA - 259) & 511)]) + ((0.00854935311f * fVec54[((IOTA - 258) & 511)]) + ((0.00815050863f * fVec54[((IOTA - 257) & 511)]) + ((0.00686195446f * fVec54[((IOTA - 256) & 511)]) + ((0.00523336651f * fVec54[((IOTA - 255) & 511)]) + ((0.00349304685f * fVec54[((IOTA - 254) & 511)]) + ((0.00211681845f * fVec54[((IOTA - 253) & 511)]) + ((0.00145685952f * fVec54[((IOTA - 252) & 511)]) + ((0.00137181813f * fVec54[((IOTA - 251) & 511)]) + ((0.00181561941f * fVec54[((IOTA - 250) & 511)]) + ((0.00250444142f * fVec54[((IOTA - 249) & 511)]) + ((0.00304996967f * fVec54[((IOTA - 248) & 511)]) + ((0.00334840408f * fVec54[((IOTA - 247) & 511)]) + ((0.00333872857f * fVec54[((IOTA - 246) & 511)]) + ((0.00297220144f * fVec54[((IOTA - 245) & 511)]) + ((0.00239073485f * fVec54[((IOTA - 244) & 511)]) + ((0.0019274503f * fVec54[((IOTA - 243) & 511)]) + ((0.00200732471f * fVec54[((IOTA - 242) & 511)]) + ((0.0026343069f * fVec54[((IOTA - 241) & 511)]) + ((0.00302492455f * fVec54[((IOTA - 240) & 511)]) + ((0.00263874978f * fVec54[((IOTA - 239) & 511)]) + ((0.00161242858f * fVec54[((IOTA - 238) & 511)]) + ((0.000361129642f * fVec54[((IOTA - 237) & 511)]) + ((0.000821616501f * fVec54[((IOTA - 235) & 511)]) + ((0.00292421784f * fVec54[((IOTA - 234) & 511)]) + ((0.00529293483f * fVec54[((IOTA - 233) & 511)]) + ((0.00666669523f * fVec54[((IOTA - 232) & 511)]) + ((0.00625929283f * fVec54[((IOTA - 231) & 511)]) + ((0.00264678011f * fVec54[((IOTA - 229) & 511)]) + ((0.00110224634f * fVec54[((IOTA - 228) & 511)]) + ((0.00085001858f * fVec54[((IOTA - 227) & 511)]) + (((0.00186768454f * fVec54[((IOTA - 226) & 511)]) + ((0.00363752479f * fVec54[((IOTA - 225) & 511)]) + ((0.00522991084f * fVec54[((IOTA - 224) & 511)]) + ((0.00592840835f * fVec54[((IOTA - 223) & 511)]) + ((0.00612472091f * fVec54[((IOTA - 222) & 511)]) + ((0.00628134329f * fVec54[((IOTA - 221) & 511)]) + ((0.00621460006f * fVec54[((IOTA - 220) & 511)]) + ((0.00596549874f * fVec54[((IOTA - 219) & 511)]) + ((0.0051906486f * fVec54[((IOTA - 218) & 511)]) + ((0.00337427203f * fVec54[((IOTA - 217) & 511)]) + ((0.00104573881f * fVec54[((IOTA - 216) & 511)]) + ((0.00019519357f * fVec54[((IOTA - 211) & 511)]) + ((0.00253119785f * fVec54[((IOTA - 210) & 511)]) + ((0.00360362697f * fVec54[((IOTA - 209) & 511)]) + ((0.00321669551f * fVec54[((IOTA - 208) & 511)]) + ((0.00234044716f * fVec54[((IOTA - 207) & 511)]) + ((0.00172340358f * fVec54[((IOTA - 206) & 511)]) + ((0.00178030645f * fVec54[((IOTA - 205) & 511)]) + ((0.00242940476f * fVec54[((IOTA - 204) & 511)]) + ((0.0031802631f * fVec54[((IOTA - 203) & 511)]) + ((0.00385042466f * fVec54[((IOTA - 202) & 511)]) + ((0.004031335f * fVec54[((IOTA - 201) & 511)]) + ((0.00347965211f * fVec54[((IOTA - 200) & 511)]) + ((0.00256006047f * fVec54[((IOTA - 199) & 511)]) + ((0.00165366568f * fVec54[((IOTA - 198) & 511)]) + ((0.00114766322f * fVec54[((IOTA - 197) & 511)]) + ((0.00163885579f * fVec54[((IOTA - 196) & 511)]) + ((0.00270736869f * fVec54[((IOTA - 195) & 511)]) + ((0.00347682182f * fVec54[((IOTA - 194) & 511)]) + ((0.00366928382f * fVec54[((IOTA - 193) & 511)]) + ((0.00290598534f * fVec54[((IOTA - 192) & 511)]) + ((0.00144790765f * fVec54[((IOTA - 191) & 511)]) + ((0.000181634445f * fVec54[((IOTA - 190) & 511)]) + ((0.000660090707f * fVec54[((IOTA - 188) & 511)]) + ((0.00333273876f * fVec54[((IOTA - 187) & 511)]) + ((0.00700376695f * fVec54[((IOTA - 186) & 511)]) + ((0.00997761451f * fVec54[((IOTA - 185) & 511)]) + ((0.010763457f * fVec54[((IOTA - 184) & 511)]) + ((0.0086124111f * fVec54[((IOTA - 183) & 511)]) + ((0.00406408124f * fVec54[((IOTA - 182) & 511)]) + ((0.000655647833f * fVec54[((IOTA - 177) & 511)]) + ((0.0030120234f * fVec54[((IOTA - 176) & 511)]) + ((0.00362360384f * fVec54[((IOTA - 175) & 511)]) + ((0.00275117299f * fVec54[((IOTA - 174) & 511)]) + ((0.0014864793f * fVec54[((IOTA - 173) & 511)]) + ((0.000964284409f * fVec54[((IOTA - 172) & 511)]) + ((0.00190911908f * fVec54[((IOTA - 171) & 511)]) + ((0.00318388361f * fVec54[((IOTA - 170) & 511)]) + ((0.00315054459f * fVec54[((IOTA - 169) & 511)]) + ((0.0013330495f * fVec54[((IOTA - 168) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.046995908f * fVec54[((IOTA - 25) & 511)]) + ((0.0315921344f * fVec54[((IOTA - 24) & 511)]) + ((0.00355561031f * fVec54[((IOTA - 23) & 511)]) + ((0.00664306525f * fVec54[((IOTA - 19) & 511)]) + ((0.0342835411f * fVec54[((IOTA - 18) & 511)]) + ((0.0394124836f * fVec54[((IOTA - 17) & 511)]) + ((0.0165069066f * fVec54[((IOTA - 16) & 511)]) + ((0.0272137243f * fVec54[((IOTA - 13) & 511)]) + ((0.0762913004f * fVec54[((IOTA - 12) & 511)]) + ((0.079324089f * fVec54[((IOTA - 11) & 511)]) + ((0.018812567f * fVec54[((IOTA - 10) & 511)]) + ((0.153407469f * fVec54[((IOTA - 4) & 511)]) + ((0.248121113f * fVec54[((IOTA - 3) & 511)]) + ((0.266688704f * fVec54[((IOTA - 2) & 511)]) + ((0.201959729f * fVec54[((IOTA - 1) & 511)]) + ((fSlow167 * fTemp0) + ((0.0394820906f * fVec54[((IOTA - 26) & 511)]) + (0.018379692f * fVec54[((IOTA - 27) & 511)])))))))))))))))))) + (0.000906592235f * fVec54[((IOTA - 34) & 511)])) + (0.020375859f * fVec54[((IOTA - 35) & 511)])) + (0.024001997f * fVec54[((IOTA - 36) & 511)])) + (0.0185161717f * fVec54[((IOTA - 37) & 511)])) + (0.00754745211f * fVec54[((IOTA - 38) & 511)])) + (0.0158762373f * fVec54[((IOTA - 47) & 511)])) + (0.029051492f * fVec54[((IOTA - 48) & 511)])) + (0.0320403799f * fVec54[((IOTA - 49) & 511)])) + (0.0202611983f * fVec54[((IOTA - 50) & 511)])) + (0.000107124448f * fVec54[((IOTA - 51) & 511)])) + (0.0097782407f * fVec54[((IOTA - 59) & 511)])) + (0.0231244992f * fVec54[((IOTA - 60) & 511)])) + (0.0264451597f * fVec54[((IOTA - 61) & 511)])) + (0.0177515913f * fVec54[((IOTA - 62) & 511)])) + (0.00471854396f * fVec54[((IOTA - 63) & 511)])) + (0.0110687688f * fVec54[((IOTA - 73) & 511)])) + (0.0178449582f * fVec54[((IOTA - 74) & 511)])) + (0.0135844331f * fVec54[((IOTA - 75) & 511)])) + (0.00330808852f * fVec54[((IOTA - 76) & 511)])) + (0.00237447675f * fVec54[((IOTA - 80) & 511)])) + (0.00486864988f * fVec54[((IOTA - 81) & 511)])) + (0.00329982815f * fVec54[((IOTA - 82) & 511)])) + (0.00108704157f * fVec54[((IOTA - 93) & 511)])) + (0.00640597614f * fVec54[((IOTA - 94) & 511)])) + (0.00977705605f * fVec54[((IOTA - 95) & 511)])) + (0.0116775855f * fVec54[((IOTA - 96) & 511)])) + (0.0122520421f * fVec54[((IOTA - 97) & 511)])) + (0.0104471184f * fVec54[((IOTA - 98) & 511)])) + (0.00479489705f * fVec54[((IOTA - 99) & 511)])) + (0.00406046072f * fVec54[((IOTA - 108) & 511)])) + (0.00694679841f * fVec54[((IOTA - 109) & 511)])) + (0.00745760603f * fVec54[((IOTA - 110) & 511)])) + (0.00529882591f * fVec54[((IOTA - 111) & 511)])) + (0.00052199699f * fVec54[((IOTA - 112) & 511)])) + (0.00246998388f * fVec54[((IOTA - 128) & 511)])) + (0.00700123282f * fVec54[((IOTA - 129) & 511)])) + (0.00902521051f * fVec54[((IOTA - 130) & 511)])) + (0.00666330522f * fVec54[((IOTA - 131) & 511)])) + (0.000833431724f * fVec54[((IOTA - 132) & 511)])) + (0.00229219999f * fVec54[((IOTA - 137) & 511)])) + (0.00509389071f * fVec54[((IOTA - 138) & 511)])) + (0.00503475033f * fVec54[((IOTA - 139) & 511)])) + (0.00182592077f * fVec54[((IOTA - 140) & 511)])) + (0.00276562106f * fVec54[((IOTA - 147) & 511)])) + (0.00507621793f * fVec54[((IOTA - 148) & 511)])) + (0.00553969992f * fVec54[((IOTA - 149) & 511)])) + (0.00518663321f * fVec54[((IOTA - 150) & 511)])) + (0.00478854496f * fVec54[((IOTA - 151) & 511)])) + (0.00451298337f * fVec54[((IOTA - 152) & 511)])) + (0.00440901844f * fVec54[((IOTA - 153) & 511)])) + (0.00405345066f * fVec54[((IOTA - 154) & 511)])) + (0.00318131642f * fVec54[((IOTA - 155) & 511)])) + (0.00186383398f * fVec54[((IOTA - 156) & 511)])) + (5.72316349e-05f * fVec54[((IOTA - 157) & 511)])) + (0.00466489932f * fVec54[((IOTA - 230) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000526044983f * fVec54[((IOTA - 288) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000336939935f * fVec54[((IOTA - 289) & 511)])) + (0.000690993853f * fVec54[((IOTA - 290) & 511)])) + (0.00183938118f * fVec54[((IOTA - 291) & 511)])) + (0.00369627075f * fVec54[((IOTA - 292) & 511)])) + (0.00550195109f * fVec54[((IOTA - 293) & 511)])) + (0.00654821657f * fVec54[((IOTA - 294) & 511)])) + (0.00674814917f * fVec54[((IOTA - 295) & 511)])) + (0.00652649533f * fVec54[((IOTA - 296) & 511)])) + (0.00617701607f * fVec54[((IOTA - 297) & 511)])) + (0.00576438149f * fVec54[((IOTA - 298) & 511)])) + (0.00550688757f * fVec54[((IOTA - 299) & 511)])) + (0.00536691817f * fVec54[((IOTA - 300) & 511)])) + (0.00529635791f * fVec54[((IOTA - 301) & 511)])) + (0.00548987277f * fVec54[((IOTA - 302) & 511)])) + (0.00566071272f * fVec54[((IOTA - 303) & 511)])) + (0.005556155f * fVec54[((IOTA - 304) & 511)])) + (0.00530876499f * fVec54[((IOTA - 305) & 511)])) + (0.00502527226f * fVec54[((IOTA - 306) & 511)])) + (0.00509458221f * fVec54[((IOTA - 307) & 511)])) + (0.00549596129f * fVec54[((IOTA - 308) & 511)])) + (0.00549642229f * fVec54[((IOTA - 309) & 511)])) + (0.00499334885f * fVec54[((IOTA - 310) & 511)])) + (0.00397617649f * fVec54[((IOTA - 311) & 511)])) + (0.0023408751f * fVec54[((IOTA - 312) & 511)])) + (0.000806313008f * fVec54[((IOTA - 313) & 511)])) + (0.000244131777f * fVec54[((IOTA - 327) & 511)])) + (0.00112028141f * fVec54[((IOTA - 328) & 511)])) + (0.00153054669f * fVec54[((IOTA - 329) & 511)])) + (0.00136622321f * fVec54[((IOTA - 330) & 511)])) + (0.000482833479f * fVec54[((IOTA - 331) & 511)])) + (9.44538042e-05f * fVec54[((IOTA - 333) & 511)])) + (0.00105962716f * fVec54[((IOTA - 334) & 511)])) + (0.00226475252f * fVec54[((IOTA - 335) & 511)])) + (0.00344684022f * fVec54[((IOTA - 336) & 511)])) + (0.00414490979f * fVec54[((IOTA - 337) & 511)])) + (0.00443198998f * fVec54[((IOTA - 338) & 511)])) + (0.00431815209f * fVec54[((IOTA - 339) & 511)])) + (0.00386520149f * fVec54[((IOTA - 340) & 511)])) + (0.00361057092f * fVec54[((IOTA - 341) & 511)])) + (0.00347807258f * fVec54[((IOTA - 342) & 511)])) + (0.00315070944f * fVec54[((IOTA - 343) & 511)])) + (0.00259300414f * fVec54[((IOTA - 344) & 511)])) + (0.00149447657f * fVec54[((IOTA - 345) & 511)])) + (2.40248628e-05f * fVec54[((IOTA - 346) & 511)])) + (0.00128197204f * fVec54[((IOTA - 350) & 511)])) + (0.00293909339f * fVec54[((IOTA - 351) & 511)])) + (0.00405901298f * fVec54[((IOTA - 352) & 511)])) + (0.0042403508f * fVec54[((IOTA - 353) & 511)])) + (0.00314050727f * fVec54[((IOTA - 354) & 511)])) + (0.00126413442f * fVec54[((IOTA - 355) & 511)])) + (0.00123711443f * fVec54[((IOTA - 367) & 511)])) + (0.00177375693f * fVec54[((IOTA - 368) & 511)])) + (0.00127861509f * fVec54[((IOTA - 369) & 511)])) + (0.000292642042f * fVec54[((IOTA - 370) & 511)])) + (9.35322605e-05f * fVec54[((IOTA - 379) & 511)])) + (0.000461507123f * fVec54[((IOTA - 380) & 511)])) + (0.000653739087f * fVec54[((IOTA - 381) & 511)])) + (0.000555039383f * fVec54[((IOTA - 382) & 511)])) + (0.000488099176f * fVec54[((IOTA - 383) & 511)])) + (0.000627541915f * fVec54[((IOTA - 384) & 511)])) + (0.000758987386f * fVec54[((IOTA - 385) & 511)])) + (0.00105498638f * fVec54[((IOTA - 386) & 511)])) + (0.00132544711f * fVec54[((IOTA - 387) & 511)])) + (0.0013230117f * fVec54[((IOTA - 388) & 511)])) + (0.00122957816f * fVec54[((IOTA - 389) & 511)])) + (0.000729663763f * fVec54[((IOTA - 390) & 511)])) + (8.72132368e-05f * fVec54[((IOTA - 399) & 511)])) + (0.0012070341f * fVec54[((IOTA - 400) & 511)])) + (0.00145396357f * fVec54[((IOTA - 401) & 511)])) + (0.000862425659f * fVec54[((IOTA - 402) & 511)])) + (3.27131711e-05f * fVec54[((IOTA - 412) & 511)])) + (0.000392625108f * fVec54[((IOTA - 413) & 511)])) + (0.000489646103f * fVec54[((IOTA - 415) & 511)])))))) + (0.000581598375f * fVec54[((IOTA - 426) & 511)])) + (0.000446171034f * fVec54[((IOTA - 427) & 511)])) + (0.000295242295f * fVec54[((IOTA - 428) & 511)])) + (2.84677371e-05f * fVec54[((IOTA - 429) & 511)])) + (0.00013917964f * fVec54[((IOTA - 489) & 511)])) + (0.000159781426f * fVec54[((IOTA - 490) & 511)])) + (0.000305115245f * fVec54[((IOTA - 491) & 511)])) + (0.000358792953f * fVec54[((IOTA - 492) & 511)])) + (0.000352605712f * fVec54[((IOTA - 493) & 511)])) + (0.000281715766f * fVec54[((IOTA - 494) & 511)])) + (8.83322209e-05f * fVec54[((IOTA - 495) & 511)])) - ((((((((((((((((0.000210793223f * fVec54[((IOTA - 496) & 511)]) + ((6.21024519e-05f * fVec54[((IOTA - 488) & 511)]) + ((0.000549214426f * fVec54[((IOTA - 487) & 511)]) + ((0.00081592286f * fVec54[((IOTA - 486) & 511)]) + ((0.00101467082f * fVec54[((IOTA - 485) & 511)]) + ((0.00124823861f * fVec54[((IOTA - 484) & 511)]) + ((0.00130224507f * fVec54[((IOTA - 483) & 511)]) + ((0.0013290015f * fVec54[((IOTA - 482) & 511)]) + ((0.00133410236f * fVec54[((IOTA - 481) & 511)]) + ((0.00127459969f * fVec54[((IOTA - 480) & 511)]) + ((0.00132386712f * fVec54[((IOTA - 479) & 511)]) + ((0.00146021647f * fVec54[((IOTA - 478) & 511)]) + ((0.00177250663f * fVec54[((IOTA - 477) & 511)]) + ((0.00232780911f * fVec54[((IOTA - 476) & 511)]) + ((0.00274587423f * fVec54[((IOTA - 475) & 511)]) + ((0.00285204453f * fVec54[((IOTA - 474) & 511)]) + ((0.00261587696f * fVec54[((IOTA - 473) & 511)]) + ((0.00193663221f * fVec54[((IOTA - 472) & 511)]) + ((0.00116474368f * fVec54[((IOTA - 471) & 511)]) + ((0.000574588776f * fVec54[((IOTA - 470) & 511)]) + ((0.000284249894f * fVec54[((IOTA - 469) & 511)]) + ((0.000530883204f * fVec54[((IOTA - 468) & 511)]) + ((0.00129793352f * fVec54[((IOTA - 467) & 511)]) + ((0.00229203515f * fVec54[((IOTA - 466) & 511)]) + ((0.00294360192f * fVec54[((IOTA - 465) & 511)]) + ((0.00262575038f * fVec54[((IOTA - 464) & 511)]) + ((0.00161512708f * fVec54[((IOTA - 463) & 511)]) + ((0.000701821409f * fVec54[((IOTA - 462) & 511)]) + ((0.000192297623f * fVec54[((IOTA - 461) & 511)]) + ((0.000406217296f * fVec54[((IOTA - 460) & 511)]) + ((0.00140314922f * fVec54[((IOTA - 459) & 511)]) + ((0.00281732343f * fVec54[((IOTA - 458) & 511)]) + ((0.00424532034f * fVec54[((IOTA - 457) & 511)]) + ((0.00502932025f * fVec54[((IOTA - 456) & 511)]) + ((0.00473368308f * fVec54[((IOTA - 455) & 511)]) + ((0.00383291626f * fVec54[((IOTA - 454) & 511)]) + ((0.00272836583f * fVec54[((IOTA - 453) & 511)]) + ((0.0015907404f * fVec54[((IOTA - 452) & 511)]) + ((0.00102151651f * fVec54[((IOTA - 451) & 511)]) + ((0.000890498515f * fVec54[((IOTA - 450) & 511)]) + ((0.000709489454f * fVec54[((IOTA - 449) & 511)]) + ((0.000665290747f * fVec54[((IOTA - 448) & 511)]) + ((0.000691882335f * fVec54[((IOTA - 447) & 511)]) + ((0.000660551246f * fVec54[((IOTA - 446) & 511)]) + ((0.000733053777f * fVec54[((IOTA - 445) & 511)]) + ((0.00106597878f * fVec54[((IOTA - 444) & 511)]) + ((0.00213659788f * fVec54[((IOTA - 443) & 511)]) + ((0.00394250872f * fVec54[((IOTA - 442) & 511)]) + ((0.00552324438f * fVec54[((IOTA - 441) & 511)]) + ((0.00630135275f * fVec54[((IOTA - 440) & 511)]) + ((0.00618201867f * fVec54[((IOTA - 439) & 511)]) + ((0.00527174072f * fVec54[((IOTA - 438) & 511)]) + ((0.00417433213f * fVec54[((IOTA - 437) & 511)]) + ((0.00326207932f * fVec54[((IOTA - 436) & 511)]) + ((0.00255693402f * fVec54[((IOTA - 435) & 511)]) + ((0.00222891243f * fVec54[((IOTA - 434) & 511)]) + ((0.00204829825f * fVec54[((IOTA - 433) & 511)]) + ((0.00171527453f * fVec54[((IOTA - 432) & 511)]) + ((0.00128536159f * fVec54[((IOTA - 431) & 511)]) + ((0.000626291148f * fVec54[((IOTA - 430) & 511)]) + ((0.000190224033f * fVec54[((IOTA - 422) & 511)]) + ((0.000545067713f * fVec54[((IOTA - 421) & 511)]) + ((0.000971393194f * fVec54[((IOTA - 420) & 511)]) + ((0.0011425619f * fVec54[((IOTA - 419) & 511)]) + ((0.000865881331f * fVec54[((IOTA - 418) & 511)]) + ((0.000487901736f * fVec54[((IOTA - 417) & 511)]) + ((0.000481056049f * fVec54[((IOTA - 411) & 511)]) + ((0.000803449657f * fVec54[((IOTA - 410) & 511)]) + ((0.00118093612f * fVec54[((IOTA - 409) & 511)]) + ((0.00164115988f * fVec54[((IOTA - 408) & 511)]) + ((0.00183233805f * fVec54[((IOTA - 407) & 511)]) + ((0.00172297563f * fVec54[((IOTA - 405) & 511)]) + ((0.00100726588f * fVec54[((IOTA - 404) & 511)]) + ((6.46696426e-05f * fVec54[((IOTA - 403) & 511)]) + ((0.00161502836f * fVec54[((IOTA - 398) & 511)]) + ((0.00352111971f * fVec54[((IOTA - 397) & 511)]) + ((0.00494102063f * fVec54[((IOTA - 396) & 511)]) + ((0.00545225572f * fVec54[((IOTA - 395) & 511)]) + ((0.00488010282f * fVec54[((IOTA - 394) & 511)]) + ((0.00337542407f * fVec54[((IOTA - 393) & 511)]) + ((0.00173107162f * fVec54[((IOTA - 392) & 511)]) + ((0.000360175036f * fVec54[((IOTA - 391) & 511)]) + ((0.000272632577f * fVec54[((IOTA - 378) & 511)]) + ((0.00039910851f * fVec54[((IOTA - 377) & 511)]) + ((0.0002672025f * fVec54[((IOTA - 376) & 511)]) + ((0.00031400146f * fVec54[((IOTA - 375) & 511)]) + ((0.000600752421f * fVec54[((IOTA - 374) & 511)]) + ((0.000882007647f * fVec54[((IOTA - 373) & 511)]) + ((0.00106466236f * fVec54[((IOTA - 372) & 511)]) + ((0.000681515317f * fVec54[((IOTA - 371) & 511)]) + ((4.77209687e-06f * fVec54[((IOTA - 366) & 511)]) + ((0.000968036242f * fVec54[((IOTA - 365) & 511)]) + ((0.00144017395f * fVec54[((IOTA - 364) & 511)]) + ((0.0014092708f * fVec54[((IOTA - 363) & 511)]) + ((0.00102250371f * fVec54[((IOTA - 362) & 511)]) + ((0.000935323071f * fVec54[((IOTA - 361) & 511)]) + ((0.00144491298f * fVec54[((IOTA - 360) & 511)]) + ((0.00229239743f * fVec54[((IOTA - 359) & 511)]) + ((0.00285898848f * fVec54[((IOTA - 358) & 511)]) + ((0.00237016566f * fVec54[((IOTA - 357) & 511)]) + ((0.000758823007f * fVec54[((IOTA - 356) & 511)]) + ((0.000378374942f * fVec54[((IOTA - 349) & 511)]) + ((0.00119416602f * fVec54[((IOTA - 348) & 511)]) + ((0.000996339601f * fVec54[((IOTA - 347) & 511)]) + ((0.000230868813f * fVec54[((IOTA - 332) & 511)]) + ((0.000743716955f * fVec54[((IOTA - 326) & 511)]) + ((0.00140235946f * fVec54[((IOTA - 325) & 511)]) + ((0.0017077052f * fVec54[((IOTA - 324) & 511)]) + ((0.00149487145f * fVec54[((IOTA - 323) & 511)]) + ((0.000957208686f * fVec54[((IOTA - 322) & 511)]) + ((0.000590287149f * fVec54[((IOTA - 321) & 511)]) + ((0.000371035654f * fVec54[((IOTA - 320) & 511)]) + ((0.000478588045f * fVec54[((IOTA - 319) & 511)]) + ((0.000951942988f * fVec54[((IOTA - 318) & 511)]) + ((0.00122441119f * fVec54[((IOTA - 317) & 511)]) + ((0.00129247038f * fVec54[((IOTA - 316) & 511)]) + ((0.00108345458f * fVec54[((IOTA - 315) & 511)]) + ((0.000308340881f * fVec54[((IOTA - 314) & 511)]) + ((((((((((((((((((0.0039558704f * fVec54[((IOTA - 166) & 511)]) + ((0.00521473913f * fVec54[((IOTA - 165) & 511)]) + ((0.00465996284f * fVec54[((IOTA - 164) & 511)]) + ((0.00315926597f * fVec54[((IOTA - 163) & 511)]) + ((0.00208259141f * fVec54[((IOTA - 162) & 511)]) + ((0.0016724579f * fVec54[((IOTA - 161) & 511)]) + ((0.00166344037f * fVec54[((IOTA - 160) & 511)]) + ((0.00176937971f * fVec54[((IOTA - 159) & 511)]) + ((0.00137830153f * fVec54[((IOTA - 158) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0292949658f * fVec54[((IOTA - 22) & 511)]) + ((0.0434018895f * fVec54[((IOTA - 21) & 511)]) + ((0.0252202209f * fVec54[((IOTA - 20) & 511)]) + ((0.0135866711f * fVec54[((IOTA - 15) & 511)]) + ((0.0162626766f * fVec54[((IOTA - 14) & 511)]) + ((0.0977122709f * fVec54[((IOTA - 9) & 511)]) + ((0.212066188f * fVec54[((IOTA - 8) & 511)]) + ((0.244203225f * fVec54[((IOTA - 7) & 511)]) + ((0.170659021f * fVec54[((IOTA - 6) & 511)]) + ((0.0156380627f * fVec54[((IOTA - 5) & 511)]) + ((0.027928248f * fVec54[((IOTA - 29) & 511)]) + (((0.0482322983f * fVec54[((IOTA - 30) & 511)]) + ((0.00316051673f * fVec54[((IOTA - 28) & 511)]) + (0.056172803f * fVec54[((IOTA - 31) & 511)]))) + (0.0521649644f * fVec54[((IOTA - 32) & 511)]))))))))))))) + (0.0302524716f * fVec54[((IOTA - 33) & 511)])) + (0.00604023924f * fVec54[((IOTA - 39) & 511)])) + (0.0167160872f * fVec54[((IOTA - 40) & 511)])) + (0.0214526989f * fVec54[((IOTA - 41) & 511)])) + (0.0247481838f * fVec54[((IOTA - 42) & 511)])) + (0.0331192911f * fVec54[((IOTA - 43) & 511)])) + (0.0402240604f * fVec54[((IOTA - 44) & 511)])) + (0.0312992968f * fVec54[((IOTA - 45) & 511)])) + (0.00689723482f * fVec54[((IOTA - 46) & 511)])) + (0.0162779801f * fVec54[((IOTA - 52) & 511)])) + (0.0289857369f * fVec54[((IOTA - 53) & 511)])) + (0.0395836197f * fVec54[((IOTA - 54) & 511)])) + (0.0458023325f * fVec54[((IOTA - 55) & 511)])) + (0.0446878113f * fVec54[((IOTA - 56) & 511)])) + (0.0304618478f * fVec54[((IOTA - 57) & 511)])) + (0.00845447183f * fVec54[((IOTA - 58) & 511)])) + (0.00634986348f * fVec54[((IOTA - 64) & 511)])) + (0.0124240993f * fVec54[((IOTA - 65) & 511)])) + (0.0184835251f * fVec54[((IOTA - 66) & 511)])) + (0.0261554457f * fVec54[((IOTA - 67) & 511)])) + (0.03171058f * fVec54[((IOTA - 68) & 511)])) + (0.0352315046f * fVec54[((IOTA - 69) & 511)])) + (0.0345901698f * fVec54[((IOTA - 70) & 511)])) + (0.0240916461f * fVec54[((IOTA - 71) & 511)])) + (0.00536800455f * fVec54[((IOTA - 72) & 511)])) + (0.00453401357f * fVec54[((IOTA - 77) & 511)])) + (0.00745411729f * fVec54[((IOTA - 78) & 511)])) + (0.00393355684f * fVec54[((IOTA - 79) & 511)])) + (0.00114094932f * fVec54[((IOTA - 83) & 511)])) + (0.00649608579f * fVec54[((IOTA - 84) & 511)])) + (0.0125951692f * fVec54[((IOTA - 85) & 511)])) + (0.0202438552f * fVec54[((IOTA - 86) & 511)])) + (0.0270955078f * fVec54[((IOTA - 87) & 511)])) + (0.0314142853f * fVec54[((IOTA - 88) & 511)])) + (0.0313247032f * fVec54[((IOTA - 89) & 511)])) + (0.0240907259f * fVec54[((IOTA - 90) & 511)])) + (0.0126628997f * fVec54[((IOTA - 91) & 511)])) + (0.00439513009f * fVec54[((IOTA - 92) & 511)])) + (0.0049044569f * fVec54[((IOTA - 100) & 511)])) + (0.0143122207f * fVec54[((IOTA - 101) & 511)])) + (0.018989956f * fVec54[((IOTA - 102) & 511)])) + (0.018545825f * fVec54[((IOTA - 103) & 511)])) + (0.0146617992f * fVec54[((IOTA - 104) & 511)])) + (0.00973308645f * fVec54[((IOTA - 105) & 511)])) + (0.00477932999f * fVec54[((IOTA - 106) & 511)])) + (9.70857218e-06f * fVec54[((IOTA - 107) & 511)])) + (0.00578682637f * fVec54[((IOTA - 113) & 511)])) + (0.0108479057f * fVec54[((IOTA - 114) & 511)])) + (0.0140741449f * fVec54[((IOTA - 115) & 511)])) + (0.0152986869f * fVec54[((IOTA - 116) & 511)])) + (0.0148662739f * fVec54[((IOTA - 117) & 511)])) + (0.0140175708f * fVec54[((IOTA - 118) & 511)])) + (0.0123381689f * fVec54[((IOTA - 119) & 511)])) + (0.0100956317f * fVec54[((IOTA - 120) & 511)])) + (0.00707057538f * fVec54[((IOTA - 121) & 511)])) + (0.0035421825f * fVec54[((IOTA - 122) & 511)])) + (0.00105248531f * fVec54[((IOTA - 123) & 511)])) + (0.000805194024f * fVec54[((IOTA - 124) & 511)])) + (0.002509641f * fVec54[((IOTA - 125) & 511)])) + (0.0034082029f * fVec54[((IOTA - 126) & 511)])) + (0.00158396084f * fVec54[((IOTA - 127) & 511)])) + (0.00478469441f * fVec54[((IOTA - 133) & 511)])) + (0.00807096343f * fVec54[((IOTA - 134) & 511)])) + (0.00771213742f * fVec54[((IOTA - 135) & 511)])) + (0.00300251227f * fVec54[((IOTA - 136) & 511)])) + (0.00319658685f * fVec54[((IOTA - 141) & 511)])) + (0.00743420608f * fVec54[((IOTA - 142) & 511)])) + (0.0091728149f * fVec54[((IOTA - 143) & 511)])) + (0.00831114594f * fVec54[((IOTA - 144) & 511)])) + (0.00542948162f * fVec54[((IOTA - 145) & 511)])) + (0.00120071555f * fVec54[((IOTA - 146) & 511)])) + (0.00148210209f * fVec54[((IOTA - 167) & 511)]))))))))))) + (0.00243239943f * fVec54[((IOTA - 178) & 511)])) + (0.00497004762f * fVec54[((IOTA - 179) & 511)])) + (0.00495105842f * fVec54[((IOTA - 180) & 511)])) + (0.0012817746f * fVec54[((IOTA - 181) & 511)])) + (0.000256045721f * fVec54[((IOTA - 189) & 511)])) + (0.00201749383f * fVec54[((IOTA - 212) & 511)])) + (0.00321626756f * fVec54[((IOTA - 213) & 511)])) + (0.0029982999f * fVec54[((IOTA - 214) & 511)])) + (0.00130283739f * fVec54[((IOTA - 215) & 511)])) + (0.000152969267f * fVec54[((IOTA - 236) & 511)])) + (3.21539119e-05f * fVec54[((IOTA - 276) & 511)])) + (0.00173837785f * fVec54[((IOTA - 277) & 511)])) + (0.00210523419f * fVec54[((IOTA - 278) & 511)])) + (0.00117264269f * fVec54[((IOTA - 279) & 511)])) + (0.00190753909f * fVec54[((IOTA - 406) & 511)])) + (0.000848800875f * fVec54[((IOTA - 497) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00166659988f * fVec54[((IOTA - 498) & 511)])) + (0.0023063845f * fVec54[((IOTA - 499) & 511)])) + (0.00284019671f * fVec54[((IOTA - 500) & 511)])) + (0.00313415518f * fVec54[((IOTA - 501) & 511)])) + (0.00305997441f * fVec54[((IOTA - 502) & 511)])) + (0.00291556213f * fVec54[((IOTA - 503) & 511)])) + (0.00286139129f * fVec54[((IOTA - 504) & 511)])) + (0.00313010719f * fVec54[((IOTA - 505) & 511)])) + (0.00371266017f * fVec54[((IOTA - 506) & 511)])) + (0.00405315449f * fVec54[((IOTA - 507) & 511)])) + (0.00398470042f * fVec54[((IOTA - 508) & 511)])) + (0.00362324156f * fVec54[((IOTA - 509) & 511)])) + (0.00290048914f * fVec54[((IOTA - 510) & 511)])) + (0.00214670133f * fVec54[((IOTA - 511) & 511)]))) : ((((((((((((((((((((((((((((((((((((((((((0.00392238609f * fVec53[((IOTA - 431) & 511)]) + ((0.00282040844f * fVec53[((IOTA - 430) & 511)]) + ((0.0017404058f * fVec53[((IOTA - 429) & 511)]) + ((0.00109303975f * fVec53[((IOTA - 428) & 511)]) + ((0.000948667526f * fVec53[((IOTA - 427) & 511)]) + ((0.00153764244f * fVec53[((IOTA - 426) & 511)]) + ((0.00279558916f * fVec53[((IOTA - 425) & 511)]) + ((0.00407270435f * fVec53[((IOTA - 424) & 511)]) + ((0.00524378428f * fVec53[((IOTA - 423) & 511)]) + ((0.00624297652f * fVec53[((IOTA - 422) & 511)]) + ((0.00660425751f * fVec53[((IOTA - 421) & 511)]) + ((0.00660953904f * fVec53[((IOTA - 420) & 511)]) + ((0.00681691943f * fVec53[((IOTA - 419) & 511)]) + ((0.0069568227f * fVec53[((IOTA - 418) & 511)]) + ((0.00660362979f * fVec53[((IOTA - 417) & 511)]) + ((0.00557367178f * fVec53[((IOTA - 416) & 511)]) + ((0.00406265864f * fVec53[((IOTA - 415) & 511)]) + ((0.00302945077f * fVec53[((IOTA - 414) & 511)]) + ((0.00277254265f * fVec53[((IOTA - 413) & 511)]) + ((0.00297382893f * fVec53[((IOTA - 412) & 511)]) + ((0.0037606922f * fVec53[((IOTA - 411) & 511)]) + ((0.00494100526f * fVec53[((IOTA - 410) & 511)]) + ((0.00598858017f * fVec53[((IOTA - 409) & 511)]) + ((0.0060880417f * fVec53[((IOTA - 408) & 511)]) + ((0.00487759104f * fVec53[((IOTA - 407) & 511)]) + ((0.00288356422f * fVec53[((IOTA - 406) & 511)]) + ((0.000846879557f * fVec53[((IOTA - 405) & 511)]) + ((0.000262521673f * fVec53[((IOTA - 402) & 511)]) + ((0.002236309f * fVec53[((IOTA - 401) & 511)]) + ((0.00483585615f * fVec53[((IOTA - 400) & 511)]) + ((0.00718625216f * fVec53[((IOTA - 399) & 511)]) + ((0.00868803263f * fVec53[((IOTA - 398) & 511)]) + ((0.00910061412f * fVec53[((IOTA - 397) & 511)]) + ((0.0086089205f * fVec53[((IOTA - 396) & 511)]) + ((0.00776747055f * fVec53[((IOTA - 395) & 511)]) + ((0.00737538701f * fVec53[((IOTA - 394) & 511)]) + ((0.00810832717f * fVec53[((IOTA - 393) & 511)]) + ((0.00989803951f * fVec53[((IOTA - 392) & 511)]) + ((0.0123514794f * fVec53[((IOTA - 391) & 511)]) + ((0.0152522177f * fVec53[((IOTA - 390) & 511)]) + ((0.0180526823f * fVec53[((IOTA - 389) & 511)]) + ((0.0200649537f * fVec53[((IOTA - 388) & 511)]) + ((0.0210639238f * fVec53[((IOTA - 387) & 511)]) + ((0.021190457f * fVec53[((IOTA - 386) & 511)]) + ((0.02091006f * fVec53[((IOTA - 385) & 511)]) + ((0.0202753246f * fVec53[((IOTA - 384) & 511)]) + ((0.0187075827f * fVec53[((IOTA - 383) & 511)]) + ((0.0159151703f * fVec53[((IOTA - 382) & 511)]) + ((0.0116641875f * fVec53[((IOTA - 381) & 511)]) + ((0.00632105349f * fVec53[((IOTA - 380) & 511)]) + ((0.00141742453f * fVec53[((IOTA - 379) & 511)]) + ((4.96380962e-05f * fVec53[((IOTA - 364) & 511)]) + ((0.00127962651f * fVec53[((IOTA - 350) & 511)]) + ((0.00364095438f * fVec53[((IOTA - 349) & 511)]) + ((0.00411898177f * fVec53[((IOTA - 348) & 511)]) + ((0.00388545264f * fVec53[((IOTA - 347) & 511)]) + ((0.00399078615f * fVec53[((IOTA - 346) & 511)]) + ((0.00444957148f * fVec53[((IOTA - 345) & 511)]) + ((0.00490499521f * fVec53[((IOTA - 344) & 511)]) + ((0.00524821598f * fVec53[((IOTA - 343) & 511)]) + ((0.0051015541f * fVec53[((IOTA - 342) & 511)]) + ((0.00415857416f * fVec53[((IOTA - 341) & 511)]) + ((0.00246259896f * fVec53[((IOTA - 340) & 511)]) + ((9.87225212e-05f * fVec53[((IOTA - 339) & 511)]) + ((0.000682526734f * fVec53[((IOTA - 327) & 511)]) + ((0.00158340251f * fVec53[((IOTA - 326) & 511)]) + ((0.00118212262f * fVec53[((IOTA - 325) & 511)]) + ((0.00121033983f * fVec53[((IOTA - 302) & 511)]) + ((0.00404821755f * fVec53[((IOTA - 301) & 511)]) + ((0.00641094893f * fVec53[((IOTA - 300) & 511)]) + ((0.00854029879f * fVec53[((IOTA - 299) & 511)]) + ((0.0102914898f * fVec53[((IOTA - 298) & 511)]) + ((0.0108286832f * fVec53[((IOTA - 297) & 511)]) + ((0.00979218818f * fVec53[((IOTA - 296) & 511)]) + ((0.00753120845f * fVec53[((IOTA - 295) & 511)]) + ((0.00440392178f * fVec53[((IOTA - 294) & 511)]) + ((0.000741767697f * fVec53[((IOTA - 293) & 511)]) + ((0.00319672143f * fVec53[((IOTA - 270) & 511)]) + ((0.00758627616f * fVec53[((IOTA - 269) & 511)]) + ((0.0113178277f * fVec53[((IOTA - 268) & 511)]) + ((0.0139718149f * fVec53[((IOTA - 267) & 511)]) + ((0.0157598648f * fVec53[((IOTA - 266) & 511)]) + ((0.0171070434f * fVec53[((IOTA - 265) & 511)]) + ((0.0182463601f * fVec53[((IOTA - 264) & 511)]) + ((0.0192971844f * fVec53[((IOTA - 263) & 511)]) + ((0.0198501498f * fVec53[((IOTA - 262) & 511)]) + ((0.0195927247f * fVec53[((IOTA - 261) & 511)]) + ((0.0184371565f * fVec53[((IOTA - 260) & 511)]) + ((0.0161556043f * fVec53[((IOTA - 259) & 511)]) + ((0.0126254875f * fVec53[((IOTA - 258) & 511)]) + ((0.00789023656f * fVec53[((IOTA - 257) & 511)]) + ((0.00209016399f * fVec53[((IOTA - 256) & 511)]) + ((0.00805204175f * fVec53[((IOTA - 250) & 511)]) + ((0.0176778827f * fVec53[((IOTA - 249) & 511)]) + ((0.0255816747f * fVec53[((IOTA - 248) & 511)]) + ((0.0307706129f * fVec53[((IOTA - 247) & 511)]) + ((0.0328388363f * fVec53[((IOTA - 246) & 511)]) + ((0.0314254016f * fVec53[((IOTA - 245) & 511)]) + ((0.0268458985f * fVec53[((IOTA - 244) & 511)]) + ((0.0197783876f * fVec53[((IOTA - 243) & 511)]) + ((0.0106543954f * fVec53[((IOTA - 242) & 511)]) + ((2.07936391e-05f * fVec53[((IOTA - 241) & 511)]) + ((0.00308414875f * fVec53[((IOTA - 231) & 511)]) + ((0.00776699046f * fVec53[((IOTA - 230) & 511)]) + ((0.0121854264f * fVec53[((IOTA - 229) & 511)]) + ((0.0157852378f * fVec53[((IOTA - 228) & 511)]) + ((0.017998131f * fVec53[((IOTA - 227) & 511)]) + ((0.0184377469f * fVec53[((IOTA - 226) & 511)]) + ((0.0173183382f * fVec53[((IOTA - 225) & 511)]) + ((0.0149277579f * fVec53[((IOTA - 224) & 511)]) + ((0.0119155925f * fVec53[((IOTA - 223) & 511)]) + ((0.00988795608f * fVec53[((IOTA - 222) & 511)]) + ((0.00990882423f * fVec53[((IOTA - 221) & 511)]) + ((0.0120612569f * fVec53[((IOTA - 220) & 511)]) + ((0.0157217868f * fVec53[((IOTA - 219) & 511)]) + ((0.0190988891f * fVec53[((IOTA - 218) & 511)]) + ((0.0209057387f * fVec53[((IOTA - 217) & 511)]) + ((0.021265395f * fVec53[((IOTA - 216) & 511)]) + ((0.0209456272f * fVec53[((IOTA - 215) & 511)]) + ((0.0212644339f * fVec53[((IOTA - 214) & 511)]) + (((0.0283034705f * fVec53[((IOTA - 212) & 511)]) + ((0.0341116339f * fVec53[((IOTA - 211) & 511)]) + ((0.038786605f * fVec53[((IOTA - 210) & 511)]) + ((0.0395931937f * fVec53[((IOTA - 209) & 511)]) + ((0.035670992f * fVec53[((IOTA - 208) & 511)]) + ((0.0285054967f * fVec53[((IOTA - 207) & 511)]) + ((0.0200167187f * fVec53[((IOTA - 206) & 511)]) + ((0.0121535901f * fVec53[((IOTA - 205) & 511)]) + ((0.006113193f * fVec53[((IOTA - 204) & 511)]) + ((0.00202966714f * fVec53[((IOTA - 203) & 511)]) + ((0.000892713666f * fVec53[((IOTA - 195) & 511)]) + ((0.00832941011f * fVec53[((IOTA - 194) & 511)]) + ((0.0144040817f * fVec53[((IOTA - 193) & 511)]) + ((0.0187448114f * fVec53[((IOTA - 192) & 511)]) + ((0.021987699f * fVec53[((IOTA - 191) & 511)]) + ((0.0247705467f * fVec53[((IOTA - 190) & 511)]) + ((0.0271194652f * fVec53[((IOTA - 189) & 511)]) + ((0.0285214148f * fVec53[((IOTA - 188) & 511)]) + ((0.0284752846f * fVec53[((IOTA - 187) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.298238128f * fVec53[((IOTA - 4) & 511)]) + ((0.108597264f * fVec53[((IOTA - 8) & 511)]) + ((0.241760343f * fVec53[((IOTA - 5) & 511)]) + ((0.109594017f * fVec53[((IOTA - 9) & 511)]) + ((((((0.15824908f * fVec53[((IOTA - 1) & 511)]) + ((0.299284816f * fVec53[((IOTA - 3) & 511)]) + (((fSlow165 * fTemp0) + (0.245742828f * fVec53[((IOTA - 2) & 511)])) + (0.182249457f * fVec53[((IOTA - 6) & 511)])))) + (0.135255426f * fVec53[((IOTA - 7) & 511)])) + (0.110729605f * fVec53[((IOTA - 10) & 511)])) + (0.0836955309f * fVec53[((IOTA - 11) & 511)])) + (0.0313752107f * fVec53[((IOTA - 12) & 511)])))))) + (0.00375086814f * fVec53[((IOTA - 62) & 511)])) + (0.0060467869f * fVec53[((IOTA - 63) & 511)])) + (0.00261509651f * fVec53[((IOTA - 64) & 511)])) + (0.00563579379f * fVec53[((IOTA - 70) & 511)])) + (0.0161424559f * fVec53[((IOTA - 71) & 511)])) + (0.0211766437f * fVec53[((IOTA - 72) & 511)])) + (0.0211947411f * fVec53[((IOTA - 73) & 511)])) + (0.0177967343f * fVec53[((IOTA - 74) & 511)])) + (0.011182541f * fVec53[((IOTA - 75) & 511)])) + (0.00331985671f * fVec53[((IOTA - 76) & 511)])) + (0.0102134123f * fVec53[((IOTA - 111) & 511)])) + (0.018783886f * fVec53[((IOTA - 112) & 511)])) + (0.0222541727f * fVec53[((IOTA - 113) & 511)])) + (0.0201267786f * fVec53[((IOTA - 114) & 511)])) + (0.0137198567f * fVec53[((IOTA - 115) & 511)])) + (0.00687228236f * fVec53[((IOTA - 116) & 511)])) + (0.00359039288f * fVec53[((IOTA - 117) & 511)])) + (0.00280943932f * fVec53[((IOTA - 118) & 511)])) + (0.00334663317f * fVec53[((IOTA - 119) & 511)])) + (0.00390646793f * fVec53[((IOTA - 120) & 511)])) + (0.00270248065f * fVec53[((IOTA - 121) & 511)])) + (1.21141784e-05f * fVec53[((IOTA - 122) & 511)])) + (0.00360668031f * fVec53[((IOTA - 127) & 511)])) + (0.0059439647f * fVec53[((IOTA - 128) & 511)])) + (0.00787849165f * fVec53[((IOTA - 129) & 511)])) + (0.00936933979f * fVec53[((IOTA - 130) & 511)])) + (0.011599333f * fVec53[((IOTA - 131) & 511)])) + (0.0153309219f * fVec53[((IOTA - 132) & 511)])) + (0.0190268699f * fVec53[((IOTA - 133) & 511)])) + (0.0209872872f * fVec53[((IOTA - 134) & 511)])) + (0.0205350034f * fVec53[((IOTA - 135) & 511)])) + (0.0171081126f * fVec53[((IOTA - 136) & 511)])) + (0.0119756088f * fVec53[((IOTA - 137) & 511)])) + (0.0079107713f * fVec53[((IOTA - 138) & 511)])) + (0.00554866809f * fVec53[((IOTA - 139) & 511)])) + (0.00354400463f * fVec53[((IOTA - 140) & 511)])) + (0.00165893137f * fVec53[((IOTA - 141) & 511)])) + (0.00430198619f * fVec53[((IOTA - 147) & 511)])) + (0.00964781642f * fVec53[((IOTA - 148) & 511)])) + (0.0127284564f * fVec53[((IOTA - 149) & 511)])) + (0.012308009f * fVec53[((IOTA - 150) & 511)])) + (0.00925451424f * fVec53[((IOTA - 151) & 511)])) + (0.00511876494f * fVec53[((IOTA - 152) & 511)])) + (0.00178265758f * fVec53[((IOTA - 153) & 511)])) + (0.000632518902f * fVec53[((IOTA - 154) & 511)])) + (0.00156020839f * fVec53[((IOTA - 155) & 511)])) + (0.00393686397f * fVec53[((IOTA - 156) & 511)])) + (0.00621350389f * fVec53[((IOTA - 157) & 511)])) + (0.00641804002f * fVec53[((IOTA - 158) & 511)])) + (0.00377938058f * fVec53[((IOTA - 159) & 511)])) + (0.00456000166f * fVec53[((IOTA - 164) & 511)])) + (0.0158419311f * fVec53[((IOTA - 165) & 511)])) + (0.0279963706f * fVec53[((IOTA - 166) & 511)])) + (0.0381355472f * fVec53[((IOTA - 167) & 511)])) + (0.0437168628f * fVec53[((IOTA - 168) & 511)])) + (0.042916853f * fVec53[((IOTA - 169) & 511)])) + (0.0357533507f * fVec53[((IOTA - 170) & 511)])) + (0.0242356043f * fVec53[((IOTA - 171) & 511)])) + (0.0116548073f * fVec53[((IOTA - 172) & 511)])) + (0.0013512033f * fVec53[((IOTA - 173) & 511)])) + (0.00166938314f * fVec53[((IOTA - 179) & 511)])) + (0.0050784708f * fVec53[((IOTA - 180) & 511)])) + (0.00875717122f * fVec53[((IOTA - 181) & 511)])) + (0.0129116829f * fVec53[((IOTA - 182) & 511)])) + (0.0173857771f * fVec53[((IOTA - 183) & 511)])) + (0.0213509686f * fVec53[((IOTA - 184) & 511)])) + (0.0244823918f * fVec53[((IOTA - 185) & 511)])) + (0.0269382335f * fVec53[((IOTA - 186) & 511)])) + (0.0236525759f * fVec53[((IOTA - 213) & 511)]))))))))))))))))))))) + (0.00479238573f * fVec53[((IOTA - 432) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00538073247f * fVec53[((IOTA - 433) & 511)])) + (0.005129328f * fVec53[((IOTA - 434) & 511)])) + (0.0039870562f * fVec53[((IOTA - 435) & 511)])) + (0.00260560447f * fVec53[((IOTA - 436) & 511)])) + (0.00120147597f * fVec53[((IOTA - 437) & 511)])) + (0.00137181208f * fVec53[((IOTA - 447) & 511)])) + (0.00301763183f * fVec53[((IOTA - 448) & 511)])) + (0.00230762688f * fVec53[((IOTA - 449) & 511)])) + (0.000700882636f * fVec53[((IOTA - 455) & 511)])) + (0.00156862941f * fVec53[((IOTA - 456) & 511)])) + (0.00125857489f * fVec53[((IOTA - 457) & 511)])) + (0.000280840322f * fVec53[((IOTA - 458) & 511)])) + (4.6572648e-05f * fVec53[((IOTA - 460) & 511)])) + (0.00102800038f * fVec53[((IOTA - 461) & 511)])) + (0.00197205134f * fVec53[((IOTA - 462) & 511)])) + (0.00220550643f * fVec53[((IOTA - 463) & 511)])) + (0.00158624677f * fVec53[((IOTA - 464) & 511)])) + (0.000509457197f * fVec53[((IOTA - 465) & 511)])) + (0.00107298512f * fVec53[((IOTA - 470) & 511)])) + (0.00315014832f * fVec53[((IOTA - 471) & 511)])) + (0.00496061658f * fVec53[((IOTA - 472) & 511)])) + (0.00602215249f * fVec53[((IOTA - 473) & 511)])) + (0.00605627894f * fVec53[((IOTA - 474) & 511)])) + (0.0050335601f * fVec53[((IOTA - 475) & 511)])) + (0.00275444565f * fVec53[((IOTA - 476) & 511)])) + (0.00144844875f * fVec53[((IOTA - 487) & 511)])) + (0.00459217047f * fVec53[((IOTA - 488) & 511)])) + (0.0066177384f * fVec53[((IOTA - 489) & 511)])) + (0.00744999247f * fVec53[((IOTA - 490) & 511)])) + (0.00748260459f * fVec53[((IOTA - 491) & 511)])) + (0.0074352189f * fVec53[((IOTA - 492) & 511)])) + (0.00763491727f * fVec53[((IOTA - 493) & 511)])) + (0.00784244575f * fVec53[((IOTA - 494) & 511)])) + (0.00781707186f * fVec53[((IOTA - 495) & 511)])) + (0.00726946257f * fVec53[((IOTA - 496) & 511)])) + (0.00601299293f * fVec53[((IOTA - 497) & 511)])) + (0.00406509591f * fVec53[((IOTA - 498) & 511)])) + (0.00197585532f * fVec53[((IOTA - 499) & 511)])) + (0.000349573325f * fVec53[((IOTA - 500) & 511)])) - ((((((((((((((((((0.00768987369f * fVec53[((IOTA - 480) & 511)]) + ((0.00605535554f * fVec53[((IOTA - 479) & 511)]) + ((0.00358592393f * fVec53[((IOTA - 478) & 511)]) + ((0.000425508246f * fVec53[((IOTA - 477) & 511)]) + ((0.000790851656f * fVec53[((IOTA - 469) & 511)]) + ((0.00178409787f * fVec53[((IOTA - 468) & 511)]) + ((0.00164430542f * fVec53[((IOTA - 467) & 511)]) + ((0.000695305411f * fVec53[((IOTA - 466) & 511)]) + ((0.000309759285f * fVec53[((IOTA - 459) & 511)]) + ((0.00102382666f * fVec53[((IOTA - 454) & 511)]) + ((0.00267884322f * fVec53[((IOTA - 453) & 511)]) + ((0.00327147404f * fVec53[((IOTA - 452) & 511)]) + ((0.00233477307f * fVec53[((IOTA - 451) & 511)]) + ((5.14108688e-05f * fVec53[((IOTA - 450) & 511)]) + ((0.00198006583f * fVec53[((IOTA - 446) & 511)]) + ((0.0057802028f * fVec53[((IOTA - 445) & 511)]) + ((0.00879565626f * fVec53[((IOTA - 444) & 511)]) + ((0.0100283772f * fVec53[((IOTA - 443) & 511)]) + ((0.00926337857f * fVec53[((IOTA - 442) & 511)]) + ((0.00719386013f * fVec53[((IOTA - 441) & 511)]) + ((0.00467933295f * fVec53[((IOTA - 440) & 511)]) + ((0.002306371f * fVec53[((IOTA - 439) & 511)]) + ((0.00038236985f * fVec53[((IOTA - 438) & 511)]) + ((0.000445526093f * fVec53[((IOTA - 404) & 511)]) + ((0.000628345646f * fVec53[((IOTA - 403) & 511)]) + (((((0.00301984791f * fVec53[((IOTA - 375) & 511)]) + ((0.00349126384f * fVec53[((IOTA - 374) & 511)]) + ((0.0052354373f * fVec53[((IOTA - 373) & 511)]) + ((0.00754221482f * fVec53[((IOTA - 372) & 511)]) + ((0.00985896401f * fVec53[((IOTA - 371) & 511)]) + ((0.0117389411f * fVec53[((IOTA - 370) & 511)]) + ((0.01242649f * fVec53[((IOTA - 369) & 511)]) + ((0.0113188988f * fVec53[((IOTA - 368) & 511)]) + ((0.00833458081f * fVec53[((IOTA - 367) & 511)]) + ((0.00431144098f * fVec53[((IOTA - 366) & 511)]) + ((0.00104244146f * fVec53[((IOTA - 365) & 511)]) + ((0.000944826752f * fVec53[((IOTA - 363) & 511)]) + ((0.00354670081f * fVec53[((IOTA - 362) & 511)]) + ((0.00648326427f * fVec53[((IOTA - 361) & 511)]) + ((0.00840412639f * fVec53[((IOTA - 360) & 511)]) + ((0.00961188041f * fVec53[((IOTA - 359) & 511)]) + ((0.0105482861f * fVec53[((IOTA - 358) & 511)]) + ((0.0118317911f * fVec53[((IOTA - 357) & 511)]) + ((0.0138595011f * fVec53[((IOTA - 356) & 511)]) + ((0.0155838784f * fVec53[((IOTA - 355) & 511)]) + ((0.0158106852f * fVec53[((IOTA - 354) & 511)]) + ((0.0137517303f * fVec53[((IOTA - 353) & 511)]) + ((0.00921632536f * fVec53[((IOTA - 352) & 511)]) + ((0.00345119135f * fVec53[((IOTA - 351) & 511)]) + ((0.00302830571f * fVec53[((IOTA - 338) & 511)]) + ((0.00685614254f * fVec53[((IOTA - 337) & 511)]) + ((0.010927923f * fVec53[((IOTA - 336) & 511)]) + ((0.0146339545f * fVec53[((IOTA - 335) & 511)]) + ((0.016909264f * fVec53[((IOTA - 334) & 511)]) + ((0.016781956f * fVec53[((IOTA - 333) & 511)]) + ((0.0144798318f * fVec53[((IOTA - 332) & 511)]) + ((0.0108767338f * fVec53[((IOTA - 331) & 511)]) + ((0.00375164347f * fVec53[((IOTA - 329) & 511)]) + ((0.00120262057f * fVec53[((IOTA - 328) & 511)]) + ((0.00047307834f * fVec53[((IOTA - 324) & 511)]) + ((0.00350958295f * fVec53[((IOTA - 323) & 511)]) + ((0.00785023812f * fVec53[((IOTA - 322) & 511)]) + ((0.0126544423f * fVec53[((IOTA - 321) & 511)]) + ((0.0168180019f * fVec53[((IOTA - 320) & 511)]) + ((0.0200426821f * fVec53[((IOTA - 319) & 511)]) + ((0.0228367206f * fVec53[((IOTA - 318) & 511)]) + ((0.0255328864f * fVec53[((IOTA - 317) & 511)]) + ((0.0278743804f * fVec53[((IOTA - 316) & 511)]) + ((0.0292436443f * fVec53[((IOTA - 315) & 511)]) + ((0.0292256568f * fVec53[((IOTA - 314) & 511)]) + ((0.0274553727f * fVec53[((IOTA - 313) & 511)]) + ((0.0239825379f * fVec53[((IOTA - 312) & 511)]) + ((0.0203002915f * fVec53[((IOTA - 311) & 511)]) + ((0.0179722775f * fVec53[((IOTA - 310) & 511)]) + ((0.0171708632f * fVec53[((IOTA - 309) & 511)]) + ((0.0170110539f * fVec53[((IOTA - 308) & 511)]) + ((0.0162140336f * fVec53[((IOTA - 307) & 511)]) + ((0.0141896475f * fVec53[((IOTA - 306) & 511)]) + ((0.0109259291f * fVec53[((IOTA - 305) & 511)]) + ((0.00676938612f * fVec53[((IOTA - 304) & 511)]) + ((0.00244317204f * fVec53[((IOTA - 303) & 511)]) + ((0.00305275526f * fVec53[((IOTA - 292) & 511)]) + ((0.00618059607f * fVec53[((IOTA - 291) & 511)]) + ((0.00797935668f * fVec53[((IOTA - 290) & 511)]) + ((0.00831873715f * fVec53[((IOTA - 289) & 511)]) + ((0.00803848729f * fVec53[((IOTA - 288) & 511)]) + ((0.00907516666f * fVec53[((IOTA - 287) & 511)]) + ((0.0123789571f * fVec53[((IOTA - 286) & 511)]) + ((0.0174869746f * fVec53[((IOTA - 285) & 511)]) + ((0.023352826f * fVec53[((IOTA - 284) & 511)]) + ((0.0283369683f * fVec53[((IOTA - 283) & 511)]) + ((0.0312160272f * fVec53[((IOTA - 282) & 511)]) + ((0.0316225514f * fVec53[((IOTA - 281) & 511)]) + ((0.0294608101f * fVec53[((IOTA - 280) & 511)]) + ((0.025426887f * fVec53[((IOTA - 279) & 511)]) + ((0.0204749852f * fVec53[((IOTA - 278) & 511)]) + ((0.0152865276f * fVec53[((IOTA - 277) & 511)]) + ((0.0106118489f * fVec53[((IOTA - 276) & 511)]) + ((0.00721834693f * fVec53[((IOTA - 275) & 511)]) + ((0.00526886201f * fVec53[((IOTA - 274) & 511)]) + ((0.00422317022f * fVec53[((IOTA - 273) & 511)]) + ((0.00311672408f * fVec53[((IOTA - 272) & 511)]) + ((0.000714806374f * fVec53[((IOTA - 271) & 511)]) + ((0.0044172178f * fVec53[((IOTA - 255) & 511)]) + ((0.0101388814f * fVec53[((IOTA - 254) & 511)]) + ((0.0125268381f * fVec53[((IOTA - 253) & 511)]) + ((0.00953409914f * fVec53[((IOTA - 252) & 511)]) + ((0.00175994355f * fVec53[((IOTA - 251) & 511)]) + ((0.0108635481f * fVec53[((IOTA - 240) & 511)]) + ((0.020135127f * fVec53[((IOTA - 239) & 511)]) + ((0.0258852281f * fVec53[((IOTA - 238) & 511)]) + ((0.0271184668f * fVec53[((IOTA - 237) & 511)]) + ((0.0244716816f * fVec53[((IOTA - 236) & 511)]) + ((0.0191125181f * fVec53[((IOTA - 235) & 511)]) + ((0.012479933f * fVec53[((IOTA - 234) & 511)]) + ((0.00648274738f * fVec53[((IOTA - 233) & 511)]) + ((0.00156504707f * fVec53[((IOTA - 232) & 511)]) + (((0.000719644595f * fVec53[((IOTA - 202) & 511)]) + ((0.00386284944f * fVec53[((IOTA - 201) & 511)]) + ((0.00786966458f * fVec53[((IOTA - 200) & 511)]) + ((0.011490454f * fVec53[((IOTA - 199) & 511)]) + ((0.0131890886f * fVec53[((IOTA - 198) & 511)]) + ((0.011381723f * fVec53[((IOTA - 197) & 511)]) + ((0.0062579345f * fVec53[((IOTA - 196) & 511)]) + ((0.00181933213f * fVec53[((IOTA - 178) & 511)]) + ((0.00540307723f * fVec53[((IOTA - 177) & 511)]) + ((0.00790630281f * fVec53[((IOTA - 176) & 511)]) + ((0.00800964236f * fVec53[((IOTA - 175) & 511)]) + ((0.00514543103f * fVec53[((IOTA - 174) & 511)]) + ((0.00300865714f * fVec53[((IOTA - 163) & 511)]) + ((0.00556994183f * fVec53[((IOTA - 162) & 511)]) + ((0.00413364405f * fVec53[((IOTA - 161) & 511)]) + ((0.00044925604f * fVec53[((IOTA - 160) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.059827853f * fVec53[((IOTA - 14) & 511)]) + ((0.0377110727f * fVec53[((IOTA - 18) & 511)]) + ((0.0608397126f * fVec53[((IOTA - 15) & 511)]) + ((0.0420641378f * fVec53[((IOTA - 19) & 511)]) + ((0.0273188669f * fVec53[((IOTA - 13) & 511)]) + (((0.0509961136f * fVec53[((IOTA - 16) & 511)]) + (0.0394460857f * fVec53[((IOTA - 17) & 511)])) + (0.0420925021f * fVec53[((IOTA - 20) & 511)]))))))) + (0.0392596833f * fVec53[((IOTA - 21) & 511)])) + (0.0311766192f * fVec53[((IOTA - 22) & 511)])) + (0.0275052693f * fVec53[((IOTA - 23) & 511)])) + (0.0320177004f * fVec53[((IOTA - 24) & 511)])) + (0.0386316702f * fVec53[((IOTA - 25) & 511)])) + (0.0541182309f * fVec53[((IOTA - 26) & 511)])) + (0.0689363331f * fVec53[((IOTA - 27) & 511)])) + (0.0743016675f * fVec53[((IOTA - 28) & 511)])) + (0.0794042572f * fVec53[((IOTA - 29) & 511)])) + (0.0863695741f * fVec53[((IOTA - 30) & 511)])) + (0.0966154486f * fVec53[((IOTA - 31) & 511)])) + (0.109206662f * fVec53[((IOTA - 32) & 511)])) + (0.117871717f * fVec53[((IOTA - 33) & 511)])) + (0.119222447f * fVec53[((IOTA - 34) & 511)])) + (0.113904975f * fVec53[((IOTA - 35) & 511)])) + (0.101879805f * fVec53[((IOTA - 36) & 511)])) + (0.0840449184f * fVec53[((IOTA - 37) & 511)])) + (0.0619501136f * fVec53[((IOTA - 38) & 511)])) + (0.0400045179f * fVec53[((IOTA - 39) & 511)])) + (0.0288390033f * fVec53[((IOTA - 40) & 511)])) + (0.0265123546f * fVec53[((IOTA - 41) & 511)])) + (0.0267635025f * fVec53[((IOTA - 42) & 511)])) + (0.027831981f * fVec53[((IOTA - 43) & 511)])) + (0.0229315646f * fVec53[((IOTA - 44) & 511)])) + (0.0126584312f * fVec53[((IOTA - 45) & 511)])) + (0.00351464283f * fVec53[((IOTA - 46) & 511)])) + (0.000427613501f * fVec53[((IOTA - 47) & 511)])) + (0.00464295363f * fVec53[((IOTA - 48) & 511)])) + (0.0157505572f * fVec53[((IOTA - 49) & 511)])) + (0.0348744504f * fVec53[((IOTA - 50) & 511)])) + (0.0540720262f * fVec53[((IOTA - 51) & 511)])) + (0.0644821078f * fVec53[((IOTA - 52) & 511)])) + (0.0632638633f * fVec53[((IOTA - 53) & 511)])) + (0.052025333f * fVec53[((IOTA - 54) & 511)])) + (0.0369527601f * fVec53[((IOTA - 55) & 511)])) + (0.0258339271f * fVec53[((IOTA - 56) & 511)])) + (0.0190807562f * fVec53[((IOTA - 57) & 511)])) + (0.0147576807f * fVec53[((IOTA - 58) & 511)])) + (0.015106922f * fVec53[((IOTA - 59) & 511)])) + (0.0125699025f * fVec53[((IOTA - 60) & 511)])) + (0.00334149972f * fVec53[((IOTA - 61) & 511)])) + (0.00522937998f * fVec53[((IOTA - 65) & 511)])) + (0.0129160406f * fVec53[((IOTA - 66) & 511)])) + (0.0167434718f * fVec53[((IOTA - 67) & 511)])) + (0.0136833657f * fVec53[((IOTA - 68) & 511)])) + (0.00530520407f * fVec53[((IOTA - 69) & 511)])) + (0.00344819995f * fVec53[((IOTA - 77) & 511)])) + (0.00785559323f * fVec53[((IOTA - 78) & 511)])) + (0.00855872873f * fVec53[((IOTA - 79) & 511)])) + (0.00670394069f * fVec53[((IOTA - 80) & 511)])) + (0.00347069232f * fVec53[((IOTA - 81) & 511)])) + (0.000851311721f * fVec53[((IOTA - 82) & 511)])) + (0.00321064517f * fVec53[((IOTA - 83) & 511)])) + (0.00964161195f * fVec53[((IOTA - 84) & 511)])) + (0.0178962685f * fVec53[((IOTA - 85) & 511)])) + (0.0266116317f * fVec53[((IOTA - 86) & 511)])) + (0.0314317197f * fVec53[((IOTA - 87) & 511)])) + (0.0319477133f * fVec53[((IOTA - 88) & 511)])) + (0.0297840144f * fVec53[((IOTA - 89) & 511)])) + (0.0247272607f * fVec53[((IOTA - 90) & 511)])) + (0.0213389285f * fVec53[((IOTA - 91) & 511)])) + (0.0229906589f * fVec53[((IOTA - 92) & 511)])) + (0.0274962932f * fVec53[((IOTA - 93) & 511)])) + (0.0327432193f * fVec53[((IOTA - 94) & 511)])) + (0.0377248488f * fVec53[((IOTA - 95) & 511)])) + (0.0422746949f * fVec53[((IOTA - 96) & 511)])) + (0.0449494757f * fVec53[((IOTA - 97) & 511)])) + (0.0435910337f * fVec53[((IOTA - 98) & 511)])) + (0.0401329733f * fVec53[((IOTA - 99) & 511)])) + (0.0347026363f * fVec53[((IOTA - 100) & 511)])) + (0.0276655219f * fVec53[((IOTA - 101) & 511)])) + (0.0225955471f * fVec53[((IOTA - 102) & 511)])) + (0.0187994353f * fVec53[((IOTA - 103) & 511)])) + (0.0163305942f * fVec53[((IOTA - 104) & 511)])) + (0.0174658857f * fVec53[((IOTA - 105) & 511)])) + (0.0199321788f * fVec53[((IOTA - 106) & 511)])) + (0.0205177926f * fVec53[((IOTA - 107) & 511)])) + (0.0181921795f * fVec53[((IOTA - 108) & 511)])) + (0.0113393962f * fVec53[((IOTA - 109) & 511)])) + (0.000728545245f * fVec53[((IOTA - 110) & 511)])) + (0.00335612521f * fVec53[((IOTA - 123) & 511)])) + (0.00570829352f * fVec53[((IOTA - 124) & 511)])) + (0.00433127396f * fVec53[((IOTA - 125) & 511)])) + (2.2307504e-05f * fVec53[((IOTA - 126) & 511)])) + (0.000400652178f * fVec53[((IOTA - 142) & 511)])) + (0.00320392335f * fVec53[((IOTA - 143) & 511)])) + (0.0050897724f * fVec53[((IOTA - 144) & 511)])) + (0.004216264f * fVec53[((IOTA - 145) & 511)])) + (0.000800712965f * fVec53[((IOTA - 146) & 511)])) + (0.00706352293f * fVec53[((IOTA - 330) & 511)])))))))))))))))))) + (0.00345769152f * fVec53[((IOTA - 376) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00335239479f * fVec53[((IOTA - 377) & 511)])) + (0.00184219424f * fVec53[((IOTA - 378) & 511)])) + (0.00854188763f * fVec53[((IOTA - 481) & 511)]))))))))))))))))))))))))))) + (0.00868552085f * fVec53[((IOTA - 482) & 511)])) + (0.00817584153f * fVec53[((IOTA - 483) & 511)])) + (0.00699482672f * fVec53[((IOTA - 484) & 511)])) + (0.00502802012f * fVec53[((IOTA - 485) & 511)])) + (0.00209045922f * fVec53[((IOTA - 486) & 511)])) + (0.000944531057f * fVec53[((IOTA - 501) & 511)])) + (0.00235183584f * fVec53[((IOTA - 502) & 511)])) + (0.00399241131f * fVec53[((IOTA - 503) & 511)])) + (0.00567852566f * fVec53[((IOTA - 504) & 511)])) + (0.00731315464f * fVec53[((IOTA - 505) & 511)])) + (0.00887812767f * fVec53[((IOTA - 506) & 511)])) + (0.0104728686f * fVec53[((IOTA - 507) & 511)])) + (0.012123527f * fVec53[((IOTA - 508) & 511)])) + (0.0137919132f * fVec53[((IOTA - 509) & 511)])) + (0.0154259149f * fVec53[((IOTA - 510) & 511)])) + (0.0168608818f * fVec53[((IOTA - 511) & 511)])))) : (iSlow158 ? (((((((((((((((((((((((((((((((0.00913522951f * fVec52[((IOTA - 454) & 511)]) + ((0.00726425601f * fVec52[((IOTA - 453) & 511)]) + ((0.00635562977f * fVec52[((IOTA - 452) & 511)]) + ((0.0063731377f * fVec52[((IOTA - 451) & 511)]) + ((0.00658133719f * fVec52[((IOTA - 450) & 511)]) + ((0.00597451674f * fVec52[((IOTA - 449) & 511)]) + ((0.00439263368f * fVec52[((IOTA - 448) & 511)]) + ((0.00234194426f * fVec52[((IOTA - 447) & 511)]) + ((0.000380494632f * fVec52[((IOTA - 446) & 511)]) + ((0.000250635669f * fVec52[((IOTA - 436) & 511)]) + ((0.0021408177f * fVec52[((IOTA - 435) & 511)]) + ((0.0028172438f * fVec52[((IOTA - 434) & 511)]) + ((0.00265662046f * fVec52[((IOTA - 433) & 511)]) + ((0.00202529738f * fVec52[((IOTA - 432) & 511)]) + ((0.0010873368f * fVec52[((IOTA - 431) & 511)]) + ((0.000103616621f * fVec52[((IOTA - 430) & 511)]) + ((0.00173976226f * fVec52[((IOTA - 421) & 511)]) + ((0.00356076332f * fVec52[((IOTA - 420) & 511)]) + ((0.00383682968f * fVec52[((IOTA - 419) & 511)]) + ((0.00280132052f * fVec52[((IOTA - 418) & 511)]) + ((0.000940974802f * fVec52[((IOTA - 417) & 511)]) + ((0.00160140079f * fVec52[((IOTA - 411) & 511)]) + ((0.00342487544f * fVec52[((IOTA - 410) & 511)]) + ((0.00464674784f * fVec52[((IOTA - 409) & 511)]) + ((0.00502330018f * fVec52[((IOTA - 408) & 511)]) + ((0.00468214974f * fVec52[((IOTA - 407) & 511)]) + ((0.00418269541f * fVec52[((IOTA - 406) & 511)]) + ((0.00380405597f * fVec52[((IOTA - 405) & 511)]) + ((0.00348752458f * fVec52[((IOTA - 404) & 511)]) + ((0.00311375502f * fVec52[((IOTA - 403) & 511)]) + ((0.00244532898f * fVec52[((IOTA - 402) & 511)]) + ((0.00143575296f * fVec52[((IOTA - 401) & 511)]) + ((0.00022675097f * fVec52[((IOTA - 400) & 511)]) + ((0.00019985158f * fVec52[((IOTA - 395) & 511)]) + ((0.00106140366f * fVec52[((IOTA - 394) & 511)]) + ((0.0017789905f * fVec52[((IOTA - 393) & 511)]) + ((0.00210232381f * fVec52[((IOTA - 392) & 511)]) + ((0.00180882728f * fVec52[((IOTA - 391) & 511)]) + ((0.00096829934f * fVec52[((IOTA - 390) & 511)]) + ((2.78269872e-05f * fVec52[((IOTA - 389) & 511)]) + (((0.00029353518f * fVec52[((IOTA - 386) & 511)]) + ((0.00165152783f * fVec52[((IOTA - 385) & 511)]) + ((0.00277774502f * fVec52[((IOTA - 384) & 511)]) + ((0.00282060634f * fVec52[((IOTA - 383) & 511)]) + ((0.00147080747f * fVec52[((IOTA - 382) & 511)]) + ((0.000723499805f * fVec52[((IOTA - 360) & 511)]) + ((0.00238917302f * fVec52[((IOTA - 359) & 511)]) + ((0.00302513409f * fVec52[((IOTA - 358) & 511)]) + ((0.00248803571f * fVec52[((IOTA - 357) & 511)]) + ((0.00118345581f * fVec52[((IOTA - 356) & 511)]) + ((0.000413191039f * fVec52[((IOTA - 350) & 511)]) + ((0.00154474191f * fVec52[((IOTA - 349) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((fSlow162 * fTemp0) + (0.162936896f * fVec52[((IOTA - 1) & 511)])) + (0.257790774f * fVec52[((IOTA - 2) & 511)])) + (0.313184083f * fVec52[((IOTA - 3) & 511)])) + (0.298456669f * fVec52[((IOTA - 4) & 511)])) + (0.197986633f * fVec52[((IOTA - 5) & 511)])) + (0.0542216823f * fVec52[((IOTA - 6) & 511)])) + (0.0704090223f * fVec52[((IOTA - 11) & 511)])) + (0.160123944f * fVec52[((IOTA - 12) & 511)])) + (0.195172876f * fVec52[((IOTA - 13) & 511)])) + (0.173884585f * fVec52[((IOTA - 14) & 511)])) + (0.130135447f * fVec52[((IOTA - 15) & 511)])) + (0.079771623f * fVec52[((IOTA - 16) & 511)])) + (0.0381323099f * fVec52[((IOTA - 17) & 511)])) + (0.013904145f * fVec52[((IOTA - 18) & 511)])) + (0.00238113385f * fVec52[((IOTA - 50) & 511)])) + (0.00917306729f * fVec52[((IOTA - 51) & 511)])) + (0.00566985086f * fVec52[((IOTA - 52) & 511)])) + (0.00290992297f * fVec52[((IOTA - 61) & 511)])) + (0.0098931659f * fVec52[((IOTA - 62) & 511)])) + (0.0155838486f * fVec52[((IOTA - 63) & 511)])) + (0.0182272904f * fVec52[((IOTA - 64) & 511)])) + (0.0171106178f * fVec52[((IOTA - 65) & 511)])) + (0.0161119401f * fVec52[((IOTA - 66) & 511)])) + (0.0144029045f * fVec52[((IOTA - 67) & 511)])) + (0.00925600622f * fVec52[((IOTA - 68) & 511)])) + (0.000593408942f * fVec52[((IOTA - 76) & 511)])) + (0.000221224036f * fVec52[((IOTA - 84) & 511)])) + (0.00351968035f * fVec52[((IOTA - 112) & 511)])) + (0.0104125626f * fVec52[((IOTA - 113) & 511)])) + (0.0167998839f * fVec52[((IOTA - 114) & 511)])) + (0.0196778066f * fVec52[((IOTA - 115) & 511)])) + (0.0158957411f * fVec52[((IOTA - 116) & 511)])) + (0.00792746432f * fVec52[((IOTA - 117) & 511)])) + (0.00237116264f * fVec52[((IOTA - 122) & 511)])) + (0.00784804113f * fVec52[((IOTA - 123) & 511)])) + (0.00941836834f * fVec52[((IOTA - 124) & 511)])) + (0.00701524364f * fVec52[((IOTA - 125) & 511)])) + (0.00248127244f * fVec52[((IOTA - 126) & 511)])) + (3.12281772e-05f * fVec52[((IOTA - 129) & 511)])) + (0.00315607525f * fVec52[((IOTA - 130) & 511)])) + (0.00479716761f * fVec52[((IOTA - 131) & 511)])) + (0.00411463529f * fVec52[((IOTA - 132) & 511)])) + (0.00183290523f * fVec52[((IOTA - 133) & 511)])) + (0.000189338811f * fVec52[((IOTA - 134) & 511)])) + (0.000780390576f * fVec52[((IOTA - 135) & 511)])) + (0.00337061286f * fVec52[((IOTA - 136) & 511)])) + (0.00596195599f * fVec52[((IOTA - 137) & 511)])) + (0.00678787474f * fVec52[((IOTA - 138) & 511)])) + (0.00597494189f * fVec52[((IOTA - 139) & 511)])) + (0.00318753486f * fVec52[((IOTA - 140) & 511)])) + (0.00465018768f * fVec52[((IOTA - 153) & 511)])) + (0.00650759554f * fVec52[((IOTA - 154) & 511)])) + (0.00438888511f * fVec52[((IOTA - 155) & 511)])) + (0.00668255752f * fVec52[((IOTA - 168) & 511)])) + (0.0151493615f * fVec52[((IOTA - 169) & 511)])) + (0.0225375257f * fVec52[((IOTA - 170) & 511)])) + (0.0265939161f * fVec52[((IOTA - 171) & 511)])) + (0.026449874f * fVec52[((IOTA - 172) & 511)])) + (0.0225079209f * fVec52[((IOTA - 173) & 511)])) + (0.0167125389f * fVec52[((IOTA - 174) & 511)])) + (0.0115919989f * fVec52[((IOTA - 175) & 511)])) + (0.00821141526f * fVec52[((IOTA - 176) & 511)])) + (0.0052850279f * fVec52[((IOTA - 177) & 511)])) + (0.00135915168f * fVec52[((IOTA - 178) & 511)])) + (0.00195426121f * fVec52[((IOTA - 185) & 511)])) + (0.00876694825f * fVec52[((IOTA - 186) & 511)])) + (0.015221402f * fVec52[((IOTA - 187) & 511)])) + (0.0213835184f * fVec52[((IOTA - 188) & 511)])) + (0.0272026695f * fVec52[((IOTA - 189) & 511)])) + (0.032280039f * fVec52[((IOTA - 190) & 511)])) + (0.0359930396f * fVec52[((IOTA - 191) & 511)])) + (0.0375145897f * fVec52[((IOTA - 192) & 511)])) + (0.0359345637f * fVec52[((IOTA - 193) & 511)])) + (0.0311130472f * fVec52[((IOTA - 194) & 511)])) + (0.0242115837f * fVec52[((IOTA - 195) & 511)])) + (0.0171994716f * fVec52[((IOTA - 196) & 511)])) + (0.011458816f * fVec52[((IOTA - 197) & 511)])) + (0.00731933024f * fVec52[((IOTA - 198) & 511)])) + (0.004668043f * fVec52[((IOTA - 199) & 511)])) + (0.00365035096f * fVec52[((IOTA - 200) & 511)])) + (0.00394744193f * fVec52[((IOTA - 201) & 511)])) + (0.00449543865f * fVec52[((IOTA - 202) & 511)])) + (0.00468079699f * fVec52[((IOTA - 203) & 511)])) + (0.00469954172f * fVec52[((IOTA - 204) & 511)])) + (0.00478020078f * fVec52[((IOTA - 205) & 511)])) + (0.00492459163f * fVec52[((IOTA - 206) & 511)])) + (0.00525198318f * fVec52[((IOTA - 207) & 511)])) + (0.00565926125f * fVec52[((IOTA - 208) & 511)])) + (0.00597281661f * fVec52[((IOTA - 209) & 511)])) + (0.00655822502f * fVec52[((IOTA - 210) & 511)])) + (0.00815239921f * fVec52[((IOTA - 211) & 511)])) + (0.0105014537f * fVec52[((IOTA - 212) & 511)])) + (0.0124259181f * fVec52[((IOTA - 213) & 511)])) + (0.0134685766f * fVec52[((IOTA - 214) & 511)])) + (0.0141936615f * fVec52[((IOTA - 215) & 511)])) + (0.014472858f * fVec52[((IOTA - 216) & 511)])) + (0.0132116415f * fVec52[((IOTA - 217) & 511)])) + (0.010442283f * fVec52[((IOTA - 218) & 511)])) + (0.00766295381f * fVec52[((IOTA - 219) & 511)])) + (0.00586000131f * fVec52[((IOTA - 220) & 511)])) + (0.00519165304f * fVec52[((IOTA - 221) & 511)])) + (0.00564414961f * fVec52[((IOTA - 222) & 511)])) + (0.00636892486f * fVec52[((IOTA - 223) & 511)])) + (0.00646025129f * fVec52[((IOTA - 224) & 511)])) + (0.00582247367f * fVec52[((IOTA - 225) & 511)])) + (0.00458143186f * fVec52[((IOTA - 226) & 511)])) + (0.00340709696f * fVec52[((IOTA - 227) & 511)])) + (0.00339047844f * fVec52[((IOTA - 228) & 511)])) + (0.00513352547f * fVec52[((IOTA - 229) & 511)])) + (0.00819599442f * fVec52[((IOTA - 230) & 511)])) + (0.0111068059f * fVec52[((IOTA - 231) & 511)])) + (0.0121248458f * fVec52[((IOTA - 232) & 511)])) + (0.0103535466f * fVec52[((IOTA - 233) & 511)])) + (0.00640656846f * fVec52[((IOTA - 234) & 511)])) + (0.00151401618f * fVec52[((IOTA - 235) & 511)])) + (0.00124316756f * fVec52[((IOTA - 242) & 511)])) + (0.00283254869f * fVec52[((IOTA - 243) & 511)])) + (0.00512281992f * fVec52[((IOTA - 244) & 511)])) + (0.00816472806f * fVec52[((IOTA - 245) & 511)])) + (0.0118961632f * fVec52[((IOTA - 246) & 511)])) + (0.0149729308f * fVec52[((IOTA - 247) & 511)])) + (0.0152618671f * fVec52[((IOTA - 248) & 511)])) + (0.0121573489f * fVec52[((IOTA - 249) & 511)])) + (0.00678663794f * fVec52[((IOTA - 250) & 511)])) + (0.000926675275f * fVec52[((IOTA - 251) & 511)])) + (0.00275834324f * fVec52[((IOTA - 259) & 511)])) + (0.00686331652f * fVec52[((IOTA - 260) & 511)])) + (0.0112196598f * fVec52[((IOTA - 261) & 511)])) + (0.0152351614f * fVec52[((IOTA - 262) & 511)])) + (0.0181858577f * fVec52[((IOTA - 263) & 511)])) + (0.0197093822f * fVec52[((IOTA - 264) & 511)])) + (0.0200225897f * fVec52[((IOTA - 265) & 511)])) + (0.0194160398f * fVec52[((IOTA - 266) & 511)])) + (0.0183428489f * fVec52[((IOTA - 267) & 511)])) + (0.0168783795f * fVec52[((IOTA - 268) & 511)])) + (0.0148019502f * fVec52[((IOTA - 269) & 511)])) + (0.0124690495f * fVec52[((IOTA - 270) & 511)])) + (0.0107209003f * fVec52[((IOTA - 271) & 511)])) + (0.00975453295f * fVec52[((IOTA - 272) & 511)])) + (0.0089943558f * fVec52[((IOTA - 273) & 511)])) + (0.00815645605f * fVec52[((IOTA - 274) & 511)])) + (0.0072677345f * fVec52[((IOTA - 275) & 511)])) + (0.0066145747f * fVec52[((IOTA - 276) & 511)])) + (0.0064314194f * fVec52[((IOTA - 277) & 511)])) + (0.0063610021f * fVec52[((IOTA - 278) & 511)])) + (0.00613463763f * fVec52[((IOTA - 279) & 511)])) + (0.00528784888f * fVec52[((IOTA - 280) & 511)])) + (0.00358812651f * fVec52[((IOTA - 281) & 511)])) + (0.00150052784f * fVec52[((IOTA - 282) & 511)])) + (0.000576172024f * fVec52[((IOTA - 302) & 511)])) + (0.00376281794f * fVec52[((IOTA - 303) & 511)])) + (0.00662091328f * fVec52[((IOTA - 304) & 511)])) + (0.008901136f * fVec52[((IOTA - 305) & 511)])) + (0.0110270735f * fVec52[((IOTA - 306) & 511)])) + (0.0134685384f * fVec52[((IOTA - 307) & 511)])) + (0.0155794034f * fVec52[((IOTA - 308) & 511)])) + (0.016383253f * fVec52[((IOTA - 309) & 511)])) + (0.015282467f * fVec52[((IOTA - 310) & 511)])) + (0.0123007353f * fVec52[((IOTA - 311) & 511)])) + (0.00786582008f * fVec52[((IOTA - 312) & 511)])) + (0.00267517194f * fVec52[((IOTA - 313) & 511)])) + (0.000927602407f * fVec52[((IOTA - 338) & 511)])) + (0.00207890291f * fVec52[((IOTA - 339) & 511)])) + (0.00299773226f * fVec52[((IOTA - 340) & 511)])) + (0.00398558797f * fVec52[((IOTA - 341) & 511)])) + (0.00505622849f * fVec52[((IOTA - 342) & 511)])) + (0.00595874852f * fVec52[((IOTA - 343) & 511)])) + (0.00651076483f * fVec52[((IOTA - 344) & 511)])) + (0.00633568736f * fVec52[((IOTA - 345) & 511)])) + (0.0053920066f * fVec52[((IOTA - 346) & 511)])) + (0.00411421014f * fVec52[((IOTA - 347) & 511)])) + (0.0028177849f * fVec52[((IOTA - 348) & 511)])) + (0.0113179032f * fVec52[((IOTA - 455) & 511)])))))))))))))) + (0.012424333f * fVec52[((IOTA - 456) & 511)])))))))))))))))))))))))))))))))))))))))))) + (0.0115981828f * fVec52[((IOTA - 457) & 511)])) + (0.00901673362f * fVec52[((IOTA - 458) & 511)])) + (0.00535861449f * fVec52[((IOTA - 459) & 511)])) + (0.00161616411f * fVec52[((IOTA - 460) & 511)])) + (0.000160546042f * fVec52[((IOTA - 483) & 511)])) + (0.00117703993f * fVec52[((IOTA - 484) & 511)])) + (0.00261808792f * fVec52[((IOTA - 485) & 511)])) + (0.00387312053f * fVec52[((IOTA - 486) & 511)])) + (0.0042803986f * fVec52[((IOTA - 487) & 511)])) + (0.00352818286f * fVec52[((IOTA - 488) & 511)])) + (0.00196454208f * fVec52[((IOTA - 489) & 511)])) + (0.000441404525f * fVec52[((IOTA - 490) & 511)])) + (0.000673256814f * fVec52[((IOTA - 492) & 511)])) + (0.00249537919f * fVec52[((IOTA - 493) & 511)])) + (0.00466653565f * fVec52[((IOTA - 494) & 511)])) + (0.00633962918f * fVec52[((IOTA - 495) & 511)])) + (0.0070242486f * fVec52[((IOTA - 496) & 511)])) + (0.00672151521f * fVec52[((IOTA - 497) & 511)])) + (0.00577095523f * fVec52[((IOTA - 498) & 511)])) + (0.00470564794f * fVec52[((IOTA - 499) & 511)])) + (0.00391435856f * fVec52[((IOTA - 500) & 511)])) + (0.00350279082f * fVec52[((IOTA - 501) & 511)])) + (0.00340558961f * fVec52[((IOTA - 502) & 511)])) + (0.00363087188f * fVec52[((IOTA - 503) & 511)])) + (0.00392096769f * fVec52[((IOTA - 504) & 511)])) + (0.0036143302f * fVec52[((IOTA - 505) & 511)])) + (0.00230437797f * fVec52[((IOTA - 506) & 511)])) + (0.000138052274f * fVec52[((IOTA - 507) & 511)])) - ((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.000634762924f * fVec52[((IOTA - 387) & 511)]) + ((0.000918326899f * fVec52[((IOTA - 381) & 511)]) + ((0.00415212428f * fVec52[((IOTA - 380) & 511)]) + ((0.00811301544f * fVec52[((IOTA - 379) & 511)]) + ((0.0123862252f * fVec52[((IOTA - 378) & 511)]) + ((0.0162530858f * fVec52[((IOTA - 377) & 511)]) + ((0.0190100372f * fVec52[((IOTA - 376) & 511)]) + ((0.0204928257f * fVec52[((IOTA - 375) & 511)]) + ((0.0210565925f * fVec52[((IOTA - 374) & 511)]) + ((0.0210883599f * fVec52[((IOTA - 373) & 511)]) + ((0.0208929144f * fVec52[((IOTA - 372) & 511)]) + ((0.0207663793f * fVec52[((IOTA - 371) & 511)]) + ((0.0206069537f * fVec52[((IOTA - 370) & 511)]) + ((0.020162845f * fVec52[((IOTA - 369) & 511)]) + ((0.0193010215f * fVec52[((IOTA - 368) & 511)]) + ((0.0177127235f * fVec52[((IOTA - 367) & 511)]) + ((0.0126568042f * fVec52[((IOTA - 365) & 511)]) + ((0.0101130754f * fVec52[((IOTA - 364) & 511)]) + ((0.00753715308f * fVec52[((IOTA - 363) & 511)]) + ((0.00474267313f * fVec52[((IOTA - 362) & 511)]) + ((0.00180623773f * fVec52[((IOTA - 361) & 511)]) + ((2.26092525e-05f * fVec52[((IOTA - 355) & 511)]) + ((0.000663440209f * fVec52[((IOTA - 354) & 511)]) + ((0.000752640888f * fVec52[((IOTA - 353) & 511)]) + ((0.000614820514f * fVec52[((IOTA - 352) & 511)]) + ((0.000305709429f * fVec52[((IOTA - 351) & 511)]) + ((0.000745838974f * fVec52[((IOTA - 337) & 511)]) + ((0.00278914627f * fVec52[((IOTA - 336) & 511)]) + ((0.00444256794f * fVec52[((IOTA - 335) & 511)]) + ((0.00510886777f * fVec52[((IOTA - 334) & 511)]) + ((0.00467322208f * fVec52[((IOTA - 333) & 511)]) + ((0.00346023869f * fVec52[((IOTA - 332) & 511)]) + ((0.00202943292f * fVec52[((IOTA - 331) & 511)]) + ((0.00138033135f * fVec52[((IOTA - 330) & 511)]) + ((0.0023572878f * fVec52[((IOTA - 329) & 511)]) + ((0.00448639505f * fVec52[((IOTA - 328) & 511)]) + ((0.0067716036f * fVec52[((IOTA - 327) & 511)]) + ((0.00835510995f * fVec52[((IOTA - 326) & 511)]) + ((0.00838471483f * fVec52[((IOTA - 325) & 511)]) + ((0.00665163854f * fVec52[((IOTA - 324) & 511)]) + ((0.00403671991f * fVec52[((IOTA - 323) & 511)]) + ((0.00170200272f * fVec52[((IOTA - 322) & 511)]) + ((0.000273283571f * fVec52[((IOTA - 321) & 511)]) + ((0.000153202564f * fVec52[((IOTA - 320) & 511)]) + ((0.00138802221f * fVec52[((IOTA - 319) & 511)]) + ((0.00357622281f * fVec52[((IOTA - 318) & 511)]) + ((0.0057673608f * fVec52[((IOTA - 317) & 511)]) + ((0.00661998568f * fVec52[((IOTA - 316) & 511)]) + ((0.00536645995f * fVec52[((IOTA - 315) & 511)]) + ((0.002093744f * fVec52[((IOTA - 314) & 511)]) + ((0.00233034976f * fVec52[((IOTA - 301) & 511)]) + ((0.00411822973f * fVec52[((IOTA - 300) & 511)]) + ((0.00464071846f * fVec52[((IOTA - 299) & 511)]) + ((0.00437388942f * fVec52[((IOTA - 298) & 511)]) + ((0.00382423028f * fVec52[((IOTA - 297) & 511)]) + ((0.00387431867f * fVec52[((IOTA - 296) & 511)]) + ((0.00499582104f * fVec52[((IOTA - 295) & 511)]) + ((0.00697010243f * fVec52[((IOTA - 294) & 511)]) + ((0.00935575832f * fVec52[((IOTA - 293) & 511)]) + ((0.0113744084f * fVec52[((IOTA - 292) & 511)]) + ((0.0125982519f * fVec52[((IOTA - 291) & 511)]) + ((0.0128641147f * fVec52[((IOTA - 290) & 511)]) + ((0.0121212518f * fVec52[((IOTA - 289) & 511)]) + ((0.0108104879f * fVec52[((IOTA - 288) & 511)]) + ((0.0094095571f * fVec52[((IOTA - 287) & 511)]) + ((0.00814034045f * fVec52[((IOTA - 286) & 511)]) + ((0.00652158633f * fVec52[((IOTA - 285) & 511)]) + ((0.00395003101f * fVec52[((IOTA - 284) & 511)]) + ((0.000985188875f * fVec52[((IOTA - 283) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.088903144f * fVec52[((IOTA - 43) & 511)]) + ((0.103211477f * fVec52[((IOTA - 42) & 511)]) + ((0.116357803f * fVec52[((IOTA - 41) & 511)]) + ((0.112935901f * fVec52[((IOTA - 40) & 511)]) + ((0.0949714184f * fVec52[((IOTA - 39) & 511)]) + ((0.0747380853f * fVec52[((IOTA - 38) & 511)]) + ((0.0563099347f * fVec52[((IOTA - 37) & 511)]) + ((0.0494039506f * fVec52[((IOTA - 36) & 511)]) + ((0.0580672845f * fVec52[((IOTA - 35) & 511)]) + ((0.0737669989f * fVec52[((IOTA - 34) & 511)]) + ((0.0892261639f * fVec52[((IOTA - 33) & 511)]) + ((0.10303539f * fVec52[((IOTA - 32) & 511)]) + ((0.105986781f * fVec52[((IOTA - 31) & 511)]) + ((0.0884402469f * fVec52[((IOTA - 30) & 511)]) + ((0.0605123416f * fVec52[((IOTA - 29) & 511)]) + ((0.0364038721f * fVec52[((IOTA - 28) & 511)]) + ((0.0181512292f * fVec52[((IOTA - 27) & 511)]) + ((0.00806389377f * fVec52[((IOTA - 26) & 511)]) + ((0.0106805516f * fVec52[((IOTA - 25) & 511)]) + ((0.0202327594f * fVec52[((IOTA - 24) & 511)]) + ((0.0259178765f * fVec52[((IOTA - 23) & 511)]) + ((0.0255191792f * fVec52[((IOTA - 22) & 511)]) + ((0.0188557524f * fVec52[((IOTA - 21) & 511)]) + ((0.0111358697f * fVec52[((IOTA - 20) & 511)]) + ((0.00141847739f * fVec52[((IOTA - 19) & 511)]) + ((0.0396438129f * fVec52[((IOTA - 10) & 511)]) + ((0.13041839f * fVec52[((IOTA - 9) & 511)]) + ((0.151384473f * fVec52[((IOTA - 8) & 511)]) + ((0.0804921091f * fVec52[((IOTA - 7) & 511)]) + (((0.0785058066f * fVec52[((IOTA - 44) & 511)]) + (0.0684496611f * fVec52[((IOTA - 45) & 511)])) + (0.0598251708f * fVec52[((IOTA - 46) & 511)]))))))))))))))))))))))))))))))) + (0.0515780859f * fVec52[((IOTA - 47) & 511)])) + (0.0374999829f * fVec52[((IOTA - 48) & 511)])) + (0.0156892426f * fVec52[((IOTA - 49) & 511)])) + (0.00698158098f * fVec52[((IOTA - 53) & 511)])) + (0.0197243765f * fVec52[((IOTA - 54) & 511)])) + (0.0261570718f * fVec52[((IOTA - 55) & 511)])) + (0.0260361414f * fVec52[((IOTA - 56) & 511)])) + (0.0200506859f * fVec52[((IOTA - 57) & 511)])) + (0.0128455628f * fVec52[((IOTA - 58) & 511)])) + (0.00760235311f * fVec52[((IOTA - 59) & 511)])) + (0.00299433107f * fVec52[((IOTA - 60) & 511)])) + (0.00127918785f * fVec52[((IOTA - 69) & 511)])) + (0.01703077f * fVec52[((IOTA - 70) & 511)])) + (0.0322396122f * fVec52[((IOTA - 71) & 511)])) + (0.0405685939f * fVec52[((IOTA - 72) & 511)])) + (0.0361705124f * fVec52[((IOTA - 73) & 511)])) + (0.0212804042f * fVec52[((IOTA - 74) & 511)])) + (0.00704848161f * fVec52[((IOTA - 75) & 511)])) + (0.00271246769f * fVec52[((IOTA - 77) & 511)])) + (0.0145966876f * fVec52[((IOTA - 78) & 511)])) + (0.0249538682f * fVec52[((IOTA - 79) & 511)])) + (0.0273687802f * fVec52[((IOTA - 80) & 511)])) + (0.0225057174f * fVec52[((IOTA - 81) & 511)])) + (0.0127004385f * fVec52[((IOTA - 82) & 511)])) + (0.00319310045f * fVec52[((IOTA - 83) & 511)])) + (0.00421747891f * fVec52[((IOTA - 85) & 511)])) + (0.0134533495f * fVec52[((IOTA - 86) & 511)])) + (0.0218936801f * fVec52[((IOTA - 87) & 511)])) + (0.0266314447f * fVec52[((IOTA - 88) & 511)])) + (0.0269815605f * fVec52[((IOTA - 89) & 511)])) + (0.0227940734f * fVec52[((IOTA - 90) & 511)])) + (0.0185197424f * fVec52[((IOTA - 91) & 511)])) + (0.0164649189f * fVec52[((IOTA - 92) & 511)])) + (0.0157851297f * fVec52[((IOTA - 93) & 511)])) + (0.0171460584f * fVec52[((IOTA - 94) & 511)])) + (0.0181370061f * fVec52[((IOTA - 95) & 511)])) + (0.0176312141f * fVec52[((IOTA - 96) & 511)])) + (0.0159106217f * fVec52[((IOTA - 97) & 511)])) + (0.0131835826f * fVec52[((IOTA - 98) & 511)])) + (0.0125156594f * fVec52[((IOTA - 99) & 511)])) + (0.0138179213f * fVec52[((IOTA - 100) & 511)])) + (0.014729213f * fVec52[((IOTA - 101) & 511)])) + (0.0148953255f * fVec52[((IOTA - 102) & 511)])) + (0.0137494355f * fVec52[((IOTA - 103) & 511)])) + (0.0110693946f * fVec52[((IOTA - 104) & 511)])) + (0.00747983716f * fVec52[((IOTA - 105) & 511)])) + (0.00556654343f * fVec52[((IOTA - 106) & 511)])) + (0.00648568198f * fVec52[((IOTA - 107) & 511)])) + (0.00823545456f * fVec52[((IOTA - 108) & 511)])) + (0.00865061581f * fVec52[((IOTA - 109) & 511)])) + (0.00708832825f * fVec52[((IOTA - 110) & 511)])) + (0.00289631868f * fVec52[((IOTA - 111) & 511)])) + (0.000953844748f * fVec52[((IOTA - 118) & 511)])) + (0.00700218044f * fVec52[((IOTA - 119) & 511)])) + (0.00758851692f * fVec52[((IOTA - 120) & 511)])) + (0.00380629767f * fVec52[((IOTA - 121) & 511)])) + (0.00149156153f * fVec52[((IOTA - 127) & 511)])) + (0.00233707484f * fVec52[((IOTA - 128) & 511)])) + (0.000773201697f * fVec52[((IOTA - 141) & 511)])) + (0.00374990935f * fVec52[((IOTA - 142) & 511)])) + (0.00463237055f * fVec52[((IOTA - 143) & 511)])) + (0.00311568752f * fVec52[((IOTA - 144) & 511)])) + (0.000686745159f * fVec52[((IOTA - 145) & 511)])) + (0.000168275554f * fVec52[((IOTA - 146) & 511)])) + (0.00308948383f * fVec52[((IOTA - 147) & 511)])) + (0.00785523001f * fVec52[((IOTA - 148) & 511)])) + (0.0113320109f * fVec52[((IOTA - 149) & 511)])) + (0.0108357258f * fVec52[((IOTA - 150) & 511)])) + (0.00624652486f * fVec52[((IOTA - 151) & 511)])) + (0.000230886042f * fVec52[((IOTA - 152) & 511)])) + (0.00103647541f * fVec52[((IOTA - 156) & 511)])) + (0.0078354422f * fVec52[((IOTA - 157) & 511)])) + (0.0135395741f * fVec52[((IOTA - 158) & 511)])) + (0.0164336506f * fVec52[((IOTA - 159) & 511)])) + (0.0165444184f * fVec52[((IOTA - 160) & 511)])) + (0.0147692533f * fVec52[((IOTA - 161) & 511)])) + (0.0121168848f * fVec52[((IOTA - 162) & 511)])) + (0.00942888111f * fVec52[((IOTA - 163) & 511)])) + (0.00753324945f * fVec52[((IOTA - 164) & 511)])) + (0.00625541434f * fVec52[((IOTA - 165) & 511)])) + (0.00415413408f * fVec52[((IOTA - 166) & 511)])) + (5.36055304e-05f * fVec52[((IOTA - 167) & 511)])) + (0.00339457486f * fVec52[((IOTA - 179) & 511)])) + (0.00773599977f * fVec52[((IOTA - 180) & 511)])) + (0.0105009899f * fVec52[((IOTA - 181) & 511)])) + (0.0110833459f * fVec52[((IOTA - 182) & 511)])) + (0.00911142305f * fVec52[((IOTA - 183) & 511)])) + (0.00448593125f * fVec52[((IOTA - 184) & 511)])) + (0.00289492728f * fVec52[((IOTA - 236) & 511)])) + (0.00526288198f * fVec52[((IOTA - 237) & 511)])) + (0.00509874197f * fVec52[((IOTA - 238) & 511)])) + (0.00351763191f * fVec52[((IOTA - 239) & 511)])) + (0.00168360583f * fVec52[((IOTA - 240) & 511)])) + (8.9625828e-05f * fVec52[((IOTA - 241) & 511)])) + (0.00395667879f * fVec52[((IOTA - 252) & 511)])) + (0.00707286876f * fVec52[((IOTA - 253) & 511)])) + (0.00825597718f * fVec52[((IOTA - 254) & 511)])) + (0.00762129063f * fVec52[((IOTA - 255) & 511)])) + (0.00571506936f * fVec52[((IOTA - 256) & 511)])) + (0.00337548275f * fVec52[((IOTA - 257) & 511)])) + (0.0153196473f * fVec52[((IOTA - 366) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00067147892f * (fVec52[((IOTA - 258) & 511)] + fVec52[((IOTA - 388) & 511)]))) + (0.000475530978f * fVec52[((IOTA - 396) & 511)])) + (0.000970927533f * fVec52[((IOTA - 397) & 511)])) + (0.00123052951f * fVec52[((IOTA - 398) & 511)])) + (0.000828585122f * fVec52[((IOTA - 399) & 511)])) + (0.000442834571f * fVec52[((IOTA - 412) & 511)])) + (0.00207654526f * fVec52[((IOTA - 413) & 511)])) + (0.00274984073f * fVec52[((IOTA - 414) & 511)])) + (0.00234078523f * fVec52[((IOTA - 415) & 511)])) + (0.000989169814f * fVec52[((IOTA - 416) & 511)])) + (0.00123926392f * fVec52[((IOTA - 422) & 511)])) + (0.0042334022f * fVec52[((IOTA - 423) & 511)])) + (0.00627813954f * fVec52[((IOTA - 424) & 511)])) + (0.00689639943f * fVec52[((IOTA - 425) & 511)])) + (0.00602472154f * fVec52[((IOTA - 426) & 511)])) + (0.00432727905f * fVec52[((IOTA - 427) & 511)])) + (0.00257302402f * fVec52[((IOTA - 428) & 511)])) + (0.00105552934f * fVec52[((IOTA - 429) & 511)])) + (0.00254983455f * fVec52[((IOTA - 437) & 511)])) + (0.00509669352f * fVec52[((IOTA - 438) & 511)])) + (0.00632834388f * fVec52[((IOTA - 439) & 511)])) + (0.00614507264f * fVec52[((IOTA - 440) & 511)])) + (0.00508405548f * fVec52[((IOTA - 441) & 511)])) + (0.0037480928f * fVec52[((IOTA - 442) & 511)])) + (0.00253831735f * fVec52[((IOTA - 443) & 511)])) + (0.00169647578f * fVec52[((IOTA - 444) & 511)])) + (0.000940820202f * fVec52[((IOTA - 445) & 511)])) + (0.0014487002f * fVec52[((IOTA - 461) & 511)])) + (0.00364915282f * fVec52[((IOTA - 462) & 511)])) + (0.00513201812f * fVec52[((IOTA - 463) & 511)])) + (0.00616656151f * fVec52[((IOTA - 464) & 511)])) + (0.00682026194f * fVec52[((IOTA - 465) & 511)])) + (0.00685465941f * fVec52[((IOTA - 466) & 511)])) + (0.00609552534f * fVec52[((IOTA - 467) & 511)])) + (0.00470877858f * fVec52[((IOTA - 468) & 511)])) + (0.00311344583f * fVec52[((IOTA - 469) & 511)])) + (0.00183889549f * fVec52[((IOTA - 470) & 511)])) + (0.00142771425f * fVec52[((IOTA - 471) & 511)])) + (0.00226499513f * fVec52[((IOTA - 472) & 511)])) + (0.00402883533f * fVec52[((IOTA - 473) & 511)])) + (0.00580894668f * fVec52[((IOTA - 474) & 511)])) + (0.00688020606f * fVec52[((IOTA - 475) & 511)])) + (0.00695170555f * fVec52[((IOTA - 476) & 511)])) + (0.00598607305f * fVec52[((IOTA - 477) & 511)])) + (0.00420812611f * fVec52[((IOTA - 478) & 511)])) + (0.00227508275f * fVec52[((IOTA - 479) & 511)])) + (0.000880992506f * fVec52[((IOTA - 480) & 511)])) + (0.000291873235f * fVec52[((IOTA - 481) & 511)])) + (0.000183928292f * fVec52[((IOTA - 482) & 511)])) + (0.000108911656f * fVec52[((IOTA - 491) & 511)])) + (0.00251025846f * fVec52[((IOTA - 508) & 511)])) + (0.00523791509f * fVec52[((IOTA - 509) & 511)])) + (0.00758163771f * fVec52[((IOTA - 510) & 511)])) + (0.00916730799f * fVec52[((IOTA - 511) & 511)]))) : (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00984676927f * fVec51[((IOTA - 272) & 511)]) + ((0.00992815103f * fVec51[((IOTA - 271) & 511)]) + ((0.0110791223f * fVec51[((IOTA - 270) & 511)]) + ((0.0132481987f * fVec51[((IOTA - 269) & 511)]) + ((0.0156181166f * fVec51[((IOTA - 268) & 511)]) + ((0.0171485655f * fVec51[((IOTA - 267) & 511)]) + ((0.0169422124f * fVec51[((IOTA - 266) & 511)]) + ((0.014641339f * fVec51[((IOTA - 265) & 511)]) + ((0.01057739f * fVec51[((IOTA - 264) & 511)]) + ((0.00617175456f * fVec51[((IOTA - 263) & 511)]) + ((0.00263614347f * fVec51[((IOTA - 262) & 511)]) + ((0.000666756649f * fVec51[((IOTA - 261) & 511)]) + ((5.7653524e-05f * fVec51[((IOTA - 260) & 511)]) + ((0.00149245095f * fVec51[((IOTA - 253) & 511)]) + ((0.00629265374f * fVec51[((IOTA - 252) & 511)]) + ((0.0116223879f * fVec51[((IOTA - 251) & 511)]) + ((0.0167477038f * fVec51[((IOTA - 250) & 511)]) + ((0.0205367934f * fVec51[((IOTA - 249) & 511)]) + ((0.0224738996f * fVec51[((IOTA - 248) & 511)]) + ((0.0227855239f * fVec51[((IOTA - 247) & 511)]) + ((0.0220169481f * fVec51[((IOTA - 246) & 511)]) + ((0.0197178014f * fVec51[((IOTA - 245) & 511)]) + ((0.0159987845f * fVec51[((IOTA - 244) & 511)]) + ((0.0108691109f * fVec51[((IOTA - 243) & 511)]) + ((0.00546691846f * fVec51[((IOTA - 242) & 511)]) + ((0.000364713371f * fVec51[((IOTA - 241) & 511)]) + ((0.00186382607f * fVec51[((IOTA - 234) & 511)]) + (((((((((((((((((((((0.0146647375f * fVec51[((IOTA - 214) & 511)]) + ((0.0103664324f * fVec51[((IOTA - 213) & 511)]) + ((0.00680799829f * fVec51[((IOTA - 212) & 511)]) + ((0.00520114554f * fVec51[((IOTA - 211) & 511)]) + ((0.00583401695f * fVec51[((IOTA - 210) & 511)]) + ((0.00682806596f * fVec51[((IOTA - 209) & 511)]) + ((0.00769064669f * fVec51[((IOTA - 208) & 511)]) + ((0.0077841999f * fVec51[((IOTA - 207) & 511)]) + ((0.00692445645f * fVec51[((IOTA - 206) & 511)]) + ((0.00545384176f * fVec51[((IOTA - 205) & 511)]) + ((0.003317622f * fVec51[((IOTA - 204) & 511)]) + ((0.000835111365f * fVec51[((IOTA - 203) & 511)]) + ((0.000985536259f * fVec51[((IOTA - 199) & 511)]) + ((0.00480382191f * fVec51[((IOTA - 198) & 511)]) + ((0.0098023992f * fVec51[((IOTA - 197) & 511)]) + ((0.0149618872f * fVec51[((IOTA - 196) & 511)]) + ((0.0197153352f * fVec51[((IOTA - 195) & 511)]) + ((0.0226752348f * fVec51[((IOTA - 194) & 511)]) + ((0.0231434107f * fVec51[((IOTA - 193) & 511)]) + ((0.0205873735f * fVec51[((IOTA - 192) & 511)]) + ((0.0163822509f * fVec51[((IOTA - 191) & 511)]) + ((0.0122302175f * fVec51[((IOTA - 190) & 511)]) + ((0.0090759322f * fVec51[((IOTA - 189) & 511)]) + ((0.00731849018f * fVec51[((IOTA - 188) & 511)]) + ((0.00560344476f * fVec51[((IOTA - 187) & 511)]) + ((0.00404634979f * fVec51[((IOTA - 186) & 511)]) + ((0.00156375673f * fVec51[((IOTA - 185) & 511)]) + ((0.00961529277f * fVec51[((IOTA - 174) & 511)]) + ((0.0202280059f * fVec51[((IOTA - 173) & 511)]) + ((0.0283427462f * fVec51[((IOTA - 172) & 511)]) + ((0.0315035693f * fVec51[((IOTA - 171) & 511)]) + ((0.0289972071f * fVec51[((IOTA - 170) & 511)]) + ((0.0212453716f * fVec51[((IOTA - 169) & 511)]) + ((0.00985923037f * fVec51[((IOTA - 168) & 511)]) + ((0.00109105604f * fVec51[((IOTA - 143) & 511)]) + ((0.00463970285f * fVec51[((IOTA - 142) & 511)]) + ((0.00565040624f * fVec51[((IOTA - 141) & 511)]) + ((0.00464093639f * fVec51[((IOTA - 140) & 511)]) + ((0.0027513681f * fVec51[((IOTA - 139) & 511)]) + ((0.0022573662f * fVec51[((IOTA - 138) & 511)]) + ((0.00479160855f * fVec51[((IOTA - 137) & 511)]) + ((0.0114133637f * fVec51[((IOTA - 136) & 511)]) + ((0.0206776783f * fVec51[((IOTA - 135) & 511)]) + ((0.0297589153f * fVec51[((IOTA - 134) & 511)]) + ((0.0357583687f * fVec51[((IOTA - 133) & 511)]) + ((0.0362186097f * fVec51[((IOTA - 132) & 511)]) + ((0.0308417063f * fVec51[((IOTA - 131) & 511)]) + ((0.0212172028f * fVec51[((IOTA - 130) & 511)]) + ((0.0104717463f * fVec51[((IOTA - 129) & 511)]) + ((0.00141472975f * fVec51[((IOTA - 128) & 511)]) + (((((((((((((((((((((((((((((0.0324230641f * fVec51[((IOTA - 6) & 511)]) + ((0.19630006f * fVec51[((IOTA - 5) & 511)]) + ((0.312567562f * fVec51[((IOTA - 4) & 511)]) + ((0.333230048f * fVec51[((IOTA - 3) & 511)]) + ((0.279997408f * fVec51[((IOTA - 2) & 511)]) + ((0.183692336f * fVec51[((IOTA - 1) & 511)]) + ((fSlow160 * fTemp0) + (((0.125138819f * fVec51[((IOTA - 13) & 511)]) + ((0.0842480659f * fVec51[((IOTA - 12) & 511)]) + (0.122418955f * fVec51[((IOTA - 14) & 511)]))) + (0.108308673f * fVec51[((IOTA - 15) & 511)]))))))))) + (0.0958751068f * fVec51[((IOTA - 16) & 511)])) + (0.0821804851f * fVec51[((IOTA - 17) & 511)])) + (0.0670220703f * fVec51[((IOTA - 18) & 511)])) + (0.0484215617f * fVec51[((IOTA - 19) & 511)])) + (0.0250578169f * fVec51[((IOTA - 20) & 511)])) + (0.00333205564f * fVec51[((IOTA - 21) & 511)])) + (0.0187907815f * fVec51[((IOTA - 24) & 511)])) + (0.0359039828f * fVec51[((IOTA - 25) & 511)])) + (0.0368855707f * fVec51[((IOTA - 26) & 511)])) + (0.0178297963f * fVec51[((IOTA - 27) & 511)])) + (0.000438939314f * fVec51[((IOTA - 65) & 511)])) + (0.00921229459f * fVec51[((IOTA - 66) & 511)])) + (0.00845161453f * fVec51[((IOTA - 67) & 511)])) + (0.00180452783f * fVec51[((IOTA - 68) & 511)])) + (0.000655818265f * fVec51[((IOTA - 76) & 511)])) + (0.00119394436f * fVec51[((IOTA - 77) & 511)])) + (0.00168074947f * fVec51[((IOTA - 82) & 511)])) + (0.00246145623f * fVec51[((IOTA - 83) & 511)])) + (0.00287666777f * fVec51[((IOTA - 84) & 511)])) + (0.00133721391f * fVec51[((IOTA - 85) & 511)])) + (0.00101666618f * fVec51[((IOTA - 114) & 511)])) + (0.0097099971f * fVec51[((IOTA - 115) & 511)])) + (0.0148611385f * fVec51[((IOTA - 116) & 511)])) + (0.01521446f * fVec51[((IOTA - 117) & 511)])) + (0.0109591689f * fVec51[((IOTA - 118) & 511)])) + (0.00464073103f * fVec51[((IOTA - 119) & 511)])) + (0.0176252127f * fVec51[((IOTA - 215) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.0183591619f * fVec51[((IOTA - 216) & 511)])) + (0.0167871416f * fVec51[((IOTA - 217) & 511)])) + (0.0136955269f * fVec51[((IOTA - 218) & 511)])) + (0.00983032119f * fVec51[((IOTA - 219) & 511)])) + (0.00633525662f * fVec51[((IOTA - 220) & 511)])) + (0.00431450782f * fVec51[((IOTA - 221) & 511)])) + (0.00402862579f * fVec51[((IOTA - 222) & 511)])) + (0.00496983249f * fVec51[((IOTA - 223) & 511)])) + (0.0066303499f * fVec51[((IOTA - 224) & 511)])) + (0.00819065236f * fVec51[((IOTA - 225) & 511)])) + (0.00929527916f * fVec51[((IOTA - 226) & 511)])) + (0.00992646441f * fVec51[((IOTA - 227) & 511)])) + (0.00987127889f * fVec51[((IOTA - 228) & 511)])) + (0.00929774623f * fVec51[((IOTA - 229) & 511)])) + (0.00807390641f * fVec51[((IOTA - 230) & 511)])) + (0.00704087364f * fVec51[((IOTA - 231) & 511)])) + (0.00586658623f * fVec51[((IOTA - 232) & 511)])) + (0.00443187077f * fVec51[((IOTA - 233) & 511)])) + (0.0101874676f * fVec51[((IOTA - 273) & 511)]))))))))))))))))))))))))))))) + (0.00987037458f * fVec51[((IOTA - 274) & 511)])) + (0.00847632904f * fVec51[((IOTA - 275) & 511)])) + (0.00642198324f * fVec51[((IOTA - 276) & 511)])) + (0.00484687695f * fVec51[((IOTA - 277) & 511)])) + (0.00424776645f * fVec51[((IOTA - 278) & 511)])) + (0.00485337432f * fVec51[((IOTA - 279) & 511)])) + (0.00604057452f * fVec51[((IOTA - 280) & 511)])) + (0.00658791186f * fVec51[((IOTA - 281) & 511)])) + (0.00563794607f * fVec51[((IOTA - 282) & 511)])) + (0.00347146019f * fVec51[((IOTA - 283) & 511)])) + (0.000630733557f * fVec51[((IOTA - 284) & 511)])) + (5.76120801e-05f * fVec51[((IOTA - 297) & 511)])) + (0.000930103473f * fVec51[((IOTA - 298) & 511)])) + (0.00175867649f * fVec51[((IOTA - 299) & 511)])) + (0.00273796218f * fVec51[((IOTA - 300) & 511)])) + (0.00351727055f * fVec51[((IOTA - 301) & 511)])) + (0.00417349953f * fVec51[((IOTA - 302) & 511)])) + (0.00472182408f * fVec51[((IOTA - 303) & 511)])) + (0.0051209568f * fVec51[((IOTA - 304) & 511)])) + (0.00519193383f * fVec51[((IOTA - 305) & 511)])) + (0.00482253265f * fVec51[((IOTA - 306) & 511)])) + (0.00494380202f * fVec51[((IOTA - 307) & 511)])) + (0.00553119276f * fVec51[((IOTA - 308) & 511)])) + (0.00628237333f * fVec51[((IOTA - 309) & 511)])) + (0.0062944633f * fVec51[((IOTA - 310) & 511)])) + (0.0052449815f * fVec51[((IOTA - 311) & 511)])) + (0.0024191821f * fVec51[((IOTA - 312) & 511)])) + (0.000488203485f * fVec51[((IOTA - 327) & 511)])) + (0.00155129656f * fVec51[((IOTA - 328) & 511)])) + (0.00152238784f * fVec51[((IOTA - 329) & 511)])) + (0.000637929887f * fVec51[((IOTA - 330) & 511)])) + (0.0012722821f * fVec51[((IOTA - 335) & 511)])) + (0.00290134083f * fVec51[((IOTA - 336) & 511)])) + (0.00418098411f * fVec51[((IOTA - 337) & 511)])) + (0.00497151865f * fVec51[((IOTA - 338) & 511)])) + (0.00520299608f * fVec51[((IOTA - 339) & 511)])) + (0.00517478585f * fVec51[((IOTA - 340) & 511)])) + (0.00488565536f * fVec51[((IOTA - 341) & 511)])) + (0.00429542735f * fVec51[((IOTA - 342) & 511)])) + (0.00337001169f * fVec51[((IOTA - 343) & 511)])) + (0.00212532235f * fVec51[((IOTA - 344) & 511)])) + (0.000264087226f * fVec51[((IOTA - 345) & 511)])) + (8.44653696e-05f * fVec51[((IOTA - 352) & 511)])) + (0.00128794974f * fVec51[((IOTA - 353) & 511)])) + (0.00131402118f * fVec51[((IOTA - 354) & 511)])) + (0.000856001396f * fVec51[((IOTA - 355) & 511)])) + (0.000464393757f * fVec51[((IOTA - 356) & 511)])) + (0.000901770312f * fVec51[((IOTA - 357) & 511)])) + (0.00221221382f * fVec51[((IOTA - 358) & 511)])) + (0.00426499685f * fVec51[((IOTA - 359) & 511)])) + (0.00593521912f * fVec51[((IOTA - 360) & 511)])) + (0.00681922445f * fVec51[((IOTA - 361) & 511)])) + (0.00677049486f * fVec51[((IOTA - 362) & 511)])) + (0.00653909985f * fVec51[((IOTA - 363) & 511)])) + (0.00630383892f * fVec51[((IOTA - 364) & 511)])) + (0.00584244728f * fVec51[((IOTA - 365) & 511)])) + (0.00475052744f * fVec51[((IOTA - 366) & 511)])) + (0.00251520285f * fVec51[((IOTA - 367) & 511)])) + (0.00189989014f * fVec51[((IOTA - 384) & 511)])) + (0.00344325043f * fVec51[((IOTA - 385) & 511)])) + (0.00351735251f * fVec51[((IOTA - 386) & 511)])) + (0.00198600022f * fVec51[((IOTA - 387) & 511)])) + (0.00108340755f * fVec51[((IOTA - 393) & 511)])) + (0.00344386697f * fVec51[((IOTA - 394) & 511)])) + (0.00441764249f * fVec51[((IOTA - 395) & 511)])) + (0.00356328627f * fVec51[((IOTA - 396) & 511)])) + (0.00141160423f * fVec51[((IOTA - 397) & 511)])) + (0.000560825691f * fVec51[((IOTA - 407) & 511)])) + (0.00262273755f * fVec51[((IOTA - 408) & 511)])) + (0.00412209705f * fVec51[((IOTA - 409) & 511)])) + (0.00494577596f * fVec51[((IOTA - 410) & 511)])) + (0.00536604552f * fVec51[((IOTA - 411) & 511)])) + (0.0050630155f * fVec51[((IOTA - 412) & 511)])) + (0.00415429566f * fVec51[((IOTA - 413) & 511)])) + (0.00295998156f * fVec51[((IOTA - 414) & 511)])) + (0.00181007897f * fVec51[((IOTA - 415) & 511)])) + (0.000650636852f * fVec51[((IOTA - 416) & 511)])) + (0.0019997349f * fVec51[((IOTA - 447) & 511)])) + (0.00385151245f * fVec51[((IOTA - 448) & 511)])) + (0.00451086694f * fVec51[((IOTA - 449) & 511)])) + (0.00400321232f * fVec51[((IOTA - 450) & 511)])) + (0.00267673098f * fVec51[((IOTA - 451) & 511)])) + (0.00108505227f * fVec51[((IOTA - 452) & 511)])) + (0.000954036601f * fVec51[((IOTA - 464) & 511)])) + (0.00255221268f * fVec51[((IOTA - 465) & 511)])) + (0.00357356668f * fVec51[((IOTA - 466) & 511)])) + (0.00449429452f * fVec51[((IOTA - 467) & 511)])) + (0.00511355512f * fVec51[((IOTA - 468) & 511)])) + (0.00524518732f * fVec51[((IOTA - 469) & 511)])) + (0.00493093068f * fVec51[((IOTA - 470) & 511)])) + (0.00419040117f * fVec51[((IOTA - 471) & 511)])) + (0.00271147955f * fVec51[((IOTA - 472) & 511)])) + (0.000549969263f * fVec51[((IOTA - 473) & 511)])) + (0.00144014321f * fVec51[((IOTA - 486) & 511)])) + (0.00291273184f * fVec51[((IOTA - 487) & 511)])) + (0.00401900336f * fVec51[((IOTA - 488) & 511)])) + (0.00421548542f * fVec51[((IOTA - 489) & 511)])) + (0.0035710996f * fVec51[((IOTA - 490) & 511)])) + (0.0025516781f * fVec51[((IOTA - 491) & 511)])) + (0.00144857308f * fVec51[((IOTA - 492) & 511)])) + (0.000497373752f * fVec51[((IOTA - 493) & 511)])) + (0.000727741048f * fVec51[((IOTA - 503) & 511)])) + (0.00218667695f * fVec51[((IOTA - 504) & 511)])) + (0.00264695846f * fVec51[((IOTA - 505) & 511)])) + (0.00239368668f * fVec51[((IOTA - 506) & 511)])) + (0.00192230195f * fVec51[((IOTA - 507) & 511)])) + (0.00185741112f * fVec51[((IOTA - 508) & 511)])) + (0.00193233555f * fVec51[((IOTA - 509) & 511)])) + (0.00186477182f * fVec51[((IOTA - 510) & 511)])) + (0.00129683223f * fVec51[((IOTA - 511) & 511)])) - (((((((((0.000537015963f * fVec51[((IOTA - 494) & 511)]) + ((1.76415779e-05f * fVec51[((IOTA - 485) & 511)]) + ((0.00121800089f * fVec51[((IOTA - 484) & 511)]) + ((0.00203843135f * fVec51[((IOTA - 483) & 511)]) + ((0.00243760506f * fVec51[((IOTA - 482) & 511)]) + ((0.00300019886f * fVec51[((IOTA - 481) & 511)]) + ((0.00391734904f * fVec51[((IOTA - 480) & 511)]) + ((0.00524637988f * fVec51[((IOTA - 479) & 511)]) + ((0.0064687808f * fVec51[((IOTA - 478) & 511)]) + ((0.00699045788f * fVec51[((IOTA - 477) & 511)]) + ((0.0063996953f * fVec51[((IOTA - 476) & 511)]) + ((0.00470615644f * fVec51[((IOTA - 475) & 511)]) + (((((((((((((((((((0.00760910148f * fVec51[((IOTA - 441) & 511)]) + ((0.00749177951f * fVec51[((IOTA - 440) & 511)]) + ((0.00712681934f * fVec51[((IOTA - 439) & 511)]) + ((0.00664322125f * fVec51[((IOTA - 438) & 511)]) + ((0.00613149581f * fVec51[((IOTA - 437) & 511)]) + ((0.00569712091f * fVec51[((IOTA - 436) & 511)]) + ((0.00538195996f * fVec51[((IOTA - 435) & 511)]) + ((0.00515422504f * fVec51[((IOTA - 434) & 511)]) + ((0.00504553877f * fVec51[((IOTA - 433) & 511)]) + ((0.0047981469f * fVec51[((IOTA - 432) & 511)]) + ((0.00426873891f * fVec51[((IOTA - 431) & 511)]) + ((0.00337371277f * fVec51[((IOTA - 430) & 511)]) + ((0.00224622199f * fVec51[((IOTA - 429) & 511)]) + ((0.00105564995f * fVec51[((IOTA - 428) & 511)]) + ((0.000513494015f * fVec51[((IOTA - 427) & 511)]) + ((0.000692087691f * fVec51[((IOTA - 426) & 511)]) + ((0.00149668613f * fVec51[((IOTA - 425) & 511)]) + ((0.00235474389f * fVec51[((IOTA - 424) & 511)]) + ((0.00311587611f * fVec51[((IOTA - 423) & 511)]) + ((0.00342799397f * fVec51[((IOTA - 422) & 511)]) + ((0.00321859913f * fVec51[((IOTA - 421) & 511)]) + ((0.00270720292f * fVec51[((IOTA - 420) & 511)]) + ((0.00204081647f * fVec51[((IOTA - 419) & 511)]) + ((0.00127910823f * fVec51[((IOTA - 418) & 511)]) + ((0.000361053739f * fVec51[((IOTA - 417) & 511)]) + ((0.00180695392f * fVec51[((IOTA - 406) & 511)]) + ((0.00376971997f * fVec51[((IOTA - 405) & 511)]) + ((0.00501732854f * fVec51[((IOTA - 404) & 511)]) + ((0.00578512298f * fVec51[((IOTA - 403) & 511)]) + ((0.00616702531f * fVec51[((IOTA - 402) & 511)]) + ((0.00604209583f * fVec51[((IOTA - 401) & 511)]) + ((0.00501728756f * fVec51[((IOTA - 400) & 511)]) + ((0.00340282731f * fVec51[((IOTA - 399) & 511)]) + ((0.00116018252f * fVec51[((IOTA - 398) & 511)]) + ((0.00157091208f * fVec51[((IOTA - 392) & 511)]) + ((0.00344020734f * fVec51[((IOTA - 391) & 511)]) + ((0.00285861501f * fVec51[((IOTA - 389) & 511)]) + ((0.00056596566f * fVec51[((IOTA - 388) & 511)]) + ((0.000245088711f * fVec51[((IOTA - 383) & 511)]) + ((0.00237156264f * fVec51[((IOTA - 382) & 511)]) + ((0.00386664551f * fVec51[((IOTA - 381) & 511)]) + ((0.00448919553f * fVec51[((IOTA - 380) & 511)]) + ((0.00437730178f * fVec51[((IOTA - 379) & 511)]) + ((0.00421799393f * fVec51[((IOTA - 378) & 511)]) + ((0.00498850225f * fVec51[((IOTA - 377) & 511)]) + ((0.0066234828f * fVec51[((IOTA - 376) & 511)]) + ((0.00879494473f * fVec51[((IOTA - 375) & 511)]) + ((0.0107632615f * fVec51[((IOTA - 374) & 511)]) + ((0.0121570192f * fVec51[((IOTA - 373) & 511)]) + ((0.0122826891f * fVec51[((IOTA - 372) & 511)]) + ((0.0109648434f * fVec51[((IOTA - 371) & 511)]) + ((0.00823827274f * fVec51[((IOTA - 370) & 511)]) + ((0.00456831465f * fVec51[((IOTA - 369) & 511)]) + ((0.000737857074f * fVec51[((IOTA - 368) & 511)]) + ((0.00393013796f * fVec51[((IOTA - 390) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.112236708f * fVec51[((IOTA - 10) & 511)]) + ((0.194532335f * fVec51[((IOTA - 9) & 511)]) + ((0.205606684f * fVec51[((IOTA - 8) & 511)]) + ((0.121708281f * fVec51[((IOTA - 7) & 511)]) + (0.00415787334f * fVec51[((IOTA - 11) & 511)]))))) + (0.00783626083f * fVec51[((IOTA - 22) & 511)])) + (0.000931131653f * fVec51[((IOTA - 23) & 511)])) + (0.0129656065f * fVec51[((IOTA - 28) & 511)])) + (0.0476692691f * fVec51[((IOTA - 29) & 511)])) + (0.0777970925f * fVec51[((IOTA - 30) & 511)])) + (0.0950095206f * fVec51[((IOTA - 31) & 511)])) + (0.0957416221f * fVec51[((IOTA - 32) & 511)])) + (0.0848280564f * fVec51[((IOTA - 33) & 511)])) + (0.0634941906f * fVec51[((IOTA - 34) & 511)])) + (0.0360883325f * fVec51[((IOTA - 35) & 511)])) + (0.013316256f * fVec51[((IOTA - 36) & 511)])) + (0.00405037962f * fVec51[((IOTA - 37) & 511)])) + (0.00890280865f * fVec51[((IOTA - 38) & 511)])) + (0.0227127373f * fVec51[((IOTA - 39) & 511)])) + (0.0417911299f * fVec51[((IOTA - 40) & 511)])) + (0.0564800054f * fVec51[((IOTA - 41) & 511)])) + (0.0633699596f * fVec51[((IOTA - 42) & 511)])) + (0.0672684759f * fVec51[((IOTA - 43) & 511)])) + (0.072996065f * fVec51[((IOTA - 44) & 511)])) + (0.0776655823f * fVec51[((IOTA - 45) & 511)])) + (0.0805581659f * fVec51[((IOTA - 46) & 511)])) + (0.0803681388f * fVec51[((IOTA - 47) & 511)])) + (0.0713874027f * fVec51[((IOTA - 48) & 511)])) + (0.0542602241f * fVec51[((IOTA - 49) & 511)])) + (0.043419078f * fVec51[((IOTA - 50) & 511)])) + (0.03860588f * fVec51[((IOTA - 51) & 511)])) + (0.0363004431f * fVec51[((IOTA - 52) & 511)])) + (0.0385061987f * fVec51[((IOTA - 53) & 511)])) + (0.0369693376f * fVec51[((IOTA - 54) & 511)])) + (0.0272924006f * fVec51[((IOTA - 55) & 511)])) + (0.0152711682f * fVec51[((IOTA - 56) & 511)])) + (0.00601248769f * fVec51[((IOTA - 57) & 511)])) + (0.00683517987f * fVec51[((IOTA - 58) & 511)])) + (0.0187162273f * fVec51[((IOTA - 59) & 511)])) + (0.033161208f * fVec51[((IOTA - 60) & 511)])) + (0.0445126407f * fVec51[((IOTA - 61) & 511)])) + (0.0452989414f * fVec51[((IOTA - 62) & 511)])) + (0.0339121819f * fVec51[((IOTA - 63) & 511)])) + (0.0161883999f * fVec51[((IOTA - 64) & 511)])) + (0.00739584118f * fVec51[((IOTA - 69) & 511)])) + (0.0163332745f * fVec51[((IOTA - 70) & 511)])) + (0.0215199031f * fVec51[((IOTA - 71) & 511)])) + (0.0218603946f * fVec51[((IOTA - 72) & 511)])) + (0.01762731f * fVec51[((IOTA - 73) & 511)])) + (0.0111229178f * fVec51[((IOTA - 74) & 511)])) + (0.00444248039f * fVec51[((IOTA - 75) & 511)])) + (0.0012078844f * fVec51[((IOTA - 78) & 511)])) + (0.00335286371f * fVec51[((IOTA - 79) & 511)])) + (0.00443795696f * fVec51[((IOTA - 80) & 511)])) + (0.00190725131f * fVec51[((IOTA - 81) & 511)])) + (0.00124386651f * fVec51[((IOTA - 86) & 511)])) + (0.00376326405f * fVec51[((IOTA - 87) & 511)])) + (0.00661484711f * fVec51[((IOTA - 88) & 511)])) + (0.00967857987f * fVec51[((IOTA - 89) & 511)])) + (0.0101080611f * fVec51[((IOTA - 90) & 511)])) + (0.0120764608f * fVec51[((IOTA - 91) & 511)])) + (0.0159708634f * fVec51[((IOTA - 92) & 511)])) + (0.019796839f * fVec51[((IOTA - 93) & 511)])) + (0.023756627f * fVec51[((IOTA - 94) & 511)])) + (0.0256120637f * fVec51[((IOTA - 95) & 511)])) + (0.0255048163f * fVec51[((IOTA - 96) & 511)])) + (0.0248668864f * fVec51[((IOTA - 97) & 511)])) + (0.022170458f * fVec51[((IOTA - 98) & 511)])) + (0.0191613771f * fVec51[((IOTA - 99) & 511)])) + (0.0183559973f * fVec51[((IOTA - 100) & 511)])) + (0.0187906586f * fVec51[((IOTA - 101) & 511)])) + (0.0202508289f * fVec51[((IOTA - 102) & 511)])) + (0.0212314315f * fVec51[((IOTA - 103) & 511)])) + (0.0210626647f * fVec51[((IOTA - 104) & 511)])) + (0.0204730947f * fVec51[((IOTA - 105) & 511)])) + (0.019976791f * fVec51[((IOTA - 106) & 511)])) + (0.0204123165f * fVec51[((IOTA - 107) & 511)])) + (0.0215954855f * fVec51[((IOTA - 108) & 511)])) + (0.0225300714f * fVec51[((IOTA - 109) & 511)])) + (0.0225426964f * fVec51[((IOTA - 110) & 511)])) + (0.0201191958f * fVec51[((IOTA - 111) & 511)])) + (0.0151228812f * fVec51[((IOTA - 112) & 511)])) + (0.00827791356f * fVec51[((IOTA - 113) & 511)])) + (0.000179827679f * fVec51[((IOTA - 120) & 511)])) + (0.00312019372f * fVec51[((IOTA - 121) & 511)])) + (0.00428514648f * fVec51[((IOTA - 122) & 511)])) + (0.00456769764f * fVec51[((IOTA - 123) & 511)])) + (0.0059940652f * fVec51[((IOTA - 124) & 511)])) + (0.00707015255f * fVec51[((IOTA - 125) & 511)])) + (0.00665892987f * fVec51[((IOTA - 126) & 511)])) + (0.00405000942f * fVec51[((IOTA - 127) & 511)])) + (0.00391278462f * fVec51[((IOTA - 144) & 511)])) + (0.00820619613f * fVec51[((IOTA - 145) & 511)])) + (0.00991449878f * fVec51[((IOTA - 146) & 511)])) + (0.00903349463f * fVec51[((IOTA - 147) & 511)])) + (0.00741862273f * fVec51[((IOTA - 148) & 511)])) + (0.00672953716f * fVec51[((IOTA - 149) & 511)])) + (0.00713216513f * fVec51[((IOTA - 150) & 511)])) + (0.00890835933f * fVec51[((IOTA - 151) & 511)])) + (0.0114095807f * fVec51[((IOTA - 152) & 511)])) + (0.0127489334f * fVec51[((IOTA - 153) & 511)])) + (0.0121818576f * fVec51[((IOTA - 154) & 511)])) + (0.0108533613f * fVec51[((IOTA - 155) & 511)])) + (0.00934446137f * fVec51[((IOTA - 156) & 511)])) + (0.00878441706f * fVec51[((IOTA - 157) & 511)])) + (0.00959563628f * fVec51[((IOTA - 158) & 511)])) + (0.0105652995f * fVec51[((IOTA - 159) & 511)])) + (0.0107323378f * fVec51[((IOTA - 160) & 511)])) + (0.0100467885f * fVec51[((IOTA - 161) & 511)])) + (0.00898065232f * fVec51[((IOTA - 162) & 511)])) + (0.00871837512f * fVec51[((IOTA - 163) & 511)])) + (0.00927928276f * fVec51[((IOTA - 164) & 511)])) + (0.00943077728f * fVec51[((IOTA - 165) & 511)])) + (0.0070979516f * fVec51[((IOTA - 166) & 511)])) + (0.000630651135f * fVec51[((IOTA - 167) & 511)])) + (0.000408221036f * fVec51[((IOTA - 175) & 511)])) + (0.0071745622f * fVec51[((IOTA - 176) & 511)])) + (0.0104907863f * fVec51[((IOTA - 177) & 511)])) + (0.0119862799f * fVec51[((IOTA - 178) & 511)])) + (0.012277713f * fVec51[((IOTA - 179) & 511)])) + (0.0119388662f * fVec51[((IOTA - 180) & 511)])) + (0.0107438937f * fVec51[((IOTA - 181) & 511)])) + (0.0083828168f * fVec51[((IOTA - 182) & 511)])) + (0.00525777088f * fVec51[((IOTA - 183) & 511)])) + (0.0016143783f * fVec51[((IOTA - 184) & 511)])) + (0.0013131164f * fVec51[((IOTA - 200) & 511)])) + (0.00199323799f * fVec51[((IOTA - 201) & 511)])) + (0.00136213424f * fVec51[((IOTA - 202) & 511)])) + (0.00131451478f * fVec51[((IOTA - 235) & 511)])) + (0.00485177059f * fVec51[((IOTA - 236) & 511)])) + (0.0076012467f * fVec51[((IOTA - 237) & 511)])) + (0.00857666694f * fVec51[((IOTA - 238) & 511)])) + (0.00709507288f * fVec51[((IOTA - 239) & 511)])) + (0.00380981434f * fVec51[((IOTA - 240) & 511)])) + (0.0021350272f * fVec51[((IOTA - 254) & 511)])) + (0.00386491837f * fVec51[((IOTA - 255) & 511)])) + (0.00381450215f * fVec51[((IOTA - 256) & 511)])) + (0.00246536266f * fVec51[((IOTA - 257) & 511)])) + (0.000932200812f * fVec51[((IOTA - 258) & 511)])) + (0.000133400783f * fVec51[((IOTA - 259) & 511)])) + (0.00184305944f * fVec51[((IOTA - 285) & 511)])) + (0.0031677722f * fVec51[((IOTA - 286) & 511)])) + (0.00281749247f * fVec51[((IOTA - 287) & 511)])) + (0.00153961778f * fVec51[((IOTA - 288) & 511)])) + (0.000249653123f * fVec51[((IOTA - 289) & 511)])) + (3.12551856e-06f * fVec51[((IOTA - 290) & 511)])) + (0.000876685604f * fVec51[((IOTA - 291) & 511)])) + (0.00213075057f * fVec51[((IOTA - 292) & 511)])) + (0.00313915126f * fVec51[((IOTA - 293) & 511)])) + (0.003106541f * fVec51[((IOTA - 294) & 511)])) + (0.00232427195f * fVec51[((IOTA - 295) & 511)])) + (0.000889968127f * fVec51[((IOTA - 296) & 511)])) + (0.00166306691f * fVec51[((IOTA - 313) & 511)])) + (0.00632448262f * fVec51[((IOTA - 314) & 511)])) + (0.0102019841f * fVec51[((IOTA - 315) & 511)])) + (0.0123920739f * fVec51[((IOTA - 316) & 511)])) + (0.0122720385f * fVec51[((IOTA - 317) & 511)])) + (0.0103008831f * fVec51[((IOTA - 318) & 511)])) + (0.00776207633f * fVec51[((IOTA - 319) & 511)])) + (0.00581871951f * fVec51[((IOTA - 320) & 511)])) + (0.00493397377f * fVec51[((IOTA - 321) & 511)])) + (0.00495675579f * fVec51[((IOTA - 322) & 511)])) + (0.00523396069f * fVec51[((IOTA - 323) & 511)])) + (0.00494861323f * fVec51[((IOTA - 324) & 511)])) + (0.0036176499f * fVec51[((IOTA - 325) & 511)])) + (0.00144030759f * fVec51[((IOTA - 326) & 511)])) + (0.000487093348f * fVec51[((IOTA - 331) & 511)])) + (0.00118349912f * fVec51[((IOTA - 332) & 511)])) + (0.00123543665f * fVec51[((IOTA - 333) & 511)])) + (0.000327292364f * fVec51[((IOTA - 334) & 511)])) + (0.00195602234f * fVec51[((IOTA - 346) & 511)])) + (0.00409470964f * fVec51[((IOTA - 347) & 511)])) + (0.00557469996f * fVec51[((IOTA - 348) & 511)])) + (0.00583483977f * fVec51[((IOTA - 349) & 511)])) + (0.00452998886f * fVec51[((IOTA - 350) & 511)])) + (0.00221492816f * fVec51[((IOTA - 351) & 511)])) + (0.00753726065f * fVec51[((IOTA - 442) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.0068878578f * fVec51[((IOTA - 443) & 511)])) + (0.00565044722f * fVec51[((IOTA - 444) & 511)])) + (0.0035402989f * fVec51[((IOTA - 445) & 511)])) + (0.000791521743f * fVec51[((IOTA - 446) & 511)])) + (0.000662973151f * fVec51[((IOTA - 453) & 511)])) + (0.00215480709f * fVec51[((IOTA - 454) & 511)])) + (0.00341405347f * fVec51[((IOTA - 455) & 511)])) + (0.00461494736f * fVec51[((IOTA - 456) & 511)])) + (0.00592596643f * fVec51[((IOTA - 457) & 511)])) + (0.00699798297f * fVec51[((IOTA - 458) & 511)])) + (0.00755889108f * fVec51[((IOTA - 459) & 511)])) + (0.00726276962f * fVec51[((IOTA - 460) & 511)])) + (0.00605278788f * fVec51[((IOTA - 461) & 511)])) + (0.00391122187f * fVec51[((IOTA - 462) & 511)])) + (0.00130908657f * fVec51[((IOTA - 463) & 511)])) + (0.00212696753f * fVec51[((IOTA - 474) & 511)])) + (0.00184696587f * fVec51[((IOTA - 495) & 511)])))))))))))))) + (0.0035122945f * fVec51[((IOTA - 496) & 511)])) + (0.00513555529f * fVec51[((IOTA - 497) & 511)])) + (0.00635733921f * fVec51[((IOTA - 498) & 511)])) + (0.00673969416f * fVec51[((IOTA - 499) & 511)])) + (0.00591437006f * fVec51[((IOTA - 500) & 511)])) + (0.00392705388f * fVec51[((IOTA - 501) & 511)])) + (0.00146814762f * fVec51[((IOTA - 502) & 511)])))))) : (iSlow136 ? (iSlow148 ? ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0256537851f * fVec50[((IOTA - 100) & 511)]) + ((0.0239022188f * fVec50[((IOTA - 99) & 511)]) + ((0.0127245542f * fVec50[((IOTA - 98) & 511)]) + ((0.000762199517f * fVec50[((IOTA - 97) & 511)]) + ((((((((((((((((((((0.00929388218f * fVec50[((IOTA - 16) & 511)]) + ((0.00340585783f * fVec50[((IOTA - 15) & 511)]) + ((0.015841227f * fVec50[((IOTA - 14) & 511)]) + ((0.0529066585f * fVec50[((IOTA - 13) & 511)]) + ((0.0707637295f * fVec50[((IOTA - 12) & 511)]) + ((0.0413945466f * fVec50[((IOTA - 11) & 511)]) + ((0.0392157547f * fVec50[((IOTA - 5) & 511)]) + ((0.184915677f * fVec50[((IOTA - 4) & 511)]) + ((0.251032472f * fVec50[((IOTA - 3) & 511)]) + ((0.247471601f * fVec50[((IOTA - 2) & 511)]) + ((0.210618928f * fVec50[((IOTA - 1) & 511)]) + ((fSlow155 * fTemp0) + ((0.0144157736f * fVec50[((IOTA - 24) & 511)]) + (((0.0213431008f * fVec50[((IOTA - 18) & 511)]) + ((0.0188173167f * fVec50[((IOTA - 19) & 511)]) + ((0.0152716525f * fVec50[((IOTA - 17) & 511)]) + (0.00312447874f * fVec50[((IOTA - 20) & 511)])))) + (0.0255323481f * fVec50[((IOTA - 25) & 511)]))))))))))))))) + (0.0106848869f * fVec50[((IOTA - 26) & 511)])) + (0.00205150107f * fVec50[((IOTA - 37) & 511)])) + (0.0311119799f * fVec50[((IOTA - 38) & 511)])) + (0.0430363268f * fVec50[((IOTA - 39) & 511)])) + (0.0410700142f * fVec50[((IOTA - 40) & 511)])) + (0.0347424634f * fVec50[((IOTA - 41) & 511)])) + (0.0227960013f * fVec50[((IOTA - 42) & 511)])) + (0.00466888957f * fVec50[((IOTA - 49) & 511)])) + (0.0351665951f * fVec50[((IOTA - 50) & 511)])) + (0.044849135f * fVec50[((IOTA - 51) & 511)])) + (0.0366408378f * fVec50[((IOTA - 52) & 511)])) + (0.00485166395f * fVec50[((IOTA - 53) & 511)])) + (0.0142643191f * fVec50[((IOTA - 60) & 511)])) + (0.0104318224f * fVec50[((IOTA - 61) & 511)])) + (0.0132335965f * fVec50[((IOTA - 74) & 511)])) + (0.0192985088f * fVec50[((IOTA - 75) & 511)])) + (0.011991444f * fVec50[((IOTA - 76) & 511)])) + (0.015382587f * fVec50[((IOTA - 101) & 511)])))))) + (0.00307429302f * fVec50[((IOTA - 109) & 511)])) + (0.00731335348f * fVec50[((IOTA - 110) & 511)])) + (0.00757261412f * fVec50[((IOTA - 111) & 511)])) + (0.00463341922f * fVec50[((IOTA - 112) & 511)])) + (0.00153945433f * fVec50[((IOTA - 131) & 511)])) + (0.00442053378f * fVec50[((IOTA - 132) & 511)])) + (0.00504261628f * fVec50[((IOTA - 133) & 511)])) + (0.00426207762f * fVec50[((IOTA - 134) & 511)])) + (0.00355167454f * fVec50[((IOTA - 135) & 511)])) + (0.00328312023f * fVec50[((IOTA - 136) & 511)])) + (0.00169586577f * fVec50[((IOTA - 137) & 511)])) + (0.000468986109f * fVec50[((IOTA - 146) & 511)])) + (0.00557241403f * fVec50[((IOTA - 147) & 511)])) + (0.00967705809f * fVec50[((IOTA - 148) & 511)])) + (0.0112779429f * fVec50[((IOTA - 149) & 511)])) + (0.00914335717f * fVec50[((IOTA - 150) & 511)])) + (0.00466368534f * fVec50[((IOTA - 151) & 511)])) + (0.000688996632f * fVec50[((IOTA - 157) & 511)])) + (0.00459562521f * fVec50[((IOTA - 158) & 511)])) + (0.00427025603f * fVec50[((IOTA - 159) & 511)])) + (0.000695440453f * fVec50[((IOTA - 160) & 511)])) + (0.000728773419f * fVec50[((IOTA - 166) & 511)])) + (0.00296695204f * fVec50[((IOTA - 167) & 511)])) + (0.00351719512f * fVec50[((IOTA - 168) & 511)])) + (0.00295514893f * fVec50[((IOTA - 169) & 511)])) + (0.00346394302f * fVec50[((IOTA - 170) & 511)])) + (0.00363135198f * fVec50[((IOTA - 171) & 511)])) + (0.00213501975f * fVec50[((IOTA - 172) & 511)])) + (0.00132653816f * fVec50[((IOTA - 173) & 511)])) + (0.000985400751f * fVec50[((IOTA - 174) & 511)])) + (0.00284836581f * fVec50[((IOTA - 179) & 511)])) + (0.00610788027f * fVec50[((IOTA - 180) & 511)])) + (0.00852945261f * fVec50[((IOTA - 181) & 511)])) + (0.0100847064f * fVec50[((IOTA - 182) & 511)])) + (0.009490164f * fVec50[((IOTA - 183) & 511)])) + (0.00621627457f * fVec50[((IOTA - 184) & 511)])) + (0.00235846872f * fVec50[((IOTA - 185) & 511)])) + (0.00282057794f * fVec50[((IOTA - 189) & 511)])) + (0.00594115304f * fVec50[((IOTA - 190) & 511)])) + (0.00825092383f * fVec50[((IOTA - 191) & 511)])) + (0.0092671793f * fVec50[((IOTA - 192) & 511)])) + (0.0101111308f * fVec50[((IOTA - 193) & 511)])) + (0.0113587044f * fVec50[((IOTA - 194) & 511)])) + (0.0124521591f * fVec50[((IOTA - 195) & 511)])) + (0.012120625f * fVec50[((IOTA - 196) & 511)])) + (0.00983684603f * fVec50[((IOTA - 197) & 511)])) + (0.00672119623f * fVec50[((IOTA - 198) & 511)])) + (0.0029155896f * fVec50[((IOTA - 199) & 511)])) + (0.00134060252f * fVec50[((IOTA - 204) & 511)])) + (0.00506145135f * fVec50[((IOTA - 205) & 511)])) + (0.0077275387f * fVec50[((IOTA - 206) & 511)])) + (0.00874292664f * fVec50[((IOTA - 207) & 511)])) + (0.00833425671f * fVec50[((IOTA - 208) & 511)])) + (0.00695186341f * fVec50[((IOTA - 209) & 511)])) + (0.0054235924f * fVec50[((IOTA - 210) & 511)])) + (0.00416449504f * fVec50[((IOTA - 211) & 511)])) + (0.003590615f * fVec50[((IOTA - 212) & 511)])) + (0.00432304386f * fVec50[((IOTA - 213) & 511)])) + (0.00570184272f * fVec50[((IOTA - 214) & 511)])) + (0.00640047388f * fVec50[((IOTA - 215) & 511)])) + (0.00610552588f * fVec50[((IOTA - 216) & 511)])) + (0.00482062344f * fVec50[((IOTA - 217) & 511)])) + (0.0039378549f * fVec50[((IOTA - 218) & 511)])) + (0.00489168847f * fVec50[((IOTA - 219) & 511)])) + (0.00635945797f * fVec50[((IOTA - 220) & 511)])) + (0.00757351238f * fVec50[((IOTA - 221) & 511)])) + (0.0082032159f * fVec50[((IOTA - 222) & 511)])) + (0.00716134114f * fVec50[((IOTA - 223) & 511)])) + (0.00555314496f * fVec50[((IOTA - 224) & 511)])) + (0.00463087903f * fVec50[((IOTA - 225) & 511)])) + (0.00412013335f * fVec50[((IOTA - 226) & 511)])) + (0.00460182084f * fVec50[((IOTA - 227) & 511)])) + (0.00622132421f * fVec50[((IOTA - 228) & 511)])) + (0.00822868012f * fVec50[((IOTA - 229) & 511)])) + (0.0103454851f * fVec50[((IOTA - 230) & 511)])) + (0.0117702559f * fVec50[((IOTA - 231) & 511)])) + (0.0122173093f * fVec50[((IOTA - 232) & 511)])) + (0.0122651719f * fVec50[((IOTA - 233) & 511)])) + (0.0117525049f * fVec50[((IOTA - 234) & 511)])) + (0.010462801f * fVec50[((IOTA - 235) & 511)])) + (0.00868161954f * fVec50[((IOTA - 236) & 511)])) + (0.00673303008f * fVec50[((IOTA - 237) & 511)])) + (0.0052242754f * fVec50[((IOTA - 238) & 511)])) + (0.00446697045f * fVec50[((IOTA - 239) & 511)])) + (0.00394987455f * fVec50[((IOTA - 240) & 511)])) + (0.00360703329f * fVec50[((IOTA - 241) & 511)])) + (0.0039187409f * fVec50[((IOTA - 242) & 511)])) + (0.00433918368f * fVec50[((IOTA - 243) & 511)])) + (0.00448503112f * fVec50[((IOTA - 244) & 511)])) + (0.00467533339f * fVec50[((IOTA - 245) & 511)])) + (0.00466789817f * fVec50[((IOTA - 246) & 511)])) + (0.0042606215f * fVec50[((IOTA - 247) & 511)])) + (0.00352760404f * fVec50[((IOTA - 248) & 511)])) + (0.00294737332f * fVec50[((IOTA - 249) & 511)])) + (0.00329157757f * fVec50[((IOTA - 250) & 511)])) + (0.00458701281f * fVec50[((IOTA - 251) & 511)])) + (0.00610475149f * fVec50[((IOTA - 252) & 511)])) + (0.00781356636f * fVec50[((IOTA - 253) & 511)])) + (0.00984564424f * fVec50[((IOTA - 254) & 511)])) + (0.011430637f * fVec50[((IOTA - 255) & 511)])) + (0.012073135f * fVec50[((IOTA - 256) & 511)])) + (0.0118690785f * fVec50[((IOTA - 257) & 511)])) + (0.0111229252f * fVec50[((IOTA - 258) & 511)])) + (0.0103784464f * fVec50[((IOTA - 259) & 511)])) + (0.00959902257f * fVec50[((IOTA - 260) & 511)])) + (0.00907842629f * fVec50[((IOTA - 261) & 511)])) + (0.00919859204f * fVec50[((IOTA - 262) & 511)])) + (0.00926525891f * fVec50[((IOTA - 263) & 511)])) + (0.00874075852f * fVec50[((IOTA - 264) & 511)])) + (0.00776725309f * fVec50[((IOTA - 265) & 511)])) + (0.00665025506f * fVec50[((IOTA - 266) & 511)])) + (0.00618247688f * fVec50[((IOTA - 267) & 511)])) + (0.0072960984f * fVec50[((IOTA - 268) & 511)])) + (0.00978275761f * fVec50[((IOTA - 269) & 511)])) + (0.0121302595f * fVec50[((IOTA - 270) & 511)])) + (0.0130726006f * fVec50[((IOTA - 271) & 511)])) + (0.0121361148f * fVec50[((IOTA - 272) & 511)])) + (0.0094662793f * fVec50[((IOTA - 273) & 511)])) + (0.00617854251f * fVec50[((IOTA - 274) & 511)])) + (0.00328810792f * fVec50[((IOTA - 275) & 511)])) + (0.00157470815f * fVec50[((IOTA - 276) & 511)])) + (0.00159636233f * fVec50[((IOTA - 277) & 511)])) + (0.00306958426f * fVec50[((IOTA - 278) & 511)])) + (0.00499125384f * fVec50[((IOTA - 279) & 511)])) + (0.00604372332f * fVec50[((IOTA - 280) & 511)])) + (0.00580184208f * fVec50[((IOTA - 281) & 511)])) + (0.00499363896f * fVec50[((IOTA - 282) & 511)])) + (0.00429596845f * fVec50[((IOTA - 283) & 511)])) + (0.00399572309f * fVec50[((IOTA - 284) & 511)])) + (0.00441663014f * fVec50[((IOTA - 285) & 511)])) + (0.00518016191f * fVec50[((IOTA - 286) & 511)])) + (0.00559855998f * fVec50[((IOTA - 287) & 511)])) + (0.00581891136f * fVec50[((IOTA - 288) & 511)])) + (0.00582157541f * fVec50[((IOTA - 289) & 511)])) + (0.00537157897f * fVec50[((IOTA - 290) & 511)])) + (0.00484726485f * fVec50[((IOTA - 291) & 511)])) + (0.0046308171f * fVec50[((IOTA - 292) & 511)])) + (0.00507492712f * fVec50[((IOTA - 293) & 511)])) + (0.00574883725f * fVec50[((IOTA - 294) & 511)])) + (0.0057662474f * fVec50[((IOTA - 295) & 511)])) + (0.00506365113f * fVec50[((IOTA - 296) & 511)])) + (0.00440541608f * fVec50[((IOTA - 297) & 511)])) + (0.00474190665f * fVec50[((IOTA - 298) & 511)])) + (0.00602767663f * fVec50[((IOTA - 299) & 511)])) + (0.00724002719f * fVec50[((IOTA - 300) & 511)])) + (0.00795966201f * fVec50[((IOTA - 301) & 511)])) + (0.00820628367f * fVec50[((IOTA - 302) & 511)])) + (0.00784414262f * fVec50[((IOTA - 303) & 511)])) + (0.00731180469f * fVec50[((IOTA - 304) & 511)])) + (0.00699984934f * fVec50[((IOTA - 305) & 511)])) + (0.00677915709f * fVec50[((IOTA - 306) & 511)])) + (0.00731676118f * fVec50[((IOTA - 307) & 511)])) + (0.00856733974f * fVec50[((IOTA - 308) & 511)])) + (0.00985812768f * fVec50[((IOTA - 309) & 511)])) + (0.0104786931f * fVec50[((IOTA - 310) & 511)])) + (0.0095804045f * fVec50[((IOTA - 311) & 511)])) + (0.00773137994f * fVec50[((IOTA - 312) & 511)])) + (0.00621153507f * fVec50[((IOTA - 313) & 511)])) + (0.00491665723f * fVec50[((IOTA - 314) & 511)])) + (0.00343510183f * fVec50[((IOTA - 315) & 511)])) + (0.00176829379f * fVec50[((IOTA - 316) & 511)])) + (0.000193214044f * fVec50[((IOTA - 320) & 511)])) + (0.00122350315f * fVec50[((IOTA - 321) & 511)])) + (0.00190769788f * fVec50[((IOTA - 322) & 511)])) + (0.00149041507f * fVec50[((IOTA - 323) & 511)])) + (0.000701636076f * fVec50[((IOTA - 324) & 511)])) + (0.0014296039f * fVec50[((IOTA - 329) & 511)])) + (0.00314929243f * fVec50[((IOTA - 330) & 511)])) + (0.00359687256f * fVec50[((IOTA - 331) & 511)])) + (0.00324755674f * fVec50[((IOTA - 332) & 511)])) + (0.00300564431f * fVec50[((IOTA - 333) & 511)])) + (0.0029401863f * fVec50[((IOTA - 334) & 511)])) + (0.00297903363f * fVec50[((IOTA - 335) & 511)])) + (0.00321499817f * fVec50[((IOTA - 336) & 511)])) + (0.0035575605f * fVec50[((IOTA - 337) & 511)])) + (0.00444733026f * fVec50[((IOTA - 338) & 511)])) + (0.00556411175f * fVec50[((IOTA - 339) & 511)])) + (0.00645103119f * fVec50[((IOTA - 340) & 511)])) + (0.00688476348f * fVec50[((IOTA - 341) & 511)])) + (0.00614047004f * fVec50[((IOTA - 342) & 511)])) + (0.00430770917f * fVec50[((IOTA - 343) & 511)])) + (0.00231042085f * fVec50[((IOTA - 344) & 511)])) + (0.000624808948f * fVec50[((IOTA - 345) & 511)])) + (0.000382989179f * fVec50[((IOTA - 347) & 511)])) + (0.00236128783f * fVec50[((IOTA - 348) & 511)])) + (0.00502337888f * fVec50[((IOTA - 349) & 511)])) + (0.00755346939f * fVec50[((IOTA - 350) & 511)])) + (0.00846535712f * fVec50[((IOTA - 351) & 511)])) + (0.00757778762f * fVec50[((IOTA - 352) & 511)])) + (0.00510001974f * fVec50[((IOTA - 353) & 511)])) + (0.00146532245f * fVec50[((IOTA - 354) & 511)])) + (0.000801759306f * fVec50[((IOTA - 359) & 511)])) + (0.00303770741f * fVec50[((IOTA - 360) & 511)])) + (0.00372041529f * fVec50[((IOTA - 361) & 511)])) + (0.00258870237f * fVec50[((IOTA - 362) & 511)])) + (0.00019516563f * fVec50[((IOTA - 363) & 511)])) + (2.92127952e-05f * fVec50[((IOTA - 378) & 511)])) + (0.000381657388f * fVec50[((IOTA - 379) & 511)])) + (0.000720935874f * fVec50[((IOTA - 380) & 511)])) + (0.0008645528f * fVec50[((IOTA - 381) & 511)])) + (0.000497796573f * fVec50[((IOTA - 382) & 511)])) + (0.000271497294f * fVec50[((IOTA - 383) & 511)])) + (0.000745409168f * fVec50[((IOTA - 384) & 511)])) + (0.00145915756f * fVec50[((IOTA - 385) & 511)])) + (0.00163108949f * fVec50[((IOTA - 386) & 511)])) + (0.000927997287f * fVec50[((IOTA - 387) & 511)])) + (0.000165394973f * fVec50[((IOTA - 425) & 511)])) + (0.00218142569f * fVec50[((IOTA - 426) & 511)])) + (0.00261556078f * fVec50[((IOTA - 427) & 511)])) + (0.00196903571f * fVec50[((IOTA - 428) & 511)])) + (0.000926169567f * fVec50[((IOTA - 429) & 511)])) + (0.00105816964f * fVec50[((IOTA - 496) & 511)])) + (0.00241909409f * fVec50[((IOTA - 497) & 511)])) + (0.00204388052f * fVec50[((IOTA - 498) & 511)])) + (0.000230822247f * fVec50[((IOTA - 499) & 511)])) - (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0272030607f * fVec50[((IOTA - 10) & 511)]) + ((0.122098871f * fVec50[((IOTA - 9) & 511)]) + ((0.203513414f * fVec50[((IOTA - 8) & 511)]) + ((0.195940793f * fVec50[((IOTA - 7) & 511)]) + ((0.0986849666f * fVec50[((IOTA - 6) & 511)]) + (((0.00887923315f * fVec50[((IOTA - 21) & 511)]) + (0.0106463805f * fVec50[((IOTA - 22) & 511)])) + (0.00346081425f * fVec50[((IOTA - 23) & 511)]))))))) + (0.00711518293f * fVec50[((IOTA - 27) & 511)])) + (0.0110903671f * fVec50[((IOTA - 28) & 511)])) + (0.0066359737f * fVec50[((IOTA - 29) & 511)])) + (0.00307076145f * fVec50[((IOTA - 30) & 511)])) + (0.0225423165f * fVec50[((IOTA - 31) & 511)])) + (0.0433927663f * fVec50[((IOTA - 32) & 511)])) + (0.0497430228f * fVec50[((IOTA - 33) & 511)])) + (0.0480340235f * fVec50[((IOTA - 34) & 511)])) + (0.0394698121f * fVec50[((IOTA - 35) & 511)])) + (0.0256424155f * fVec50[((IOTA - 36) & 511)])) + (0.00303845061f * fVec50[((IOTA - 43) & 511)])) + (0.0450661108f * fVec50[((IOTA - 44) & 511)])) + (0.0774179175f * fVec50[((IOTA - 45) & 511)])) + (0.0837955326f * fVec50[((IOTA - 46) & 511)])) + (0.0738057718f * fVec50[((IOTA - 47) & 511)])) + (0.0423542373f * fVec50[((IOTA - 48) & 511)])) + (0.0282368176f * fVec50[((IOTA - 54) & 511)])) + (0.0490211584f * fVec50[((IOTA - 55) & 511)])) + (0.0570170321f * fVec50[((IOTA - 56) & 511)])) + (0.0420816541f * fVec50[((IOTA - 57) & 511)])) + (0.019885214f * fVec50[((IOTA - 58) & 511)])) + (0.000629022252f * fVec50[((IOTA - 59) & 511)])) + (0.000669945031f * fVec50[((IOTA - 62) & 511)])) + (0.00846433546f * fVec50[((IOTA - 63) & 511)])) + (0.0132529577f * fVec50[((IOTA - 64) & 511)])) + (0.0136877131f * fVec50[((IOTA - 65) & 511)])) + (0.0139198359f * fVec50[((IOTA - 66) & 511)])) + (0.0151886605f * fVec50[((IOTA - 67) & 511)])) + (0.0227421001f * fVec50[((IOTA - 68) & 511)])) + (0.035218671f * fVec50[((IOTA - 69) & 511)])) + (0.0418282822f * fVec50[((IOTA - 70) & 511)])) + (0.0376216844f * fVec50[((IOTA - 71) & 511)])) + (0.0237774365f * fVec50[((IOTA - 72) & 511)])) + (0.00426517567f * fVec50[((IOTA - 73) & 511)])) + (0.00234675873f * fVec50[((IOTA - 77) & 511)])) + (0.0141282603f * fVec50[((IOTA - 78) & 511)])) + (0.0174427312f * fVec50[((IOTA - 79) & 511)])) + (0.0140123069f * fVec50[((IOTA - 80) & 511)])) + (0.00945113041f * fVec50[((IOTA - 81) & 511)])) + (0.00656729424f * fVec50[((IOTA - 82) & 511)])) + (0.0074425349f * fVec50[((IOTA - 83) & 511)])) + (0.011363104f * fVec50[((IOTA - 84) & 511)])) + (0.0148386322f * fVec50[((IOTA - 85) & 511)])) + (0.017196605f * fVec50[((IOTA - 86) & 511)])) + (0.0177253187f * fVec50[((IOTA - 87) & 511)])) + (0.016877247f * fVec50[((IOTA - 88) & 511)])) + (0.0161938872f * fVec50[((IOTA - 89) & 511)])) + (0.0178317614f * fVec50[((IOTA - 90) & 511)])) + (0.0184535962f * fVec50[((IOTA - 91) & 511)])) + (0.0200855527f * fVec50[((IOTA - 92) & 511)])) + (0.0230570585f * fVec50[((IOTA - 93) & 511)])) + (0.0221346691f * fVec50[((IOTA - 94) & 511)])) + (0.020639576f * fVec50[((IOTA - 95) & 511)])) + (0.0124672763f * fVec50[((IOTA - 96) & 511)])) + (0.00208055926f * fVec50[((IOTA - 102) & 511)])) + (0.0214382373f * fVec50[((IOTA - 103) & 511)])) + (0.0352152623f * fVec50[((IOTA - 104) & 511)])) + (0.0380931795f * fVec50[((IOTA - 105) & 511)])) + (0.030305326f * fVec50[((IOTA - 106) & 511)])) + (0.0189726446f * fVec50[((IOTA - 107) & 511)])) + (0.00688005472f * fVec50[((IOTA - 108) & 511)])) + (0.00259660184f * fVec50[((IOTA - 113) & 511)])) + (0.0116686467f * fVec50[((IOTA - 114) & 511)])) + (0.0192671269f * fVec50[((IOTA - 115) & 511)])) + (0.0227719322f * fVec50[((IOTA - 116) & 511)])) + (0.0206480641f * fVec50[((IOTA - 117) & 511)])) + (0.0147402752f * fVec50[((IOTA - 118) & 511)])) + (0.0075660157f * fVec50[((IOTA - 119) & 511)])) + (0.00292785699f * fVec50[((IOTA - 120) & 511)])) + (0.00483128009f * fVec50[((IOTA - 121) & 511)])) + (0.00946293306f * fVec50[((IOTA - 122) & 511)])) + (0.0115028173f * fVec50[((IOTA - 123) & 511)])) + (0.0125951879f * fVec50[((IOTA - 124) & 511)])) + (0.011328252f * fVec50[((IOTA - 125) & 511)])) + (0.00925546885f * fVec50[((IOTA - 126) & 511)])) + (0.00886132754f * fVec50[((IOTA - 127) & 511)])) + (0.00717348512f * fVec50[((IOTA - 128) & 511)])) + (0.00491039967f * fVec50[((IOTA - 129) & 511)])) + (0.00236928044f * fVec50[((IOTA - 130) & 511)])) + (0.000941628125f * fVec50[((IOTA - 138) & 511)])) + (0.00364950532f * fVec50[((IOTA - 139) & 511)])) + (0.00741892913f * fVec50[((IOTA - 140) & 511)])) + (0.0125066508f * fVec50[((IOTA - 141) & 511)])) + (0.0169282071f * fVec50[((IOTA - 142) & 511)])) + (0.0174571984f * fVec50[((IOTA - 143) & 511)])) + (0.0128552224f * fVec50[((IOTA - 144) & 511)])) + (0.00588254118f * fVec50[((IOTA - 145) & 511)])) + (0.00058940053f * fVec50[((IOTA - 152) & 511)])) + (0.00540060597f * fVec50[((IOTA - 153) & 511)])) + (0.00848121941f * fVec50[((IOTA - 154) & 511)])) + (0.00847099535f * fVec50[((IOTA - 155) & 511)])) + (0.00488357199f * fVec50[((IOTA - 156) & 511)])) + (0.00360545376f * fVec50[((IOTA - 161) & 511)])) + (0.00652606133f * fVec50[((IOTA - 162) & 511)])) + (0.00760046393f * fVec50[((IOTA - 163) & 511)])) + (0.00635890057f * fVec50[((IOTA - 164) & 511)])) + (0.00285121566f * fVec50[((IOTA - 165) & 511)])) + (0.000262482557f * fVec50[((IOTA - 175) & 511)])) + (0.00154927466f * fVec50[((IOTA - 176) & 511)])) + (0.00169589696f * fVec50[((IOTA - 177) & 511)])) + (0.000161212869f * fVec50[((IOTA - 178) & 511)])) + (0.0013114512f * fVec50[((IOTA - 186) & 511)])) + (0.00258043082f * fVec50[((IOTA - 187) & 511)])) + (0.000409073662f * fVec50[((IOTA - 188) & 511)])) + (0.00111702923f * fVec50[((IOTA - 200) & 511)])) + (0.00396220386f * fVec50[((IOTA - 201) & 511)])) + (0.00458506122f * fVec50[((IOTA - 202) & 511)])) + (0.00237278081f * fVec50[((IOTA - 203) & 511)])) + (8.00490379e-05f * fVec50[((IOTA - 317) & 511)])) + (0.000970685855f * fVec50[((IOTA - 318) & 511)])) + (0.000562820584f * fVec50[((IOTA - 319) & 511)])) + (0.000355139375f * fVec50[((IOTA - 325) & 511)])) + (0.00132625923f * fVec50[((IOTA - 326) & 511)])) + (0.00134292571f * fVec50[((IOTA - 327) & 511)])) + (0.00038559176f * fVec50[((IOTA - 328) & 511)])) + (0.000291013625f * fVec50[((IOTA - 346) & 511)])) + (0.00183573458f * fVec50[((IOTA - 355) & 511)])) + (0.00386948464f * fVec50[((IOTA - 356) & 511)])) + (0.00396867841f * fVec50[((IOTA - 357) & 511)])) + (0.00207262859f * fVec50[((IOTA - 358) & 511)])) + (0.00163691351f * fVec50[((IOTA - 364) & 511)])) + (0.00205131527f * fVec50[((IOTA - 365) & 511)])) + (0.00137077551f * fVec50[((IOTA - 366) & 511)])) + (0.000489215367f * fVec50[((IOTA - 367) & 511)])) + (0.000624003354f * fVec50[((IOTA - 368) & 511)])) + (0.00173022132f * fVec50[((IOTA - 369) & 511)])) + (0.00300982641f * fVec50[((IOTA - 370) & 511)])) + (0.00408676919f * fVec50[((IOTA - 371) & 511)])) + (0.00471857935f * fVec50[((IOTA - 372) & 511)])) + (0.00459986925f * fVec50[((IOTA - 373) & 511)])) + (0.00355040468f * fVec50[((IOTA - 374) & 511)])) + (0.001775729f * fVec50[((IOTA - 375) & 511)])) + (0.000505448319f * fVec50[((IOTA - 376) & 511)])) + (0.00021994859f * fVec50[((IOTA - 377) & 511)])) + (0.000137235504f * fVec50[((IOTA - 388) & 511)])) + (0.00099066738f * fVec50[((IOTA - 389) & 511)])) + (0.00180831831f * fVec50[((IOTA - 390) & 511)])) + (0.00278730644f * fVec50[((IOTA - 391) & 511)])) + (0.00353996456f * fVec50[((IOTA - 392) & 511)])) + (0.00384457782f * fVec50[((IOTA - 393) & 511)])) + (0.00371635705f * fVec50[((IOTA - 394) & 511)])) + (0.00364656234f * fVec50[((IOTA - 395) & 511)])) + (0.00438905926f * fVec50[((IOTA - 396) & 511)])) + (0.0056283921f * fVec50[((IOTA - 397) & 511)])) + (0.00626797834f * fVec50[((IOTA - 398) & 511)])) + (0.00555478688f * fVec50[((IOTA - 399) & 511)])) + (0.00344157638f * fVec50[((IOTA - 400) & 511)])) + (0.00115720835f * fVec50[((IOTA - 401) & 511)])) + (0.000320443418f * fVec50[((IOTA - 402) & 511)])) + (0.000899527688f * fVec50[((IOTA - 403) & 511)])) + (0.00205332879f * fVec50[((IOTA - 404) & 511)])) + (0.00347292656f * fVec50[((IOTA - 405) & 511)])) + (0.0047924947f * fVec50[((IOTA - 406) & 511)])) + (0.00544657838f * fVec50[((IOTA - 407) & 511)])) + (0.00482396875f * fVec50[((IOTA - 408) & 511)])) + (0.00339334272f * fVec50[((IOTA - 409) & 511)])) + (0.00251017138f * fVec50[((IOTA - 410) & 511)])) + (0.00234068697f * fVec50[((IOTA - 411) & 511)])) + (0.00265496597f * fVec50[((IOTA - 412) & 511)])) + (0.0035285335f * fVec50[((IOTA - 413) & 511)])) + (0.00398596469f * fVec50[((IOTA - 414) & 511)])) + (0.00363141391f * fVec50[((IOTA - 415) & 511)])) + (0.00280576991f * fVec50[((IOTA - 416) & 511)])) + (0.00166417472f * fVec50[((IOTA - 417) & 511)])) + (0.00135968532f * fVec50[((IOTA - 418) & 511)])) + (0.00202163775f * fVec50[((IOTA - 419) & 511)])) + (0.00281305006f * fVec50[((IOTA - 420) & 511)])) + (0.00388218602f * fVec50[((IOTA - 421) & 511)])) + (0.00465671485f * fVec50[((IOTA - 422) & 511)])) + (0.00406307075f * fVec50[((IOTA - 423) & 511)])) + (0.0022896342f * fVec50[((IOTA - 424) & 511)])) + (0.00106671965f * fVec50[((IOTA - 430) & 511)])) + (0.00368212583f * fVec50[((IOTA - 431) & 511)])) + (0.00561593892f * fVec50[((IOTA - 432) & 511)])) + (0.00661280192f * fVec50[((IOTA - 433) & 511)])) + (0.00631246343f * fVec50[((IOTA - 434) & 511)])) + (0.00503388047f * fVec50[((IOTA - 435) & 511)])) + (0.00404953305f * fVec50[((IOTA - 436) & 511)])) + (0.00404525781f * fVec50[((IOTA - 437) & 511)])) + (0.00508843409f * fVec50[((IOTA - 438) & 511)])) + (0.00683398964f * fVec50[((IOTA - 439) & 511)])) + (0.00848676451f * fVec50[((IOTA - 440) & 511)])) + (0.00961584412f * fVec50[((IOTA - 441) & 511)])) + (0.0100627113f * fVec50[((IOTA - 442) & 511)])) + (0.00956788845f * fVec50[((IOTA - 443) & 511)])) + (0.00852808915f * fVec50[((IOTA - 444) & 511)])) + (0.0072237635f * fVec50[((IOTA - 445) & 511)])) + (0.00637280988f * fVec50[((IOTA - 446) & 511)])) + (0.00637243828f * fVec50[((IOTA - 447) & 511)])) + (0.00644771662f * fVec50[((IOTA - 448) & 511)])) + (0.00621032668f * fVec50[((IOTA - 449) & 511)])) + (0.00545416819f * fVec50[((IOTA - 450) & 511)])) + (0.00419336697f * fVec50[((IOTA - 451) & 511)])) + (0.00307596615f * fVec50[((IOTA - 452) & 511)])) + (0.0022892626f * fVec50[((IOTA - 453) & 511)])) + (0.00198173709f * fVec50[((IOTA - 454) & 511)])) + (0.00265775388f * fVec50[((IOTA - 455) & 511)])) + (0.00379324611f * fVec50[((IOTA - 456) & 511)])) + (0.00470621884f * fVec50[((IOTA - 457) & 511)])) + (0.00550900027f * fVec50[((IOTA - 458) & 511)])) + (0.00572774094f * fVec50[((IOTA - 459) & 511)])) + (0.00492653949f * fVec50[((IOTA - 460) & 511)])) + (0.00375136314f * fVec50[((IOTA - 461) & 511)])) + (0.00289458595f * fVec50[((IOTA - 462) & 511)])) + (0.00300617097f * fVec50[((IOTA - 463) & 511)])) + (0.0039233258f * fVec50[((IOTA - 464) & 511)])) + (0.00452741003f * fVec50[((IOTA - 465) & 511)])) + (0.00469212374f * fVec50[((IOTA - 466) & 511)])) + (0.00477434089f * fVec50[((IOTA - 467) & 511)])) + (0.00435203966f * fVec50[((IOTA - 468) & 511)])) + (0.00321571063f * fVec50[((IOTA - 469) & 511)])) + (0.00179933477f * fVec50[((IOTA - 470) & 511)])) + (0.000633173157f * fVec50[((IOTA - 471) & 511)])) + (0.000425151549f * fVec50[((IOTA - 472) & 511)])) + (0.000578186009f * fVec50[((IOTA - 473) & 511)])) + (0.000344668981f * fVec50[((IOTA - 474) & 511)])) + (0.000417809468f * fVec50[((IOTA - 475) & 511)])) + (0.000769758131f * fVec50[((IOTA - 476) & 511)])) + (0.00157814706f * fVec50[((IOTA - 477) & 511)])) + (0.00303095393f * fVec50[((IOTA - 478) & 511)])) + (0.00399120012f * fVec50[((IOTA - 479) & 511)])) + (0.00440749153f * fVec50[((IOTA - 480) & 511)])) + (0.00476179458f * fVec50[((IOTA - 481) & 511)])) + (0.0048690429f * fVec50[((IOTA - 482) & 511)])) + (0.00473670196f * fVec50[((IOTA - 483) & 511)])) + (0.00435454911f * fVec50[((IOTA - 484) & 511)])) + (0.00339786522f * fVec50[((IOTA - 485) & 511)])) + (0.00242975075f * fVec50[((IOTA - 486) & 511)])) + (0.0015954948f * fVec50[((IOTA - 487) & 511)])) + (0.000835866667f * fVec50[((IOTA - 488) & 511)])) + (0.000962817576f * fVec50[((IOTA - 489) & 511)])) + (0.00178365922f * fVec50[((IOTA - 490) & 511)])) + (0.00290778279f * fVec50[((IOTA - 491) & 511)])) + (0.00405941531f * fVec50[((IOTA - 492) & 511)])) + (0.00435247365f * fVec50[((IOTA - 493) & 511)])) + (0.00329523301f * fVec50[((IOTA - 494) & 511)])) + (0.00126393f * fVec50[((IOTA - 495) & 511)])) + (0.0020660921f * fVec50[((IOTA - 500) & 511)])) + (0.00391211174f * fVec50[((IOTA - 501) & 511)])) + (0.00526027288f * fVec50[((IOTA - 502) & 511)])) + (0.00626128679f * fVec50[((IOTA - 503) & 511)])) + (0.00645673135f * fVec50[((IOTA - 504) & 511)])) + (0.00620329473f * fVec50[((IOTA - 505) & 511)])) + (0.00589954853f * fVec50[((IOTA - 506) & 511)])) + (0.00568960607f * fVec50[((IOTA - 507) & 511)])) + (0.00587922661f * fVec50[((IOTA - 508) & 511)])) + (0.00620221021f * fVec50[((IOTA - 509) & 511)])) + (0.00642891228f * fVec50[((IOTA - 510) & 511)])) + (0.00652333535f * fVec50[((IOTA - 511) & 511)]))) : (iSlow149 ? ((((((((((0.00117667904f * fVec49[((IOTA - 422) & 511)]) + ((4.13930975e-05f * fVec49[((IOTA - 421) & 511)]) + ((3.20291147e-05f * fVec49[((IOTA - 391) & 511)]) + ((0.00177140627f * fVec49[((IOTA - 390) & 511)]) + ((0.00299195899f * fVec49[((IOTA - 389) & 511)]) + ((0.00351295341f * fVec49[((IOTA - 388) & 511)]) + ((0.00290796347f * fVec49[((IOTA - 387) & 511)]) + ((0.000426394865f * fVec49[((IOTA - 386) & 511)]) + ((0.00111553539f * fVec49[((IOTA - 381) & 511)]) + ((0.00287723634f * fVec49[((IOTA - 380) & 511)]) + ((0.00430565374f * fVec49[((IOTA - 379) & 511)]) + ((0.00372084882f * fVec49[((IOTA - 377) & 511)]) + ((0.000487290788f * fVec49[((IOTA - 376) & 511)]) + ((0.0018386892f * fVec49[((IOTA - 364) & 511)]) + ((0.00468154019f * fVec49[((IOTA - 363) & 511)]) + ((0.00691568013f * fVec49[((IOTA - 362) & 511)]) + ((0.00689648744f * fVec49[((IOTA - 361) & 511)]) + ((0.00422798377f * fVec49[((IOTA - 360) & 511)]) + (((0.00275690202f * fVec49[((IOTA - 354) & 511)]) + ((0.00845767278f * fVec49[((IOTA - 353) & 511)]) + ((0.0118088052f * fVec49[((IOTA - 352) & 511)]) + ((0.0121961329f * fVec49[((IOTA - 351) & 511)]) + ((0.00981620234f * fVec49[((IOTA - 350) & 511)]) + ((0.00601749728f * fVec49[((IOTA - 349) & 511)]) + ((0.00283971941f * fVec49[((IOTA - 348) & 511)]) + ((0.00119525194f * fVec49[((IOTA - 347) & 511)]) + ((0.000989309512f * fVec49[((IOTA - 346) & 511)]) + ((0.00210146559f * fVec49[((IOTA - 345) & 511)]) + ((0.00438568043f * fVec49[((IOTA - 344) & 511)]) + ((0.00713604037f * fVec49[((IOTA - 343) & 511)]) + ((0.0090161534f * fVec49[((IOTA - 342) & 511)]) + ((0.00911478326f * fVec49[((IOTA - 341) & 511)]) + ((0.00778453145f * fVec49[((IOTA - 340) & 511)]) + ((0.00589223299f * fVec49[((IOTA - 339) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00343608949f * fVec49[((IOTA - 250) & 511)]) + ((0.0010695844f * fVec49[((IOTA - 249) & 511)]) + ((0.00104422122f * fVec49[((IOTA - 247) & 511)]) + ((0.00435017841f * fVec49[((IOTA - 246) & 511)]) + ((0.00749329198f * fVec49[((IOTA - 245) & 511)]) + ((0.00935759209f * fVec49[((IOTA - 244) & 511)]) + ((0.0101522151f * fVec49[((IOTA - 243) & 511)]) + ((0.00997117069f * fVec49[((IOTA - 242) & 511)]) + ((0.00892142951f * fVec49[((IOTA - 241) & 511)]) + ((0.00763061736f * fVec49[((IOTA - 240) & 511)]) + ((0.00730139529f * fVec49[((IOTA - 239) & 511)]) + ((0.00915543269f * fVec49[((IOTA - 238) & 511)]) + ((0.0121887531f * fVec49[((IOTA - 237) & 511)]) + ((0.0142944362f * fVec49[((IOTA - 236) & 511)]) + ((0.015193549f * fVec49[((IOTA - 235) & 511)]) + ((0.0159457866f * fVec49[((IOTA - 234) & 511)]) + ((0.0171615016f * fVec49[((IOTA - 233) & 511)]) + ((0.0181914922f * fVec49[((IOTA - 232) & 511)]) + ((0.0174004342f * fVec49[((IOTA - 231) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((0.0031175022f * fVec49[((IOTA - 186) & 511)]) + ((0.00660016295f * fVec49[((IOTA - 185) & 511)]) + ((0.0113012679f * fVec49[((IOTA - 184) & 511)]) + ((0.015797453f * fVec49[((IOTA - 183) & 511)]) + ((0.0171982124f * fVec49[((IOTA - 182) & 511)]) + ((0.0143677341f * fVec49[((IOTA - 181) & 511)]) + ((0.00662871916f * fVec49[((IOTA - 180) & 511)]) + ((0.00459689368f * fVec49[((IOTA - 174) & 511)]) + (((((((((((((((((((((((((((((((((((((((0.0200931542f * fVec49[((IOTA - 52) & 511)]) + ((0.0116334045f * fVec49[((IOTA - 51) & 511)]) + ((0.00119661633f * fVec49[((IOTA - 43) & 511)]) + ((0.0180157498f * fVec49[((IOTA - 42) & 511)]) + ((0.0304626282f * fVec49[((IOTA - 41) & 511)]) + ((0.0357557014f * fVec49[((IOTA - 40) & 511)]) + ((0.0305201449f * fVec49[((IOTA - 39) & 511)]) + ((0.018462453f * fVec49[((IOTA - 38) & 511)]) + ((0.00180774508f * fVec49[((IOTA - 37) & 511)]) + ((0.00502195535f * fVec49[((IOTA - 29) & 511)]) + ((0.0192466583f * fVec49[((IOTA - 28) & 511)]) + ((0.0281984117f * fVec49[((IOTA - 27) & 511)]) + ((0.0252072904f * fVec49[((IOTA - 26) & 511)]) + ((0.00414042268f * fVec49[((IOTA - 25) & 511)]) + ((0.00486490969f * fVec49[((IOTA - 22) & 511)]) + ((0.0202751607f * fVec49[((IOTA - 21) & 511)]) + ((0.0205693766f * fVec49[((IOTA - 20) & 511)]) + ((0.0130048636f * fVec49[((IOTA - 19) & 511)]) + ((0.00907308049f * fVec49[((IOTA - 18) & 511)]) + ((0.0103873331f * fVec49[((IOTA - 17) & 511)]) + ((0.0195429828f * fVec49[((IOTA - 16) & 511)]) + ((0.0315925181f * fVec49[((IOTA - 15) & 511)]) + ((0.0500227287f * fVec49[((IOTA - 14) & 511)]) + ((0.0483769588f * fVec49[((IOTA - 13) & 511)]) + ((0.0133327208f * fVec49[((IOTA - 12) & 511)]) + ((0.0303266663f * fVec49[((IOTA - 6) & 511)]) + ((0.137107849f * fVec49[((IOTA - 5) & 511)]) + ((0.219896197f * fVec49[((IOTA - 4) & 511)]) + ((0.251254231f * fVec49[((IOTA - 3) & 511)]) + ((0.245081574f * fVec49[((IOTA - 2) & 511)]) + ((0.19649142f * fVec49[((IOTA - 1) & 511)]) + ((fSlow153 * fTemp0) + (0.0134011516f * fVec49[((IOTA - 53) & 511)]))))))))))))))))))))))))))))))))) + (0.00195136527f * fVec49[((IOTA - 74) & 511)])) + (0.0069599878f * fVec49[((IOTA - 75) & 511)])) + (0.00141313113f * fVec49[((IOTA - 76) & 511)])) + (0.000101141632f * fVec49[((IOTA - 89) & 511)])) + (0.00235202536f * fVec49[((IOTA - 98) & 511)])) + (0.0145511031f * fVec49[((IOTA - 99) & 511)])) + (0.0213773623f * fVec49[((IOTA - 100) & 511)])) + (0.0202377364f * fVec49[((IOTA - 101) & 511)])) + (0.0133272335f * fVec49[((IOTA - 102) & 511)])) + (0.00100592896f * fVec49[((IOTA - 103) & 511)])) + (0.00905884895f * fVec49[((IOTA - 111) & 511)])) + (0.0116910134f * fVec49[((IOTA - 112) & 511)])) + (0.00485982466f * fVec49[((IOTA - 113) & 511)])) + (0.00144537771f * fVec49[((IOTA - 132) & 511)])) + (0.00665333821f * fVec49[((IOTA - 133) & 511)])) + (0.0111397263f * fVec49[((IOTA - 134) & 511)])) + (0.0124093303f * fVec49[((IOTA - 135) & 511)])) + (0.0098540606f * fVec49[((IOTA - 136) & 511)])) + (0.00488810241f * fVec49[((IOTA - 137) & 511)])) + (0.00266521703f * fVec49[((IOTA - 146) & 511)])) + (0.00997861195f * fVec49[((IOTA - 147) & 511)])) + (0.0137805101f * fVec49[((IOTA - 148) & 511)])) + (0.0132369436f * fVec49[((IOTA - 149) & 511)])) + (0.0076552364f * fVec49[((IOTA - 150) & 511)])) + (0.000590540934f * fVec49[((IOTA - 151) & 511)])) + (0.00141096069f * fVec49[((IOTA - 157) & 511)])) + (0.00248804875f * fVec49[((IOTA - 158) & 511)])) + (0.00188532239f * fVec49[((IOTA - 159) & 511)])) + (0.000805629883f * fVec49[((IOTA - 166) & 511)])) + (0.00282331696f * fVec49[((IOTA - 167) & 511)])) + (0.00318211876f * fVec49[((IOTA - 168) & 511)])) + (0.00440949295f * fVec49[((IOTA - 169) & 511)])) + (0.00715876743f * fVec49[((IOTA - 170) & 511)])) + (0.00930283591f * fVec49[((IOTA - 171) & 511)])) + (0.00973654725f * fVec49[((IOTA - 172) & 511)])) + (0.00810594019f * fVec49[((IOTA - 173) & 511)])) + (0.000788700767f * fVec49[((IOTA - 187) & 511)])))))))))) + (0.00105752284f * fVec49[((IOTA - 188) & 511)])) + (0.00363313267f * fVec49[((IOTA - 189) & 511)])) + (0.00628278498f * fVec49[((IOTA - 190) & 511)])) + (0.00812693126f * fVec49[((IOTA - 191) & 511)])) + (0.00937786978f * fVec49[((IOTA - 192) & 511)])) + (0.0108413547f * fVec49[((IOTA - 193) & 511)])) + (0.0137437377f * fVec49[((IOTA - 194) & 511)])) + (0.0172214359f * fVec49[((IOTA - 195) & 511)])) + (0.0189842544f * fVec49[((IOTA - 196) & 511)])) + (0.0171347745f * fVec49[((IOTA - 197) & 511)])) + (0.0115053803f * fVec49[((IOTA - 198) & 511)])) + (0.00533108553f * fVec49[((IOTA - 199) & 511)])) + (0.000583440531f * fVec49[((IOTA - 200) & 511)])) + (0.00228923792f * fVec49[((IOTA - 204) & 511)])) + (0.00735844672f * fVec49[((IOTA - 205) & 511)])) + (0.0106923394f * fVec49[((IOTA - 206) & 511)])) + (0.0104258116f * fVec49[((IOTA - 207) & 511)])) + (0.0076556392f * fVec49[((IOTA - 208) & 511)])) + (0.00522008399f * fVec49[((IOTA - 209) & 511)])) + (0.00402018102f * fVec49[((IOTA - 210) & 511)])) + (0.00406086119f * fVec49[((IOTA - 211) & 511)])) + (0.00529000256f * fVec49[((IOTA - 212) & 511)])) + (0.00839352049f * fVec49[((IOTA - 213) & 511)])) + (0.0129140159f * fVec49[((IOTA - 214) & 511)])) + (0.0163382608f * fVec49[((IOTA - 215) & 511)])) + (0.0166463684f * fVec49[((IOTA - 216) & 511)])) + (0.0135755911f * fVec49[((IOTA - 217) & 511)])) + (0.00838989392f * fVec49[((IOTA - 218) & 511)])) + (0.00419905502f * fVec49[((IOTA - 219) & 511)])) + (0.00282372022f * fVec49[((IOTA - 220) & 511)])) + (0.00369393546f * fVec49[((IOTA - 221) & 511)])) + (0.00599160744f * fVec49[((IOTA - 222) & 511)])) + (0.00806609727f * fVec49[((IOTA - 223) & 511)])) + (0.0083512906f * fVec49[((IOTA - 224) & 511)])) + (0.00719296746f * fVec49[((IOTA - 225) & 511)])) + (0.00606484339f * fVec49[((IOTA - 226) & 511)])) + (0.00605002278f * fVec49[((IOTA - 227) & 511)])) + (0.00813449733f * fVec49[((IOTA - 228) & 511)])) + (0.0116854012f * fVec49[((IOTA - 229) & 511)])) + (0.0149196722f * fVec49[((IOTA - 230) & 511)])) + (0.00620061904f * fVec49[((IOTA - 251) & 511)]))))))))))))))))))))) + (0.00847894326f * fVec49[((IOTA - 252) & 511)])) + (0.0108999256f * fVec49[((IOTA - 253) & 511)])) + (0.0141450176f * fVec49[((IOTA - 254) & 511)])) + (0.0162370875f * fVec49[((IOTA - 255) & 511)])) + (0.0163794681f * fVec49[((IOTA - 256) & 511)])) + (0.0148758609f * fVec49[((IOTA - 257) & 511)])) + (0.0124055482f * fVec49[((IOTA - 258) & 511)])) + (0.0113552799f * fVec49[((IOTA - 259) & 511)])) + (0.0123935491f * fVec49[((IOTA - 260) & 511)])) + (0.0139702372f * fVec49[((IOTA - 261) & 511)])) + (0.0153038688f * fVec49[((IOTA - 262) & 511)])) + (0.0160340928f * fVec49[((IOTA - 263) & 511)])) + (0.0149102155f * fVec49[((IOTA - 264) & 511)])) + (0.0117561882f * fVec49[((IOTA - 265) & 511)])) + (0.00824404135f * fVec49[((IOTA - 266) & 511)])) + (0.00656249048f * fVec49[((IOTA - 267) & 511)])) + (0.00782958325f * fVec49[((IOTA - 268) & 511)])) + (0.0116589218f * fVec49[((IOTA - 269) & 511)])) + (0.0163514689f * fVec49[((IOTA - 270) & 511)])) + (0.0189705193f * fVec49[((IOTA - 271) & 511)])) + (0.018207863f * fVec49[((IOTA - 272) & 511)])) + (0.0149890641f * fVec49[((IOTA - 273) & 511)])) + (0.0112646185f * fVec49[((IOTA - 274) & 511)])) + (0.00915586669f * fVec49[((IOTA - 275) & 511)])) + (0.00842049625f * fVec49[((IOTA - 276) & 511)])) + (0.00781243714f * fVec49[((IOTA - 277) & 511)])) + (0.00736126816f * fVec49[((IOTA - 278) & 511)])) + (0.00732074305f * fVec49[((IOTA - 279) & 511)])) + (0.0072895512f * fVec49[((IOTA - 280) & 511)])) + (0.00651805894f * fVec49[((IOTA - 281) & 511)])) + (0.00506784441f * fVec49[((IOTA - 282) & 511)])) + (0.00409595994f * fVec49[((IOTA - 283) & 511)])) + (0.00443073222f * fVec49[((IOTA - 284) & 511)])) + (0.00589018641f * fVec49[((IOTA - 285) & 511)])) + (0.00741816405f * fVec49[((IOTA - 286) & 511)])) + (0.00854405575f * fVec49[((IOTA - 287) & 511)])) + (0.00982503965f * fVec49[((IOTA - 288) & 511)])) + (0.0109946802f * fVec49[((IOTA - 289) & 511)])) + (0.0111705456f * fVec49[((IOTA - 290) & 511)])) + (0.00981846638f * fVec49[((IOTA - 291) & 511)])) + (0.00737860054f * fVec49[((IOTA - 292) & 511)])) + (0.00491870521f * fVec49[((IOTA - 293) & 511)])) + (0.00336955022f * fVec49[((IOTA - 294) & 511)])) + (0.0032037301f * fVec49[((IOTA - 295) & 511)])) + (0.00411540084f * fVec49[((IOTA - 296) & 511)])) + (0.00553364819f * fVec49[((IOTA - 297) & 511)])) + (0.00714859786f * fVec49[((IOTA - 298) & 511)])) + (0.00879256893f * fVec49[((IOTA - 299) & 511)])) + (0.0100395381f * fVec49[((IOTA - 300) & 511)])) + (0.0105968099f * fVec49[((IOTA - 301) & 511)])) + (0.0105787339f * fVec49[((IOTA - 302) & 511)])) + (0.0103335073f * fVec49[((IOTA - 303) & 511)])) + (0.0107939783f * fVec49[((IOTA - 304) & 511)])) + (0.0122569054f * fVec49[((IOTA - 305) & 511)])) + (0.0132551445f * fVec49[((IOTA - 306) & 511)])) + (0.0129461382f * fVec49[((IOTA - 307) & 511)])) + (0.0112976711f * fVec49[((IOTA - 308) & 511)])) + (0.00902976468f * fVec49[((IOTA - 309) & 511)])) + (0.00760826236f * fVec49[((IOTA - 310) & 511)])) + (0.00707833795f * fVec49[((IOTA - 311) & 511)])) + (0.00707715983f * fVec49[((IOTA - 312) & 511)])) + (0.0081268996f * fVec49[((IOTA - 313) & 511)])) + (0.00982125662f * fVec49[((IOTA - 314) & 511)])) + (0.0113308784f * fVec49[((IOTA - 315) & 511)])) + (0.011471739f * fVec49[((IOTA - 316) & 511)])) + (0.00930320751f * fVec49[((IOTA - 317) & 511)])) + (0.0061524976f * fVec49[((IOTA - 318) & 511)])) + (0.0033455519f * fVec49[((IOTA - 319) & 511)])) + (0.000941157341f * fVec49[((IOTA - 320) & 511)])) + (0.000775429886f * fVec49[((IOTA - 325) & 511)])) + (0.0010691504f * fVec49[((IOTA - 326) & 511)])) + (0.000566728413f * fVec49[((IOTA - 327) & 511)])) + (8.45845789e-05f * fVec49[((IOTA - 328) & 511)])) + (0.000443944708f * fVec49[((IOTA - 329) & 511)])) + (0.00186597463f * fVec49[((IOTA - 330) & 511)])) + (0.00357232988f * fVec49[((IOTA - 331) & 511)])) + (0.00489659794f * fVec49[((IOTA - 332) & 511)])) + (0.00546624092f * fVec49[((IOTA - 333) & 511)])) + (0.00493851816f * fVec49[((IOTA - 334) & 511)])) + (0.00403183931f * fVec49[((IOTA - 335) & 511)])) + (0.00334840454f * fVec49[((IOTA - 336) & 511)])) + (0.00320385396f * fVec49[((IOTA - 337) & 511)])) + (0.00416578539f * fVec49[((IOTA - 338) & 511)])) + (0.00489036553f * fVec49[((IOTA - 378) & 511)])))))))))))))))))) + (0.00013419427f * fVec49[((IOTA - 429) & 511)])))))))))))))))))))) + (0.000897004735f * fVec49[((IOTA - 430) & 511)])) + (0.00112403091f * fVec49[((IOTA - 473) & 511)])) + (0.000112087f * fVec49[((IOTA - 474) & 511)])) + (0.000926708337f * fVec49[((IOTA - 496) & 511)])) + (0.00403661421f * fVec49[((IOTA - 497) & 511)])) + (0.00465856446f * fVec49[((IOTA - 498) & 511)])) + (0.00297654886f * fVec49[((IOTA - 499) & 511)])) - ((((((((((((((((((((((((((((0.00282911537f * fVec49[((IOTA - 480) & 511)]) + ((0.00526944548f * fVec49[((IOTA - 479) & 511)]) + ((0.00725395605f * fVec49[((IOTA - 478) & 511)]) + ((0.00781429745f * fVec49[((IOTA - 477) & 511)]) + ((0.00632932503f * fVec49[((IOTA - 476) & 511)]) + ((0.00305917999f * fVec49[((IOTA - 475) & 511)]) + ((0.000292262994f * fVec49[((IOTA - 472) & 511)]) + ((0.00341050932f * fVec49[((IOTA - 471) & 511)]) + ((0.00703750318f * fVec49[((IOTA - 470) & 511)]) + ((0.00921927392f * fVec49[((IOTA - 469) & 511)]) + ((0.00915747881f * fVec49[((IOTA - 468) & 511)]) + ((0.00742148189f * fVec49[((IOTA - 467) & 511)]) + ((0.0048338105f * fVec49[((IOTA - 466) & 511)]) + ((0.00252615521f * fVec49[((IOTA - 465) & 511)]) + ((0.00138705503f * fVec49[((IOTA - 464) & 511)]) + ((0.00197561178f * fVec49[((IOTA - 463) & 511)]) + ((0.00425743917f * fVec49[((IOTA - 462) & 511)]) + ((0.00702339504f * fVec49[((IOTA - 461) & 511)]) + ((0.00859310664f * fVec49[((IOTA - 460) & 511)]) + ((0.0085677132f * fVec49[((IOTA - 459) & 511)]) + ((0.0073379823f * fVec49[((IOTA - 458) & 511)]) + ((0.00550682796f * fVec49[((IOTA - 457) & 511)]) + ((0.00421356596f * fVec49[((IOTA - 456) & 511)]) + ((0.00405168347f * fVec49[((IOTA - 455) & 511)]) + ((0.00497324485f * fVec49[((IOTA - 454) & 511)]) + ((0.00648218486f * fVec49[((IOTA - 453) & 511)]) + ((0.0071470784f * fVec49[((IOTA - 452) & 511)]) + ((0.00634585135f * fVec49[((IOTA - 451) & 511)]) + ((0.0052484856f * fVec49[((IOTA - 450) & 511)]) + ((0.00441947719f * fVec49[((IOTA - 449) & 511)]) + ((0.0044295541f * fVec49[((IOTA - 448) & 511)]) + ((0.0059997309f * fVec49[((IOTA - 447) & 511)]) + ((0.00927871279f * fVec49[((IOTA - 446) & 511)]) + ((0.0131429639f * fVec49[((IOTA - 445) & 511)]) + ((0.015627075f * fVec49[((IOTA - 444) & 511)]) + ((0.0159136653f * fVec49[((IOTA - 443) & 511)]) + ((0.0146204028f * fVec49[((IOTA - 442) & 511)]) + ((0.0125449505f * fVec49[((IOTA - 441) & 511)]) + ((0.00988599658f * fVec49[((IOTA - 440) & 511)]) + ((0.00730474386f * fVec49[((IOTA - 439) & 511)]) + ((0.00585350627f * fVec49[((IOTA - 438) & 511)]) + ((0.0062163081f * fVec49[((IOTA - 437) & 511)]) + ((0.00751961581f * fVec49[((IOTA - 436) & 511)]) + ((0.0085075926f * fVec49[((IOTA - 435) & 511)]) + ((0.00828822516f * fVec49[((IOTA - 434) & 511)]) + ((0.00627906434f * fVec49[((IOTA - 433) & 511)]) + ((0.00339153362f * fVec49[((IOTA - 432) & 511)]) + ((0.00058461912f * fVec49[((IOTA - 431) & 511)]) + ((0.00206549838f * fVec49[((IOTA - 428) & 511)]) + ((0.00422519306f * fVec49[((IOTA - 427) & 511)]) + ((0.00534513127f * fVec49[((IOTA - 426) & 511)]) + ((0.00482252426f * fVec49[((IOTA - 425) & 511)]) + ((0.00270199031f * fVec49[((IOTA - 424) & 511)]) + ((0.000118040014f * fVec49[((IOTA - 423) & 511)]) + ((0.00338139478f * fVec49[((IOTA - 420) & 511)]) + ((0.00753347576f * fVec49[((IOTA - 419) & 511)]) + ((0.0107498253f * fVec49[((IOTA - 418) & 511)]) + ((0.0125855375f * fVec49[((IOTA - 417) & 511)]) + ((0.0123927109f * fVec49[((IOTA - 416) & 511)]) + ((0.00991163868f * fVec49[((IOTA - 415) & 511)]) + ((0.00629093964f * fVec49[((IOTA - 414) & 511)]) + ((0.00253139529f * fVec49[((IOTA - 413) & 511)]) + ((0.000397869386f * fVec49[((IOTA - 412) & 511)]) + ((0.00121472357f * fVec49[((IOTA - 411) & 511)]) + ((0.00387711916f * fVec49[((IOTA - 410) & 511)]) + ((0.00644975249f * fVec49[((IOTA - 409) & 511)]) + ((0.0070541841f * fVec49[((IOTA - 408) & 511)]) + ((0.00548878219f * fVec49[((IOTA - 407) & 511)]) + ((0.00328614423f * fVec49[((IOTA - 406) & 511)]) + ((0.00173057104f * fVec49[((IOTA - 405) & 511)]) + ((0.00101405242f * fVec49[((IOTA - 404) & 511)]) + ((0.00170530099f * fVec49[((IOTA - 403) & 511)]) + ((0.00392198516f * fVec49[((IOTA - 402) & 511)]) + ((0.00673193857f * fVec49[((IOTA - 401) & 511)]) + ((0.00910086185f * fVec49[((IOTA - 400) & 511)]) + ((0.00975468569f * fVec49[((IOTA - 399) & 511)]) + ((0.00860715285f * fVec49[((IOTA - 398) & 511)]) + ((0.00651136134f * fVec49[((IOTA - 397) & 511)]) + ((0.00442356989f * fVec49[((IOTA - 396) & 511)]) + ((0.00308404677f * fVec49[((IOTA - 395) & 511)]) + ((0.00246048439f * fVec49[((IOTA - 394) & 511)]) + ((0.00209597731f * fVec49[((IOTA - 393) & 511)]) + ((0.00139834126f * fVec49[((IOTA - 392) & 511)]) + ((0.00272775628f * fVec49[((IOTA - 385) & 511)]) + ((0.00434890715f * fVec49[((IOTA - 384) & 511)]) + ((0.00377520267f * fVec49[((IOTA - 383) & 511)]) + ((0.00139669795f * fVec49[((IOTA - 382) & 511)]) + ((0.00463667419f * fVec49[((IOTA - 375) & 511)]) + ((0.0097972583f * fVec49[((IOTA - 374) & 511)]) + ((0.0125031546f * fVec49[((IOTA - 373) & 511)]) + ((0.012126524f * fVec49[((IOTA - 372) & 511)]) + ((0.00959326886f * fVec49[((IOTA - 371) & 511)]) + ((0.00627469225f * fVec49[((IOTA - 370) & 511)]) + ((0.00350824045f * fVec49[((IOTA - 369) & 511)]) + ((0.00192643609f * fVec49[((IOTA - 368) & 511)]) + ((0.00138578378f * fVec49[((IOTA - 367) & 511)]) + ((0.00134622026f * fVec49[((IOTA - 366) & 511)]) + ((0.000412845518f * fVec49[((IOTA - 365) & 511)]) + ((8.35922547e-05f * fVec49[((IOTA - 359) & 511)]) + ((0.00474206358f * fVec49[((IOTA - 358) & 511)]) + ((0.00738371629f * fVec49[((IOTA - 357) & 511)]) + ((0.00671243574f * fVec49[((IOTA - 356) & 511)]) + ((0.00307865161f * fVec49[((IOTA - 355) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.07921426f * fVec49[((IOTA - 7) & 511)]) + (0.142595783f * fVec49[((IOTA - 8) & 511)])) + (0.141165286f * fVec49[((IOTA - 9) & 511)])) + (0.0902406648f * fVec49[((IOTA - 10) & 511)])) + (0.031730216f * fVec49[((IOTA - 11) & 511)])) + (0.00853196345f * fVec49[((IOTA - 23) & 511)])) + (0.0125226574f * fVec49[((IOTA - 24) & 511)])) + (0.0115863374f * fVec49[((IOTA - 30) & 511)])) + (0.0385351442f * fVec49[((IOTA - 31) & 511)])) + (0.0691281259f * fVec49[((IOTA - 32) & 511)])) + (0.0797938555f * fVec49[((IOTA - 33) & 511)])) + (0.0682271495f * fVec49[((IOTA - 34) & 511)])) + (0.0467375144f * fVec49[((IOTA - 35) & 511)])) + (0.0217545517f * fVec49[((IOTA - 36) & 511)])) + (0.0269296132f * fVec49[((IOTA - 44) & 511)])) + (0.0601226985f * fVec49[((IOTA - 45) & 511)])) + (0.0818741471f * fVec49[((IOTA - 46) & 511)])) + (0.0812835768f * fVec49[((IOTA - 47) & 511)])) + (0.0629499853f * fVec49[((IOTA - 48) & 511)])) + (0.0377468169f * fVec49[((IOTA - 49) & 511)])) + (0.0116230175f * fVec49[((IOTA - 50) & 511)])) + (0.00240947958f * fVec49[((IOTA - 54) & 511)])) + (0.0187018514f * fVec49[((IOTA - 55) & 511)])) + (0.0251153577f * fVec49[((IOTA - 56) & 511)])) + (0.0241998117f * fVec49[((IOTA - 57) & 511)])) + (0.0226550587f * fVec49[((IOTA - 58) & 511)])) + (0.0224650856f * fVec49[((IOTA - 59) & 511)])) + (0.0203167703f * fVec49[((IOTA - 60) & 511)])) + (0.0179289319f * fVec49[((IOTA - 61) & 511)])) + (0.0199236441f * fVec49[((IOTA - 62) & 511)])) + (0.02165341f * fVec49[((IOTA - 63) & 511)])) + (0.0210261885f * fVec49[((IOTA - 64) & 511)])) + (0.0205883197f * fVec49[((IOTA - 65) & 511)])) + (0.0220345668f * fVec49[((IOTA - 66) & 511)])) + (0.0255498774f * fVec49[((IOTA - 67) & 511)])) + (0.0293281786f * fVec49[((IOTA - 68) & 511)])) + (0.0365815461f * fVec49[((IOTA - 69) & 511)])) + (0.0392912887f * fVec49[((IOTA - 70) & 511)])) + (0.0347249061f * fVec49[((IOTA - 71) & 511)])) + (0.0268231388f * fVec49[((IOTA - 72) & 511)])) + (0.0123401564f * fVec49[((IOTA - 73) & 511)])) + (0.00804002117f * fVec49[((IOTA - 77) & 511)])) + (0.0145926829f * fVec49[((IOTA - 78) & 511)])) + (0.0156110767f * fVec49[((IOTA - 79) & 511)])) + (0.012983501f * fVec49[((IOTA - 80) & 511)])) + (0.0131132603f * fVec49[((IOTA - 81) & 511)])) + (0.0159929153f * fVec49[((IOTA - 82) & 511)])) + (0.019814875f * fVec49[((IOTA - 83) & 511)])) + (0.0247534867f * fVec49[((IOTA - 84) & 511)])) + (0.0253381673f * fVec49[((IOTA - 85) & 511)])) + (0.0186786279f * fVec49[((IOTA - 86) & 511)])) + (0.00798610225f * fVec49[((IOTA - 87) & 511)])) + (0.000620275736f * fVec49[((IOTA - 88) & 511)])) + (0.00810634345f * fVec49[((IOTA - 90) & 511)])) + (0.0224012434f * fVec49[((IOTA - 91) & 511)])) + (0.0355877429f * fVec49[((IOTA - 92) & 511)])) + (0.0439909659f * fVec49[((IOTA - 93) & 511)])) + (0.0456468761f * fVec49[((IOTA - 94) & 511)])) + (0.0396187417f * fVec49[((IOTA - 95) & 511)])) + (0.0264306646f * fVec49[((IOTA - 96) & 511)])) + (0.0111427642f * fVec49[((IOTA - 97) & 511)])) + (0.0149615929f * fVec49[((IOTA - 104) & 511)])) + (0.0301400423f * fVec49[((IOTA - 105) & 511)])) + (0.040889062f * fVec49[((IOTA - 106) & 511)])) + (0.0423564836f * fVec49[((IOTA - 107) & 511)])) + (0.033373259f * fVec49[((IOTA - 108) & 511)])) + (0.0176468398f * fVec49[((IOTA - 109) & 511)])) + (0.00170437107f * fVec49[((IOTA - 110) & 511)])) + (0.00564263435f * fVec49[((IOTA - 114) & 511)])) + (0.0166489724f * fVec49[((IOTA - 115) & 511)])) + (0.0248468444f * fVec49[((IOTA - 116) & 511)])) + (0.0271953978f * fVec49[((IOTA - 117) & 511)])) + (0.025214918f * fVec49[((IOTA - 118) & 511)])) + (0.0194000769f * fVec49[((IOTA - 119) & 511)])) + (0.0150632001f * fVec49[((IOTA - 120) & 511)])) + (0.0158178546f * fVec49[((IOTA - 121) & 511)])) + (0.0171101242f * fVec49[((IOTA - 122) & 511)])) + (0.0163393766f * fVec49[((IOTA - 123) & 511)])) + (0.0147795249f * fVec49[((IOTA - 124) & 511)])) + (0.0119631849f * fVec49[((IOTA - 125) & 511)])) + (0.00963410363f * fVec49[((IOTA - 126) & 511)])) + (0.0103346854f * fVec49[((IOTA - 127) & 511)])) + (0.010958341f * fVec49[((IOTA - 128) & 511)])) + (0.0106310099f * fVec49[((IOTA - 129) & 511)])) + (0.00931340829f * fVec49[((IOTA - 130) & 511)])) + (0.00444983179f * fVec49[((IOTA - 131) & 511)])) + (0.000514142215f * fVec49[((IOTA - 138) & 511)])) + (0.00622353237f * fVec49[((IOTA - 139) & 511)])) + (0.0126693156f * fVec49[((IOTA - 140) & 511)])) + (0.0186865665f * fVec49[((IOTA - 141) & 511)])) + (0.0232711807f * fVec49[((IOTA - 142) & 511)])) + (0.0236821957f * fVec49[((IOTA - 143) & 511)])) + (0.0176727921f * fVec49[((IOTA - 144) & 511)])) + (0.00758956559f * fVec49[((IOTA - 145) & 511)])) + (0.00582712004f * fVec49[((IOTA - 152) & 511)])) + (0.00900288299f * fVec49[((IOTA - 153) & 511)])) + (0.0072442512f * fVec49[((IOTA - 154) & 511)])) + (0.00394108472f * fVec49[((IOTA - 155) & 511)])) + (0.00092853792f * fVec49[((IOTA - 156) & 511)])) + (0.000732176472f * fVec49[((IOTA - 160) & 511)])) + (0.00519162044f * fVec49[((IOTA - 161) & 511)])) + (0.00972442422f * fVec49[((IOTA - 162) & 511)])) + (0.0111482218f * fVec49[((IOTA - 163) & 511)])) + (0.00810256042f * fVec49[((IOTA - 164) & 511)])) + (0.00325786648f * fVec49[((IOTA - 165) & 511)])) + (0.000624895561f * fVec49[((IOTA - 175) & 511)])) + (0.00681832107f * fVec49[((IOTA - 176) & 511)])) + (0.0109218154f * fVec49[((IOTA - 177) & 511)])) + (0.0102075301f * fVec49[((IOTA - 178) & 511)])) + (0.0034836526f * fVec49[((IOTA - 179) & 511)])) + (0.0028108214f * fVec49[((IOTA - 201) & 511)])) + (0.00372984074f * fVec49[((IOTA - 202) & 511)])) + (0.00188336894f * fVec49[((IOTA - 203) & 511)])) + (0.000168548897f * fVec49[((IOTA - 248) & 511)])) + (0.000742346514f * fVec49[((IOTA - 321) & 511)])) + (0.00150286267f * fVec49[((IOTA - 322) & 511)])) + (0.00136525789f * fVec49[((IOTA - 323) & 511)])) + (0.000314711127f * fVec49[((IOTA - 324) & 511)])) + (0.00147542264f * fVec49[((IOTA - 481) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00217219023f * fVec49[((IOTA - 482) & 511)])) + (0.00473846728f * fVec49[((IOTA - 483) & 511)])) + (0.00772000803f * fVec49[((IOTA - 484) & 511)])) + (0.00888267253f * fVec49[((IOTA - 485) & 511)])) + (0.00769926468f * fVec49[((IOTA - 486) & 511)])) + (0.00477071339f * fVec49[((IOTA - 487) & 511)])) + (0.0018768576f * fVec49[((IOTA - 488) & 511)])) + (0.00117990375f * fVec49[((IOTA - 489) & 511)])) + (0.00267923204f * fVec49[((IOTA - 490) & 511)])) + (0.00534032518f * fVec49[((IOTA - 491) & 511)])) + (0.00797853619f * fVec49[((IOTA - 492) & 511)])) + (0.00881879963f * fVec49[((IOTA - 493) & 511)])) + (0.00705821486f * fVec49[((IOTA - 494) & 511)])) + (0.00338967331f * fVec49[((IOTA - 495) & 511)])) + (0.000172920525f * fVec49[((IOTA - 500) & 511)])) + (0.00358767807f * fVec49[((IOTA - 501) & 511)])) + (0.00602078391f * fVec49[((IOTA - 502) & 511)])) + (0.00751815876f * fVec49[((IOTA - 503) & 511)])) + (0.00829315465f * fVec49[((IOTA - 504) & 511)])) + (0.00848030671f * fVec49[((IOTA - 505) & 511)])) + (0.00808547623f * fVec49[((IOTA - 506) & 511)])) + (0.00737239933f * fVec49[((IOTA - 507) & 511)])) + (0.00688138744f * fVec49[((IOTA - 508) & 511)])) + (0.00673919404f * fVec49[((IOTA - 509) & 511)])) + (0.00692802062f * fVec49[((IOTA - 510) & 511)])) + (0.00748628424f * fVec49[((IOTA - 511) & 511)]))) : (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0166844577f * fVec48[((IOTA - 274) & 511)]) + ((0.0169060994f * fVec48[((IOTA - 273) & 511)]) + ((0.0168881658f * fVec48[((IOTA - 272) & 511)]) + ((0.0167499036f * fVec48[((IOTA - 271) & 511)]) + ((0.0162804481f * fVec48[((IOTA - 270) & 511)]) + ((0.015853487f * fVec48[((IOTA - 269) & 511)]) + ((0.0153646115f * fVec48[((IOTA - 268) & 511)]) + ((0.0142693492f * fVec48[((IOTA - 267) & 511)]) + ((0.0129396543f * fVec48[((IOTA - 266) & 511)]) + ((0.0124829281f * fVec48[((IOTA - 265) & 511)]) + ((0.0135881938f * fVec48[((IOTA - 264) & 511)]) + ((0.0157422628f * fVec48[((IOTA - 263) & 511)]) + ((0.017439235f * fVec48[((IOTA - 262) & 511)]) + ((0.0174969062f * fVec48[((IOTA - 261) & 511)]) + ((0.0164891109f * fVec48[((IOTA - 260) & 511)]) + ((0.0158734024f * fVec48[((IOTA - 259) & 511)]) + ((0.0155616608f * fVec48[((IOTA - 258) & 511)]) + ((0.014607016f * fVec48[((IOTA - 257) & 511)]) + ((0.0126108769f * fVec48[((IOTA - 256) & 511)]) + ((0.0100881066f * fVec48[((IOTA - 255) & 511)]) + ((0.00810373761f * fVec48[((IOTA - 254) & 511)]) + ((0.00796727091f * fVec48[((IOTA - 253) & 511)]) + ((0.0095923245f * fVec48[((IOTA - 252) & 511)]) + ((0.0114706736f * fVec48[((IOTA - 251) & 511)]) + ((0.0124142915f * fVec48[((IOTA - 250) & 511)]) + ((0.0112298895f * fVec48[((IOTA - 249) & 511)]) + ((0.007732559f * fVec48[((IOTA - 248) & 511)]) + ((0.00361248804f * fVec48[((IOTA - 247) & 511)]) + ((0.00142840622f * fVec48[((IOTA - 246) & 511)]) + ((0.0025258055f * fVec48[((IOTA - 245) & 511)]) + ((0.00604810053f * fVec48[((IOTA - 244) & 511)]) + ((0.0105998404f * fVec48[((IOTA - 243) & 511)]) + ((0.0147506669f * fVec48[((IOTA - 242) & 511)]) + ((0.0161154233f * fVec48[((IOTA - 241) & 511)]) + ((0.0142124519f * fVec48[((IOTA - 240) & 511)]) + ((0.0117264166f * fVec48[((IOTA - 239) & 511)]) + ((0.0104128262f * fVec48[((IOTA - 238) & 511)]) + ((0.0109181479f * fVec48[((IOTA - 237) & 511)]) + ((0.0136625916f * fVec48[((IOTA - 236) & 511)]) + ((0.0180935059f * fVec48[((IOTA - 235) & 511)]) + ((0.0230938867f * fVec48[((IOTA - 234) & 511)]) + ((0.0264405347f * fVec48[((IOTA - 233) & 511)]) + ((0.0258554891f * fVec48[((IOTA - 232) & 511)]) + ((0.0213286504f * fVec48[((IOTA - 231) & 511)]) + ((0.015009569f * fVec48[((IOTA - 230) & 511)]) + ((0.00990902167f * fVec48[((IOTA - 229) & 511)]) + ((0.00790860876f * fVec48[((IOTA - 228) & 511)]) + ((0.00840144884f * fVec48[((IOTA - 227) & 511)]) + ((0.00902133994f * fVec48[((IOTA - 226) & 511)]) + ((0.00798727944f * fVec48[((IOTA - 225) & 511)]) + ((0.00536771957f * fVec48[((IOTA - 224) & 511)]) + ((0.00227254024f * fVec48[((IOTA - 223) & 511)]) + ((0.00022436725f * fVec48[((IOTA - 222) & 511)]) + ((0.000925809611f * fVec48[((IOTA - 221) & 511)]) + ((((((((((((0.0026409626f * fVec48[((IOTA - 210) & 511)]) + ((0.00344476989f * fVec48[((IOTA - 209) & 511)]) + ((0.00640723063f * fVec48[((IOTA - 208) & 511)]) + ((0.01073578f * fVec48[((IOTA - 207) & 511)]) + ((0.0140525699f * fVec48[((IOTA - 206) & 511)]) + ((0.0136079239f * fVec48[((IOTA - 205) & 511)]) + ((0.0104547329f * fVec48[((IOTA - 204) & 511)]) + ((0.00797851477f * fVec48[((IOTA - 203) & 511)]) + ((0.00657683797f * fVec48[((IOTA - 202) & 511)]) + ((0.0051361355f * fVec48[((IOTA - 201) & 511)]) + ((0.00380055513f * fVec48[((IOTA - 200) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.246837214f * fVec48[((IOTA - 3) & 511)]) + ((0.0411093123f * fVec48[((IOTA - 16) & 511)]) + ((((0.0419350788f * fVec48[((IOTA - 15) & 511)]) + ((fSlow151 * fTemp0) + ((0.144509926f * fVec48[((IOTA - 5) & 511)]) + ((0.209111616f * fVec48[((IOTA - 4) & 511)]) + (((0.024514921f * fVec48[((IOTA - 13) & 511)]) + ((0.00103471009f * fVec48[((IOTA - 12) & 511)]) + ((((0.210763872f * fVec48[((IOTA - 1) & 511)]) + (0.250985324f * fVec48[((IOTA - 2) & 511)])) + (0.049694676f * fVec48[((IOTA - 6) & 511)])) + (0.034232717f * fVec48[((IOTA - 14) & 511)])))) + (0.0361872911f * fVec48[((IOTA - 17) & 511)])))))) + (0.0344140008f * fVec48[((IOTA - 18) & 511)])) + (0.0197211299f * fVec48[((IOTA - 19) & 511)])))) + (0.0111987935f * fVec48[((IOTA - 20) & 511)])) + (0.00128769642f * fVec48[((IOTA - 21) & 511)])) + (0.0183589738f * fVec48[((IOTA - 25) & 511)])) + (0.0387760624f * fVec48[((IOTA - 26) & 511)])) + (0.0368547849f * fVec48[((IOTA - 27) & 511)])) + (0.0174591504f * fVec48[((IOTA - 28) & 511)])) + (0.000685738865f * fVec48[((IOTA - 42) & 511)])) + (0.000649686437f * fVec48[((IOTA - 43) & 511)])) + (0.00340286363f * fVec48[((IOTA - 53) & 511)])) + (0.028350044f * fVec48[((IOTA - 54) & 511)])) + (0.0412421823f * fVec48[((IOTA - 55) & 511)])) + (0.0388750508f * fVec48[((IOTA - 56) & 511)])) + (0.0201428253f * fVec48[((IOTA - 57) & 511)])) + (0.00135174813f * fVec48[((IOTA - 66) & 511)])) + (0.00750958547f * fVec48[((IOTA - 101) & 511)])) + (0.00916926563f * fVec48[((IOTA - 102) & 511)])) + (0.00285043195f * fVec48[((IOTA - 103) & 511)])) + (0.00590234203f * fVec48[((IOTA - 127) & 511)])) + (0.00532494625f * fVec48[((IOTA - 128) & 511)])) + (0.000725817867f * fVec48[((IOTA - 129) & 511)])) + (0.00128850155f * fVec48[((IOTA - 133) & 511)])) + (0.00534981722f * fVec48[((IOTA - 134) & 511)])) + (0.00674737478f * fVec48[((IOTA - 135) & 511)])) + (0.00516905962f * fVec48[((IOTA - 136) & 511)])) + (0.00186952157f * fVec48[((IOTA - 137) & 511)])) + (0.00502339471f * fVec48[((IOTA - 145) & 511)])) + (0.00985035859f * fVec48[((IOTA - 146) & 511)])) + (0.00841074064f * fVec48[((IOTA - 147) & 511)])) + (0.00281856069f * fVec48[((IOTA - 148) & 511)])) + (0.00508462777f * fVec48[((IOTA - 154) & 511)])) + (0.00822313875f * fVec48[((IOTA - 155) & 511)])) + (0.00683239521f * fVec48[((IOTA - 156) & 511)])) + (0.00227071298f * fVec48[((IOTA - 157) & 511)])) + (0.000673566479f * fVec48[((IOTA - 168) & 511)])) + (0.00642411085f * fVec48[((IOTA - 169) & 511)])) + (0.0122860335f * fVec48[((IOTA - 170) & 511)])) + (0.0154874194f * fVec48[((IOTA - 171) & 511)])) + (0.0155305639f * fVec48[((IOTA - 172) & 511)])) + (0.0118686426f * fVec48[((IOTA - 173) & 511)])) + (0.00541207287f * fVec48[((IOTA - 174) & 511)])) + (0.000720800366f * fVec48[((IOTA - 180) & 511)])) + (0.00624307478f * fVec48[((IOTA - 181) & 511)])) + (0.0111915451f * fVec48[((IOTA - 182) & 511)])) + (0.0139356162f * fVec48[((IOTA - 183) & 511)])) + (0.0146541558f * fVec48[((IOTA - 184) & 511)])) + (0.0141159408f * fVec48[((IOTA - 185) & 511)])) + (0.0114333509f * fVec48[((IOTA - 186) & 511)])) + (0.00683877571f * fVec48[((IOTA - 187) & 511)])) + (0.00297704898f * fVec48[((IOTA - 188) & 511)])) + (0.00256724702f * fVec48[((IOTA - 189) & 511)])) + (0.0063504884f * fVec48[((IOTA - 190) & 511)])) + (0.0118876603f * fVec48[((IOTA - 191) & 511)])) + (0.0166174956f * fVec48[((IOTA - 192) & 511)])) + (0.0190826543f * fVec48[((IOTA - 193) & 511)])) + (0.017564211f * fVec48[((IOTA - 194) & 511)])) + (0.0133626815f * fVec48[((IOTA - 195) & 511)])) + (0.00916908029f * fVec48[((IOTA - 196) & 511)])) + (0.0055797291f * fVec48[((IOTA - 197) & 511)])) + (0.00343941152f * fVec48[((IOTA - 198) & 511)])) + (0.00309747132f * fVec48[((IOTA - 199) & 511)])) + (0.00344820786f * fVec48[((IOTA - 211) & 511)]))))))))))))) + (0.00531621184f * fVec48[((IOTA - 212) & 511)])) + (0.00871374831f * fVec48[((IOTA - 213) & 511)])) + (0.0135067049f * fVec48[((IOTA - 214) & 511)])) + (0.0179301556f * fVec48[((IOTA - 215) & 511)])) + (0.0209856275f * fVec48[((IOTA - 216) & 511)])) + (0.0219897367f * fVec48[((IOTA - 217) & 511)])) + (0.01865495f * fVec48[((IOTA - 218) & 511)])) + (0.0117512569f * fVec48[((IOTA - 219) & 511)])) + (0.00505096046f * fVec48[((IOTA - 220) & 511)])) + (0.0152443442f * fVec48[((IOTA - 275) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.013158136f * fVec48[((IOTA - 276) & 511)])) + (0.01166193f * fVec48[((IOTA - 277) & 511)])) + (0.0109971594f * fVec48[((IOTA - 278) & 511)])) + (0.010880176f * fVec48[((IOTA - 279) & 511)])) + (0.0114973411f * fVec48[((IOTA - 280) & 511)])) + (0.0120639578f * fVec48[((IOTA - 281) & 511)])) + (0.0114516243f * fVec48[((IOTA - 282) & 511)])) + (0.0098687876f * fVec48[((IOTA - 283) & 511)])) + (0.00775241293f * fVec48[((IOTA - 284) & 511)])) + (0.0060336981f * fVec48[((IOTA - 285) & 511)])) + (0.00549052702f * fVec48[((IOTA - 286) & 511)])) + (0.00625134446f * fVec48[((IOTA - 287) & 511)])) + (0.00843524002f * fVec48[((IOTA - 288) & 511)])) + (0.010692697f * fVec48[((IOTA - 289) & 511)])) + (0.0112485662f * fVec48[((IOTA - 290) & 511)])) + (0.00983354077f * fVec48[((IOTA - 291) & 511)])) + (0.00732015539f * fVec48[((IOTA - 292) & 511)])) + (0.00572685013f * fVec48[((IOTA - 293) & 511)])) + (0.00605367543f * fVec48[((IOTA - 294) & 511)])) + (0.00783687644f * fVec48[((IOTA - 295) & 511)])) + (0.010008228f * fVec48[((IOTA - 296) & 511)])) + (0.0111544402f * fVec48[((IOTA - 297) & 511)])) + (0.00993661862f * fVec48[((IOTA - 298) & 511)])) + (0.0069308267f * fVec48[((IOTA - 299) & 511)])) + (0.00487664528f * fVec48[((IOTA - 300) & 511)])) + (0.00531531358f * fVec48[((IOTA - 301) & 511)])) + (0.00794679858f * fVec48[((IOTA - 302) & 511)])) + (0.0122784143f * fVec48[((IOTA - 303) & 511)])) + (0.0173575915f * fVec48[((IOTA - 304) & 511)])) + (0.020963544f * fVec48[((IOTA - 305) & 511)])) + (0.0207582861f * fVec48[((IOTA - 306) & 511)])) + (0.0168789364f * fVec48[((IOTA - 307) & 511)])) + (0.0116063962f * fVec48[((IOTA - 308) & 511)])) + (0.0072629177f * fVec48[((IOTA - 309) & 511)])) + (0.00509788422f * fVec48[((IOTA - 310) & 511)])) + (0.0053577153f * fVec48[((IOTA - 311) & 511)])) + (0.00792929903f * fVec48[((IOTA - 312) & 511)])) + (0.0117350575f * fVec48[((IOTA - 313) & 511)])) + (0.0147694992f * fVec48[((IOTA - 314) & 511)])) + (0.0161461495f * fVec48[((IOTA - 315) & 511)])) + (0.0154104829f * fVec48[((IOTA - 316) & 511)])) + (0.012463198f * fVec48[((IOTA - 317) & 511)])) + (0.00831481814f * fVec48[((IOTA - 318) & 511)])) + (0.00437014597f * fVec48[((IOTA - 319) & 511)])) + (0.00182191608f * fVec48[((IOTA - 320) & 511)])) + (0.00101222377f * fVec48[((IOTA - 321) & 511)])) + (0.00134000974f * fVec48[((IOTA - 322) & 511)])) + (0.0020410181f * fVec48[((IOTA - 323) & 511)])) + (0.00255402178f * fVec48[((IOTA - 324) & 511)])) + (0.00221400149f * fVec48[((IOTA - 325) & 511)])) + (0.00112967286f * fVec48[((IOTA - 326) & 511)])) + (0.00147932535f * fVec48[((IOTA - 329) & 511)])) + (0.00401956448f * fVec48[((IOTA - 330) & 511)])) + (0.00515242759f * fVec48[((IOTA - 331) & 511)])) + (0.00484257517f * fVec48[((IOTA - 332) & 511)])) + (0.00457363762f * fVec48[((IOTA - 333) & 511)])) + (0.00446811318f * fVec48[((IOTA - 334) & 511)])) + (0.0049649179f * fVec48[((IOTA - 335) & 511)])) + (0.00631496264f * fVec48[((IOTA - 336) & 511)])) + (0.00802246481f * fVec48[((IOTA - 337) & 511)])) + (0.00981455483f * fVec48[((IOTA - 338) & 511)])) + (0.0101138446f * fVec48[((IOTA - 339) & 511)])) + (0.00881564897f * fVec48[((IOTA - 340) & 511)])) + (0.00765134813f * fVec48[((IOTA - 341) & 511)])) + (0.00662877969f * fVec48[((IOTA - 342) & 511)])) + (0.00547736371f * fVec48[((IOTA - 343) & 511)])) + (0.00463521155f * fVec48[((IOTA - 344) & 511)])) + (0.0040328824f * fVec48[((IOTA - 345) & 511)])) + (0.00403762143f * fVec48[((IOTA - 346) & 511)])) + (0.00495184725f * fVec48[((IOTA - 347) & 511)])) + (0.00642082794f * fVec48[((IOTA - 348) & 511)])) + (0.00909486972f * fVec48[((IOTA - 349) & 511)])) + (0.0124425702f * fVec48[((IOTA - 350) & 511)])) + (0.0141619043f * fVec48[((IOTA - 351) & 511)])) + (0.0130670452f * fVec48[((IOTA - 352) & 511)])) + (0.00945496f * fVec48[((IOTA - 353) & 511)])) + (0.00437383167f * fVec48[((IOTA - 354) & 511)])) + (0.00310583413f * fVec48[((IOTA - 361) & 511)])) + (0.00516240066f * fVec48[((IOTA - 362) & 511)])) + (0.00537069328f * fVec48[((IOTA - 363) & 511)])) + (0.00508149946f * fVec48[((IOTA - 364) & 511)])) + (0.00454192143f * fVec48[((IOTA - 365) & 511)])) + (0.00348943286f * fVec48[((IOTA - 366) & 511)])) + (0.0012452635f * fVec48[((IOTA - 367) & 511)])) + (0.00104201958f * fVec48[((IOTA - 379) & 511)])) + (0.000619116239f * fVec48[((IOTA - 380) & 511)])) + (0.000945477281f * fVec48[((IOTA - 388) & 511)])) + (0.00172298914f * fVec48[((IOTA - 389) & 511)])) + (0.0012396574f * fVec48[((IOTA - 390) & 511)])) + (8.81175511e-05f * fVec48[((IOTA - 391) & 511)])) + (0.000548188575f * fVec48[((IOTA - 409) & 511)])) + (0.000537286047f * fVec48[((IOTA - 410) & 511)])) + (0.0016176193f * fVec48[((IOTA - 421) & 511)])) + (0.00273096981f * fVec48[((IOTA - 422) & 511)])) + (0.00112539856f * fVec48[((IOTA - 423) & 511)])) + (0.000125006307f * fVec48[((IOTA - 430) & 511)])) + (0.000748861581f * fVec48[((IOTA - 497) & 511)])) + (6.97197393e-05f * fVec48[((IOTA - 498) & 511)])) - ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00864678435f * fVec48[((IOTA - 452) & 511)]) + ((0.00790201128f * fVec48[((IOTA - 451) & 511)]) + ((0.00640373072f * fVec48[((IOTA - 450) & 511)]) + ((0.0051607592f * fVec48[((IOTA - 449) & 511)]) + ((0.005615131f * fVec48[((IOTA - 448) & 511)]) + ((0.00786149874f * fVec48[((IOTA - 447) & 511)]) + ((0.0117631499f * fVec48[((IOTA - 446) & 511)]) + ((0.0159384459f * fVec48[((IOTA - 445) & 511)]) + ((0.0178397149f * fVec48[((IOTA - 444) & 511)]) + ((0.016976811f * fVec48[((IOTA - 443) & 511)]) + ((0.0140818711f * fVec48[((IOTA - 442) & 511)]) + ((0.0105013466f * fVec48[((IOTA - 441) & 511)]) + ((0.00836387835f * fVec48[((IOTA - 440) & 511)]) + ((0.0079227332f * fVec48[((IOTA - 439) & 511)]) + ((0.00844090804f * fVec48[((IOTA - 438) & 511)]) + ((0.0104415696f * fVec48[((IOTA - 437) & 511)]) + ((0.0128833139f * fVec48[((IOTA - 436) & 511)]) + ((0.0134395249f * fVec48[((IOTA - 435) & 511)]) + ((0.0118320026f * fVec48[((IOTA - 434) & 511)]) + ((0.00823221356f * fVec48[((IOTA - 433) & 511)]) + ((0.0037451447f * fVec48[((IOTA - 432) & 511)]) + ((0.000643987674f * fVec48[((IOTA - 431) & 511)]) + ((0.00163654378f * fVec48[((IOTA - 429) & 511)]) + ((0.00531590218f * fVec48[((IOTA - 428) & 511)]) + ((0.00826207176f * fVec48[((IOTA - 427) & 511)]) + ((0.00850127451f * fVec48[((IOTA - 426) & 511)]) + ((0.00621414604f * fVec48[((IOTA - 425) & 511)]) + ((0.00245066546f * fVec48[((IOTA - 424) & 511)]) + ((0.00159488525f * fVec48[((IOTA - 420) & 511)]) + ((0.00564656826f * fVec48[((IOTA - 419) & 511)]) + ((0.00888914801f * fVec48[((IOTA - 418) & 511)]) + ((0.0108112609f * fVec48[((IOTA - 417) & 511)]) + ((0.0114488378f * fVec48[((IOTA - 416) & 511)]) + ((0.0107136965f * fVec48[((IOTA - 415) & 511)]) + ((0.00934206322f * fVec48[((IOTA - 414) & 511)]) + ((0.00715940632f * fVec48[((IOTA - 413) & 511)]) + ((0.00428732438f * fVec48[((IOTA - 412) & 511)]) + ((0.00150964782f * fVec48[((IOTA - 411) & 511)]) + ((0.000990883447f * fVec48[((IOTA - 408) & 511)]) + ((0.00191430841f * fVec48[((IOTA - 407) & 511)]) + ((0.00259091053f * fVec48[((IOTA - 406) & 511)]) + ((0.00352015812f * fVec48[((IOTA - 405) & 511)]) + ((0.00399444532f * fVec48[((IOTA - 404) & 511)]) + ((0.00467414455f * fVec48[((IOTA - 403) & 511)]) + ((0.00584234763f * fVec48[((IOTA - 402) & 511)]) + ((0.00763737969f * fVec48[((IOTA - 401) & 511)]) + ((0.00945279188f * fVec48[((IOTA - 400) & 511)]) + ((0.00925354287f * fVec48[((IOTA - 399) & 511)]) + ((0.00660886383f * fVec48[((IOTA - 398) & 511)]) + ((0.00341342529f * fVec48[((IOTA - 397) & 511)]) + ((0.00125464844f * fVec48[((IOTA - 396) & 511)]) + ((0.000626518857f * fVec48[((IOTA - 395) & 511)]) + ((0.000798511319f * fVec48[((IOTA - 394) & 511)]) + ((0.000643089414f * fVec48[((IOTA - 393) & 511)]) + ((0.00037446199f * fVec48[((IOTA - 392) & 511)]) + ((7.20429234e-05f * fVec48[((IOTA - 387) & 511)]) + ((0.00177554972f * fVec48[((IOTA - 386) & 511)]) + ((0.00400890969f * fVec48[((IOTA - 385) & 511)]) + ((0.00552264601f * fVec48[((IOTA - 384) & 511)]) + ((0.00566666992f * fVec48[((IOTA - 383) & 511)]) + ((0.00392110134f * fVec48[((IOTA - 382) & 511)]) + ((0.00118049933f * fVec48[((IOTA - 381) & 511)]) + ((0.000243199058f * fVec48[((IOTA - 378) & 511)]) + ((0.00341528375f * fVec48[((IOTA - 377) & 511)]) + ((0.00729057658f * fVec48[((IOTA - 376) & 511)]) + ((0.0112311598f * fVec48[((IOTA - 375) & 511)]) + ((0.014563065f * fVec48[((IOTA - 374) & 511)]) + ((0.0161860734f * fVec48[((IOTA - 373) & 511)]) + ((0.0160306208f * fVec48[((IOTA - 372) & 511)]) + ((0.0142780524f * fVec48[((IOTA - 371) & 511)]) + ((0.010805686f * fVec48[((IOTA - 370) & 511)]) + ((0.00656429399f * fVec48[((IOTA - 369) & 511)]) + ((0.00238537462f * fVec48[((IOTA - 368) & 511)]) + ((0.00118022086f * fVec48[((IOTA - 360) & 511)]) + ((0.00596013758f * fVec48[((IOTA - 359) & 511)]) + ((0.00933902897f * fVec48[((IOTA - 358) & 511)]) + ((0.00948989764f * fVec48[((IOTA - 357) & 511)]) + ((0.00633097533f * fVec48[((IOTA - 356) & 511)]) + ((0.00124482997f * fVec48[((IOTA - 355) & 511)]) + ((0.000164589845f * fVec48[((IOTA - 328) & 511)]) + ((5.88595867e-07f * fVec48[((IOTA - 327) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.107243948f * fVec48[((IOTA - 8) & 511)]) + ((0.0571940392f * fVec48[((IOTA - 7) & 511)]) + (((0.0888614655f * fVec48[((IOTA - 9) & 511)]) + (0.0403710119f * fVec48[((IOTA - 10) & 511)])) + (0.0151753053f * fVec48[((IOTA - 11) & 511)])))) + (0.0136186723f * fVec48[((IOTA - 22) & 511)])) + (0.0176826511f * fVec48[((IOTA - 23) & 511)])) + (0.00885597616f * fVec48[((IOTA - 24) & 511)])) + (0.012886907f * fVec48[((IOTA - 29) & 511)])) + (0.0428345278f * fVec48[((IOTA - 30) & 511)])) + (0.0636188015f * fVec48[((IOTA - 31) & 511)])) + (0.0722377747f * fVec48[((IOTA - 32) & 511)])) + (0.0606565289f * fVec48[((IOTA - 33) & 511)])) + (0.0320471488f * fVec48[((IOTA - 34) & 511)])) + (0.00629340531f * fVec48[((IOTA - 35) & 511)])) + (0.00403421419f * fVec48[((IOTA - 36) & 511)])) + (0.0116304001f * fVec48[((IOTA - 37) & 511)])) + (0.0158234742f * fVec48[((IOTA - 38) & 511)])) + (0.0193647258f * fVec48[((IOTA - 39) & 511)])) + (0.0127106402f * fVec48[((IOTA - 40) & 511)])) + (0.0062140529f * fVec48[((IOTA - 41) & 511)])) + (0.0118046226f * fVec48[((IOTA - 44) & 511)])) + (0.0206443686f * fVec48[((IOTA - 45) & 511)])) + (0.0387437269f * fVec48[((IOTA - 46) & 511)])) + (0.0548184216f * fVec48[((IOTA - 47) & 511)])) + (0.0603421219f * fVec48[((IOTA - 48) & 511)])) + (0.0689251944f * fVec48[((IOTA - 49) & 511)])) + (0.070370324f * fVec48[((IOTA - 50) & 511)])) + (0.0565904751f * fVec48[((IOTA - 51) & 511)])) + (0.028963089f * fVec48[((IOTA - 52) & 511)])) + (0.0103758443f * fVec48[((IOTA - 58) & 511)])) + (0.0443897992f * fVec48[((IOTA - 59) & 511)])) + (0.063618958f * fVec48[((IOTA - 60) & 511)])) + (0.0711818188f * fVec48[((IOTA - 61) & 511)])) + (0.0710361525f * fVec48[((IOTA - 62) & 511)])) + (0.0528299659f * fVec48[((IOTA - 63) & 511)])) + (0.0319528654f * fVec48[((IOTA - 64) & 511)])) + (0.0135239251f * fVec48[((IOTA - 65) & 511)])) + (0.00297221728f * fVec48[((IOTA - 67) & 511)])) + (0.0196850765f * fVec48[((IOTA - 68) & 511)])) + (0.0369838811f * fVec48[((IOTA - 69) & 511)])) + (0.0472936295f * fVec48[((IOTA - 70) & 511)])) + (0.0452815108f * fVec48[((IOTA - 71) & 511)])) + (0.034807913f * fVec48[((IOTA - 72) & 511)])) + (0.0191244986f * fVec48[((IOTA - 73) & 511)])) + (0.00414630538f * fVec48[((IOTA - 74) & 511)])) + (0.00101206917f * fVec48[((IOTA - 75) & 511)])) + (0.00829013251f * fVec48[((IOTA - 76) & 511)])) + (0.0166672375f * fVec48[((IOTA - 77) & 511)])) + (0.0180400163f * fVec48[((IOTA - 78) & 511)])) + (0.0140301771f * fVec48[((IOTA - 79) & 511)])) + (0.0110352263f * fVec48[((IOTA - 80) & 511)])) + (0.0130745405f * fVec48[((IOTA - 81) & 511)])) + (0.0191514455f * fVec48[((IOTA - 82) & 511)])) + (0.025340721f * fVec48[((IOTA - 83) & 511)])) + (0.0290055536f * fVec48[((IOTA - 84) & 511)])) + (0.0247637574f * fVec48[((IOTA - 85) & 511)])) + (0.0138255078f * fVec48[((IOTA - 86) & 511)])) + (0.00464304769f * fVec48[((IOTA - 87) & 511)])) + (0.00116953487f * fVec48[((IOTA - 88) & 511)])) + (0.00682576699f * fVec48[((IOTA - 89) & 511)])) + (0.0202089511f * fVec48[((IOTA - 90) & 511)])) + (0.0299790613f * fVec48[((IOTA - 91) & 511)])) + (0.0339562856f * fVec48[((IOTA - 92) & 511)])) + (0.0355913118f * fVec48[((IOTA - 93) & 511)])) + (0.0323519856f * fVec48[((IOTA - 94) & 511)])) + (0.027845744f * fVec48[((IOTA - 95) & 511)])) + (0.0258826837f * fVec48[((IOTA - 96) & 511)])) + (0.0248598661f * fVec48[((IOTA - 97) & 511)])) + (0.0216757022f * fVec48[((IOTA - 98) & 511)])) + (0.0131267607f * fVec48[((IOTA - 99) & 511)])) + (0.00158856669f * fVec48[((IOTA - 100) & 511)])) + (0.0085535571f * fVec48[((IOTA - 104) & 511)])) + (0.020218119f * fVec48[((IOTA - 105) & 511)])) + (0.0275561474f * fVec48[((IOTA - 106) & 511)])) + (0.0289030317f * fVec48[((IOTA - 107) & 511)])) + (0.0245855097f * fVec48[((IOTA - 108) & 511)])) + (0.0182999708f * fVec48[((IOTA - 109) & 511)])) + (0.0129599404f * fVec48[((IOTA - 110) & 511)])) + (0.00920568965f * fVec48[((IOTA - 111) & 511)])) + (0.00947496854f * fVec48[((IOTA - 112) & 511)])) + (0.00958820432f * fVec48[((IOTA - 113) & 511)])) + (0.00681093102f * fVec48[((IOTA - 114) & 511)])) + (0.00835176837f * fVec48[((IOTA - 115) & 511)])) + (0.0127664227f * fVec48[((IOTA - 116) & 511)])) + (0.0159302987f * fVec48[((IOTA - 117) & 511)])) + (0.0208765101f * fVec48[((IOTA - 118) & 511)])) + (0.0252795182f * fVec48[((IOTA - 119) & 511)])) + (0.0307110734f * fVec48[((IOTA - 120) & 511)])) + (0.0368650071f * fVec48[((IOTA - 121) & 511)])) + (0.038200371f * fVec48[((IOTA - 122) & 511)])) + (0.034713693f * fVec48[((IOTA - 123) & 511)])) + (0.0265501179f * fVec48[((IOTA - 124) & 511)])) + (0.0140377656f * fVec48[((IOTA - 125) & 511)])) + (0.00102309557f * fVec48[((IOTA - 126) & 511)])) + (0.00334317889f * fVec48[((IOTA - 130) & 511)])) + (0.00335048884f * fVec48[((IOTA - 131) & 511)])) + (0.00167965796f * fVec48[((IOTA - 132) & 511)])) + (0.00436738925f * fVec48[((IOTA - 138) & 511)])) + (0.0106114242f * fVec48[((IOTA - 139) & 511)])) + (0.0139128827f * fVec48[((IOTA - 140) & 511)])) + (0.016309686f * fVec48[((IOTA - 141) & 511)])) + (0.0170093626f * fVec48[((IOTA - 142) & 511)])) + (0.0133667998f * fVec48[((IOTA - 143) & 511)])) + (0.00485053519f * fVec48[((IOTA - 144) & 511)])) + (0.00586049771f * fVec48[((IOTA - 149) & 511)])) + (0.0127730817f * fVec48[((IOTA - 150) & 511)])) + (0.0142852068f * fVec48[((IOTA - 151) & 511)])) + (0.0112048015f * fVec48[((IOTA - 152) & 511)])) + (0.00330272829f * fVec48[((IOTA - 153) & 511)])) + (0.00475538615f * fVec48[((IOTA - 158) & 511)])) + (0.0106366668f * fVec48[((IOTA - 159) & 511)])) + (0.0124406498f * fVec48[((IOTA - 160) & 511)])) + (0.0111120073f * fVec48[((IOTA - 161) & 511)])) + (0.00721633481f * fVec48[((IOTA - 162) & 511)])) + (0.00376543216f * fVec48[((IOTA - 163) & 511)])) + (0.00299213268f * fVec48[((IOTA - 164) & 511)])) + (0.00238314457f * fVec48[((IOTA - 165) & 511)])) + (0.00203312002f * fVec48[((IOTA - 166) & 511)])) + (0.00201301882f * fVec48[((IOTA - 167) & 511)])) + (0.000953437295f * fVec48[((IOTA - 175) & 511)])) + (0.00612822734f * fVec48[((IOTA - 176) & 511)])) + (0.00957714766f * fVec48[((IOTA - 177) & 511)])) + (0.00864619669f * fVec48[((IOTA - 178) & 511)])) + (0.00433310261f * fVec48[((IOTA - 179) & 511)])) + (0.00840318389f * fVec48[((IOTA - 453) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00703941751f * fVec48[((IOTA - 454) & 511)])) + (0.00505229225f * fVec48[((IOTA - 455) & 511)])) + (0.00345043791f * fVec48[((IOTA - 456) & 511)])) + (0.00301957456f * fVec48[((IOTA - 457) & 511)])) + (0.00443227775f * fVec48[((IOTA - 458) & 511)])) + (0.00692199962f * fVec48[((IOTA - 459) & 511)])) + (0.00832092017f * fVec48[((IOTA - 460) & 511)])) + (0.00780655351f * fVec48[((IOTA - 461) & 511)])) + (0.0058111581f * fVec48[((IOTA - 462) & 511)])) + (0.00318800518f * fVec48[((IOTA - 463) & 511)])) + (0.00126793562f * fVec48[((IOTA - 464) & 511)])) + (0.00111468229f * fVec48[((IOTA - 465) & 511)])) + (0.00307006063f * fVec48[((IOTA - 466) & 511)])) + (0.00628343225f * fVec48[((IOTA - 467) & 511)])) + (0.00867317431f * fVec48[((IOTA - 468) & 511)])) + (0.00866369624f * fVec48[((IOTA - 469) & 511)])) + (0.00641014194f * fVec48[((IOTA - 470) & 511)])) + (0.003175647f * fVec48[((IOTA - 471) & 511)])) + (0.00102919713f * fVec48[((IOTA - 472) & 511)])) + (0.00135481451f * fVec48[((IOTA - 473) & 511)])) + (0.00359334657f * fVec48[((IOTA - 474) & 511)])) + (0.00627256092f * fVec48[((IOTA - 475) & 511)])) + (0.00742366677f * fVec48[((IOTA - 476) & 511)])) + (0.00670060562f * fVec48[((IOTA - 477) & 511)])) + (0.00507254852f * fVec48[((IOTA - 478) & 511)])) + (0.00347481389f * fVec48[((IOTA - 479) & 511)])) + (0.00311766565f * fVec48[((IOTA - 480) & 511)])) + (0.00416244194f * fVec48[((IOTA - 481) & 511)])) + (0.0065275291f * fVec48[((IOTA - 482) & 511)])) + (0.0095259808f * fVec48[((IOTA - 483) & 511)])) + (0.0113674719f * fVec48[((IOTA - 484) & 511)])) + (0.011104729f * fVec48[((IOTA - 485) & 511)])) + (0.00896001328f * fVec48[((IOTA - 486) & 511)])) + (0.00589026278f * fVec48[((IOTA - 487) & 511)])) + (0.00387417758f * fVec48[((IOTA - 488) & 511)])) + (0.00431039929f * fVec48[((IOTA - 489) & 511)])) + (0.00605209591f * fVec48[((IOTA - 490) & 511)])) + (0.0079992665f * fVec48[((IOTA - 491) & 511)])) + (0.00932654552f * fVec48[((IOTA - 492) & 511)])) + (0.00889193453f * fVec48[((IOTA - 493) & 511)])) + (0.00674935663f * fVec48[((IOTA - 494) & 511)])) + (0.0035235649f * fVec48[((IOTA - 495) & 511)])) + (0.000502131879f * fVec48[((IOTA - 496) & 511)])) + (0.00160615938f * fVec48[((IOTA - 499) & 511)])) + (0.00298838504f * fVec48[((IOTA - 500) & 511)])) + (0.00388278812f * fVec48[((IOTA - 501) & 511)])) + (0.00477511622f * fVec48[((IOTA - 502) & 511)])) + (0.00555312308f * fVec48[((IOTA - 503) & 511)])) + (0.0066180937f * fVec48[((IOTA - 504) & 511)])) + (0.00814936124f * fVec48[((IOTA - 505) & 511)])) + (0.0100604482f * fVec48[((IOTA - 506) & 511)])) + (0.0121254697f * fVec48[((IOTA - 507) & 511)])) + (0.0135386996f * fVec48[((IOTA - 508) & 511)])) + (0.0134893283f * fVec48[((IOTA - 509) & 511)])) + (0.0117109921f * fVec48[((IOTA - 510) & 511)])) + (0.0089109214f * fVec48[((IOTA - 511) & 511)]))))) : (iSlow137 ? (iSlow143 ? (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00502572721f * fVec47[((IOTA - 242) & 511)]) + ((0.0045219399f * fVec47[((IOTA - 241) & 511)]) + ((0.00319885369f * fVec47[((IOTA - 240) & 511)]) + ((0.00180537766f * fVec47[((IOTA - 239) & 511)]) + ((0.00175921246f * fVec47[((IOTA - 238) & 511)]) + ((0.00341807725f * fVec47[((IOTA - 237) & 511)]) + ((0.00615357608f * fVec47[((IOTA - 236) & 511)]) + ((0.00860952679f * fVec47[((IOTA - 235) & 511)]) + ((0.00977818388f * fVec47[((IOTA - 234) & 511)]) + ((0.00924419984f * fVec47[((IOTA - 233) & 511)]) + ((0.007499523f * fVec47[((IOTA - 232) & 511)]) + ((0.00600409461f * fVec47[((IOTA - 231) & 511)]) + ((0.0055783065f * fVec47[((IOTA - 230) & 511)]) + ((0.0061609121f * fVec47[((IOTA - 229) & 511)]) + ((0.00687324302f * fVec47[((IOTA - 228) & 511)]) + ((0.0065896688f * fVec47[((IOTA - 227) & 511)]) + ((0.00528449612f * fVec47[((IOTA - 226) & 511)]) + ((0.00383407297f * fVec47[((IOTA - 225) & 511)]) + ((0.00295366487f * fVec47[((IOTA - 224) & 511)]) + ((0.00339327147f * fVec47[((IOTA - 223) & 511)]) + ((0.00553337019f * fVec47[((IOTA - 222) & 511)]) + ((0.0084500825f * fVec47[((IOTA - 221) & 511)]) + ((0.0106747653f * fVec47[((IOTA - 220) & 511)]) + ((0.0107386392f * fVec47[((IOTA - 219) & 511)]) + ((0.00803753268f * fVec47[((IOTA - 218) & 511)]) + ((0.00395151507f * fVec47[((IOTA - 217) & 511)]) + ((0.000531185884f * fVec47[((IOTA - 216) & 511)]) + ((0.000611061696f * fVec47[((IOTA - 213) & 511)]) + ((0.00308345864f * fVec47[((IOTA - 212) & 511)]) + ((0.00598949147f * fVec47[((IOTA - 211) & 511)]) + ((0.00756073464f * fVec47[((IOTA - 210) & 511)]) + ((0.0069438722f * fVec47[((IOTA - 209) & 511)]) + ((0.00534106744f * fVec47[((IOTA - 208) & 511)]) + ((0.00404189993f * fVec47[((IOTA - 207) & 511)]) + ((0.00355339842f * fVec47[((IOTA - 206) & 511)]) + ((0.00313818781f * fVec47[((IOTA - 205) & 511)]) + ((0.00259205699f * fVec47[((IOTA - 204) & 511)]) + ((0.00206656894f * fVec47[((IOTA - 203) & 511)]) + ((0.00114095118f * fVec47[((IOTA - 202) & 511)]) + ((0.000628053676f * fVec47[((IOTA - 201) & 511)]) + ((0.00108478917f * fVec47[((IOTA - 200) & 511)]) + ((0.00158676831f * fVec47[((IOTA - 199) & 511)]) + ((0.002015559f * fVec47[((IOTA - 198) & 511)]) + ((0.00363480998f * fVec47[((IOTA - 197) & 511)]) + ((0.00650805281f * fVec47[((IOTA - 196) & 511)]) + ((0.00895305071f * fVec47[((IOTA - 195) & 511)]) + ((0.0102515016f * fVec47[((IOTA - 194) & 511)]) + ((0.0098588448f * fVec47[((IOTA - 193) & 511)]) + ((0.00810768455f * fVec47[((IOTA - 192) & 511)]) + ((0.00619817153f * fVec47[((IOTA - 191) & 511)]) + ((0.0041203429f * fVec47[((IOTA - 190) & 511)]) + ((0.00213829009f * fVec47[((IOTA - 189) & 511)]) + ((0.000682134647f * fVec47[((IOTA - 188) & 511)]) + ((0.0007272074f * fVec47[((IOTA - 186) & 511)]) + ((0.00286259735f * fVec47[((IOTA - 185) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0212265942f * fVec47[((IOTA - 39) & 511)]) + ((0.0288775098f * fVec47[((IOTA - 38) & 511)]) + ((0.0173823535f * fVec47[((IOTA - 37) & 511)]) + ((0.0218622237f * fVec47[((IOTA - 25) & 511)]) + ((0.0281972848f * fVec47[((IOTA - 24) & 511)]) + ((0.019026991f * fVec47[((IOTA - 23) & 511)]) + ((0.00309867645f * fVec47[((IOTA - 22) & 511)]) + ((0.0176932588f * fVec47[((IOTA - 18) & 511)]) + ((0.0246281587f * fVec47[((IOTA - 17) & 511)]) + ((0.0180379767f * fVec47[((IOTA - 16) & 511)]) + ((0.0249822922f * fVec47[((IOTA - 13) & 511)]) + ((0.0830062479f * fVec47[((IOTA - 12) & 511)]) + ((0.0947087854f * fVec47[((IOTA - 11) & 511)]) + ((0.0408024788f * fVec47[((IOTA - 10) & 511)]) + ((0.127937943f * fVec47[((IOTA - 4) & 511)]) + ((0.238482609f * fVec47[((IOTA - 3) & 511)]) + ((0.276490867f * fVec47[((IOTA - 2) & 511)]) + ((0.236814529f * fVec47[((IOTA - 1) & 511)]) + ((fSlow147 * fTemp0) + (((0.0188197438f * fVec47[((IOTA - 40) & 511)]) + (0.0188963097f * fVec47[((IOTA - 41) & 511)])) + (0.0108676478f * fVec47[((IOTA - 42) & 511)]))))))))))))))))))))) + (0.0161054675f * fVec47[((IOTA - 49) & 511)])) + (0.0159618892f * fVec47[((IOTA - 50) & 511)])) + (0.00567476498f * fVec47[((IOTA - 51) & 511)])) + (0.00265548658f * fVec47[((IOTA - 60) & 511)])) + (0.00435563689f * fVec47[((IOTA - 61) & 511)])) + (0.00208502822f * fVec47[((IOTA - 62) & 511)])) + (0.000228470191f * fVec47[((IOTA - 63) & 511)])) + (0.00334963156f * fVec47[((IOTA - 75) & 511)])) + (0.00532475812f * fVec47[((IOTA - 76) & 511)])) + (0.00488559483f * fVec47[((IOTA - 77) & 511)])) + (0.000629793853f * fVec47[((IOTA - 96) & 511)])) + (0.00729019428f * fVec47[((IOTA - 97) & 511)])) + (0.0118277948f * fVec47[((IOTA - 98) & 511)])) + (0.0119145634f * fVec47[((IOTA - 99) & 511)])) + (0.00967749488f * fVec47[((IOTA - 100) & 511)])) + (0.000306264497f * fVec47[((IOTA - 101) & 511)])) + (0.00487590441f * fVec47[((IOTA - 108) & 511)])) + (0.0101108579f * fVec47[((IOTA - 109) & 511)])) + (0.00732687348f * fVec47[((IOTA - 110) & 511)])) + (0.00324321026f * fVec47[((IOTA - 111) & 511)])) + (0.00560028013f * fVec47[((IOTA - 129) & 511)])) + (0.00739040598f * fVec47[((IOTA - 130) & 511)])) + (0.0056145764f * fVec47[((IOTA - 131) & 511)])) + (0.000738467555f * fVec47[((IOTA - 132) & 511)])) + (0.00218916358f * fVec47[((IOTA - 137) & 511)])) + (0.00336771552f * fVec47[((IOTA - 138) & 511)])) + (0.00121297967f * fVec47[((IOTA - 145) & 511)])) + (0.00457097078f * fVec47[((IOTA - 146) & 511)])) + (0.00462696236f * fVec47[((IOTA - 147) & 511)])) + (0.00207567913f * fVec47[((IOTA - 148) & 511)])) + (0.00218346529f * fVec47[((IOTA - 153) & 511)])) + (0.00558738271f * fVec47[((IOTA - 154) & 511)])) + (0.00634366088f * fVec47[((IOTA - 155) & 511)])) + (0.00464907242f * fVec47[((IOTA - 156) & 511)])) + (0.00162900938f * fVec47[((IOTA - 157) & 511)])) + (0.00037784921f * fVec47[((IOTA - 167) & 511)])) + (0.00218448881f * fVec47[((IOTA - 168) & 511)])) + (0.0024706223f * fVec47[((IOTA - 169) & 511)])) + (0.00153394975f * fVec47[((IOTA - 170) & 511)])) + (0.000317592639f * fVec47[((IOTA - 171) & 511)])) + (0.000948751345f * fVec47[((IOTA - 174) & 511)])) + (0.00233066082f * fVec47[((IOTA - 175) & 511)])) + (0.00356496545f * fVec47[((IOTA - 176) & 511)])) + (0.00442691427f * fVec47[((IOTA - 177) & 511)])) + (0.00496929185f * fVec47[((IOTA - 178) & 511)])) + (0.0048740278f * fVec47[((IOTA - 179) & 511)])) + (0.00347539922f * fVec47[((IOTA - 180) & 511)])) + (0.00251078233f * fVec47[((IOTA - 181) & 511)])) + (0.00336133502f * fVec47[((IOTA - 182) & 511)])) + (0.00441701943f * fVec47[((IOTA - 183) & 511)])) + (0.0043848101f * fVec47[((IOTA - 184) & 511)])) + (0.00478940923f * fVec47[((IOTA - 243) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00384007813f * fVec47[((IOTA - 244) & 511)])) + (0.00321482215f * fVec47[((IOTA - 245) & 511)])) + (0.00325532304f * fVec47[((IOTA - 246) & 511)])) + (0.00352763757f * fVec47[((IOTA - 247) & 511)])) + (0.00423526019f * fVec47[((IOTA - 248) & 511)])) + (0.00492677791f * fVec47[((IOTA - 249) & 511)])) + (0.00495758886f * fVec47[((IOTA - 250) & 511)])) + (0.00453886343f * fVec47[((IOTA - 251) & 511)])) + (0.00434639025f * fVec47[((IOTA - 252) & 511)])) + (0.00499396119f * fVec47[((IOTA - 253) & 511)])) + (0.00642421888f * fVec47[((IOTA - 254) & 511)])) + (0.00789091736f * fVec47[((IOTA - 255) & 511)])) + (0.0093623586f * fVec47[((IOTA - 256) & 511)])) + (0.0110767372f * fVec47[((IOTA - 257) & 511)])) + (0.0123452991f * fVec47[((IOTA - 258) & 511)])) + (0.0121735372f * fVec47[((IOTA - 259) & 511)])) + (0.0101580461f * fVec47[((IOTA - 260) & 511)])) + (0.00679480052f * fVec47[((IOTA - 261) & 511)])) + (0.00367572019f * fVec47[((IOTA - 262) & 511)])) + (0.00230421731f * fVec47[((IOTA - 263) & 511)])) + (0.00291995378f * fVec47[((IOTA - 264) & 511)])) + (0.00527971936f * fVec47[((IOTA - 265) & 511)])) + (0.00815282576f * fVec47[((IOTA - 266) & 511)])) + (0.0101048183f * fVec47[((IOTA - 267) & 511)])) + (0.0107848374f * fVec47[((IOTA - 268) & 511)])) + (0.0100350762f * fVec47[((IOTA - 269) & 511)])) + (0.00817029551f * fVec47[((IOTA - 270) & 511)])) + (0.00614593318f * fVec47[((IOTA - 271) & 511)])) + (0.0045824009f * fVec47[((IOTA - 272) & 511)])) + (0.00386341615f * fVec47[((IOTA - 273) & 511)])) + (0.00364484126f * fVec47[((IOTA - 274) & 511)])) + (0.0029705544f * fVec47[((IOTA - 275) & 511)])) + (0.00200696057f * fVec47[((IOTA - 276) & 511)])) + (0.00157315424f * fVec47[((IOTA - 277) & 511)])) + (0.00187491486f * fVec47[((IOTA - 278) & 511)])) + (0.00303790811f * fVec47[((IOTA - 279) & 511)])) + (0.00462958962f * fVec47[((IOTA - 280) & 511)])) + (0.00568305608f * fVec47[((IOTA - 281) & 511)])) + (0.00617370708f * fVec47[((IOTA - 282) & 511)])) + (0.00588542409f * fVec47[((IOTA - 283) & 511)])) + (0.00485498877f * fVec47[((IOTA - 284) & 511)])) + (0.00361246103f * fVec47[((IOTA - 285) & 511)])) + (0.00250525447f * fVec47[((IOTA - 286) & 511)])) + (0.0020530913f * fVec47[((IOTA - 287) & 511)])) + (0.00260055298f * fVec47[((IOTA - 288) & 511)])) + (0.00347546767f * fVec47[((IOTA - 289) & 511)])) + (0.00401559332f * fVec47[((IOTA - 290) & 511)])) + (0.00444547599f * fVec47[((IOTA - 291) & 511)])) + (0.0047815959f * fVec47[((IOTA - 292) & 511)])) + (0.0052644331f * fVec47[((IOTA - 293) & 511)])) + (0.00575836003f * fVec47[((IOTA - 294) & 511)])) + (0.00561597571f * fVec47[((IOTA - 295) & 511)])) + (0.00502289506f * fVec47[((IOTA - 296) & 511)])) + (0.00447553582f * fVec47[((IOTA - 297) & 511)])) + (0.00433417503f * fVec47[((IOTA - 298) & 511)])) + (0.00471311621f * fVec47[((IOTA - 299) & 511)])) + (0.0051302379f * fVec47[((IOTA - 300) & 511)])) + (0.0055045723f * fVec47[((IOTA - 301) & 511)])) + (0.00588153442f * fVec47[((IOTA - 302) & 511)])) + (0.00607745349f * fVec47[((IOTA - 303) & 511)])) + (0.0062151975f * fVec47[((IOTA - 304) & 511)])) + (0.00647345465f * fVec47[((IOTA - 305) & 511)])) + (0.00670062844f * fVec47[((IOTA - 306) & 511)])) + (0.00725419726f * fVec47[((IOTA - 307) & 511)])) + (0.00832462125f * fVec47[((IOTA - 308) & 511)])) + (0.00903374515f * fVec47[((IOTA - 309) & 511)])) + (0.00895233452f * fVec47[((IOTA - 310) & 511)])) + (0.0080889184f * fVec47[((IOTA - 311) & 511)])) + (0.00647748075f * fVec47[((IOTA - 312) & 511)])) + (0.0046493453f * fVec47[((IOTA - 313) & 511)])) + (0.00250232033f * fVec47[((IOTA - 314) & 511)])) + (0.000510577578f * fVec47[((IOTA - 320) & 511)])) + (0.0020460966f * fVec47[((IOTA - 321) & 511)])) + (0.00278695254f * fVec47[((IOTA - 322) & 511)])) + (0.00202685269f * fVec47[((IOTA - 323) & 511)])) + (0.000526443124f * fVec47[((IOTA - 324) & 511)])) + (0.00162737165f * fVec47[((IOTA - 328) & 511)])) + (0.00340961525f * fVec47[((IOTA - 329) & 511)])) + (0.00379114924f * fVec47[((IOTA - 330) & 511)])) + (0.00276685553f * fVec47[((IOTA - 331) & 511)])) + (0.00148665905f * fVec47[((IOTA - 332) & 511)])) + (0.00121325254f * fVec47[((IOTA - 333) & 511)])) + (0.00170632591f * fVec47[((IOTA - 334) & 511)])) + (0.00264043966f * fVec47[((IOTA - 335) & 511)])) + (0.00359700434f * fVec47[((IOTA - 336) & 511)])) + (0.00383509649f * fVec47[((IOTA - 337) & 511)])) + (0.00390603254f * fVec47[((IOTA - 338) & 511)])) + (0.00386737427f * fVec47[((IOTA - 339) & 511)])) + (0.00333287846f * fVec47[((IOTA - 340) & 511)])) + (0.00299310777f * fVec47[((IOTA - 341) & 511)])) + (0.00299781654f * fVec47[((IOTA - 342) & 511)])) + (0.00315794349f * fVec47[((IOTA - 343) & 511)])) + (0.00361897796f * fVec47[((IOTA - 344) & 511)])) + (0.00367462821f * fVec47[((IOTA - 345) & 511)])) + (0.00299522327f * fVec47[((IOTA - 346) & 511)])) + (0.00253466656f * fVec47[((IOTA - 347) & 511)])) + (0.00252838852f * fVec47[((IOTA - 348) & 511)])) + (0.00266353926f * fVec47[((IOTA - 349) & 511)])) + (0.00290640816f * fVec47[((IOTA - 350) & 511)])) + (0.0028556711f * fVec47[((IOTA - 351) & 511)])) + (0.00294295093f * fVec47[((IOTA - 352) & 511)])) + (0.0033531459f * fVec47[((IOTA - 353) & 511)])) + (0.00304128602f * fVec47[((IOTA - 354) & 511)])) + (0.00233417517f * fVec47[((IOTA - 355) & 511)])) + (0.00175928092f * fVec47[((IOTA - 356) & 511)])) + (0.000850211829f * fVec47[((IOTA - 357) & 511)])) + (0.000312372111f * fVec47[((IOTA - 368) & 511)])) + (0.00125252502f * fVec47[((IOTA - 369) & 511)])) + (0.00146328658f * fVec47[((IOTA - 370) & 511)])) + (0.000617305748f * fVec47[((IOTA - 371) & 511)])) + (0.00118581951f * fVec47[((IOTA - 378) & 511)])) + (0.00165896676f * fVec47[((IOTA - 379) & 511)])) + (0.00106912805f * fVec47[((IOTA - 380) & 511)])) + (9.00779851e-05f * fVec47[((IOTA - 381) & 511)])) + (0.000257950276f * fVec47[((IOTA - 385) & 511)])) + (0.00141275441f * fVec47[((IOTA - 386) & 511)])) + (0.00200389f * fVec47[((IOTA - 387) & 511)])) + (0.00193315838f * fVec47[((IOTA - 388) & 511)])) + (0.0016440223f * fVec47[((IOTA - 389) & 511)])) + (0.000630476512f * fVec47[((IOTA - 390) & 511)])) + (0.00137481233f * fVec47[((IOTA - 401) & 511)])) + (0.00144912675f * fVec47[((IOTA - 402) & 511)])) + (0.000297666062f * fVec47[((IOTA - 403) & 511)])) + (0.0012381603f * fVec47[((IOTA - 426) & 511)])) + (0.00181302056f * fVec47[((IOTA - 427) & 511)])) + (0.00136710145f * fVec47[((IOTA - 428) & 511)])) + (0.000601405744f * fVec47[((IOTA - 429) & 511)])) + (0.000137744006f * fVec47[((IOTA - 495) & 511)])) + (0.000764398836f * fVec47[((IOTA - 496) & 511)])) + (0.000570458826f * fVec47[((IOTA - 497) & 511)])) - (((((((((((((((((((((((((((((((((0.00307929609f * fVec47[((IOTA - 476) & 511)]) + ((0.0029538013f * fVec47[((IOTA - 475) & 511)]) + ((0.00266950997f * fVec47[((IOTA - 474) & 511)]) + ((0.00241981726f * fVec47[((IOTA - 473) & 511)]) + ((0.00189757068f * fVec47[((IOTA - 472) & 511)]) + ((0.00156639842f * fVec47[((IOTA - 471) & 511)]) + ((0.00150651718f * fVec47[((IOTA - 470) & 511)]) + ((0.00173631776f * fVec47[((IOTA - 469) & 511)]) + ((0.00252582924f * fVec47[((IOTA - 468) & 511)]) + ((0.00324515533f * fVec47[((IOTA - 467) & 511)]) + ((0.00350876898f * fVec47[((IOTA - 466) & 511)]) + ((0.0036345711f * fVec47[((IOTA - 465) & 511)]) + ((0.00337614305f * fVec47[((IOTA - 464) & 511)]) + ((0.00284884684f * fVec47[((IOTA - 463) & 511)]) + ((0.00288143195f * fVec47[((IOTA - 462) & 511)]) + ((0.00308482349f * fVec47[((IOTA - 461) & 511)]) + ((0.00340050505f * fVec47[((IOTA - 460) & 511)]) + ((0.00415405398f * fVec47[((IOTA - 459) & 511)]) + ((0.00431499956f * fVec47[((IOTA - 458) & 511)]) + ((0.00378292659f * fVec47[((IOTA - 457) & 511)]) + ((0.00317155756f * fVec47[((IOTA - 456) & 511)]) + ((0.00269124471f * fVec47[((IOTA - 455) & 511)]) + ((0.00305517297f * fVec47[((IOTA - 454) & 511)]) + ((0.00402272446f * fVec47[((IOTA - 453) & 511)]) + ((0.00450259354f * fVec47[((IOTA - 452) & 511)]) + ((0.00456544338f * fVec47[((IOTA - 451) & 511)]) + ((0.00418571755f * fVec47[((IOTA - 450) & 511)]) + ((0.00346304802f * fVec47[((IOTA - 449) & 511)]) + ((0.00315279141f * fVec47[((IOTA - 448) & 511)]) + ((0.0030854037f * fVec47[((IOTA - 447) & 511)]) + ((0.00319813704f * fVec47[((IOTA - 446) & 511)]) + ((0.00380148785f * fVec47[((IOTA - 445) & 511)]) + ((0.00450279796f * fVec47[((IOTA - 444) & 511)]) + ((0.00536085758f * fVec47[((IOTA - 443) & 511)]) + ((0.00629940676f * fVec47[((IOTA - 442) & 511)]) + ((0.00660229335f * fVec47[((IOTA - 441) & 511)]) + ((0.00662300456f * fVec47[((IOTA - 440) & 511)]) + ((0.00645827129f * fVec47[((IOTA - 439) & 511)]) + ((0.00590852369f * fVec47[((IOTA - 438) & 511)]) + ((0.00538112503f * fVec47[((IOTA - 437) & 511)]) + ((0.00495707709f * fVec47[((IOTA - 436) & 511)]) + ((0.00471905293f * fVec47[((IOTA - 435) & 511)]) + ((0.00481946953f * fVec47[((IOTA - 434) & 511)]) + ((0.00470096944f * fVec47[((IOTA - 433) & 511)]) + ((0.00395414233f * fVec47[((IOTA - 432) & 511)]) + ((0.0026384606f * fVec47[((IOTA - 431) & 511)]) + ((0.000828852411f * fVec47[((IOTA - 430) & 511)]) + ((0.000534734689f * fVec47[((IOTA - 425) & 511)]) + ((0.00255326228f * fVec47[((IOTA - 424) & 511)]) + ((0.00409557158f * fVec47[((IOTA - 423) & 511)]) + ((0.00429558521f * fVec47[((IOTA - 422) & 511)]) + ((0.00342179649f * fVec47[((IOTA - 421) & 511)]) + ((0.00298348581f * fVec47[((IOTA - 420) & 511)]) + ((0.00268059922f * fVec47[((IOTA - 419) & 511)]) + ((0.00199727062f * fVec47[((IOTA - 418) & 511)]) + ((0.00164064439f * fVec47[((IOTA - 417) & 511)]) + ((0.00122782169f * fVec47[((IOTA - 416) & 511)]) + ((0.000964071136f * fVec47[((IOTA - 415) & 511)]) + ((0.00166432373f * fVec47[((IOTA - 414) & 511)]) + ((0.00236839801f * fVec47[((IOTA - 413) & 511)]) + ((0.00290862564f * fVec47[((IOTA - 412) & 511)]) + ((0.00351354619f * fVec47[((IOTA - 411) & 511)]) + ((0.00375085324f * fVec47[((IOTA - 410) & 511)]) + ((0.00439989101f * fVec47[((IOTA - 409) & 511)]) + ((0.00520895328f * fVec47[((IOTA - 408) & 511)]) + ((0.00526685594f * fVec47[((IOTA - 407) & 511)]) + ((0.00463620899f * fVec47[((IOTA - 406) & 511)]) + ((0.00321291154f * fVec47[((IOTA - 405) & 511)]) + ((0.00131687615f * fVec47[((IOTA - 404) & 511)]) + ((0.000227787532f * fVec47[((IOTA - 400) & 511)]) + ((0.00221779058f * fVec47[((IOTA - 399) & 511)]) + ((0.0043562511f * fVec47[((IOTA - 398) & 511)]) + ((0.00602374831f * fVec47[((IOTA - 397) & 511)]) + ((0.00621042075f * fVec47[((IOTA - 396) & 511)]) + ((0.00560928788f * fVec47[((IOTA - 395) & 511)]) + ((0.0046590697f * fVec47[((IOTA - 394) & 511)]) + ((0.00331336167f * fVec47[((IOTA - 393) & 511)]) + ((0.00220093504f * fVec47[((IOTA - 392) & 511)]) + ((0.000984782353f * fVec47[((IOTA - 391) & 511)]) + ((0.000760236289f * fVec47[((IOTA - 384) & 511)]) + ((0.00134918792f * fVec47[((IOTA - 383) & 511)]) + ((0.000941108447f * fVec47[((IOTA - 382) & 511)]) + ((4.39812429e-05f * fVec47[((IOTA - 377) & 511)]) + ((0.00123085873f * fVec47[((IOTA - 376) & 511)]) + ((0.00216763373f * fVec47[((IOTA - 375) & 511)]) + ((0.00230623037f * fVec47[((IOTA - 374) & 511)]) + ((0.00166053651f * fVec47[((IOTA - 373) & 511)]) + ((0.000670431182f * fVec47[((IOTA - 372) & 511)]) + ((0.00221072743f * fVec47[((IOTA - 366) & 511)]) + ((0.00282680523f * fVec47[((IOTA - 365) & 511)]) + ((0.00306346407f * fVec47[((IOTA - 364) & 511)]) + ((0.00300511811f * fVec47[((IOTA - 363) & 511)]) + ((0.00266678073f * fVec47[((IOTA - 362) & 511)]) + ((0.00238300115f * fVec47[((IOTA - 361) & 511)]) + ((0.00189026911f * fVec47[((IOTA - 360) & 511)]) + ((0.0010111914f * fVec47[((IOTA - 359) & 511)]) + ((0.000104715582f * fVec47[((IOTA - 358) & 511)]) + ((0.000775828958f * fVec47[((IOTA - 327) & 511)]) + ((0.00184192043f * fVec47[((IOTA - 326) & 511)]) + ((0.000950320624f * fVec47[((IOTA - 325) & 511)]) + ((0.00148580596f * fVec47[((IOTA - 319) & 511)]) + ((0.0032495223f * fVec47[((IOTA - 318) & 511)]) + ((0.00354575552f * fVec47[((IOTA - 317) & 511)]) + ((0.00233134301f * fVec47[((IOTA - 316) & 511)]) + ((0.000103726052f * fVec47[((IOTA - 315) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0597332865f * fVec47[((IOTA - 5) & 511)]) + (0.193707839f * fVec47[((IOTA - 6) & 511)])) + (0.234113023f * fVec47[((IOTA - 7) & 511)])) + (0.193793103f * fVec47[((IOTA - 8) & 511)])) + (0.0752013177f * fVec47[((IOTA - 9) & 511)])) + (0.0128579922f * fVec47[((IOTA - 14) & 511)])) + (0.00138467317f * fVec47[((IOTA - 15) & 511)])) + (0.00158175267f * fVec47[((IOTA - 19) & 511)])) + (0.0214395411f * fVec47[((IOTA - 20) & 511)])) + (0.0202618074f * fVec47[((IOTA - 21) & 511)])) + (0.00631742226f * fVec47[((IOTA - 26) & 511)])) + (0.0173032284f * fVec47[((IOTA - 27) & 511)])) + (0.0106455237f * fVec47[((IOTA - 28) & 511)])) + (0.00417275168f * fVec47[((IOTA - 29) & 511)])) + (0.0126713198f * fVec47[((IOTA - 30) & 511)])) + (0.0322689712f * fVec47[((IOTA - 31) & 511)])) + (0.0438990407f * fVec47[((IOTA - 32) & 511)])) + (0.0419435687f * fVec47[((IOTA - 33) & 511)])) + (0.027951926f * fVec47[((IOTA - 34) & 511)])) + (0.011931384f * fVec47[((IOTA - 35) & 511)])) + (0.00103162974f * fVec47[((IOTA - 36) & 511)])) + (0.0100420713f * fVec47[((IOTA - 43) & 511)])) + (0.0446031839f * fVec47[((IOTA - 44) & 511)])) + (0.0615992956f * fVec47[((IOTA - 45) & 511)])) + (0.0499387905f * fVec47[((IOTA - 46) & 511)])) + (0.0289368797f * fVec47[((IOTA - 47) & 511)])) + (0.0031668148f * fVec47[((IOTA - 48) & 511)])) + (0.00660584169f * fVec47[((IOTA - 52) & 511)])) + (0.021495156f * fVec47[((IOTA - 53) & 511)])) + (0.0291098356f * fVec47[((IOTA - 54) & 511)])) + (0.0249028616f * fVec47[((IOTA - 55) & 511)])) + (0.0190414563f * fVec47[((IOTA - 56) & 511)])) + (0.0125615876f * fVec47[((IOTA - 57) & 511)])) + (0.00633188942f * fVec47[((IOTA - 58) & 511)])) + (0.00232905708f * fVec47[((IOTA - 59) & 511)])) + (0.00502030179f * fVec47[((IOTA - 64) & 511)])) + (0.0155781712f * fVec47[((IOTA - 65) & 511)])) + (0.0228703432f * fVec47[((IOTA - 66) & 511)])) + (0.0248655677f * fVec47[((IOTA - 67) & 511)])) + (0.0254819859f * fVec47[((IOTA - 68) & 511)])) + (0.0201781094f * fVec47[((IOTA - 69) & 511)])) + (0.0153853223f * fVec47[((IOTA - 70) & 511)])) + (0.0163224377f * fVec47[((IOTA - 71) & 511)])) + (0.0137075549f * fVec47[((IOTA - 72) & 511)])) + (0.0104105715f * fVec47[((IOTA - 73) & 511)])) + (0.00431622798f * fVec47[((IOTA - 74) & 511)])) + (0.000589190517f * fVec47[((IOTA - 78) & 511)])) + (0.00375522068f * fVec47[((IOTA - 79) & 511)])) + (0.00111297285f * fVec47[((IOTA - 80) & 511)])) + (0.00530227274f * fVec47[((IOTA - 81) & 511)])) + (0.0107487384f * fVec47[((IOTA - 82) & 511)])) + (0.0125551736f * fVec47[((IOTA - 83) & 511)])) + (0.0169404615f * fVec47[((IOTA - 84) & 511)])) + (0.0199367758f * fVec47[((IOTA - 85) & 511)])) + (0.0214580335f * fVec47[((IOTA - 86) & 511)])) + (0.0214494355f * fVec47[((IOTA - 87) & 511)])) + (0.0172650479f * fVec47[((IOTA - 88) & 511)])) + (0.0150969708f * fVec47[((IOTA - 89) & 511)])) + (0.0165566057f * fVec47[((IOTA - 90) & 511)])) + (0.0157258771f * fVec47[((IOTA - 91) & 511)])) + (0.01429132f * fVec47[((IOTA - 92) & 511)])) + (0.0117805386f * fVec47[((IOTA - 93) & 511)])) + (0.00561269978f * fVec47[((IOTA - 94) & 511)])) + (0.00208963454f * fVec47[((IOTA - 95) & 511)])) + (0.0140899085f * fVec47[((IOTA - 102) & 511)])) + (0.0259844773f * fVec47[((IOTA - 103) & 511)])) + (0.0321820341f * fVec47[((IOTA - 104) & 511)])) + (0.0288691837f * fVec47[((IOTA - 105) & 511)])) + (0.017504096f * fVec47[((IOTA - 106) & 511)])) + (0.00533431163f * fVec47[((IOTA - 107) & 511)])) + (0.000388801564f * fVec47[((IOTA - 112) & 511)])) + (0.00554657448f * fVec47[((IOTA - 113) & 511)])) + (0.0107594524f * fVec47[((IOTA - 114) & 511)])) + (0.0160619635f * fVec47[((IOTA - 115) & 511)])) + (0.0189269837f * fVec47[((IOTA - 116) & 511)])) + (0.0174546205f * fVec47[((IOTA - 117) & 511)])) + (0.0136924395f * fVec47[((IOTA - 118) & 511)])) + (0.00799928419f * fVec47[((IOTA - 119) & 511)])) + (0.00329944072f * fVec47[((IOTA - 120) & 511)])) + (0.00217425311f * fVec47[((IOTA - 121) & 511)])) + (0.00360795716f * fVec47[((IOTA - 122) & 511)])) + (0.0073643378f * fVec47[((IOTA - 123) & 511)])) + (0.0113256462f * fVec47[((IOTA - 124) & 511)])) + (0.0127050988f * fVec47[((IOTA - 125) & 511)])) + (0.0113932043f * fVec47[((IOTA - 126) & 511)])) + (0.00752948038f * fVec47[((IOTA - 127) & 511)])) + (0.000781834591f * fVec47[((IOTA - 128) & 511)])) + (0.0044946773f * fVec47[((IOTA - 133) & 511)])) + (0.00565129006f * fVec47[((IOTA - 134) & 511)])) + (0.00476514967f * fVec47[((IOTA - 135) & 511)])) + (0.00238668639f * fVec47[((IOTA - 136) & 511)])) + (0.000126893632f * fVec47[((IOTA - 139) & 511)])) + (0.00554486876f * fVec47[((IOTA - 140) & 511)])) + (0.0113184806f * fVec47[((IOTA - 141) & 511)])) + (0.0126562044f * fVec47[((IOTA - 142) & 511)])) + (0.00863719918f * fVec47[((IOTA - 143) & 511)])) + (0.00343657052f * fVec47[((IOTA - 144) & 511)])) + (0.00133519853f * fVec47[((IOTA - 149) & 511)])) + (0.00378319947f * fVec47[((IOTA - 150) & 511)])) + (0.00363682304f * fVec47[((IOTA - 151) & 511)])) + (0.00140408752f * fVec47[((IOTA - 152) & 511)])) + (0.0022029141f * fVec47[((IOTA - 158) & 511)])) + (0.00535649015f * fVec47[((IOTA - 159) & 511)])) + (0.0071108574f * fVec47[((IOTA - 160) & 511)])) + (0.00748925237f * fVec47[((IOTA - 161) & 511)])) + (0.00578476908f * fVec47[((IOTA - 162) & 511)])) + (0.00288805133f * fVec47[((IOTA - 163) & 511)])) + (0.00121427607f * fVec47[((IOTA - 164) & 511)])) + (0.000630680937f * fVec47[((IOTA - 165) & 511)])) + (0.00045666704f * fVec47[((IOTA - 166) & 511)])) + (0.00103391567f * fVec47[((IOTA - 172) & 511)])) + (0.000687218737f * fVec47[((IOTA - 173) & 511)])) + (5.22383489e-05f * fVec47[((IOTA - 187) & 511)])) + (0.00108270766f * fVec47[((IOTA - 214) & 511)])) + (0.00127842231f * fVec47[((IOTA - 215) & 511)])) + (0.000974512193f * fVec47[((IOTA - 367) & 511)])) + (0.00279067177f * fVec47[((IOTA - 477) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00275931507f * fVec47[((IOTA - 478) & 511)])) + (0.00281834323f * fVec47[((IOTA - 479) & 511)])) + (0.00271789311f * fVec47[((IOTA - 480) & 511)])) + (0.00290828478f * fVec47[((IOTA - 481) & 511)])) + (0.00310921948f * fVec47[((IOTA - 482) & 511)])) + (0.00298249628f * fVec47[((IOTA - 483) & 511)])) + (0.00260874163f * fVec47[((IOTA - 484) & 511)])) + (0.00188791472f * fVec47[((IOTA - 485) & 511)])) + (0.00141756516f * fVec47[((IOTA - 486) & 511)])) + (0.00116951019f * fVec47[((IOTA - 487) & 511)])) + (0.000726149883f * fVec47[((IOTA - 488) & 511)])) + (0.000749897677f * fVec47[((IOTA - 489) & 511)])) + (0.00123137049f * fVec47[((IOTA - 490) & 511)])) + (0.00186481513f * fVec47[((IOTA - 491) & 511)])) + (0.00254544849f * fVec47[((IOTA - 492) & 511)])) + (0.00229650643f * fVec47[((IOTA - 493) & 511)])) + (0.00100556156f * fVec47[((IOTA - 494) & 511)])) + (0.000638528727f * fVec47[((IOTA - 498) & 511)])) + (0.00234707259f * fVec47[((IOTA - 499) & 511)])) + (0.00425334414f * fVec47[((IOTA - 500) & 511)])) + (0.00552801322f * fVec47[((IOTA - 501) & 511)])) + (0.00528507587f * fVec47[((IOTA - 502) & 511)])) + (0.00407554256f * fVec47[((IOTA - 503) & 511)])) + (0.0027073496f * fVec47[((IOTA - 504) & 511)])) + (0.00183089962f * fVec47[((IOTA - 505) & 511)])) + (0.00227869535f * fVec47[((IOTA - 506) & 511)])) + (0.00366057083f * fVec47[((IOTA - 507) & 511)])) + (0.0051247105f * fVec47[((IOTA - 508) & 511)])) + (0.00631278194f * fVec47[((IOTA - 509) & 511)])) + (0.00644540787f * fVec47[((IOTA - 510) & 511)])) + (0.00544557814f * fVec47[((IOTA - 511) & 511)]))) : ((((((((((((((((((((((((((((((((((((((((((((0.00419117324f * fVec46[((IOTA - 336) & 511)]) + ((0.00370501075f * fVec46[((IOTA - 335) & 511)]) + ((0.00325695332f * fVec46[((IOTA - 334) & 511)]) + ((0.00260741403f * fVec46[((IOTA - 333) & 511)]) + ((0.0020492631f * fVec46[((IOTA - 332) & 511)]) + ((0.00218083337f * fVec46[((IOTA - 331) & 511)]) + ((0.00215463294f * fVec46[((IOTA - 330) & 511)]) + ((0.001113059f * fVec46[((IOTA - 329) & 511)]) + ((0.00103322836f * fVec46[((IOTA - 323) & 511)]) + ((0.00193321751f * fVec46[((IOTA - 322) & 511)]) + ((0.00165348081f * fVec46[((IOTA - 321) & 511)]) + ((0.00067693647f * fVec46[((IOTA - 320) & 511)]) + ((0.000512709375f * fVec46[((IOTA - 315) & 511)]) + ((0.00177925685f * fVec46[((IOTA - 314) & 511)]) + ((0.00283024646f * fVec46[((IOTA - 313) & 511)]) + ((0.003740218f * fVec46[((IOTA - 312) & 511)]) + ((0.0046948758f * fVec46[((IOTA - 311) & 511)]) + ((0.00531097129f * fVec46[((IOTA - 310) & 511)]) + ((0.00537977973f * fVec46[((IOTA - 309) & 511)]) + ((0.00484697893f * fVec46[((IOTA - 308) & 511)]) + ((0.00423264736f * fVec46[((IOTA - 307) & 511)]) + ((0.00421513803f * fVec46[((IOTA - 306) & 511)]) + ((0.00453606574f * fVec46[((IOTA - 305) & 511)]) + ((0.00481854239f * fVec46[((IOTA - 304) & 511)]) + ((0.00516740233f * fVec46[((IOTA - 303) & 511)]) + ((0.00568795344f * fVec46[((IOTA - 302) & 511)]) + ((0.006212031f * fVec46[((IOTA - 301) & 511)]) + ((0.00664639007f * fVec46[((IOTA - 300) & 511)]) + ((0.00686906464f * fVec46[((IOTA - 299) & 511)]) + ((0.0065569235f * fVec46[((IOTA - 298) & 511)]) + ((0.00557959173f * fVec46[((IOTA - 297) & 511)]) + ((0.00412343536f * fVec46[((IOTA - 296) & 511)]) + ((0.00288938684f * fVec46[((IOTA - 295) & 511)]) + ((0.00236918265f * fVec46[((IOTA - 294) & 511)]) + ((0.00239796564f * fVec46[((IOTA - 293) & 511)]) + ((0.00276320148f * fVec46[((IOTA - 292) & 511)]) + ((0.00345301768f * fVec46[((IOTA - 291) & 511)]) + ((0.00432258612f * fVec46[((IOTA - 290) & 511)]) + ((0.00506436313f * fVec46[((IOTA - 289) & 511)]) + ((0.00534746982f * fVec46[((IOTA - 288) & 511)]) + ((0.00528779346f * fVec46[((IOTA - 287) & 511)]) + ((0.00522307912f * fVec46[((IOTA - 286) & 511)]) + ((0.00489827804f * fVec46[((IOTA - 285) & 511)]) + ((0.0040390701f * fVec46[((IOTA - 284) & 511)]) + ((0.00286778389f * fVec46[((IOTA - 283) & 511)]) + ((0.00206396915f * fVec46[((IOTA - 282) & 511)]) + ((0.00210519135f * fVec46[((IOTA - 281) & 511)]) + ((0.00258162292f * fVec46[((IOTA - 280) & 511)]) + ((0.00303956913f * fVec46[((IOTA - 279) & 511)]) + ((0.00300234603f * fVec46[((IOTA - 277) & 511)]) + ((0.00278099393f * fVec46[((IOTA - 276) & 511)]) + ((0.00316915568f * fVec46[((IOTA - 275) & 511)]) + ((0.00430765934f * fVec46[((IOTA - 274) & 511)]) + ((0.0058712638f * fVec46[((IOTA - 273) & 511)]) + ((0.00711038243f * fVec46[((IOTA - 272) & 511)]) + ((0.00783742126f * fVec46[((IOTA - 271) & 511)]) + ((0.00784557778f * fVec46[((IOTA - 270) & 511)]) + ((0.00691107428f * fVec46[((IOTA - 269) & 511)]) + ((0.00558872428f * fVec46[((IOTA - 268) & 511)]) + ((0.00440972252f * fVec46[((IOTA - 267) & 511)]) + ((0.00374654774f * fVec46[((IOTA - 266) & 511)]) + ((0.00370003516f * fVec46[((IOTA - 265) & 511)]) + ((0.00393889658f * fVec46[((IOTA - 264) & 511)]) + ((0.00460868422f * fVec46[((IOTA - 263) & 511)]) + ((0.00596189592f * fVec46[((IOTA - 262) & 511)]) + ((0.00754458411f * fVec46[((IOTA - 261) & 511)]) + ((0.00894818082f * fVec46[((IOTA - 260) & 511)]) + ((0.00937410071f * fVec46[((IOTA - 259) & 511)]) + ((0.00850339886f * fVec46[((IOTA - 258) & 511)]) + ((0.00724906987f * fVec46[((IOTA - 257) & 511)]) + ((0.00617005304f * fVec46[((IOTA - 256) & 511)]) + ((0.0058879857f * fVec46[((IOTA - 255) & 511)]) + ((0.00639146799f * fVec46[((IOTA - 254) & 511)]) + ((0.00708298525f * fVec46[((IOTA - 253) & 511)]) + ((0.00774552999f * fVec46[((IOTA - 252) & 511)]) + ((0.00321979355f * fVec46[((IOTA - 278) & 511)]) + ((0.00755003188f * fVec46[((IOTA - 251) & 511)]) + ((0.00611362094f * fVec46[((IOTA - 250) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00227848766f * fVec46[((IOTA - 152) & 511)]) + ((0.0024385266f * fVec46[((IOTA - 151) & 511)]) + ((0.00129183475f * fVec46[((IOTA - 150) & 511)]) + ((0.00177276973f * fVec46[((IOTA - 149) & 511)]) + ((0.00244907616f * fVec46[((IOTA - 148) & 511)]) + ((0.00247326121f * fVec46[((IOTA - 147) & 511)]) + ((0.00262243534f * fVec46[((IOTA - 146) & 511)]) + ((0.00144806318f * fVec46[((IOTA - 145) & 511)]) + ((0.000226201955f * fVec46[((IOTA - 134) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((0.25518623f * fVec46[((IOTA - 2) & 511)]) + ((0.0118100457f * fVec46[((IOTA - 15) & 511)]) + ((0.0309515093f * fVec46[((IOTA - 16) & 511)]) + ((0.0924109146f * fVec46[((IOTA - 11) & 511)]) + ((0.00827404764f * fVec46[((IOTA - 14) & 511)]) + ((0.0463821366f * fVec46[((IOTA - 13) & 511)]) + ((0.0881471857f * fVec46[((IOTA - 12) & 511)]) + (((0.225140482f * fVec46[((IOTA - 1) & 511)]) + ((0.223491222f * fVec46[((IOTA - 3) & 511)]) + ((0.115797907f * fVec46[((IOTA - 4) & 511)]) + ((fSlow145 * fTemp0) + (0.0366690345f * fVec46[((IOTA - 10) & 511)]))))) + (0.0268693604f * fVec46[((IOTA - 17) & 511)]))))))))) + (0.0172327161f * fVec46[((IOTA - 18) & 511)])) + (0.0139701571f * fVec46[((IOTA - 23) & 511)])) + (0.0385565571f * fVec46[((IOTA - 24) & 511)])) + (0.0410734341f * fVec46[((IOTA - 25) & 511)])) + (0.0265692472f * fVec46[((IOTA - 26) & 511)])) + (0.0105205085f * fVec46[((IOTA - 27) & 511)])) + (0.0182237774f * fVec46[((IOTA - 35) & 511)])) + (0.0259796362f * fVec46[((IOTA - 36) & 511)])) + (0.0237320736f * fVec46[((IOTA - 37) & 511)])) + (0.0190500133f * fVec46[((IOTA - 38) & 511)])) + (0.0057817027f * fVec46[((IOTA - 39) & 511)])) + (0.0012764358f * fVec46[((IOTA - 41) & 511)])) + (0.00265540695f * fVec46[((IOTA - 42) & 511)])) + (0.0121682584f * fVec46[((IOTA - 49) & 511)])) + (0.0212932006f * fVec46[((IOTA - 50) & 511)])) + (0.0141371554f * fVec46[((IOTA - 51) & 511)])) + (0.00492869876f * fVec46[((IOTA - 52) & 511)])) + (0.00463397196f * fVec46[((IOTA - 59) & 511)])) + (0.0196346808f * fVec46[((IOTA - 60) & 511)])) + (0.0232858732f * fVec46[((IOTA - 61) & 511)])) + (0.0145373465f * fVec46[((IOTA - 62) & 511)])) + (0.00407345872f * fVec46[((IOTA - 63) & 511)])) + (0.00350856828f * fVec46[((IOTA - 72) & 511)])) + (0.0128289135f * fVec46[((IOTA - 73) & 511)])) + (0.0165080391f * fVec46[((IOTA - 74) & 511)])) + (0.00885965955f * fVec46[((IOTA - 75) & 511)])) + (0.00509840529f * fVec46[((IOTA - 80) & 511)])) + (0.0037013581f * fVec46[((IOTA - 81) & 511)])) + (0.0081035858f * fVec46[((IOTA - 98) & 511)])) + (0.0137393577f * fVec46[((IOTA - 99) & 511)])) + (0.0133890808f * fVec46[((IOTA - 100) & 511)])) + (0.00349266548f * fVec46[((IOTA - 101) & 511)])) + (0.00264583342f * fVec46[((IOTA - 108) & 511)])) + (0.00783770531f * fVec46[((IOTA - 109) & 511)])) + (0.00705602858f * fVec46[((IOTA - 110) & 511)])) + (0.00426804321f * fVec46[((IOTA - 111) & 511)])) + (0.000433225185f * fVec46[((IOTA - 112) & 511)])) + (0.000611497555f * fVec46[((IOTA - 120) & 511)])) + (0.00766985631f * fVec46[((IOTA - 129) & 511)])) + (0.0133339074f * fVec46[((IOTA - 130) & 511)])) + (0.016831832f * fVec46[((IOTA - 131) & 511)])) + (0.0144963451f * fVec46[((IOTA - 132) & 511)])) + (0.00749892183f * fVec46[((IOTA - 133) & 511)])) + (0.000944454689f * fVec46[((IOTA - 153) & 511)]))))))))))) + (0.000157015398f * fVec46[((IOTA - 154) & 511)])) + (6.2037725e-05f * fVec46[((IOTA - 165) & 511)])) + (0.00116511388f * fVec46[((IOTA - 166) & 511)])) + (0.00181014976f * fVec46[((IOTA - 167) & 511)])) + (0.00328768883f * fVec46[((IOTA - 168) & 511)])) + (0.00515316846f * fVec46[((IOTA - 169) & 511)])) + (0.00638535898f * fVec46[((IOTA - 170) & 511)])) + (0.00528763607f * fVec46[((IOTA - 171) & 511)])) + (0.00158914411f * fVec46[((IOTA - 172) & 511)])) + (0.00302303582f * fVec46[((IOTA - 178) & 511)])) + (0.00638841372f * fVec46[((IOTA - 179) & 511)])) + (0.00812773965f * fVec46[((IOTA - 180) & 511)])) + (0.00833936036f * fVec46[((IOTA - 181) & 511)])) + (0.00732294843f * fVec46[((IOTA - 182) & 511)])) + (0.00438264012f * fVec46[((IOTA - 183) & 511)])) + (0.000506694429f * fVec46[((IOTA - 184) & 511)])) + (0.0015554484f * fVec46[((IOTA - 187) & 511)])) + (0.00482786354f * fVec46[((IOTA - 188) & 511)])) + (0.00698939292f * fVec46[((IOTA - 189) & 511)])) + (0.00792559702f * fVec46[((IOTA - 190) & 511)])) + (0.00736385584f * fVec46[((IOTA - 191) & 511)])) + (0.00588634843f * fVec46[((IOTA - 192) & 511)])) + (0.00606077816f * fVec46[((IOTA - 193) & 511)])) + (0.00714700669f * fVec46[((IOTA - 194) & 511)])) + (0.00708726794f * fVec46[((IOTA - 195) & 511)])) + (0.00558611052f * fVec46[((IOTA - 196) & 511)])) + (0.00267864764f * fVec46[((IOTA - 197) & 511)])) + (9.47257504e-05f * fVec46[((IOTA - 198) & 511)])) + (0.00107315928f * fVec46[((IOTA - 202) & 511)])) + (0.00208443869f * fVec46[((IOTA - 203) & 511)])) + (0.00219960231f * fVec46[((IOTA - 204) & 511)])) + (0.00228903722f * fVec46[((IOTA - 205) & 511)])) + (0.0037084436f * fVec46[((IOTA - 206) & 511)])) + (0.00610045716f * fVec46[((IOTA - 207) & 511)])) + (0.00824091956f * fVec46[((IOTA - 208) & 511)])) + (0.00892777555f * fVec46[((IOTA - 209) & 511)])) + (0.00774307363f * fVec46[((IOTA - 210) & 511)])) + (0.00503198989f * fVec46[((IOTA - 211) & 511)])) + (0.00219642185f * fVec46[((IOTA - 212) & 511)])) + (0.000637477729f * fVec46[((IOTA - 213) & 511)])) + (0.000470605679f * fVec46[((IOTA - 214) & 511)])) + (0.00158032635f * fVec46[((IOTA - 215) & 511)])) + (0.00301985536f * fVec46[((IOTA - 216) & 511)])) + (0.00378906121f * fVec46[((IOTA - 217) & 511)])) + (0.00489005912f * fVec46[((IOTA - 218) & 511)])) + (0.00653472217f * fVec46[((IOTA - 219) & 511)])) + (0.00784088485f * fVec46[((IOTA - 220) & 511)])) + (0.00819598138f * fVec46[((IOTA - 221) & 511)])) + (0.00732496381f * fVec46[((IOTA - 222) & 511)])) + (0.00578648923f * fVec46[((IOTA - 223) & 511)])) + (0.00455193734f * fVec46[((IOTA - 224) & 511)])) + (0.00416522427f * fVec46[((IOTA - 225) & 511)])) + (0.00458257832f * fVec46[((IOTA - 226) & 511)])) + (0.00575515581f * fVec46[((IOTA - 227) & 511)])) + (0.00701827044f * fVec46[((IOTA - 228) & 511)])) + (0.00748969475f * fVec46[((IOTA - 229) & 511)])) + (0.00716649974f * fVec46[((IOTA - 230) & 511)])) + (0.00626925053f * fVec46[((IOTA - 231) & 511)])) + (0.00546379853f * fVec46[((IOTA - 232) & 511)])) + (0.00500434078f * fVec46[((IOTA - 233) & 511)])) + (0.00441661896f * fVec46[((IOTA - 234) & 511)])) + (0.00400131242f * fVec46[((IOTA - 235) & 511)])) + (0.00411764113f * fVec46[((IOTA - 236) & 511)])) + (0.00455873925f * fVec46[((IOTA - 237) & 511)])) + (0.00538740074f * fVec46[((IOTA - 238) & 511)])) + (0.00623860955f * fVec46[((IOTA - 239) & 511)])) + (0.00634089345f * fVec46[((IOTA - 240) & 511)])) + (0.00572810462f * fVec46[((IOTA - 241) & 511)])) + (0.00472529652f * fVec46[((IOTA - 242) & 511)])) + (0.0034739594f * fVec46[((IOTA - 243) & 511)])) + (0.00210490823f * fVec46[((IOTA - 244) & 511)])) + (0.000837888103f * fVec46[((IOTA - 245) & 511)])) + (0.000153173693f * fVec46[((IOTA - 246) & 511)])) + (0.000532800797f * fVec46[((IOTA - 247) & 511)])) + (0.0019905949f * fVec46[((IOTA - 248) & 511)])) + (0.00405604392f * fVec46[((IOTA - 249) & 511)])) + (0.00448391587f * fVec46[((IOTA - 337) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00470791338f * fVec46[((IOTA - 338) & 511)])) + (0.00432485342f * fVec46[((IOTA - 339) & 511)])) + (0.00306850951f * fVec46[((IOTA - 340) & 511)])) + (0.00170033984f * fVec46[((IOTA - 341) & 511)])) + (0.000498034526f * fVec46[((IOTA - 342) & 511)])) + (0.000507450197f * fVec46[((IOTA - 344) & 511)])) + (0.00135066081f * fVec46[((IOTA - 345) & 511)])) + (0.00235205144f * fVec46[((IOTA - 346) & 511)])) + (0.00383579405f * fVec46[((IOTA - 347) & 511)])) + (0.00496170158f * fVec46[((IOTA - 348) & 511)])) + (0.00519385515f * fVec46[((IOTA - 349) & 511)])) + (0.00485154521f * fVec46[((IOTA - 350) & 511)])) + (0.00407364778f * fVec46[((IOTA - 351) & 511)])) + (0.00304388301f * fVec46[((IOTA - 352) & 511)])) + (0.00164661556f * fVec46[((IOTA - 353) & 511)])) + (0.00137213757f * fVec46[((IOTA - 359) & 511)])) + (0.00258811004f * fVec46[((IOTA - 360) & 511)])) + (0.00272698654f * fVec46[((IOTA - 361) & 511)])) + (0.00181865226f * fVec46[((IOTA - 362) & 511)])) + (0.000281217042f * fVec46[((IOTA - 363) & 511)])) + (0.000483390875f * fVec46[((IOTA - 377) & 511)])) + (0.000664339866f * fVec46[((IOTA - 378) & 511)])) + (0.000217573252f * fVec46[((IOTA - 379) & 511)])) + (0.000207338482f * fVec46[((IOTA - 386) & 511)])) + (0.000240971334f * fVec46[((IOTA - 387) & 511)])) + (0.000246419106f * fVec46[((IOTA - 400) & 511)])) + (6.48722053e-05f * fVec46[((IOTA - 401) & 511)])) + (0.000564795919f * fVec46[((IOTA - 425) & 511)])) + (0.00139896804f * fVec46[((IOTA - 426) & 511)])) + (0.0013723583f * fVec46[((IOTA - 427) & 511)])) + (0.000846264884f * fVec46[((IOTA - 428) & 511)])) + (0.000164668076f * fVec46[((IOTA - 429) & 511)])) + (0.00023687724f * fVec46[((IOTA - 469) & 511)])) + (0.00139934616f * fVec46[((IOTA - 470) & 511)])) + (0.00181638496f * fVec46[((IOTA - 471) & 511)])) + (0.0014840574f * fVec46[((IOTA - 472) & 511)])) + (0.000538406428f * fVec46[((IOTA - 473) & 511)])) + (0.000854861923f * fVec46[((IOTA - 494) & 511)])) + (0.0018406962f * fVec46[((IOTA - 495) & 511)])) + (0.00214707479f * fVec46[((IOTA - 496) & 511)])) + (0.00133545045f * fVec46[((IOTA - 497) & 511)])) - ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00640450558f * fVec46[((IOTA - 443) & 511)]) + ((0.00712420698f * fVec46[((IOTA - 442) & 511)]) + ((0.00688106287f * fVec46[((IOTA - 441) & 511)]) + ((0.0062367199f * fVec46[((IOTA - 440) & 511)]) + ((0.00576611469f * fVec46[((IOTA - 439) & 511)]) + ((0.00534019526f * fVec46[((IOTA - 438) & 511)]) + ((0.00523265265f * fVec46[((IOTA - 437) & 511)]) + ((0.00512504671f * fVec46[((IOTA - 436) & 511)]) + ((0.00503620971f * fVec46[((IOTA - 435) & 511)]) + ((0.00519429613f * fVec46[((IOTA - 434) & 511)]) + ((0.00501756696f * fVec46[((IOTA - 433) & 511)]) + ((0.00417741155f * fVec46[((IOTA - 432) & 511)]) + ((0.00276883831f * fVec46[((IOTA - 431) & 511)]) + ((0.00107432483f * fVec46[((IOTA - 430) & 511)]) + ((0.000631462783f * fVec46[((IOTA - 424) & 511)]) + ((0.00164894573f * fVec46[((IOTA - 423) & 511)]) + ((0.00199812092f * fVec46[((IOTA - 422) & 511)]) + ((0.0015537478f * fVec46[((IOTA - 421) & 511)]) + ((0.00110880751f * fVec46[((IOTA - 420) & 511)]) + ((0.000930944923f * fVec46[((IOTA - 419) & 511)]) + ((0.00110786268f * fVec46[((IOTA - 418) & 511)]) + ((0.00220284564f * fVec46[((IOTA - 417) & 511)]) + ((0.0035293526f * fVec46[((IOTA - 416) & 511)]) + ((0.00438748952f * fVec46[((IOTA - 415) & 511)]) + ((0.00481888885f * fVec46[((IOTA - 414) & 511)]) + ((0.00434765313f * fVec46[((IOTA - 413) & 511)]) + ((0.00298505742f * fVec46[((IOTA - 412) & 511)]) + ((0.00152168982f * fVec46[((IOTA - 411) & 511)]) + ((0.000380351674f * fVec46[((IOTA - 410) & 511)]) + ((0.000318030361f * fVec46[((IOTA - 409) & 511)]) + ((0.00138252974f * fVec46[((IOTA - 408) & 511)]) + ((0.0023695291f * fVec46[((IOTA - 407) & 511)]) + ((0.00314846588f * fVec46[((IOTA - 406) & 511)]) + ((0.00362593634f * fVec46[((IOTA - 405) & 511)]) + ((0.00343742967f * fVec46[((IOTA - 404) & 511)]) + ((0.00260583963f * fVec46[((IOTA - 403) & 511)]) + ((0.00116936537f * fVec46[((IOTA - 402) & 511)]) + ((0.000656341203f * fVec46[((IOTA - 399) & 511)]) + ((0.00265751686f * fVec46[((IOTA - 398) & 511)]) + ((0.00454875641f * fVec46[((IOTA - 397) & 511)]) + ((0.00500260852f * fVec46[((IOTA - 396) & 511)]) + ((0.00441416306f * fVec46[((IOTA - 395) & 511)]) + ((0.00364102051f * fVec46[((IOTA - 394) & 511)]) + ((0.0032646684f * fVec46[((IOTA - 393) & 511)]) + ((0.00335130095f * fVec46[((IOTA - 392) & 511)]) + ((0.00300644012f * fVec46[((IOTA - 391) & 511)]) + ((0.00197626604f * fVec46[((IOTA - 390) & 511)]) + ((0.00110112363f * fVec46[((IOTA - 389) & 511)]) + ((0.000339948107f * fVec46[((IOTA - 388) & 511)]) + ((0.000170525163f * fVec46[((IOTA - 385) & 511)]) + ((0.00103662955f * fVec46[((IOTA - 384) & 511)]) + ((0.00226239581f * fVec46[((IOTA - 383) & 511)]) + ((0.00266145309f * fVec46[((IOTA - 382) & 511)]) + ((0.00186299207f * fVec46[((IOTA - 381) & 511)]) + ((0.000698003918f * fVec46[((IOTA - 380) & 511)]) + ((9.05687921e-05f * fVec46[((IOTA - 376) & 511)]) + ((0.000969364308f * fVec46[((IOTA - 375) & 511)]) + ((0.00205064844f * fVec46[((IOTA - 374) & 511)]) + ((0.00291691022f * fVec46[((IOTA - 373) & 511)]) + ((0.00323752314f * fVec46[((IOTA - 372) & 511)]) + ((0.00296524959f * fVec46[((IOTA - 371) & 511)]) + ((0.00237400085f * fVec46[((IOTA - 370) & 511)]) + ((0.0019415943f * fVec46[((IOTA - 369) & 511)]) + ((0.00178583851f * fVec46[((IOTA - 368) & 511)]) + ((0.00183184724f * fVec46[((IOTA - 367) & 511)]) + ((0.00185946515f * fVec46[((IOTA - 366) & 511)]) + ((0.00152509054f * fVec46[((IOTA - 365) & 511)]) + ((0.000903295819f * fVec46[((IOTA - 364) & 511)]) + ((0.00057651056f * fVec46[((IOTA - 358) & 511)]) + ((0.00239783991f * fVec46[((IOTA - 357) & 511)]) + ((0.00317910686f * fVec46[((IOTA - 356) & 511)]) + ((0.00243329909f * fVec46[((IOTA - 355) & 511)]) + ((0.00043832697f * fVec46[((IOTA - 354) & 511)]) + ((5.60544431e-05f * fVec46[((IOTA - 343) & 511)]) + ((0.000507639255f * fVec46[((IOTA - 328) & 511)]) + ((0.00186097668f * fVec46[((IOTA - 327) & 511)]) + ((0.00214653928f * fVec46[((IOTA - 326) & 511)]) + ((0.00126176095f * fVec46[((IOTA - 325) & 511)]) + ((0.000126311556f * fVec46[((IOTA - 324) & 511)]) + ((0.000111415982f * fVec46[((IOTA - 319) & 511)]) + ((0.000761742238f * fVec46[((IOTA - 318) & 511)]) + ((0.00090487022f * fVec46[((IOTA - 317) & 511)]) + ((0.000418109819f * fVec46[((IOTA - 316) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0621742532f * fVec46[((IOTA - 5) & 511)]) + ((0.19163911f * fVec46[((IOTA - 6) & 511)]) + (((0.24571152f * fVec46[((IOTA - 7) & 511)]) + (0.203438208f * fVec46[((IOTA - 8) & 511)])) + (0.0787723884f * fVec46[((IOTA - 9) & 511)])))) + (0.000474604778f * fVec46[((IOTA - 19) & 511)])) + (0.02386906f * fVec46[((IOTA - 20) & 511)])) + (0.0279447548f * fVec46[((IOTA - 21) & 511)])) + (0.0133117065f * fVec46[((IOTA - 22) & 511)])) + (0.00685980637f * fVec46[((IOTA - 28) & 511)])) + (0.0285413563f * fVec46[((IOTA - 29) & 511)])) + (0.0510413647f * fVec46[((IOTA - 30) & 511)])) + (0.0694556311f * fVec46[((IOTA - 31) & 511)])) + (0.0646898076f * fVec46[((IOTA - 32) & 511)])) + (0.0369835049f * fVec46[((IOTA - 33) & 511)])) + (0.00701650698f * fVec46[((IOTA - 34) & 511)])) + (0.00144163892f * fVec46[((IOTA - 40) & 511)])) + (0.00881122611f * fVec46[((IOTA - 43) & 511)])) + (0.0384578332f * fVec46[((IOTA - 44) & 511)])) + (0.0573558062f * fVec46[((IOTA - 45) & 511)])) + (0.0489245541f * fVec46[((IOTA - 46) & 511)])) + (0.0311531164f * fVec46[((IOTA - 47) & 511)])) + (0.0101406295f * fVec46[((IOTA - 48) & 511)])) + (0.00936934538f * fVec46[((IOTA - 53) & 511)])) + (0.0252766255f * fVec46[((IOTA - 54) & 511)])) + (0.0326914638f * fVec46[((IOTA - 55) & 511)])) + (0.0374407582f * fVec46[((IOTA - 56) & 511)])) + (0.0319648348f * fVec46[((IOTA - 57) & 511)])) + (0.0137900272f * fVec46[((IOTA - 58) & 511)])) + (0.00841043703f * fVec46[((IOTA - 64) & 511)])) + (0.0212662444f * fVec46[((IOTA - 65) & 511)])) + (0.0302442797f * fVec46[((IOTA - 66) & 511)])) + (0.0362849645f * fVec46[((IOTA - 67) & 511)])) + (0.0378857292f * fVec46[((IOTA - 68) & 511)])) + (0.0329273976f * fVec46[((IOTA - 69) & 511)])) + (0.0214829668f * fVec46[((IOTA - 70) & 511)])) + (0.00770550454f * fVec46[((IOTA - 71) & 511)])) + (0.00471122004f * fVec46[((IOTA - 76) & 511)])) + (0.0129461866f * fVec46[((IOTA - 77) & 511)])) + (0.0141297868f * fVec46[((IOTA - 78) & 511)])) + (0.00631481828f * fVec46[((IOTA - 79) & 511)])) + (0.00361271016f * fVec46[((IOTA - 82) & 511)])) + (0.010009815f * fVec46[((IOTA - 83) & 511)])) + (0.0164479855f * fVec46[((IOTA - 84) & 511)])) + (0.0187847316f * fVec46[((IOTA - 85) & 511)])) + (0.0203538164f * fVec46[((IOTA - 86) & 511)])) + (0.0214606076f * fVec46[((IOTA - 87) & 511)])) + (0.0195964202f * fVec46[((IOTA - 88) & 511)])) + (0.0162720438f * fVec46[((IOTA - 89) & 511)])) + (0.0124660712f * fVec46[((IOTA - 90) & 511)])) + (0.00623905053f * fVec46[((IOTA - 91) & 511)])) + (0.00244920189f * fVec46[((IOTA - 92) & 511)])) + (0.00336014992f * fVec46[((IOTA - 93) & 511)])) + (0.00457996456f * fVec46[((IOTA - 94) & 511)])) + (0.00682469364f * fVec46[((IOTA - 95) & 511)])) + (0.00674080104f * fVec46[((IOTA - 96) & 511)])) + (0.000173359644f * fVec46[((IOTA - 97) & 511)])) + (0.0116529353f * fVec46[((IOTA - 102) & 511)])) + (0.0250720903f * fVec46[((IOTA - 103) & 511)])) + (0.0310353078f * fVec46[((IOTA - 104) & 511)])) + (0.0283196904f * fVec46[((IOTA - 105) & 511)])) + (0.0184490662f * fVec46[((IOTA - 106) & 511)])) + (0.00672351196f * fVec46[((IOTA - 107) & 511)])) + (0.00614851294f * fVec46[((IOTA - 113) & 511)])) + (0.012880276f * fVec46[((IOTA - 114) & 511)])) + (0.0174381956f * fVec46[((IOTA - 115) & 511)])) + (0.0180388913f * fVec46[((IOTA - 116) & 511)])) + (0.01336521f * fVec46[((IOTA - 117) & 511)])) + (0.00730871456f * fVec46[((IOTA - 118) & 511)])) + (0.00204630289f * fVec46[((IOTA - 119) & 511)])) + (0.00158989988f * fVec46[((IOTA - 121) & 511)])) + (0.00661414303f * fVec46[((IOTA - 122) & 511)])) + (0.0118888989f * fVec46[((IOTA - 123) & 511)])) + (0.016360566f * fVec46[((IOTA - 124) & 511)])) + (0.0170310456f * fVec46[((IOTA - 125) & 511)])) + (0.0130555248f * fVec46[((IOTA - 126) & 511)])) + (0.00774861593f * fVec46[((IOTA - 127) & 511)])) + (0.000213983003f * fVec46[((IOTA - 128) & 511)])) + (0.00619946606f * fVec46[((IOTA - 135) & 511)])) + (0.00867282227f * fVec46[((IOTA - 136) & 511)])) + (0.00734259887f * fVec46[((IOTA - 137) & 511)])) + (0.00577965565f * fVec46[((IOTA - 138) & 511)])) + (0.00378862023f * fVec46[((IOTA - 139) & 511)])) + (0.00343947671f * fVec46[((IOTA - 140) & 511)])) + (0.00529544614f * fVec46[((IOTA - 141) & 511)])) + (0.00590511691f * fVec46[((IOTA - 142) & 511)])) + (0.00392289925f * fVec46[((IOTA - 143) & 511)])) + (0.00106405839f * fVec46[((IOTA - 144) & 511)])) + (0.0013967636f * fVec46[((IOTA - 155) & 511)])) + (0.00271347677f * fVec46[((IOTA - 156) & 511)])) + (0.00365667185f * fVec46[((IOTA - 157) & 511)])) + (0.00509024877f * fVec46[((IOTA - 158) & 511)])) + (0.00558815757f * fVec46[((IOTA - 159) & 511)])) + (0.005254413f * fVec46[((IOTA - 160) & 511)])) + (0.00495751342f * fVec46[((IOTA - 161) & 511)])) + (0.00434418907f * fVec46[((IOTA - 162) & 511)])) + (0.0030871206f * fVec46[((IOTA - 163) & 511)])) + (0.00155847147f * fVec46[((IOTA - 164) & 511)])) + (0.00154376496f * fVec46[((IOTA - 173) & 511)])) + (0.00355942687f * fVec46[((IOTA - 174) & 511)])) + (0.00490205688f * fVec46[((IOTA - 175) & 511)])) + (0.00392447365f * fVec46[((IOTA - 176) & 511)])) + (0.000843178947f * fVec46[((IOTA - 177) & 511)])) + (0.00139477989f * fVec46[((IOTA - 185) & 511)])) + (0.000868938398f * fVec46[((IOTA - 186) & 511)])) + (0.000961869489f * fVec46[((IOTA - 199) & 511)])) + (0.000889250543f * fVec46[((IOTA - 200) & 511)])) + (8.15307721e-05f * fVec46[((IOTA - 201) & 511)])) + (0.00550246984f * fVec46[((IOTA - 444) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00450048037f * fVec46[((IOTA - 445) & 511)])) + (0.00336304726f * fVec46[((IOTA - 446) & 511)])) + (0.00254821079f * fVec46[((IOTA - 447) & 511)])) + (0.00188620109f * fVec46[((IOTA - 448) & 511)])) + (0.00144642545f * fVec46[((IOTA - 449) & 511)])) + (0.00152657088f * fVec46[((IOTA - 450) & 511)])) + (0.001745624f * fVec46[((IOTA - 451) & 511)])) + (0.00228869123f * fVec46[((IOTA - 452) & 511)])) + (0.00301440759f * fVec46[((IOTA - 453) & 511)])) + (0.00334578985f * fVec46[((IOTA - 454) & 511)])) + (0.00380276004f * fVec46[((IOTA - 455) & 511)])) + (0.00455307076f * fVec46[((IOTA - 456) & 511)])) + (0.00487969816f * fVec46[((IOTA - 457) & 511)])) + (0.00475124549f * fVec46[((IOTA - 458) & 511)])) + (0.00401208224f * fVec46[((IOTA - 459) & 511)])) + (0.00279834587f * fVec46[((IOTA - 460) & 511)])) + (0.00228743162f * fVec46[((IOTA - 461) & 511)])) + (0.00258089835f * fVec46[((IOTA - 462) & 511)])) + (0.00318861706f * fVec46[((IOTA - 463) & 511)])) + (0.00390283903f * fVec46[((IOTA - 464) & 511)])) + (0.00409795903f * fVec46[((IOTA - 465) & 511)])) + (0.00360748265f * fVec46[((IOTA - 466) & 511)])) + (0.00270043919f * fVec46[((IOTA - 467) & 511)])) + (0.00132423919f * fVec46[((IOTA - 468) & 511)])) + (0.000701090321f * fVec46[((IOTA - 474) & 511)])) + (0.00214915304f * fVec46[((IOTA - 475) & 511)])) + (0.00332447048f * fVec46[((IOTA - 476) & 511)])) + (0.00346284313f * fVec46[((IOTA - 477) & 511)])) + (0.00297252415f * fVec46[((IOTA - 478) & 511)])) + (0.00213784771f * fVec46[((IOTA - 479) & 511)])) + (0.00157664204f * fVec46[((IOTA - 480) & 511)])) + (0.00189410523f * fVec46[((IOTA - 481) & 511)])) + (0.00238310173f * fVec46[((IOTA - 482) & 511)])) + (0.00281711435f * fVec46[((IOTA - 483) & 511)])) + (0.00307389442f * fVec46[((IOTA - 484) & 511)])) + (0.00289867679f * fVec46[((IOTA - 485) & 511)])) + (0.00284892088f * fVec46[((IOTA - 486) & 511)])) + (0.00268393802f * fVec46[((IOTA - 487) & 511)])) + (0.00206434727f * fVec46[((IOTA - 488) & 511)])) + (0.00176999811f * fVec46[((IOTA - 489) & 511)])) + (0.00153393997f * fVec46[((IOTA - 490) & 511)])) + (0.00110487128f * fVec46[((IOTA - 491) & 511)])) + (0.000860341359f * fVec46[((IOTA - 492) & 511)])) + (0.000274603721f * fVec46[((IOTA - 493) & 511)])) + (0.000395467505f * fVec46[((IOTA - 498) & 511)])) + (0.00219201297f * fVec46[((IOTA - 499) & 511)])) + (0.00373237673f * fVec46[((IOTA - 500) & 511)])) + (0.00479057804f * fVec46[((IOTA - 501) & 511)])) + (0.0048952233f * fVec46[((IOTA - 502) & 511)])) + (0.00449314294f * fVec46[((IOTA - 503) & 511)])) + (0.00407323847f * fVec46[((IOTA - 504) & 511)])) + (0.00385264214f * fVec46[((IOTA - 505) & 511)])) + (0.00425982429f * fVec46[((IOTA - 506) & 511)])) + (0.00486467686f * fVec46[((IOTA - 507) & 511)])) + (0.00527570117f * fVec46[((IOTA - 508) & 511)])) + (0.00567563996f * fVec46[((IOTA - 509) & 511)])) + (0.00571550801f * fVec46[((IOTA - 510) & 511)])) + (0.0052442099f * fVec46[((IOTA - 511) & 511)])))) : (iSlow138 ? ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00530363154f * fVec45[((IOTA - 110) & 511)]) + ((0.00285309227f * fVec45[((IOTA - 109) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((fSlow142 * fTemp0) + (0.20052518f * fVec45[((IOTA - 1) & 511)])) + (0.240813956f * fVec45[((IOTA - 2) & 511)])) + (0.251487345f * fVec45[((IOTA - 3) & 511)])) + (0.192863181f * fVec45[((IOTA - 4) & 511)])) + (0.0533908568f * fVec45[((IOTA - 5) & 511)])) + (0.025502203f * fVec45[((IOTA - 11) & 511)])) + (0.0626509041f * fVec45[((IOTA - 12) & 511)])) + (0.0725587979f * fVec45[((IOTA - 13) & 511)])) + (0.0514061823f * fVec45[((IOTA - 14) & 511)])) + (0.03563454f * fVec45[((IOTA - 15) & 511)])) + (0.0281412788f * fVec45[((IOTA - 16) & 511)])) + (0.0196455941f * fVec45[((IOTA - 17) & 511)])) + (0.0172488056f * fVec45[((IOTA - 18) & 511)])) + (0.00958224572f * fVec45[((IOTA - 19) & 511)])) + (0.0137044443f * fVec45[((IOTA - 24) & 511)])) + (0.0277740136f * fVec45[((IOTA - 25) & 511)])) + (0.0313468017f * fVec45[((IOTA - 26) & 511)])) + (0.0239053685f * fVec45[((IOTA - 27) & 511)])) + (0.0108719599f * fVec45[((IOTA - 28) & 511)])) + (0.0161287282f * fVec45[((IOTA - 37) & 511)])) + (0.0316005424f * fVec45[((IOTA - 38) & 511)])) + (0.0355179124f * fVec45[((IOTA - 39) & 511)])) + (0.0327653103f * fVec45[((IOTA - 40) & 511)])) + (0.020840589f * fVec45[((IOTA - 41) & 511)])) + (0.00131649664f * fVec45[((IOTA - 42) & 511)])) + (0.0103729507f * fVec45[((IOTA - 50) & 511)])) + (0.0107209748f * fVec45[((IOTA - 51) & 511)])) + (0.00964291859f * fVec45[((IOTA - 52) & 511)])) + (0.000490070786f * fVec45[((IOTA - 53) & 511)])) + (0.00330616906f * fVec45[((IOTA - 61) & 511)])) + (0.00678622676f * fVec45[((IOTA - 62) & 511)])) + (0.0085607972f * fVec45[((IOTA - 63) & 511)])) + (0.00213038456f * fVec45[((IOTA - 64) & 511)])) + (0.0064343228f * fVec45[((IOTA - 72) & 511)])) + (0.0110103749f * fVec45[((IOTA - 73) & 511)])) + (0.00595561089f * fVec45[((IOTA - 74) & 511)])) + (0.00598400785f * fVec45[((IOTA - 80) & 511)])) + (0.0114075579f * fVec45[((IOTA - 81) & 511)])) + (0.0080387909f * fVec45[((IOTA - 82) & 511)])) + (0.00487712026f * fVec45[((IOTA - 97) & 511)])) + (0.0110441707f * fVec45[((IOTA - 98) & 511)])) + (0.014754165f * fVec45[((IOTA - 99) & 511)])) + (0.0117994966f * fVec45[((IOTA - 100) & 511)])) + (0.0024838401f * fVec45[((IOTA - 101) & 511)])) + (0.00336460769f * fVec45[((IOTA - 111) & 511)])))) + (0.00169186248f * fVec45[((IOTA - 119) & 511)])) + (0.0038040299f * fVec45[((IOTA - 120) & 511)])) + (0.00458185514f * fVec45[((IOTA - 128) & 511)])) + (0.0160797238f * fVec45[((IOTA - 129) & 511)])) + (0.0208026953f * fVec45[((IOTA - 130) & 511)])) + (0.0192026012f * fVec45[((IOTA - 131) & 511)])) + (0.0119239148f * fVec45[((IOTA - 132) & 511)])) + (0.00430952478f * fVec45[((IOTA - 133) & 511)])) + (0.00354460953f * fVec45[((IOTA - 144) & 511)])) + (0.0093799606f * fVec45[((IOTA - 145) & 511)])) + (0.0109368842f * fVec45[((IOTA - 146) & 511)])) + (0.00734212203f * fVec45[((IOTA - 147) & 511)])) + (0.00299675204f * fVec45[((IOTA - 148) & 511)])) + (0.00151788164f * fVec45[((IOTA - 154) & 511)])) + (0.00537054287f * fVec45[((IOTA - 155) & 511)])) + (0.00677306764f * fVec45[((IOTA - 156) & 511)])) + (0.00577821583f * fVec45[((IOTA - 157) & 511)])) + (0.00106815621f * fVec45[((IOTA - 158) & 511)])) + (0.000973189715f * fVec45[((IOTA - 165) & 511)])) + (0.00709896442f * fVec45[((IOTA - 166) & 511)])) + (0.0117764063f * fVec45[((IOTA - 167) & 511)])) + (0.0128987189f * fVec45[((IOTA - 168) & 511)])) + (0.0103051085f * fVec45[((IOTA - 169) & 511)])) + (0.00571509125f * fVec45[((IOTA - 170) & 511)])) + (0.000925613102f * fVec45[((IOTA - 171) & 511)])) + (2.73417681e-05f * fVec45[((IOTA - 176) & 511)])) + (0.00373845315f * fVec45[((IOTA - 177) & 511)])) + (0.00640012231f * fVec45[((IOTA - 178) & 511)])) + (0.00780112669f * fVec45[((IOTA - 179) & 511)])) + (0.00789367221f * fVec45[((IOTA - 180) & 511)])) + (0.00622654473f * fVec45[((IOTA - 181) & 511)])) + (0.00406853948f * fVec45[((IOTA - 182) & 511)])) + (0.00252986467f * fVec45[((IOTA - 183) & 511)])) + (0.00178285688f * fVec45[((IOTA - 184) & 511)])) + (0.00267678313f * fVec45[((IOTA - 185) & 511)])) + (0.00433711475f * fVec45[((IOTA - 186) & 511)])) + (0.00593280047f * fVec45[((IOTA - 187) & 511)])) + (0.00721841725f * fVec45[((IOTA - 188) & 511)])) + (0.00725475932f * fVec45[((IOTA - 189) & 511)])) + (0.00705833966f * fVec45[((IOTA - 190) & 511)])) + (0.00805334747f * fVec45[((IOTA - 191) & 511)])) + (0.00981292687f * fVec45[((IOTA - 192) & 511)])) + (0.0111890109f * fVec45[((IOTA - 193) & 511)])) + (0.0112959566f * fVec45[((IOTA - 194) & 511)])) + (0.00927320123f * fVec45[((IOTA - 195) & 511)])) + (0.00577849522f * fVec45[((IOTA - 196) & 511)])) + (0.00260922033f * fVec45[((IOTA - 197) & 511)])) + (0.000926761422f * fVec45[((IOTA - 198) & 511)])) + (0.000333934557f * fVec45[((IOTA - 199) & 511)])) + (0.00210276339f * fVec45[((IOTA - 203) & 511)])) + (0.00453322334f * fVec45[((IOTA - 204) & 511)])) + (0.00724985544f * fVec45[((IOTA - 205) & 511)])) + (0.00924129784f * fVec45[((IOTA - 206) & 511)])) + (0.00991230085f * fVec45[((IOTA - 207) & 511)])) + (0.00899972208f * fVec45[((IOTA - 208) & 511)])) + (0.00655138632f * fVec45[((IOTA - 209) & 511)])) + (0.00513744028f * fVec45[((IOTA - 210) & 511)])) + (0.00607754663f * fVec45[((IOTA - 211) & 511)])) + (0.00804316718f * fVec45[((IOTA - 212) & 511)])) + (0.0096301632f * fVec45[((IOTA - 213) & 511)])) + (0.00981469639f * fVec45[((IOTA - 214) & 511)])) + (0.00810073689f * fVec45[((IOTA - 215) & 511)])) + (0.00514364708f * fVec45[((IOTA - 216) & 511)])) + (0.00208035624f * fVec45[((IOTA - 217) & 511)])) + (0.000101794023f * fVec45[((IOTA - 218) & 511)])) + (0.000346720684f * fVec45[((IOTA - 219) & 511)])) + (0.00220247824f * fVec45[((IOTA - 220) & 511)])) + (0.0046375934f * fVec45[((IOTA - 221) & 511)])) + (0.00739208795f * fVec45[((IOTA - 222) & 511)])) + (0.0096327085f * fVec45[((IOTA - 223) & 511)])) + (0.0109434323f * fVec45[((IOTA - 224) & 511)])) + (0.0113406777f * fVec45[((IOTA - 225) & 511)])) + (0.0108855218f * fVec45[((IOTA - 226) & 511)])) + (0.0104872212f * fVec45[((IOTA - 227) & 511)])) + (0.0100849476f * fVec45[((IOTA - 228) & 511)])) + (0.00930975936f * fVec45[((IOTA - 229) & 511)])) + (0.00857361406f * fVec45[((IOTA - 230) & 511)])) + (0.00784476195f * fVec45[((IOTA - 231) & 511)])) + (0.00761476299f * fVec45[((IOTA - 232) & 511)])) + (0.00784861017f * fVec45[((IOTA - 233) & 511)])) + (0.00784383062f * fVec45[((IOTA - 234) & 511)])) + (0.00742337108f * fVec45[((IOTA - 235) & 511)])) + (0.00693317642f * fVec45[((IOTA - 236) & 511)])) + (0.00675118808f * fVec45[((IOTA - 237) & 511)])) + (0.00710644387f * fVec45[((IOTA - 238) & 511)])) + (0.00819346868f * fVec45[((IOTA - 239) & 511)])) + (0.00941170938f * fVec45[((IOTA - 240) & 511)])) + (0.00984417927f * fVec45[((IOTA - 241) & 511)])) + (0.00909686089f * fVec45[((IOTA - 242) & 511)])) + (0.00655160332f * fVec45[((IOTA - 243) & 511)])) + (0.00287174387f * fVec45[((IOTA - 244) & 511)])) + (0.00106458692f * fVec45[((IOTA - 248) & 511)])) + (0.00447351253f * fVec45[((IOTA - 249) & 511)])) + (0.00811501313f * fVec45[((IOTA - 250) & 511)])) + (0.0105591286f * fVec45[((IOTA - 251) & 511)])) + (0.0113133984f * fVec45[((IOTA - 252) & 511)])) + (0.0112162596f * fVec45[((IOTA - 253) & 511)])) + (0.0105393585f * fVec45[((IOTA - 254) & 511)])) + (0.00919989683f * fVec45[((IOTA - 255) & 511)])) + (0.00778498873f * fVec45[((IOTA - 256) & 511)])) + (0.00725550391f * fVec45[((IOTA - 257) & 511)])) + (0.00783632044f * fVec45[((IOTA - 258) & 511)])) + (0.00914601982f * fVec45[((IOTA - 259) & 511)])) + (0.0103874132f * fVec45[((IOTA - 260) & 511)])) + (0.0108646043f * fVec45[((IOTA - 261) & 511)])) + (0.0100542847f * fVec45[((IOTA - 262) & 511)])) + (0.00812274031f * fVec45[((IOTA - 263) & 511)])) + (0.00600905297f * fVec45[((IOTA - 264) & 511)])) + (0.00468309084f * fVec45[((IOTA - 265) & 511)])) + (0.00497751776f * fVec45[((IOTA - 266) & 511)])) + (0.00678361952f * fVec45[((IOTA - 267) & 511)])) + (0.00916681346f * fVec45[((IOTA - 268) & 511)])) + (0.0109788738f * fVec45[((IOTA - 269) & 511)])) + (0.0116297984f * fVec45[((IOTA - 270) & 511)])) + (0.0111591555f * fVec45[((IOTA - 271) & 511)])) + (0.00986630656f * fVec45[((IOTA - 272) & 511)])) + (0.00850505847f * fVec45[((IOTA - 273) & 511)])) + (0.00753630698f * fVec45[((IOTA - 274) & 511)])) + (0.00662332494f * fVec45[((IOTA - 275) & 511)])) + (0.00566962501f * fVec45[((IOTA - 276) & 511)])) + (0.00485561322f * fVec45[((IOTA - 277) & 511)])) + (0.00410506735f * fVec45[((IOTA - 278) & 511)])) + (0.00327407941f * fVec45[((IOTA - 279) & 511)])) + (0.00283335382f * fVec45[((IOTA - 280) & 511)])) + (0.00345389498f * fVec45[((IOTA - 281) & 511)])) + (0.00503487f * fVec45[((IOTA - 282) & 511)])) + (0.00673210202f * fVec45[((IOTA - 283) & 511)])) + (0.00794975273f * fVec45[((IOTA - 284) & 511)])) + (0.00831832178f * fVec45[((IOTA - 285) & 511)])) + (0.00779591314f * fVec45[((IOTA - 286) & 511)])) + (0.00686626555f * fVec45[((IOTA - 287) & 511)])) + (0.00581952324f * fVec45[((IOTA - 288) & 511)])) + (0.00482656434f * fVec45[((IOTA - 289) & 511)])) + (0.00376641564f * fVec45[((IOTA - 290) & 511)])) + (0.00264568627f * fVec45[((IOTA - 291) & 511)])) + (0.00198898977f * fVec45[((IOTA - 292) & 511)])) + (0.00228717225f * fVec45[((IOTA - 293) & 511)])) + (0.00296155876f * fVec45[((IOTA - 294) & 511)])) + (0.00362567278f * fVec45[((IOTA - 295) & 511)])) + (0.00467055244f * fVec45[((IOTA - 296) & 511)])) + (0.00567142526f * fVec45[((IOTA - 297) & 511)])) + (0.00668554986f * fVec45[((IOTA - 298) & 511)])) + (0.00780975446f * fVec45[((IOTA - 299) & 511)])) + (0.0090252012f * fVec45[((IOTA - 300) & 511)])) + (0.0110647166f * fVec45[((IOTA - 301) & 511)])) + (0.0128197661f * fVec45[((IOTA - 302) & 511)])) + (0.012470345f * fVec45[((IOTA - 303) & 511)])) + (0.0100592198f * fVec45[((IOTA - 304) & 511)])) + (0.00664458377f * fVec45[((IOTA - 305) & 511)])) + (0.00346680544f * fVec45[((IOTA - 306) & 511)])) + (0.00189554412f * fVec45[((IOTA - 307) & 511)])) + (0.00220499234f * fVec45[((IOTA - 308) & 511)])) + (0.00336817699f * fVec45[((IOTA - 309) & 511)])) + (0.00448968168f * fVec45[((IOTA - 310) & 511)])) + (0.00543565396f * fVec45[((IOTA - 311) & 511)])) + (0.0064004329f * fVec45[((IOTA - 312) & 511)])) + (0.00779721653f * fVec45[((IOTA - 313) & 511)])) + (0.00884209666f * fVec45[((IOTA - 314) & 511)])) + (0.00836450234f * fVec45[((IOTA - 315) & 511)])) + (0.00615885807f * fVec45[((IOTA - 316) & 511)])) + (0.00302092824f * fVec45[((IOTA - 317) & 511)])) + (0.000292720273f * fVec45[((IOTA - 318) & 511)])) + (0.000547702424f * fVec45[((IOTA - 322) & 511)])) + (0.000745145604f * fVec45[((IOTA - 323) & 511)])) + (0.000515581109f * fVec45[((IOTA - 324) & 511)])) + (9.75113362e-05f * fVec45[((IOTA - 325) & 511)])) + (0.000361400191f * fVec45[((IOTA - 327) & 511)])) + (0.00119285379f * fVec45[((IOTA - 328) & 511)])) + (0.00227460312f * fVec45[((IOTA - 329) & 511)])) + (0.00287435111f * fVec45[((IOTA - 330) & 511)])) + (0.00264627626f * fVec45[((IOTA - 331) & 511)])) + (0.00233062124f * fVec45[((IOTA - 332) & 511)])) + (0.00224319613f * fVec45[((IOTA - 333) & 511)])) + (0.00206819084f * fVec45[((IOTA - 334) & 511)])) + (0.00196279632f * fVec45[((IOTA - 335) & 511)])) + (0.0026919595f * fVec45[((IOTA - 336) & 511)])) + (0.00443205005f * fVec45[((IOTA - 337) & 511)])) + (0.00651793042f * fVec45[((IOTA - 338) & 511)])) + (0.00748090958f * fVec45[((IOTA - 339) & 511)])) + (0.00666907011f * fVec45[((IOTA - 340) & 511)])) + (0.00518045435f * fVec45[((IOTA - 341) & 511)])) + (0.00337779755f * fVec45[((IOTA - 342) & 511)])) + (0.00168919377f * fVec45[((IOTA - 343) & 511)])) + (0.00079765683f * fVec45[((IOTA - 344) & 511)])) + (0.000443953089f * fVec45[((IOTA - 345) & 511)])) + (0.000712900423f * fVec45[((IOTA - 346) & 511)])) + (0.00170073844f * fVec45[((IOTA - 347) & 511)])) + (0.00297512114f * fVec45[((IOTA - 348) & 511)])) + (0.00448530586f * fVec45[((IOTA - 349) & 511)])) + (0.00589562068f * fVec45[((IOTA - 350) & 511)])) + (0.00616025459f * fVec45[((IOTA - 351) & 511)])) + (0.00481166784f * fVec45[((IOTA - 352) & 511)])) + (0.0018300917f * fVec45[((IOTA - 353) & 511)])) + (0.000833439641f * fVec45[((IOTA - 359) & 511)])) + (0.00148076378f * fVec45[((IOTA - 360) & 511)])) + (0.00132456562f * fVec45[((IOTA - 361) & 511)])) + (0.00021203002f * fVec45[((IOTA - 362) & 511)])) + (0.000449973624f * fVec45[((IOTA - 381) & 511)])) + (0.000420025084f * fVec45[((IOTA - 382) & 511)])) + (0.000439111609f * fVec45[((IOTA - 383) & 511)])) + (0.000660203397f * fVec45[((IOTA - 384) & 511)])) + (0.00101018324f * fVec45[((IOTA - 385) & 511)])) + (0.00127537549f * fVec45[((IOTA - 386) & 511)])) + (0.000544816256f * fVec45[((IOTA - 387) & 511)])) + (0.000366769265f * fVec45[((IOTA - 409) & 511)])) + (0.000312955119f * fVec45[((IOTA - 427) & 511)])) + (0.000925333705f * fVec45[((IOTA - 428) & 511)])) + (0.000779252965f * fVec45[((IOTA - 429) & 511)])) + (3.07867303e-05f * fVec45[((IOTA - 471) & 511)])) + (0.000887316186f * fVec45[((IOTA - 494) & 511)])) + (0.00184743991f * fVec45[((IOTA - 495) & 511)])) + (0.00184418168f * fVec45[((IOTA - 496) & 511)])) + (0.000598413404f * fVec45[((IOTA - 497) & 511)])) - ((((((((((((((((((((((((((((((((0.00218084687f * fVec45[((IOTA - 476) & 511)]) + ((0.00229521049f * fVec45[((IOTA - 475) & 511)]) + ((0.00191633729f * fVec45[((IOTA - 474) & 511)]) + ((0.00106207328f * fVec45[((IOTA - 473) & 511)]) + ((0.000124170445f * fVec45[((IOTA - 472) & 511)]) + ((0.000877602492f * fVec45[((IOTA - 470) & 511)]) + ((0.00269512506f * fVec45[((IOTA - 469) & 511)]) + ((0.00435492862f * fVec45[((IOTA - 468) & 511)]) + ((0.00492612412f * fVec45[((IOTA - 467) & 511)]) + ((0.00452853739f * fVec45[((IOTA - 466) & 511)]) + ((0.00380430883f * fVec45[((IOTA - 465) & 511)]) + ((0.00307747396f * fVec45[((IOTA - 464) & 511)]) + ((0.00280948821f * fVec45[((IOTA - 463) & 511)]) + ((0.00334663875f * fVec45[((IOTA - 462) & 511)]) + ((0.00440154271f * fVec45[((IOTA - 461) & 511)]) + ((0.00539322896f * fVec45[((IOTA - 460) & 511)]) + ((0.00589779299f * fVec45[((IOTA - 459) & 511)]) + ((0.00560653163f * fVec45[((IOTA - 458) & 511)]) + ((0.00484813377f * fVec45[((IOTA - 457) & 511)]) + ((0.0038924166f * fVec45[((IOTA - 456) & 511)]) + ((0.00278074993f * fVec45[((IOTA - 455) & 511)]) + ((0.00215573981f * fVec45[((IOTA - 454) & 511)]) + ((0.00230855541f * fVec45[((IOTA - 453) & 511)]) + ((0.00277863955f * fVec45[((IOTA - 452) & 511)]) + ((0.00334583176f * fVec45[((IOTA - 451) & 511)]) + ((0.00369829405f * fVec45[((IOTA - 450) & 511)]) + ((0.00306273205f * fVec45[((IOTA - 449) & 511)]) + ((0.00190044753f * fVec45[((IOTA - 448) & 511)]) + ((0.0012683617f * fVec45[((IOTA - 447) & 511)]) + ((0.00191193027f * fVec45[((IOTA - 446) & 511)]) + ((0.00418706145f * fVec45[((IOTA - 445) & 511)]) + ((0.00688119326f * fVec45[((IOTA - 444) & 511)]) + ((0.00867227465f * fVec45[((IOTA - 443) & 511)]) + ((0.0094806999f * fVec45[((IOTA - 442) & 511)]) + ((0.00920048635f * fVec45[((IOTA - 441) & 511)]) + ((0.00802401826f * fVec45[((IOTA - 440) & 511)]) + ((0.00635170843f * fVec45[((IOTA - 439) & 511)]) + ((0.00516403699f * fVec45[((IOTA - 438) & 511)]) + ((0.00515491283f * fVec45[((IOTA - 437) & 511)]) + ((0.00571428426f * fVec45[((IOTA - 436) & 511)]) + ((0.00661311438f * fVec45[((IOTA - 435) & 511)]) + ((0.00725503825f * fVec45[((IOTA - 434) & 511)]) + ((0.00674004667f * fVec45[((IOTA - 433) & 511)]) + ((0.00521356845f * fVec45[((IOTA - 432) & 511)]) + ((0.00304721482f * fVec45[((IOTA - 431) & 511)]) + ((0.000678203534f * fVec45[((IOTA - 430) & 511)]) + ((0.000525109004f * fVec45[((IOTA - 426) & 511)]) + ((0.00135507295f * fVec45[((IOTA - 425) & 511)]) + ((0.00196056208f * fVec45[((IOTA - 424) & 511)]) + ((0.0019307374f * fVec45[((IOTA - 423) & 511)]) + ((0.00128477905f * fVec45[((IOTA - 422) & 511)]) + ((0.000465708319f * fVec45[((IOTA - 421) & 511)]) + ((0.000194215681f * fVec45[((IOTA - 420) & 511)]) + ((0.000787042547f * fVec45[((IOTA - 419) & 511)]) + ((0.00216756435f * fVec45[((IOTA - 418) & 511)]) + ((0.00468057673f * fVec45[((IOTA - 417) & 511)]) + ((0.00729432842f * fVec45[((IOTA - 416) & 511)]) + ((0.00879343413f * fVec45[((IOTA - 415) & 511)]) + ((0.0094343964f * fVec45[((IOTA - 414) & 511)]) + ((0.00838889554f * fVec45[((IOTA - 413) & 511)]) + ((0.00566512533f * fVec45[((IOTA - 412) & 511)]) + ((0.00280740904f * fVec45[((IOTA - 411) & 511)]) + ((0.000548695214f * fVec45[((IOTA - 410) & 511)]) + ((0.000381635036f * fVec45[((IOTA - 408) & 511)]) + ((0.00179924304f * fVec45[((IOTA - 407) & 511)]) + ((0.00321610644f * fVec45[((IOTA - 406) & 511)]) + ((0.00414187461f * fVec45[((IOTA - 405) & 511)]) + ((0.00405013561f * fVec45[((IOTA - 404) & 511)]) + ((0.00329493452f * fVec45[((IOTA - 403) & 511)]) + ((0.00254026102f * fVec45[((IOTA - 402) & 511)]) + ((0.00220632646f * fVec45[((IOTA - 401) & 511)]) + ((0.00235184887f * fVec45[((IOTA - 400) & 511)]) + ((0.00286497828f * fVec45[((IOTA - 399) & 511)]) + ((0.00335902162f * fVec45[((IOTA - 398) & 511)]) + ((0.0030981428f * fVec45[((IOTA - 397) & 511)]) + ((0.00229331711f * fVec45[((IOTA - 396) & 511)]) + ((0.00147610856f * fVec45[((IOTA - 395) & 511)]) + ((0.000869657379f * fVec45[((IOTA - 394) & 511)]) + ((0.00110322563f * fVec45[((IOTA - 393) & 511)]) + ((0.0021725609f * fVec45[((IOTA - 392) & 511)]) + ((0.00292382063f * fVec45[((IOTA - 391) & 511)]) + ((0.00280374661f * fVec45[((IOTA - 390) & 511)]) + ((0.00216219528f * fVec45[((IOTA - 389) & 511)]) + ((0.000995534472f * fVec45[((IOTA - 388) & 511)]) + ((4.79486771e-05f * fVec45[((IOTA - 380) & 511)]) + ((0.00121439202f * fVec45[((IOTA - 379) & 511)]) + ((0.00283869216f * fVec45[((IOTA - 378) & 511)]) + ((0.00441007735f * fVec45[((IOTA - 377) & 511)]) + ((0.0051114019f * fVec45[((IOTA - 376) & 511)]) + ((0.00481303362f * fVec45[((IOTA - 375) & 511)]) + ((0.00395786902f * fVec45[((IOTA - 374) & 511)]) + ((0.00324487546f * fVec45[((IOTA - 373) & 511)]) + ((0.00351531291f * fVec45[((IOTA - 372) & 511)]) + ((0.00445014331f * fVec45[((IOTA - 371) & 511)]) + ((0.00552509585f * fVec45[((IOTA - 370) & 511)]) + ((0.00663375249f * fVec45[((IOTA - 369) & 511)]) + ((0.00639795f * fVec45[((IOTA - 368) & 511)]) + ((0.00489915488f * fVec45[((IOTA - 367) & 511)]) + ((0.00349340215f * fVec45[((IOTA - 366) & 511)]) + ((0.00208287034f * fVec45[((IOTA - 365) & 511)]) + ((0.00124759926f * fVec45[((IOTA - 364) & 511)]) + ((0.000868012663f * fVec45[((IOTA - 363) & 511)]) + ((0.000730155967f * fVec45[((IOTA - 358) & 511)]) + ((0.0030951947f * fVec45[((IOTA - 357) & 511)]) + ((0.00455954112f * fVec45[((IOTA - 356) & 511)]) + ((0.00416030921f * fVec45[((IOTA - 355) & 511)]) + ((0.00186758162f * fVec45[((IOTA - 354) & 511)]) + ((1.90553255e-05f * fVec45[((IOTA - 326) & 511)]) + ((0.00030770991f * fVec45[((IOTA - 321) & 511)]) + ((0.00125442678f * fVec45[((IOTA - 320) & 511)]) + ((0.00121414382f * fVec45[((IOTA - 319) & 511)]) + ((0.00132434862f * fVec45[((IOTA - 247) & 511)]) + ((0.00198750012f * fVec45[((IOTA - 246) & 511)]) + ((0.000374993775f * fVec45[((IOTA - 245) & 511)]) + ((4.01590951e-05f * fVec45[((IOTA - 202) & 511)]) + ((0.00107442494f * fVec45[((IOTA - 201) & 511)]) + ((0.000518343411f * fVec45[((IOTA - 200) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00117625017f * fVec45[((IOTA - 23) & 511)]) + ((0.0102413632f * fVec45[((IOTA - 22) & 511)]) + ((0.0114360787f * fVec45[((IOTA - 21) & 511)]) + ((0.00441013929f * fVec45[((IOTA - 20) & 511)]) + ((0.0533049218f * fVec45[((IOTA - 10) & 511)]) + ((0.148636878f * fVec45[((IOTA - 9) & 511)]) + ((0.207760856f * fVec45[((IOTA - 8) & 511)]) + ((0.186762825f * fVec45[((IOTA - 7) & 511)]) + ((0.0843145624f * fVec45[((IOTA - 6) & 511)]) + ((0.0625015274f * fVec45[((IOTA - 31) & 511)]) + (((0.00701597705f * fVec45[((IOTA - 29) & 511)]) + (0.031348601f * fVec45[((IOTA - 30) & 511)])) + (0.0772349313f * fVec45[((IOTA - 32) & 511)])))))))))))) + (0.0636293367f * fVec45[((IOTA - 33) & 511)])) + (0.0465432443f * fVec45[((IOTA - 34) & 511)])) + (0.0278512891f * fVec45[((IOTA - 35) & 511)])) + (0.00497202482f * fVec45[((IOTA - 36) & 511)])) + (0.0247024037f * fVec45[((IOTA - 43) & 511)])) + (0.0571963154f * fVec45[((IOTA - 44) & 511)])) + (0.0684160516f * fVec45[((IOTA - 45) & 511)])) + (0.0618990809f * fVec45[((IOTA - 46) & 511)])) + (0.0485417321f * fVec45[((IOTA - 47) & 511)])) + (0.0254942272f * fVec45[((IOTA - 48) & 511)])) + (0.00144336699f * fVec45[((IOTA - 49) & 511)])) + (0.0115891425f * fVec45[((IOTA - 54) & 511)])) + (0.0227975193f * fVec45[((IOTA - 55) & 511)])) + (0.0332586095f * fVec45[((IOTA - 56) & 511)])) + (0.0332695954f * fVec45[((IOTA - 57) & 511)])) + (0.0285606217f * fVec45[((IOTA - 58) & 511)])) + (0.0191477947f * fVec45[((IOTA - 59) & 511)])) + (0.00459330715f * fVec45[((IOTA - 60) & 511)])) + (0.0123770237f * fVec45[((IOTA - 65) & 511)])) + (0.0282866452f * fVec45[((IOTA - 66) & 511)])) + (0.0401408561f * fVec45[((IOTA - 67) & 511)])) + (0.046604041f * fVec45[((IOTA - 68) & 511)])) + (0.0436652303f * fVec45[((IOTA - 69) & 511)])) + (0.0273987707f * fVec45[((IOTA - 70) & 511)])) + (0.00684258575f * fVec45[((IOTA - 71) & 511)])) + (0.0061014127f * fVec45[((IOTA - 75) & 511)])) + (0.018890826f * fVec45[((IOTA - 76) & 511)])) + (0.0261894371f * fVec45[((IOTA - 77) & 511)])) + (0.0207554903f * fVec45[((IOTA - 78) & 511)])) + (0.00676620891f * fVec45[((IOTA - 79) & 511)])) + (0.00142738409f * fVec45[((IOTA - 83) & 511)])) + (0.0108476589f * fVec45[((IOTA - 84) & 511)])) + (0.0174422152f * fVec45[((IOTA - 85) & 511)])) + (0.0205365717f * fVec45[((IOTA - 86) & 511)])) + (0.0220526531f * fVec45[((IOTA - 87) & 511)])) + (0.0226880908f * fVec45[((IOTA - 88) & 511)])) + (0.0228193067f * fVec45[((IOTA - 89) & 511)])) + (0.023158174f * fVec45[((IOTA - 90) & 511)])) + (0.0199969076f * fVec45[((IOTA - 91) & 511)])) + (0.0183617771f * fVec45[((IOTA - 92) & 511)])) + (0.0182881299f * fVec45[((IOTA - 93) & 511)])) + (0.014090362f * fVec45[((IOTA - 94) & 511)])) + (0.0097309649f * fVec45[((IOTA - 95) & 511)])) + (0.00304612843f * fVec45[((IOTA - 96) & 511)])) + (0.00914856512f * fVec45[((IOTA - 102) & 511)])) + (0.0203856789f * fVec45[((IOTA - 103) & 511)])) + (0.0286332108f * fVec45[((IOTA - 104) & 511)])) + (0.0303006805f * fVec45[((IOTA - 105) & 511)])) + (0.0241412334f * fVec45[((IOTA - 106) & 511)])) + (0.0157817602f * fVec45[((IOTA - 107) & 511)])) + (0.0061040814f * fVec45[((IOTA - 108) & 511)])) + (0.00234716246f * fVec45[((IOTA - 112) & 511)])) + (0.0123711266f * fVec45[((IOTA - 113) & 511)])) + (0.019652389f * fVec45[((IOTA - 114) & 511)])) + (0.0222717896f * fVec45[((IOTA - 115) & 511)])) + (0.0203425419f * fVec45[((IOTA - 116) & 511)])) + (0.0127615444f * fVec45[((IOTA - 117) & 511)])) + (0.00497590424f * fVec45[((IOTA - 118) & 511)])) + (0.00191990659f * fVec45[((IOTA - 121) & 511)])) + (0.0115898252f * fVec45[((IOTA - 122) & 511)])) + (0.0213809349f * fVec45[((IOTA - 123) & 511)])) + (0.0287095886f * fVec45[((IOTA - 124) & 511)])) + (0.0292140283f * fVec45[((IOTA - 125) & 511)])) + (0.0225102603f * fVec45[((IOTA - 126) & 511)])) + (0.0105368458f * fVec45[((IOTA - 127) & 511)])) + (0.000490412116f * fVec45[((IOTA - 134) & 511)])) + (0.00226758933f * fVec45[((IOTA - 135) & 511)])) + (0.00133654522f * fVec45[((IOTA - 136) & 511)])) + (0.00105478009f * fVec45[((IOTA - 137) & 511)])) + (0.00451019593f * fVec45[((IOTA - 138) & 511)])) + (0.0101760346f * fVec45[((IOTA - 139) & 511)])) + (0.0135495812f * fVec45[((IOTA - 140) & 511)])) + (0.0134093966f * fVec45[((IOTA - 141) & 511)])) + (0.00987499766f * fVec45[((IOTA - 142) & 511)])) + (0.00333946943f * fVec45[((IOTA - 143) & 511)])) + (0.00210031169f * fVec45[((IOTA - 149) & 511)])) + (0.0070297257f * fVec45[((IOTA - 150) & 511)])) + (0.00873474777f * fVec45[((IOTA - 151) & 511)])) + (0.00807209127f * fVec45[((IOTA - 152) & 511)])) + (0.00445929868f * fVec45[((IOTA - 153) & 511)])) + (0.00502003543f * fVec45[((IOTA - 159) & 511)])) + (0.0104874074f * fVec45[((IOTA - 160) & 511)])) + (0.0137169827f * fVec45[((IOTA - 161) & 511)])) + (0.0126853548f * fVec45[((IOTA - 162) & 511)])) + (0.00904410146f * fVec45[((IOTA - 163) & 511)])) + (0.00457136519f * fVec45[((IOTA - 164) & 511)])) + (0.00342742214f * fVec45[((IOTA - 172) & 511)])) + (0.00647330238f * fVec45[((IOTA - 173) & 511)])) + (0.0064894408f * fVec45[((IOTA - 174) & 511)])) + (0.00374829117f * fVec45[((IOTA - 175) & 511)])) + (0.00165760005f * fVec45[((IOTA - 477) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00207275292f * fVec45[((IOTA - 478) & 511)])) + (0.00361316558f * fVec45[((IOTA - 479) & 511)])) + (0.00576102268f * fVec45[((IOTA - 480) & 511)])) + (0.00794230402f * fVec45[((IOTA - 481) & 511)])) + (0.00881360658f * fVec45[((IOTA - 482) & 511)])) + (0.00818040315f * fVec45[((IOTA - 483) & 511)])) + (0.00664396305f * fVec45[((IOTA - 484) & 511)])) + (0.004661832f * fVec45[((IOTA - 485) & 511)])) + (0.00327224843f * fVec45[((IOTA - 486) & 511)])) + (0.00259004114f * fVec45[((IOTA - 487) & 511)])) + (0.00266616931f * fVec45[((IOTA - 488) & 511)])) + (0.00342140161f * fVec45[((IOTA - 489) & 511)])) + (0.00391404796f * fVec45[((IOTA - 490) & 511)])) + (0.00355556514f * fVec45[((IOTA - 491) & 511)])) + (0.00225514453f * fVec45[((IOTA - 492) & 511)])) + (0.000593385659f * fVec45[((IOTA - 493) & 511)])) + (0.00131078623f * fVec45[((IOTA - 498) & 511)])) + (0.00288155116f * fVec45[((IOTA - 499) & 511)])) + (0.00360416528f * fVec45[((IOTA - 500) & 511)])) + (0.00382162631f * fVec45[((IOTA - 501) & 511)])) + (0.00415844703f * fVec45[((IOTA - 502) & 511)])) + (0.00502053229f * fVec45[((IOTA - 503) & 511)])) + (0.00604660483f * fVec45[((IOTA - 504) & 511)])) + (0.00670671556f * fVec45[((IOTA - 505) & 511)])) + (0.00706246728f * fVec45[((IOTA - 506) & 511)])) + (0.00725060049f * fVec45[((IOTA - 507) & 511)])) + (0.00696340436f * fVec45[((IOTA - 508) & 511)])) + (0.00624625199f * fVec45[((IOTA - 509) & 511)])) + (0.00562533829f * fVec45[((IOTA - 510) & 511)])) + (0.00545616774f * fVec45[((IOTA - 511) & 511)]))) : (((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00732742902f * fVec44[((IOTA - 311) & 511)]) + ((0.00362658361f * fVec44[((IOTA - 310) & 511)]) + ((0.00189847313f * fVec44[((IOTA - 309) & 511)]) + ((0.00252677687f * fVec44[((IOTA - 308) & 511)]) + ((0.00527671538f * fVec44[((IOTA - 307) & 511)]) + ((0.00950311217f * fVec44[((IOTA - 306) & 511)]) + ((0.01339918f * fVec44[((IOTA - 305) & 511)]) + ((0.0163567141f * fVec44[((IOTA - 304) & 511)]) + ((0.018817246f * fVec44[((IOTA - 303) & 511)]) + ((0.0196812563f * fVec44[((IOTA - 302) & 511)]) + ((0.0181781389f * fVec44[((IOTA - 301) & 511)]) + ((0.0148871392f * fVec44[((IOTA - 300) & 511)]) + ((0.0108955801f * fVec44[((IOTA - 299) & 511)]) + ((0.00745861372f * fVec44[((IOTA - 298) & 511)]) + ((0.00535283564f * fVec44[((IOTA - 297) & 511)]) + ((0.00384164276f * fVec44[((IOTA - 296) & 511)]) + ((0.00252912939f * fVec44[((IOTA - 295) & 511)]) + ((0.00226716651f * fVec44[((IOTA - 294) & 511)]) + ((0.00312351109f * fVec44[((IOTA - 293) & 511)]) + ((0.00476827007f * fVec44[((IOTA - 292) & 511)]) + ((0.00604814012f * fVec44[((IOTA - 291) & 511)]) + ((0.00656352658f * fVec44[((IOTA - 290) & 511)]) + ((0.00684349518f * fVec44[((IOTA - 289) & 511)]) + ((0.00710879778f * fVec44[((IOTA - 288) & 511)]) + ((0.00775589189f * fVec44[((IOTA - 287) & 511)]) + ((0.00822350383f * fVec44[((IOTA - 286) & 511)]) + ((0.00857869163f * fVec44[((IOTA - 285) & 511)]) + ((0.00941273198f * fVec44[((IOTA - 284) & 511)]) + ((0.0107289627f * fVec44[((IOTA - 283) & 511)]) + ((0.0126953088f * fVec44[((IOTA - 282) & 511)]) + ((0.0138184652f * fVec44[((IOTA - 281) & 511)]) + ((0.0129654035f * fVec44[((IOTA - 280) & 511)]) + ((0.0109885735f * fVec44[((IOTA - 279) & 511)]) + (((((((((((((((((((((((((((0.0101342034f * fVec44[((IOTA - 253) & 511)]) + ((0.00825542118f * fVec44[((IOTA - 252) & 511)]) + ((0.00660648011f * fVec44[((IOTA - 251) & 511)]) + ((0.00532934023f * fVec44[((IOTA - 250) & 511)]) + ((0.00496137282f * fVec44[((IOTA - 249) & 511)]) + ((0.0057114223f * fVec44[((IOTA - 248) & 511)]) + ((0.00631596893f * fVec44[((IOTA - 247) & 511)]) + ((0.00548553048f * fVec44[((IOTA - 246) & 511)]) + ((0.00405498827f * fVec44[((IOTA - 245) & 511)]) + ((0.00435185991f * fVec44[((IOTA - 244) & 511)]) + ((0.00746860402f * fVec44[((IOTA - 243) & 511)]) + ((0.0118088759f * fVec44[((IOTA - 242) & 511)]) + ((0.0158482119f * fVec44[((IOTA - 241) & 511)]) + ((0.0172337946f * fVec44[((IOTA - 240) & 511)]) + ((0.0156344008f * fVec44[((IOTA - 239) & 511)]) + ((0.0138518643f * fVec44[((IOTA - 238) & 511)]) + ((0.0127321631f * fVec44[((IOTA - 237) & 511)]) + ((0.0115889963f * fVec44[((IOTA - 236) & 511)]) + ((0.0109328702f * fVec44[((IOTA - 235) & 511)]) + ((0.0114185754f * fVec44[((IOTA - 234) & 511)]) + ((0.0132333189f * fVec44[((IOTA - 233) & 511)]) + ((0.0148507208f * fVec44[((IOTA - 232) & 511)]) + ((0.0147730894f * fVec44[((IOTA - 231) & 511)]) + ((0.0133970315f * fVec44[((IOTA - 230) & 511)]) + ((0.012434857f * fVec44[((IOTA - 229) & 511)]) + ((0.0141663356f * fVec44[((IOTA - 228) & 511)]) + ((0.0177273415f * fVec44[((IOTA - 227) & 511)]) + ((0.0203607921f * fVec44[((IOTA - 226) & 511)]) + ((0.0201110262f * fVec44[((IOTA - 225) & 511)]) + ((0.0168731753f * fVec44[((IOTA - 224) & 511)]) + ((0.0116570424f * fVec44[((IOTA - 223) & 511)]) + ((0.00523855351f * fVec44[((IOTA - 222) & 511)]) + ((0.00764158089f * fVec44[((IOTA - 217) & 511)]) + ((0.0159698986f * fVec44[((IOTA - 216) & 511)]) + ((0.0203409269f * fVec44[((IOTA - 215) & 511)]) + ((0.0204689745f * fVec44[((IOTA - 214) & 511)]) + ((0.018221993f * fVec44[((IOTA - 213) & 511)]) + ((0.0151972547f * fVec44[((IOTA - 212) & 511)]) + ((0.0118971355f * fVec44[((IOTA - 211) & 511)]) + ((0.0095456019f * fVec44[((IOTA - 210) & 511)]) + ((0.0080723092f * fVec44[((IOTA - 209) & 511)]) + ((0.00770721678f * fVec44[((IOTA - 208) & 511)]) + ((0.0088513419f * fVec44[((IOTA - 207) & 511)]) + ((0.0100900009f * fVec44[((IOTA - 206) & 511)]) + ((0.00999607798f * fVec44[((IOTA - 205) & 511)]) + ((0.00896193646f * fVec44[((IOTA - 204) & 511)]) + ((0.00786210038f * fVec44[((IOTA - 203) & 511)]) + ((0.00666883448f * fVec44[((IOTA - 202) & 511)]) + ((0.00543337036f * fVec44[((IOTA - 201) & 511)]) + ((0.00402498757f * fVec44[((IOTA - 200) & 511)]) + ((0.00327061117f * fVec44[((IOTA - 199) & 511)]) + ((0.00418213615f * fVec44[((IOTA - 198) & 511)]) + ((0.00562098436f * fVec44[((IOTA - 197) & 511)]) + ((0.00596673414f * fVec44[((IOTA - 196) & 511)]) + ((0.00627586152f * fVec44[((IOTA - 195) & 511)]) + ((0.00779332733f * fVec44[((IOTA - 194) & 511)]) + ((0.0111763328f * fVec44[((IOTA - 193) & 511)]) + ((0.0159522109f * fVec44[((IOTA - 192) & 511)]) + ((0.0186274536f * fVec44[((IOTA - 191) & 511)]) + ((0.0171734169f * fVec44[((IOTA - 190) & 511)]) + ((0.012557473f * fVec44[((IOTA - 189) & 511)]) + ((0.00741348183f * fVec44[((IOTA - 188) & 511)]) + ((0.00419334648f * fVec44[((IOTA - 187) & 511)]) + ((0.00325815193f * fVec44[((IOTA - 186) & 511)]) + ((0.00366155105f * fVec44[((IOTA - 185) & 511)]) + ((0.00527526345f * fVec44[((IOTA - 184) & 511)]) + ((0.00833848305f * fVec44[((IOTA - 183) & 511)]) + ((0.0116760358f * fVec44[((IOTA - 182) & 511)]) + ((0.0117262211f * fVec44[((IOTA - 181) & 511)]) + ((0.00725700101f * fVec44[((IOTA - 180) & 511)]) + ((0.000751820859f * fVec44[((IOTA - 179) & 511)]) + ((0.00154369138f * fVec44[((IOTA - 175) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((fSlow140 * fTemp0) + (0.190692961f * fVec44[((IOTA - 1) & 511)])) + (0.234789699f * fVec44[((IOTA - 2) & 511)])) + (0.235342145f * fVec44[((IOTA - 3) & 511)])) + (0.205696151f * fVec44[((IOTA - 4) & 511)])) + (0.148611695f * fVec44[((IOTA - 5) & 511)])) + (0.055067312f * fVec44[((IOTA - 6) & 511)])) + (0.00305889174f * fVec44[((IOTA - 12) & 511)])) + (0.0380671062f * fVec44[((IOTA - 13) & 511)])) + (0.0505118072f * fVec44[((IOTA - 14) & 511)])) + (0.048050493f * fVec44[((IOTA - 15) & 511)])) + (0.0399688035f * fVec44[((IOTA - 16) & 511)])) + (0.0312224776f * fVec44[((IOTA - 17) & 511)])) + (0.0209078919f * fVec44[((IOTA - 18) & 511)])) + (0.0112015698f * fVec44[((IOTA - 23) & 511)])) + (0.0238854941f * fVec44[((IOTA - 24) & 511)])) + (0.0458018258f * fVec44[((IOTA - 25) & 511)])) + (0.0516002588f * fVec44[((IOTA - 26) & 511)])) + (0.032549832f * fVec44[((IOTA - 27) & 511)])) + (0.00564343389f * fVec44[((IOTA - 28) & 511)])) + (0.0138513129f * fVec44[((IOTA - 40) & 511)])) + (0.0229674354f * fVec44[((IOTA - 41) & 511)])) + (0.0218240637f * fVec44[((IOTA - 42) & 511)])) + (0.0140828975f * fVec44[((IOTA - 43) & 511)])) + (0.0320650004f * fVec44[((IOTA - 52) & 511)])) + (0.0461636931f * fVec44[((IOTA - 53) & 511)])) + (0.0379378982f * fVec44[((IOTA - 54) & 511)])) + (0.015798606f * fVec44[((IOTA - 55) & 511)])) + (0.0118006282f * fVec44[((IOTA - 65) & 511)])) + (0.0163717009f * fVec44[((IOTA - 66) & 511)])) + (0.00177768571f * fVec44[((IOTA - 75) & 511)])) + (0.00563727692f * fVec44[((IOTA - 99) & 511)])) + (0.0197613277f * fVec44[((IOTA - 100) & 511)])) + (0.0238967054f * fVec44[((IOTA - 101) & 511)])) + (0.0168611519f * fVec44[((IOTA - 102) & 511)])) + (0.000271081924f * fVec44[((IOTA - 103) & 511)])) + (0.00669230055f * fVec44[((IOTA - 128) & 511)])) + (0.012510309f * fVec44[((IOTA - 129) & 511)])) + (0.013252371f * fVec44[((IOTA - 130) & 511)])) + (0.00951353833f * fVec44[((IOTA - 131) & 511)])) + (0.00261291675f * fVec44[((IOTA - 132) & 511)])) + (0.00100257294f * fVec44[((IOTA - 134) & 511)])) + (0.00527047133f * fVec44[((IOTA - 135) & 511)])) + (0.00835950859f * fVec44[((IOTA - 136) & 511)])) + (0.00689292559f * fVec44[((IOTA - 137) & 511)])) + (0.00196657795f * fVec44[((IOTA - 138) & 511)])) + (0.00281752041f * fVec44[((IOTA - 153) & 511)])) + (0.00492646405f * fVec44[((IOTA - 154) & 511)])) + (0.00340127293f * fVec44[((IOTA - 155) & 511)])) + (0.000914109871f * fVec44[((IOTA - 156) & 511)])) + (0.00461268984f * fVec44[((IOTA - 165) & 511)])) + (0.00601720996f * fVec44[((IOTA - 166) & 511)])) + (0.0038619726f * fVec44[((IOTA - 167) & 511)])) + (0.00219171448f * fVec44[((IOTA - 168) & 511)])) + (0.00273861224f * fVec44[((IOTA - 169) & 511)])) + (0.00392932212f * fVec44[((IOTA - 170) & 511)])) + (0.00512743741f * fVec44[((IOTA - 171) & 511)])) + (0.00589633547f * fVec44[((IOTA - 172) & 511)])) + (0.00495167263f * fVec44[((IOTA - 173) & 511)])) + (0.00342703331f * fVec44[((IOTA - 174) & 511)])) + (0.0124833863f * fVec44[((IOTA - 254) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.0153733091f * fVec44[((IOTA - 255) & 511)])) + (0.0172953065f * fVec44[((IOTA - 256) & 511)])) + (0.0167140812f * fVec44[((IOTA - 257) & 511)])) + (0.0145538487f * fVec44[((IOTA - 258) & 511)])) + (0.012120733f * fVec44[((IOTA - 259) & 511)])) + (0.0104087703f * fVec44[((IOTA - 260) & 511)])) + (0.00906933472f * fVec44[((IOTA - 261) & 511)])) + (0.00781868212f * fVec44[((IOTA - 262) & 511)])) + (0.00739930896f * fVec44[((IOTA - 263) & 511)])) + (0.00802958757f * fVec44[((IOTA - 264) & 511)])) + (0.00988284126f * fVec44[((IOTA - 265) & 511)])) + (0.0124076437f * fVec44[((IOTA - 266) & 511)])) + (0.0143644633f * fVec44[((IOTA - 267) & 511)])) + (0.0161480736f * fVec44[((IOTA - 268) & 511)])) + (0.0186142959f * fVec44[((IOTA - 269) & 511)])) + (0.0207764469f * fVec44[((IOTA - 270) & 511)])) + (0.0213949047f * fVec44[((IOTA - 271) & 511)])) + (0.019476654f * fVec44[((IOTA - 272) & 511)])) + (0.0156140998f * fVec44[((IOTA - 273) & 511)])) + (0.0118382387f * fVec44[((IOTA - 274) & 511)])) + (0.00916154496f * fVec44[((IOTA - 275) & 511)])) + (0.00774224196f * fVec44[((IOTA - 276) & 511)])) + (0.00775345229f * fVec44[((IOTA - 277) & 511)])) + (0.00901247002f * fVec44[((IOTA - 278) & 511)])) + (0.011245192f * fVec44[((IOTA - 312) & 511)]))))))))))))))))))))))))))))))))))) + (0.0143324584f * fVec44[((IOTA - 313) & 511)])) + (0.0158831477f * fVec44[((IOTA - 314) & 511)])) + (0.0152558619f * fVec44[((IOTA - 315) & 511)])) + (0.0128271319f * fVec44[((IOTA - 316) & 511)])) + (0.00876392424f * fVec44[((IOTA - 317) & 511)])) + (0.00378919207f * fVec44[((IOTA - 318) & 511)])) + (0.000490671489f * fVec44[((IOTA - 319) & 511)])) + (0.000725305174f * fVec44[((IOTA - 321) & 511)])) + (0.00284055108f * fVec44[((IOTA - 322) & 511)])) + (0.00467115222f * fVec44[((IOTA - 323) & 511)])) + (0.00547978003f * fVec44[((IOTA - 324) & 511)])) + (0.00599330803f * fVec44[((IOTA - 325) & 511)])) + (0.00638825539f * fVec44[((IOTA - 326) & 511)])) + (0.00615275092f * fVec44[((IOTA - 327) & 511)])) + (0.00460037589f * fVec44[((IOTA - 328) & 511)])) + (0.00160096306f * fVec44[((IOTA - 329) & 511)])) + (0.0040412806f * fVec44[((IOTA - 335) & 511)])) + (0.00805096328f * fVec44[((IOTA - 336) & 511)])) + (0.00945707969f * fVec44[((IOTA - 337) & 511)])) + (0.00915103126f * fVec44[((IOTA - 338) & 511)])) + (0.00834574364f * fVec44[((IOTA - 339) & 511)])) + (0.0080022011f * fVec44[((IOTA - 340) & 511)])) + (0.00857883692f * fVec44[((IOTA - 341) & 511)])) + (0.00796409696f * fVec44[((IOTA - 342) & 511)])) + (0.00525028678f * fVec44[((IOTA - 343) & 511)])) + (0.00163285155f * fVec44[((IOTA - 344) & 511)])) + (0.00137724914f * fVec44[((IOTA - 347) & 511)])) + (0.00633040303f * fVec44[((IOTA - 348) & 511)])) + (0.0116767334f * fVec44[((IOTA - 349) & 511)])) + (0.0155820372f * fVec44[((IOTA - 350) & 511)])) + (0.0159696378f * fVec44[((IOTA - 351) & 511)])) + (0.0123787466f * fVec44[((IOTA - 352) & 511)])) + (0.0057307356f * fVec44[((IOTA - 353) & 511)])) + (0.000284760725f * fVec44[((IOTA - 359) & 511)])) + (0.00643704692f * fVec44[((IOTA - 360) & 511)])) + (0.00916883349f * fVec44[((IOTA - 361) & 511)])) + (0.00751640787f * fVec44[((IOTA - 362) & 511)])) + (0.00324139418f * fVec44[((IOTA - 363) & 511)])) + (0.000538794789f * fVec44[((IOTA - 385) & 511)])) + (0.000746564008f * fVec44[((IOTA - 386) & 511)])) + (0.000125927851f * fVec44[((IOTA - 391) & 511)])) + (0.00328713609f * fVec44[((IOTA - 392) & 511)])) + (0.00515340129f * fVec44[((IOTA - 393) & 511)])) + (0.00451051863f * fVec44[((IOTA - 394) & 511)])) + (0.00163261918f * fVec44[((IOTA - 395) & 511)])) + (0.000236550346f * fVec44[((IOTA - 419) & 511)])) + (0.000401453115f * fVec44[((IOTA - 420) & 511)])) + (0.000672157388f * fVec44[((IOTA - 428) & 511)])) + (0.000822916627f * fVec44[((IOTA - 429) & 511)])) + (0.000240122434f * fVec44[((IOTA - 472) & 511)])) + (0.000488261227f * fVec44[((IOTA - 500) & 511)])) + (0.000880768988f * fVec44[((IOTA - 501) & 511)])) - ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00676461635f * fVec44[((IOTA - 368) & 511)]) + ((0.00590562867f * fVec44[((IOTA - 367) & 511)]) + ((0.00551573467f * fVec44[((IOTA - 366) & 511)]) + ((0.0042826226f * fVec44[((IOTA - 365) & 511)]) + ((0.00119814463f * fVec44[((IOTA - 364) & 511)]) + ((0.00680684391f * fVec44[((IOTA - 358) & 511)]) + ((0.0122102713f * fVec44[((IOTA - 357) & 511)]) + ((0.0132203661f * fVec44[((IOTA - 356) & 511)]) + ((0.00949460268f * fVec44[((IOTA - 355) & 511)]) + ((0.00248176092f * fVec44[((IOTA - 354) & 511)]) + ((0.00157401152f * fVec44[((IOTA - 346) & 511)]) + ((0.00133505045f * fVec44[((IOTA - 345) & 511)]) + ((0.000305555295f * fVec44[((IOTA - 334) & 511)]) + ((0.00377266714f * fVec44[((IOTA - 333) & 511)]) + ((0.00550940307f * fVec44[((IOTA - 332) & 511)]) + ((0.00437712669f * fVec44[((IOTA - 331) & 511)]) + ((0.00165155483f * fVec44[((IOTA - 330) & 511)]) + ((0.00023443019f * fVec44[((IOTA - 320) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0105342921f * fVec44[((IOTA - 56) & 511)]) + ((0.000629232731f * fVec44[((IOTA - 51) & 511)]) + ((0.0363522992f * fVec44[((IOTA - 50) & 511)]) + ((0.0731902719f * fVec44[((IOTA - 49) & 511)]) + ((0.100470275f * fVec44[((IOTA - 48) & 511)]) + ((0.102236547f * fVec44[((IOTA - 47) & 511)]) + ((0.0806421787f * fVec44[((IOTA - 46) & 511)]) + ((0.0475841016f * fVec44[((IOTA - 45) & 511)]) + ((0.0130009223f * fVec44[((IOTA - 44) & 511)]) + ((0.00834266469f * fVec44[((IOTA - 39) & 511)]) + ((0.0200727768f * fVec44[((IOTA - 38) & 511)]) + ((0.0236480441f * fVec44[((IOTA - 37) & 511)]) + ((0.0242167525f * fVec44[((IOTA - 36) & 511)]) + ((0.0261815302f * fVec44[((IOTA - 35) & 511)]) + ((0.04611139f * fVec44[((IOTA - 34) & 511)]) + ((0.0720970258f * fVec44[((IOTA - 33) & 511)]) + ((0.0777746141f * fVec44[((IOTA - 32) & 511)]) + ((0.0597714856f * fVec44[((IOTA - 31) & 511)]) + ((0.0479037128f * fVec44[((IOTA - 30) & 511)]) + ((0.029831754f * fVec44[((IOTA - 29) & 511)]) + ((0.00215950655f * fVec44[((IOTA - 22) & 511)]) + ((0.00527151674f * fVec44[((IOTA - 21) & 511)]) + ((0.00673464453f * fVec44[((IOTA - 20) & 511)]) + ((0.000143701676f * fVec44[((IOTA - 19) & 511)]) + ((0.0243605115f * fVec44[((IOTA - 11) & 511)]) + ((0.0514956787f * fVec44[((IOTA - 10) & 511)]) + ((0.0944765285f * fVec44[((IOTA - 9) & 511)]) + ((0.106162727f * fVec44[((IOTA - 8) & 511)]) + ((0.0525337979f * fVec44[((IOTA - 7) & 511)]) + ((0.0331688151f * fVec44[((IOTA - 57) & 511)]) + (0.0531694219f * fVec44[((IOTA - 58) & 511)]))))))))))))))))))))))))))))))) + (0.0659324005f * fVec44[((IOTA - 59) & 511)])) + (0.0655620173f * fVec44[((IOTA - 60) & 511)])) + (0.0574338064f * fVec44[((IOTA - 61) & 511)])) + (0.0404121652f * fVec44[((IOTA - 62) & 511)])) + (0.0199107211f * fVec44[((IOTA - 63) & 511)])) + (0.00293601351f * fVec44[((IOTA - 64) & 511)])) + (0.00289486023f * fVec44[((IOTA - 67) & 511)])) + (0.0300077796f * fVec44[((IOTA - 68) & 511)])) + (0.0496875271f * fVec44[((IOTA - 69) & 511)])) + (0.0571034476f * fVec44[((IOTA - 70) & 511)])) + (0.049917426f * fVec44[((IOTA - 71) & 511)])) + (0.0342106819f * fVec44[((IOTA - 72) & 511)])) + (0.0158229154f * fVec44[((IOTA - 73) & 511)])) + (0.00114087295f * fVec44[((IOTA - 74) & 511)])) + (0.0101480279f * fVec44[((IOTA - 76) & 511)])) + (0.0223028865f * fVec44[((IOTA - 77) & 511)])) + (0.0212329924f * fVec44[((IOTA - 78) & 511)])) + (0.0148330629f * fVec44[((IOTA - 79) & 511)])) + (0.00983027555f * fVec44[((IOTA - 80) & 511)])) + (0.00748881791f * fVec44[((IOTA - 81) & 511)])) + (0.00804945268f * fVec44[((IOTA - 82) & 511)])) + (0.00870682672f * fVec44[((IOTA - 83) & 511)])) + (0.00796557777f * fVec44[((IOTA - 84) & 511)])) + (0.00491246535f * fVec44[((IOTA - 85) & 511)])) + (0.00616518082f * fVec44[((IOTA - 86) & 511)])) + (0.0068565933f * fVec44[((IOTA - 87) & 511)])) + (0.00777418865f * fVec44[((IOTA - 88) & 511)])) + (0.0167953707f * fVec44[((IOTA - 89) & 511)])) + (0.02633374f * fVec44[((IOTA - 90) & 511)])) + (0.0304601733f * fVec44[((IOTA - 91) & 511)])) + (0.0335412547f * fVec44[((IOTA - 92) & 511)])) + (0.0367919691f * fVec44[((IOTA - 93) & 511)])) + (0.0373787433f * fVec44[((IOTA - 94) & 511)])) + (0.0359618217f * fVec44[((IOTA - 95) & 511)])) + (0.0325116441f * fVec44[((IOTA - 96) & 511)])) + (0.0254024081f * fVec44[((IOTA - 97) & 511)])) + (0.0127468007f * fVec44[((IOTA - 98) & 511)])) + (0.0164453518f * fVec44[((IOTA - 104) & 511)])) + (0.0285547879f * fVec44[((IOTA - 105) & 511)])) + (0.0366085954f * fVec44[((IOTA - 106) & 511)])) + (0.0401608609f * fVec44[((IOTA - 107) & 511)])) + (0.034323018f * fVec44[((IOTA - 108) & 511)])) + (0.0235350691f * fVec44[((IOTA - 109) & 511)])) + (0.0145569555f * fVec44[((IOTA - 110) & 511)])) + (0.00723135658f * fVec44[((IOTA - 111) & 511)])) + (0.00547278067f * fVec44[((IOTA - 112) & 511)])) + (0.00424922397f * fVec44[((IOTA - 113) & 511)])) + (0.00192742841f * fVec44[((IOTA - 114) & 511)])) + (0.00666218344f * fVec44[((IOTA - 115) & 511)])) + (0.0140728774f * fVec44[((IOTA - 116) & 511)])) + (0.0203129295f * fVec44[((IOTA - 117) & 511)])) + (0.0247859545f * fVec44[((IOTA - 118) & 511)])) + (0.0243087001f * fVec44[((IOTA - 119) & 511)])) + (0.0233451612f * fVec44[((IOTA - 120) & 511)])) + (0.0261373557f * fVec44[((IOTA - 121) & 511)])) + (0.0290296599f * fVec44[((IOTA - 122) & 511)])) + (0.0291121118f * fVec44[((IOTA - 123) & 511)])) + (0.0271206163f * fVec44[((IOTA - 124) & 511)])) + (0.0218623132f * fVec44[((IOTA - 125) & 511)])) + (0.0135903377f * fVec44[((IOTA - 126) & 511)])) + (0.00342932763f * fVec44[((IOTA - 127) & 511)])) + (0.000936849974f * fVec44[((IOTA - 133) & 511)])) + (0.0023154933f * fVec44[((IOTA - 139) & 511)])) + (0.00347913569f * fVec44[((IOTA - 140) & 511)])) + (0.00468718354f * fVec44[((IOTA - 141) & 511)])) + (0.00619843462f * fVec44[((IOTA - 142) & 511)])) + (0.00426548766f * fVec44[((IOTA - 143) & 511)])) + (0.00114763994f * fVec44[((IOTA - 144) & 511)])) + (8.13477673e-05f * fVec44[((IOTA - 145) & 511)])) + (0.00312278513f * fVec44[((IOTA - 146) & 511)])) + (0.00866096932f * fVec44[((IOTA - 147) & 511)])) + (0.0115335826f * fVec44[((IOTA - 148) & 511)])) + (0.0100902338f * fVec44[((IOTA - 149) & 511)])) + (0.00706874812f * fVec44[((IOTA - 150) & 511)])) + (0.00445257919f * fVec44[((IOTA - 151) & 511)])) + (0.00135889417f * fVec44[((IOTA - 152) & 511)])) + (0.00317392871f * fVec44[((IOTA - 157) & 511)])) + (0.00741574727f * fVec44[((IOTA - 158) & 511)])) + (0.0100400485f * fVec44[((IOTA - 159) & 511)])) + (0.0108706029f * fVec44[((IOTA - 160) & 511)])) + (0.00975743681f * fVec44[((IOTA - 161) & 511)])) + (0.00779701583f * fVec44[((IOTA - 162) & 511)])) + (0.00485295756f * fVec44[((IOTA - 163) & 511)])) + (0.000232774764f * fVec44[((IOTA - 164) & 511)])) + (0.00180312712f * fVec44[((IOTA - 176) & 511)])) + (0.00455271732f * fVec44[((IOTA - 177) & 511)])) + (0.00391340675f * fVec44[((IOTA - 178) & 511)])) + (0.00152159017f * fVec44[((IOTA - 218) & 511)])) + (0.00724666193f * fVec44[((IOTA - 219) & 511)])) + (0.00707711233f * fVec44[((IOTA - 220) & 511)])) + (0.00174748199f * fVec44[((IOTA - 221) & 511)])) + (0.00780369574f * fVec44[((IOTA - 369) & 511)])))))))))))))))))))) + (0.00894006714f * fVec44[((IOTA - 370) & 511)])) + (0.0100288093f * fVec44[((IOTA - 371) & 511)])) + (0.0109376041f * fVec44[((IOTA - 372) & 511)])) + (0.0117033646f * fVec44[((IOTA - 373) & 511)])) + (0.0109350197f * fVec44[((IOTA - 374) & 511)])) + (0.00792863593f * fVec44[((IOTA - 375) & 511)])) + (0.00412004348f * fVec44[((IOTA - 376) & 511)])) + (0.0015012892f * fVec44[((IOTA - 377) & 511)])) + (0.00125373201f * fVec44[((IOTA - 378) & 511)])) + (0.00298181316f * fVec44[((IOTA - 379) & 511)])) + (0.00502259424f * fVec44[((IOTA - 380) & 511)])) + (0.00593208661f * fVec44[((IOTA - 381) & 511)])) + (0.00522734318f * fVec44[((IOTA - 382) & 511)])) + (0.00310535962f * fVec44[((IOTA - 383) & 511)])) + (0.00082463026f * fVec44[((IOTA - 384) & 511)])) + (0.000537778251f * fVec44[((IOTA - 387) & 511)])) + (0.00242797472f * fVec44[((IOTA - 388) & 511)])) + (0.00318432599f * fVec44[((IOTA - 389) & 511)])) + (0.00223838584f * fVec44[((IOTA - 390) & 511)])) + (0.00272165146f * fVec44[((IOTA - 396) & 511)])) + (0.00664353836f * fVec44[((IOTA - 397) & 511)])) + (0.00851552561f * fVec44[((IOTA - 398) & 511)])) + (0.00836595707f * fVec44[((IOTA - 399) & 511)])) + (0.00667847646f * fVec44[((IOTA - 400) & 511)])) + (0.0043026912f * fVec44[((IOTA - 401) & 511)])) + (0.002859022f * fVec44[((IOTA - 402) & 511)])) + (0.00288672838f * fVec44[((IOTA - 403) & 511)])) + (0.00414635567f * fVec44[((IOTA - 404) & 511)])) + (0.00572664058f * fVec44[((IOTA - 405) & 511)])) + (0.00619584974f * fVec44[((IOTA - 406) & 511)])) + (0.00621687621f * fVec44[((IOTA - 407) & 511)])) + (0.00641729822f * fVec44[((IOTA - 408) & 511)])) + (0.00599025842f * fVec44[((IOTA - 409) & 511)])) + (0.00555531913f * fVec44[((IOTA - 410) & 511)])) + (0.00598630868f * fVec44[((IOTA - 411) & 511)])) + (0.00749334833f * fVec44[((IOTA - 412) & 511)])) + (0.00951539725f * fVec44[((IOTA - 413) & 511)])) + (0.0104178609f * fVec44[((IOTA - 414) & 511)])) + (0.0102005079f * fVec44[((IOTA - 415) & 511)])) + (0.00877522212f * fVec44[((IOTA - 416) & 511)])) + (0.00542671932f * fVec44[((IOTA - 417) & 511)])) + (0.00167232007f * fVec44[((IOTA - 418) & 511)])) + (0.000319872983f * fVec44[((IOTA - 421) & 511)])) + (0.00155995507f * fVec44[((IOTA - 422) & 511)])) + (0.00275658956f * fVec44[((IOTA - 423) & 511)])) + (0.00404581102f * fVec44[((IOTA - 424) & 511)])) + (0.00444331439f * fVec44[((IOTA - 425) & 511)])) + (0.00300475676f * fVec44[((IOTA - 426) & 511)])) + (0.000919656828f * fVec44[((IOTA - 427) & 511)])) + (0.000882250257f * fVec44[((IOTA - 430) & 511)])) + (0.00364040816f * fVec44[((IOTA - 431) & 511)])) + (0.00607799552f * fVec44[((IOTA - 432) & 511)])) + (0.00772600714f * fVec44[((IOTA - 433) & 511)])) + (0.00849571824f * fVec44[((IOTA - 434) & 511)])) + (0.00849356875f * fVec44[((IOTA - 435) & 511)])) + (0.0085391365f * fVec44[((IOTA - 436) & 511)])) + (0.00890934002f * fVec44[((IOTA - 437) & 511)])) + (0.00978133827f * fVec44[((IOTA - 438) & 511)])) + (0.0105932187f * fVec44[((IOTA - 439) & 511)])) + (0.01061018f * fVec44[((IOTA - 440) & 511)])) + (0.0108305831f * fVec44[((IOTA - 441) & 511)])) + (0.0109004881f * fVec44[((IOTA - 442) & 511)])) + (0.0103451097f * fVec44[((IOTA - 443) & 511)])) + (0.00908304285f * fVec44[((IOTA - 444) & 511)])) + (0.00700883381f * fVec44[((IOTA - 445) & 511)])) + (0.00526820589f * fVec44[((IOTA - 446) & 511)])) + (0.00476179365f * fVec44[((IOTA - 447) & 511)])) + (0.00584350713f * fVec44[((IOTA - 448) & 511)])) + (0.00758134667f * fVec44[((IOTA - 449) & 511)])) + (0.00878849439f * fVec44[((IOTA - 450) & 511)])) + (0.00881605595f * fVec44[((IOTA - 451) & 511)])) + (0.00730962586f * fVec44[((IOTA - 452) & 511)])) + (0.00477936398f * fVec44[((IOTA - 453) & 511)])) + (0.00222909218f * fVec44[((IOTA - 454) & 511)])) + (0.00139903091f * fVec44[((IOTA - 455) & 511)])) + (0.00313855521f * fVec44[((IOTA - 456) & 511)])) + (0.00640338659f * fVec44[((IOTA - 457) & 511)])) + (0.00956924167f * fVec44[((IOTA - 458) & 511)])) + (0.0109945852f * fVec44[((IOTA - 459) & 511)])) + (0.0102726491f * fVec44[((IOTA - 460) & 511)])) + (0.00791350473f * fVec44[((IOTA - 461) & 511)])) + (0.00495527405f * fVec44[((IOTA - 462) & 511)])) + (0.00315052085f * fVec44[((IOTA - 463) & 511)])) + (0.00365571352f * fVec44[((IOTA - 464) & 511)])) + (0.00574580859f * fVec44[((IOTA - 465) & 511)])) + (0.00788968988f * fVec44[((IOTA - 466) & 511)])) + (0.00884138048f * fVec44[((IOTA - 467) & 511)])) + (0.00802511536f * fVec44[((IOTA - 468) & 511)])) + (0.00588907488f * fVec44[((IOTA - 469) & 511)])) + (0.00300490204f * fVec44[((IOTA - 470) & 511)])) + (0.000378364697f * fVec44[((IOTA - 471) & 511)])) + (0.00074145291f * fVec44[((IOTA - 473) & 511)])) + (0.001977643f * fVec44[((IOTA - 474) & 511)])) + (0.0030299658f * fVec44[((IOTA - 475) & 511)])) + (0.0033453661f * fVec44[((IOTA - 476) & 511)])) + (0.00350297941f * fVec44[((IOTA - 477) & 511)])) + (0.00435215048f * fVec44[((IOTA - 478) & 511)])) + (0.00608185818f * fVec44[((IOTA - 479) & 511)])) + (0.00878181495f * fVec44[((IOTA - 480) & 511)])) + (0.0118284803f * fVec44[((IOTA - 481) & 511)])) + (0.0140664876f * fVec44[((IOTA - 482) & 511)])) + (0.0147524988f * fVec44[((IOTA - 483) & 511)])) + (0.0130859297f * fVec44[((IOTA - 484) & 511)])) + (0.00945199747f * fVec44[((IOTA - 485) & 511)])) + (0.00567979505f * fVec44[((IOTA - 486) & 511)])) + (0.0029010172f * fVec44[((IOTA - 487) & 511)])) + (0.00148490956f * fVec44[((IOTA - 488) & 511)])) + (0.00157926837f * fVec44[((IOTA - 489) & 511)])) + (0.00211783079f * fVec44[((IOTA - 490) & 511)])) + (0.00263347849f * fVec44[((IOTA - 491) & 511)])) + (0.00317892432f * fVec44[((IOTA - 492) & 511)])) + (0.0028350912f * fVec44[((IOTA - 493) & 511)])) + (0.00231624814f * fVec44[((IOTA - 494) & 511)])) + (0.00245585525f * fVec44[((IOTA - 495) & 511)])) + (0.00263789296f * fVec44[((IOTA - 496) & 511)])) + (0.00275388826f * fVec44[((IOTA - 497) & 511)])) + (0.00226196833f * fVec44[((IOTA - 498) & 511)])) + (0.000831367914f * fVec44[((IOTA - 499) & 511)])) + (0.000198737253f * fVec44[((IOTA - 502) & 511)])) + (0.0036255382f * fVec44[((IOTA - 503) & 511)])) + (0.00827368908f * fVec44[((IOTA - 504) & 511)])) + (0.0125245098f * fVec44[((IOTA - 505) & 511)])) + (0.0155080371f * fVec44[((IOTA - 506) & 511)])) + (0.0159360934f * fVec44[((IOTA - 507) & 511)])) + (0.0140130501f * fVec44[((IOTA - 508) & 511)])) + (0.0108658113f * fVec44[((IOTA - 509) & 511)])) + (0.00708297919f * fVec44[((IOTA - 510) & 511)])) + (0.00467722211f * fVec44[((IOTA - 511) & 511)]))))))) : (iSlow91 ? (iSlow115 ? (iSlow127 ? (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((fSlow134 * fTemp0) + (0.226166099f * fVec43[((IOTA - 1) & 511)])) + (0.267378777f * fVec43[((IOTA - 2) & 511)])) + (0.210294545f * fVec43[((IOTA - 3) & 511)])) + (0.0880075395f * fVec43[((IOTA - 4) & 511)])) + (0.0652625412f * fVec43[((IOTA - 10) & 511)])) + (0.107986815f * fVec43[((IOTA - 11) & 511)])) + (0.0790698752f * fVec43[((IOTA - 12) & 511)])) + (0.0270165764f * fVec43[((IOTA - 13) & 511)])) + (0.0117110675f * fVec43[((IOTA - 15) & 511)])) + (0.0335250795f * fVec43[((IOTA - 16) & 511)])) + (0.0323265381f * fVec43[((IOTA - 17) & 511)])) + (0.0124030579f * fVec43[((IOTA - 18) & 511)])) + (0.0237343423f * fVec43[((IOTA - 23) & 511)])) + (0.0470984057f * fVec43[((IOTA - 24) & 511)])) + (0.0536949746f * fVec43[((IOTA - 25) & 511)])) + (0.0317111649f * fVec43[((IOTA - 26) & 511)])) + (0.00106085092f * fVec43[((IOTA - 27) & 511)])) + (0.0196522884f * fVec43[((IOTA - 34) & 511)])) + (0.0342553779f * fVec43[((IOTA - 35) & 511)])) + (0.0265564155f * fVec43[((IOTA - 36) & 511)])) + (0.0144037632f * fVec43[((IOTA - 37) & 511)])) + (0.00892109983f * fVec43[((IOTA - 38) & 511)])) + (0.000195302535f * fVec43[((IOTA - 49) & 511)])) + (0.00449460139f * fVec43[((IOTA - 50) & 511)])) + (0.00198622094f * fVec43[((IOTA - 51) & 511)])) + (0.0163493007f * fVec43[((IOTA - 58) & 511)])) + (0.0288808104f * fVec43[((IOTA - 59) & 511)])) + (0.026863277f * fVec43[((IOTA - 60) & 511)])) + (0.0116364965f * fVec43[((IOTA - 61) & 511)])) + (0.00452475995f * fVec43[((IOTA - 74) & 511)])) + (0.00897824857f * fVec43[((IOTA - 75) & 511)])) + (0.00605662726f * fVec43[((IOTA - 76) & 511)])) + (0.00276518799f * fVec43[((IOTA - 77) & 511)])) + (0.00523380842f * fVec43[((IOTA - 92) & 511)])) + (0.00883540884f * fVec43[((IOTA - 93) & 511)])) + (0.00910036638f * fVec43[((IOTA - 94) & 511)])) + (0.0044671162f * fVec43[((IOTA - 95) & 511)])) + (0.00212358264f * fVec43[((IOTA - 108) & 511)])) + (0.0092678871f * fVec43[((IOTA - 109) & 511)])) + (0.0103631858f * fVec43[((IOTA - 110) & 511)])) + (0.0073169712f * fVec43[((IOTA - 111) & 511)])) + (0.00181130972f * fVec43[((IOTA - 112) & 511)])) + (4.55342233e-05f * fVec43[((IOTA - 128) & 511)])) + (0.0030321246f * fVec43[((IOTA - 129) & 511)])) + (0.00572637143f * fVec43[((IOTA - 130) & 511)])) + (0.00875542685f * fVec43[((IOTA - 131) & 511)])) + (0.00903589278f * fVec43[((IOTA - 132) & 511)])) + (0.00646924088f * fVec43[((IOTA - 133) & 511)])) + (0.00313975709f * fVec43[((IOTA - 134) & 511)])) + (0.00140394224f * fVec43[((IOTA - 146) & 511)])) + (0.00350132631f * fVec43[((IOTA - 147) & 511)])) + (0.0048118569f * fVec43[((IOTA - 148) & 511)])) + (0.00454426045f * fVec43[((IOTA - 149) & 511)])) + (0.00263346825f * fVec43[((IOTA - 150) & 511)])) + (0.000830704812f * fVec43[((IOTA - 151) & 511)])) + (0.000322270673f * fVec43[((IOTA - 153) & 511)])) + (0.00237946585f * fVec43[((IOTA - 154) & 511)])) + (0.00344199967f * fVec43[((IOTA - 155) & 511)])) + (0.00239038747f * fVec43[((IOTA - 156) & 511)])) + (0.000130960718f * fVec43[((IOTA - 164) & 511)])) + (0.000791406725f * fVec43[((IOTA - 165) & 511)])) + (0.000902932603f * fVec43[((IOTA - 166) & 511)])) + (0.00115376757f * fVec43[((IOTA - 167) & 511)])) + (0.0016832524f * fVec43[((IOTA - 168) & 511)])) + (0.00189901283f * fVec43[((IOTA - 169) & 511)])) + (0.00256404467f * fVec43[((IOTA - 170) & 511)])) + (0.0036885119f * fVec43[((IOTA - 171) & 511)])) + (0.00408825697f * fVec43[((IOTA - 172) & 511)])) + (0.00422099978f * fVec43[((IOTA - 173) & 511)])) + (0.00355689134f * fVec43[((IOTA - 174) & 511)])) + (0.00109328609f * fVec43[((IOTA - 175) & 511)])) + (0.00290010823f * fVec43[((IOTA - 180) & 511)])) + (0.00685146544f * fVec43[((IOTA - 181) & 511)])) + (0.00962678343f * fVec43[((IOTA - 182) & 511)])) + (0.00977044739f * fVec43[((IOTA - 183) & 511)])) + (0.00737659493f * fVec43[((IOTA - 184) & 511)])) + (0.00422047172f * fVec43[((IOTA - 185) & 511)])) + (0.00196302449f * fVec43[((IOTA - 186) & 511)])) + (0.000699578784f * fVec43[((IOTA - 187) & 511)])) + (0.000319136307f * fVec43[((IOTA - 188) & 511)])) + (0.000554100145f * fVec43[((IOTA - 189) & 511)])) + (0.00171750225f * fVec43[((IOTA - 190) & 511)])) + (0.00397966756f * fVec43[((IOTA - 191) & 511)])) + (0.00623757672f * fVec43[((IOTA - 192) & 511)])) + (0.00800929125f * fVec43[((IOTA - 193) & 511)])) + (0.00862077065f * fVec43[((IOTA - 194) & 511)])) + (0.00746043772f * fVec43[((IOTA - 195) & 511)])) + (0.0051457095f * fVec43[((IOTA - 196) & 511)])) + (0.00235871132f * fVec43[((IOTA - 197) & 511)])) + (0.000397435389f * fVec43[((IOTA - 198) & 511)])) + (5.35193831e-05f * fVec43[((IOTA - 199) & 511)])) + (0.000565186609f * fVec43[((IOTA - 200) & 511)])) + (0.0017412263f * fVec43[((IOTA - 201) & 511)])) + (0.00294514745f * fVec43[((IOTA - 202) & 511)])) + (0.00325405505f * fVec43[((IOTA - 203) & 511)])) + (0.00275558606f * fVec43[((IOTA - 204) & 511)])) + (0.00134026026f * fVec43[((IOTA - 205) & 511)])) + (0.000285282265f * fVec43[((IOTA - 206) & 511)])) + (0.00134666124f * fVec43[((IOTA - 207) & 511)])) + (0.00401599612f * fVec43[((IOTA - 208) & 511)])) + (0.00662154984f * fVec43[((IOTA - 209) & 511)])) + (0.00790449604f * fVec43[((IOTA - 210) & 511)])) + (0.00698757311f * fVec43[((IOTA - 211) & 511)])) + (0.00452056946f * fVec43[((IOTA - 212) & 511)])) + (0.00196520239f * fVec43[((IOTA - 213) & 511)])) + (0.000311778393f * fVec43[((IOTA - 216) & 511)])) + (0.0032520094f * fVec43[((IOTA - 217) & 511)])) + (0.00665154308f * fVec43[((IOTA - 218) & 511)])) + (0.00926607195f * fVec43[((IOTA - 219) & 511)])) + (0.0098013971f * fVec43[((IOTA - 220) & 511)])) + (0.00857566576f * fVec43[((IOTA - 221) & 511)])) + (0.00641169585f * fVec43[((IOTA - 222) & 511)])) + (0.0043986165f * fVec43[((IOTA - 223) & 511)])) + (0.00348106679f * fVec43[((IOTA - 224) & 511)])) + (0.00376625033f * fVec43[((IOTA - 225) & 511)])) + (0.00451915059f * fVec43[((IOTA - 226) & 511)])) + (0.00522212824f * fVec43[((IOTA - 227) & 511)])) + (0.00546243694f * fVec43[((IOTA - 228) & 511)])) + (0.00480991043f * fVec43[((IOTA - 229) & 511)])) + (0.00422730204f * fVec43[((IOTA - 230) & 511)])) + (0.00388282491f * fVec43[((IOTA - 231) & 511)])) + (0.00374354888f * fVec43[((IOTA - 232) & 511)])) + (0.00423221849f * fVec43[((IOTA - 233) & 511)])) + (0.00451439898f * fVec43[((IOTA - 234) & 511)])) + (0.00471158279f * fVec43[((IOTA - 235) & 511)])) + (0.00485818321f * fVec43[((IOTA - 236) & 511)])) + (0.0043338784f * fVec43[((IOTA - 237) & 511)])) + (0.00399312982f * fVec43[((IOTA - 238) & 511)])) + (0.00423284527f * fVec43[((IOTA - 239) & 511)])) + (0.00448367978f * fVec43[((IOTA - 240) & 511)])) + (0.00480799656f * fVec43[((IOTA - 241) & 511)])) + (0.00487771677f * fVec43[((IOTA - 242) & 511)])) + (0.00445873523f * fVec43[((IOTA - 243) & 511)])) + (0.00391176203f * fVec43[((IOTA - 244) & 511)])) + (0.00310778432f * fVec43[((IOTA - 245) & 511)])) + (0.00207761955f * fVec43[((IOTA - 246) & 511)])) + (0.00145452516f * fVec43[((IOTA - 247) & 511)])) + (0.00164352544f * fVec43[((IOTA - 248) & 511)])) + (0.00244974717f * fVec43[((IOTA - 249) & 511)])) + (0.00355626456f * fVec43[((IOTA - 250) & 511)])) + (0.00480621494f * fVec43[((IOTA - 251) & 511)])) + (0.00582354423f * fVec43[((IOTA - 252) & 511)])) + (0.00627004448f * fVec43[((IOTA - 253) & 511)])) + (0.00616917619f * fVec43[((IOTA - 254) & 511)])) + (0.00578879938f * fVec43[((IOTA - 255) & 511)])) + (0.00586531684f * fVec43[((IOTA - 256) & 511)])) + (0.00684833061f * fVec43[((IOTA - 257) & 511)])) + (0.00824484881f * fVec43[((IOTA - 258) & 511)])) + (0.0090485299f * fVec43[((IOTA - 259) & 511)])) + (0.00874605589f * fVec43[((IOTA - 260) & 511)])) + (0.0076604588f * fVec43[((IOTA - 261) & 511)])) + (0.00609952165f * fVec43[((IOTA - 262) & 511)])) + (0.00457831239f * fVec43[((IOTA - 263) & 511)])) + (0.0037746313f * fVec43[((IOTA - 264) & 511)])) + (0.00370240305f * fVec43[((IOTA - 265) & 511)])) + (0.00376499631f * fVec43[((IOTA - 266) & 511)])) + (0.00365228252f * fVec43[((IOTA - 267) & 511)])) + (0.00354946731f * fVec43[((IOTA - 268) & 511)])) + (0.00386335701f * fVec43[((IOTA - 269) & 511)])) + (0.00468525197f * fVec43[((IOTA - 270) & 511)])) + (0.00550226308f * fVec43[((IOTA - 271) & 511)])) + (0.00594058074f * fVec43[((IOTA - 272) & 511)])) + (0.00554825924f * fVec43[((IOTA - 273) & 511)])) + (0.0039786119f * fVec43[((IOTA - 274) & 511)])) + (0.00217508944f * fVec43[((IOTA - 275) & 511)])) + (0.00116891274f * fVec43[((IOTA - 276) & 511)])) + (0.00132788671f * fVec43[((IOTA - 277) & 511)])) + (0.00266045891f * fVec43[((IOTA - 278) & 511)])) + (0.00412197877f * fVec43[((IOTA - 279) & 511)])) + (0.00463018194f * fVec43[((IOTA - 280) & 511)])) + (0.00403199904f * fVec43[((IOTA - 281) & 511)])) + (0.0025787279f * fVec43[((IOTA - 282) & 511)])) + (0.00111799967f * fVec43[((IOTA - 283) & 511)])) + (0.000528594013f * fVec43[((IOTA - 284) & 511)])) + (0.000888810493f * fVec43[((IOTA - 285) & 511)])) + (0.00188073283f * fVec43[((IOTA - 286) & 511)])) + (0.00325841038f * fVec43[((IOTA - 287) & 511)])) + (0.00459322613f * fVec43[((IOTA - 288) & 511)])) + (0.0057635908f * fVec43[((IOTA - 289) & 511)])) + (0.00647343136f * fVec43[((IOTA - 290) & 511)])) + (0.00627053948f * fVec43[((IOTA - 291) & 511)])) + (0.00541050173f * fVec43[((IOTA - 292) & 511)])) + (0.00431668758f * fVec43[((IOTA - 293) & 511)])) + (0.00312857144f * fVec43[((IOTA - 294) & 511)])) + (0.00227447273f * fVec43[((IOTA - 295) & 511)])) + (0.00227787159f * fVec43[((IOTA - 296) & 511)])) + (0.00294871116f * fVec43[((IOTA - 297) & 511)])) + (0.00409868406f * fVec43[((IOTA - 298) & 511)])) + (0.00543524837f * fVec43[((IOTA - 299) & 511)])) + (0.00612459891f * fVec43[((IOTA - 300) & 511)])) + (0.00587511668f * fVec43[((IOTA - 301) & 511)])) + (0.00477242703f * fVec43[((IOTA - 302) & 511)])) + (0.00314289192f * fVec43[((IOTA - 303) & 511)])) + (0.00212962087f * fVec43[((IOTA - 304) & 511)])) + (0.002538539f * fVec43[((IOTA - 305) & 511)])) + (0.00408053631f * fVec43[((IOTA - 306) & 511)])) + (0.00621965993f * fVec43[((IOTA - 307) & 511)])) + (0.00791366957f * fVec43[((IOTA - 308) & 511)])) + (0.00807343516f * fVec43[((IOTA - 309) & 511)])) + (0.00650428236f * fVec43[((IOTA - 310) & 511)])) + (0.00356880296f * fVec43[((IOTA - 311) & 511)])) + (0.000459731556f * fVec43[((IOTA - 312) & 511)])) + (0.000500448514f * fVec43[((IOTA - 319) & 511)])) + (0.0019855937f * fVec43[((IOTA - 320) & 511)])) + (0.00272358023f * fVec43[((IOTA - 321) & 511)])) + (0.00267362408f * fVec43[((IOTA - 322) & 511)])) + (0.00128908362f * fVec43[((IOTA - 323) & 511)])) + (0.000388790388f * fVec43[((IOTA - 328) & 511)])) + (0.00143462839f * fVec43[((IOTA - 329) & 511)])) + (0.00181272859f * fVec43[((IOTA - 330) & 511)])) + (0.00146010146f * fVec43[((IOTA - 331) & 511)])) + (0.00116181839f * fVec43[((IOTA - 332) & 511)])) + (0.00182312215f * fVec43[((IOTA - 333) & 511)])) + (0.00306957494f * fVec43[((IOTA - 334) & 511)])) + (0.00397452014f * fVec43[((IOTA - 335) & 511)])) + (0.00417180266f * fVec43[((IOTA - 336) & 511)])) + (0.00378895132f * fVec43[((IOTA - 337) & 511)])) + (0.003294277f * fVec43[((IOTA - 338) & 511)])) + (0.00304433331f * fVec43[((IOTA - 339) & 511)])) + (0.00266715698f * fVec43[((IOTA - 340) & 511)])) + (0.00237187697f * fVec43[((IOTA - 341) & 511)])) + (0.00248993607f * fVec43[((IOTA - 342) & 511)])) + (0.00248363381f * fVec43[((IOTA - 343) & 511)])) + (0.00241005328f * fVec43[((IOTA - 344) & 511)])) + (0.00218709977f * fVec43[((IOTA - 345) & 511)])) + (0.00172205549f * fVec43[((IOTA - 346) & 511)])) + (0.00144729903f * fVec43[((IOTA - 347) & 511)])) + (0.00152883166f * fVec43[((IOTA - 348) & 511)])) + (0.00201575225f * fVec43[((IOTA - 349) & 511)])) + (0.00276690349f * fVec43[((IOTA - 350) & 511)])) + (0.00325732166f * fVec43[((IOTA - 351) & 511)])) + (0.00344919274f * fVec43[((IOTA - 352) & 511)])) + (0.00326814409f * fVec43[((IOTA - 353) & 511)])) + (0.00225391658f * fVec43[((IOTA - 354) & 511)])) + (0.000748016872f * fVec43[((IOTA - 355) & 511)])) + (0.000114792492f * fVec43[((IOTA - 368) & 511)])) + (0.000413471367f * fVec43[((IOTA - 377) & 511)])) + (0.000600657426f * fVec43[((IOTA - 378) & 511)])) + (0.000211668666f * fVec43[((IOTA - 379) & 511)])) + (0.000187317841f * fVec43[((IOTA - 386) & 511)])) + (0.000507378019f * fVec43[((IOTA - 387) & 511)])) + (0.00012007216f * fVec43[((IOTA - 388) & 511)])) + (0.000315836631f * fVec43[((IOTA - 399) & 511)])) + (0.000928603578f * fVec43[((IOTA - 400) & 511)])) + (0.00112093659f * fVec43[((IOTA - 401) & 511)])) + (0.000473788008f * fVec43[((IOTA - 402) & 511)])) + (0.000241266098f * fVec43[((IOTA - 425) & 511)])) + (0.00036414247f * fVec43[((IOTA - 426) & 511)])) + (6.95222989e-05f * fVec43[((IOTA - 427) & 511)])) + (0.000742737669f * fVec43[((IOTA - 467) & 511)])) + (0.00117099145f * fVec43[((IOTA - 468) & 511)])) + (0.000898742117f * fVec43[((IOTA - 469) & 511)])) + (8.50302167e-05f * fVec43[((IOTA - 470) & 511)])) - ((((((((0.00297877006f * fVec43[((IOTA - 504) & 511)]) + ((0.003221191f * fVec43[((IOTA - 503) & 511)]) + ((0.00387929427f * fVec43[((IOTA - 502) & 511)]) + ((0.00438663922f * fVec43[((IOTA - 501) & 511)]) + ((0.00397996465f * fVec43[((IOTA - 500) & 511)]) + ((0.00289872242f * fVec43[((IOTA - 499) & 511)]) + ((0.00160465622f * fVec43[((IOTA - 498) & 511)]) + ((0.000542419497f * fVec43[((IOTA - 497) & 511)]) + ((0.000358698424f * fVec43[((IOTA - 496) & 511)]) + ((0.00085393386f * fVec43[((IOTA - 495) & 511)]) + ((0.00121226907f * fVec43[((IOTA - 494) & 511)]) + ((0.00112994434f * fVec43[((IOTA - 493) & 511)]) + ((0.000610456802f * fVec43[((IOTA - 492) & 511)]) + ((0.000199130271f * fVec43[((IOTA - 491) & 511)]) + ((0.000666418113f * fVec43[((IOTA - 490) & 511)]) + ((0.00162550947f * fVec43[((IOTA - 489) & 511)]) + ((0.00273354491f * fVec43[((IOTA - 488) & 511)]) + ((0.00336363446f * fVec43[((IOTA - 487) & 511)]) + ((0.00291888276f * fVec43[((IOTA - 486) & 511)]) + ((0.00221207784f * fVec43[((IOTA - 485) & 511)]) + ((0.00169367902f * fVec43[((IOTA - 484) & 511)]) + ((0.00139348255f * fVec43[((IOTA - 483) & 511)]) + ((0.00143459532f * fVec43[((IOTA - 482) & 511)]) + ((0.00159795815f * fVec43[((IOTA - 481) & 511)]) + ((0.0019286098f * fVec43[((IOTA - 480) & 511)]) + ((0.00223596673f * fVec43[((IOTA - 479) & 511)]) + ((0.00213334942f * fVec43[((IOTA - 478) & 511)]) + ((0.00214278651f * fVec43[((IOTA - 477) & 511)]) + ((0.00247881655f * fVec43[((IOTA - 476) & 511)]) + ((0.00269177184f * fVec43[((IOTA - 475) & 511)]) + ((0.00260014227f * fVec43[((IOTA - 474) & 511)]) + ((0.00204082904f * fVec43[((IOTA - 473) & 511)]) + ((0.00129538588f * fVec43[((IOTA - 472) & 511)]) + ((0.000704858452f * fVec43[((IOTA - 471) & 511)]) + ((0.000557861757f * fVec43[((IOTA - 466) & 511)]) + ((0.00216842396f * fVec43[((IOTA - 465) & 511)]) + ((0.00302790105f * fVec43[((IOTA - 464) & 511)]) + ((0.00326441554f * fVec43[((IOTA - 463) & 511)]) + ((0.00327329151f * fVec43[((IOTA - 462) & 511)]) + ((0.00278455624f * fVec43[((IOTA - 461) & 511)]) + ((0.00222359318f * fVec43[((IOTA - 460) & 511)]) + ((0.00197259337f * fVec43[((IOTA - 459) & 511)]) + ((0.00206963439f * fVec43[((IOTA - 458) & 511)]) + (((0.00452080043f * fVec43[((IOTA - 438) & 511)]) + ((0.00411518198f * (fVec43[((IOTA - 138) & 511)] + fVec43[((IOTA - 437) & 511)])) + ((0.00286674919f * fVec43[((IOTA - 455) & 511)]) + ((0.002547679f * fVec43[((IOTA - 454) & 511)]) + ((0.00202921452f * fVec43[((IOTA - 453) & 511)]) + ((0.00152259553f * fVec43[((IOTA - 452) & 511)]) + ((0.00158660766f * fVec43[((IOTA - 451) & 511)]) + ((0.00189333735f * fVec43[((IOTA - 450) & 511)]) + ((0.00204990292f * fVec43[((IOTA - 449) & 511)]) + ((0.00215202523f * fVec43[((IOTA - 448) & 511)]) + ((0.00190145429f * fVec43[((IOTA - 447) & 511)]) + ((0.00187086733f * fVec43[((IOTA - 446) & 511)]) + ((0.00244278507f * fVec43[((IOTA - 445) & 511)]) + ((0.00318063935f * fVec43[((IOTA - 444) & 511)]) + ((0.00429662643f * fVec43[((IOTA - 443) & 511)]) + ((0.00541099673f * fVec43[((IOTA - 442) & 511)]) + ((0.00592698622f * fVec43[((IOTA - 441) & 511)]) + ((0.00596918818f * fVec43[((IOTA - 440) & 511)]) + ((0.00294135278f * fVec43[((IOTA - 456) & 511)]) + ((0.00398392417f * fVec43[((IOTA - 436) & 511)]) + ((0.00442534313f * fVec43[((IOTA - 435) & 511)]) + ((0.00512634078f * fVec43[((IOTA - 434) & 511)]) + ((0.00515969982f * fVec43[((IOTA - 433) & 511)]) + ((0.00473236991f * fVec43[((IOTA - 432) & 511)]) + ((0.00384161295f * fVec43[((IOTA - 431) & 511)]) + ((0.00246809283f * fVec43[((IOTA - 430) & 511)]) + ((0.0013291738f * fVec43[((IOTA - 429) & 511)]) + ((0.000554595143f * fVec43[((IOTA - 428) & 511)]) + ((0.00023278594f * fVec43[((IOTA - 424) & 511)]) + ((0.00095882779f * fVec43[((IOTA - 423) & 511)]) + ((0.00162329897f * fVec43[((IOTA - 422) & 511)]) + ((0.00203086436f * fVec43[((IOTA - 421) & 511)]) + ((0.00258865999f * fVec43[((IOTA - 420) & 511)]) + ((0.003100459f * fVec43[((IOTA - 419) & 511)]) + ((0.00331097282f * fVec43[((IOTA - 418) & 511)]) + ((0.00349301146f * fVec43[((IOTA - 417) & 511)]) + ((0.00331232557f * fVec43[((IOTA - 416) & 511)]) + ((0.00287150079f * fVec43[((IOTA - 415) & 511)]) + ((0.00257259095f * fVec43[((IOTA - 414) & 511)]) + ((0.00225048512f * fVec43[((IOTA - 413) & 511)]) + ((0.00164801301f * fVec43[((IOTA - 412) & 511)]) + ((0.000902635511f * fVec43[((IOTA - 411) & 511)]) + ((0.000438119285f * fVec43[((IOTA - 410) & 511)]) + ((0.000678197481f * fVec43[((IOTA - 409) & 511)]) + ((0.00125810038f * fVec43[((IOTA - 408) & 511)]) + ((0.0018159952f * fVec43[((IOTA - 407) & 511)]) + ((0.00230506016f * fVec43[((IOTA - 406) & 511)]) + ((0.00223646173f * fVec43[((IOTA - 405) & 511)]) + ((0.00171192596f * fVec43[((IOTA - 404) & 511)]) + ((0.00081717642f * fVec43[((IOTA - 403) & 511)]) + ((0.000971597154f * fVec43[((IOTA - 398) & 511)]) + ((0.00255741272f * fVec43[((IOTA - 397) & 511)]) + ((0.00359533168f * fVec43[((IOTA - 396) & 511)]) + ((0.00406446727f * fVec43[((IOTA - 395) & 511)]) + ((0.00398118561f * fVec43[((IOTA - 394) & 511)]) + ((0.00333430106f * fVec43[((IOTA - 393) & 511)]) + ((0.00277459156f * fVec43[((IOTA - 392) & 511)]) + ((0.00214057555f * fVec43[((IOTA - 391) & 511)]) + ((0.00121065229f * fVec43[((IOTA - 390) & 511)]) + ((0.00049965689f * fVec43[((IOTA - 389) & 511)]) + ((0.000578781124f * fVec43[((IOTA - 385) & 511)]) + ((0.00164689124f * fVec43[((IOTA - 384) & 511)]) + ((0.00263973745f * fVec43[((IOTA - 383) & 511)]) + ((0.0027218312f * fVec43[((IOTA - 382) & 511)]) + ((0.00214305008f * fVec43[((IOTA - 381) & 511)]) + ((0.00103679718f * fVec43[((IOTA - 380) & 511)]) + ((0.000537404325f * fVec43[((IOTA - 376) & 511)]) + ((0.00262317341f * fVec43[((IOTA - 375) & 511)]) + ((0.00448018219f * fVec43[((IOTA - 374) & 511)]) + (((0.00507037994f * fVec43[((IOTA - 372) & 511)]) + ((0.00342365401f * fVec43[((IOTA - 371) & 511)]) + ((0.00148478243f * fVec43[((IOTA - 370) & 511)]) + ((0.000277924351f * fVec43[((IOTA - 369) & 511)]) + ((0.000380178913f * fVec43[((IOTA - 367) & 511)]) + ((0.00107243238f * fVec43[((IOTA - 366) & 511)]) + ((0.00135761593f * fVec43[((IOTA - 365) & 511)]) + ((0.0013356409f * fVec43[((IOTA - 364) & 511)]) + ((0.000799061731f * fVec43[((IOTA - 363) & 511)]) + ((0.000303463079f * fVec43[((IOTA - 362) & 511)]) + ((0.000742671546f * fVec43[((IOTA - 361) & 511)]) + ((0.00180009101f * fVec43[((IOTA - 360) & 511)]) + ((0.00276244897f * fVec43[((IOTA - 359) & 511)]) + ((0.00312292948f * fVec43[((IOTA - 358) & 511)]) + ((0.00243714266f * fVec43[((IOTA - 357) & 511)]) + ((0.000894122757f * fVec43[((IOTA - 356) & 511)]) + ((0.00124589214f * fVec43[((IOTA - 327) & 511)]) + ((0.00234366534f * fVec43[((IOTA - 326) & 511)]) + ((0.00201756693f * fVec43[((IOTA - 325) & 511)]) + ((0.000679748598f * fVec43[((IOTA - 324) & 511)]) + ((0.00119989552f * fVec43[((IOTA - 318) & 511)]) + ((0.00209649326f * fVec43[((IOTA - 317) & 511)]) + ((0.00218102848f * fVec43[((IOTA - 316) & 511)]) + ((0.00193781592f * fVec43[((IOTA - 315) & 511)]) + (((0.00172941387f * fVec43[((IOTA - 314) & 511)]) + ((0.00129277911f * fVec43[((IOTA - 313) & 511)]) + ((0.00534147443f * fVec43[((IOTA - 373) & 511)]) + ((0.00118059292f * fVec43[((IOTA - 215) & 511)]) + ((0.000279178377f * fVec43[((IOTA - 214) & 511)]) + ((0.00130162202f * fVec43[((IOTA - 179) & 511)]) + ((0.00462744292f * fVec43[((IOTA - 178) & 511)]) + ((0.00472874055f * fVec43[((IOTA - 177) & 511)]) + ((0.00215255329f * fVec43[((IOTA - 176) & 511)]) + ((0.00185397314f * fVec43[((IOTA - 163) & 511)]) + ((0.00528844958f * fVec43[((IOTA - 162) & 511)]) + ((0.00842009019f * fVec43[((IOTA - 161) & 511)]) + ((0.00929669198f * fVec43[((IOTA - 160) & 511)]) + ((0.00784322247f * fVec43[((IOTA - 159) & 511)]) + ((0.00473976089f * fVec43[((IOTA - 158) & 511)]) + ((0.000747885089f * fVec43[((IOTA - 157) & 511)]) + ((0.000208963174f * fVec43[((IOTA - 152) & 511)]) + ((0.00136876851f * fVec43[((IOTA - 145) & 511)]) + ((0.00341434916f * fVec43[((IOTA - 144) & 511)]) + ((0.00433599018f * fVec43[((IOTA - 143) & 511)]) + ((0.0050465567f * fVec43[((IOTA - 142) & 511)]) + ((0.00458068773f * fVec43[((IOTA - 141) & 511)]) + ((0.00337142125f * fVec43[((IOTA - 140) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0142277628f * fVec43[((IOTA - 43) & 511)]) + ((0.00945870206f * fVec43[((IOTA - 42) & 511)]) + ((0.00900619663f * fVec43[((IOTA - 41) & 511)]) + ((0.0110591017f * fVec43[((IOTA - 40) & 511)]) + ((0.00366076222f * fVec43[((IOTA - 39) & 511)]) + ((0.0106876008f * fVec43[((IOTA - 33) & 511)]) + ((0.0432526991f * fVec43[((IOTA - 32) & 511)]) + ((0.0650593564f * fVec43[((IOTA - 31) & 511)]) + ((0.0702286586f * fVec43[((IOTA - 30) & 511)]) + ((0.0546080731f * fVec43[((IOTA - 29) & 511)]) + ((0.0271720514f * fVec43[((IOTA - 28) & 511)]) + ((0.00430735014f * fVec43[((IOTA - 22) & 511)]) + ((0.0321226902f * fVec43[((IOTA - 21) & 511)]) + ((0.0352727436f * fVec43[((IOTA - 20) & 511)]) + ((0.0133023597f * fVec43[((IOTA - 19) & 511)]) + ((0.00100360299f * fVec43[((IOTA - 14) & 511)]) + ((0.056833908f * fVec43[((IOTA - 9) & 511)]) + ((0.188104868f * fVec43[((IOTA - 8) & 511)]) + ((0.249381736f * fVec43[((IOTA - 7) & 511)]) + ((0.22239694f * fVec43[((IOTA - 6) & 511)]) + ((0.0941588655f * fVec43[((IOTA - 5) & 511)]) + (((0.0276939478f * fVec43[((IOTA - 44) & 511)]) + ((0.033925917f * fVec43[((IOTA - 45) & 511)]) + (0.0226415843f * fVec43[((IOTA - 46) & 511)]))) + (0.0098064132f * fVec43[((IOTA - 47) & 511)]))))))))))))))))))))))) + (0.00489345612f * fVec43[((IOTA - 48) & 511)])) + (0.0024223933f * fVec43[((IOTA - 52) & 511)])) + (0.0139044691f * fVec43[((IOTA - 53) & 511)])) + (0.0310570542f * fVec43[((IOTA - 54) & 511)])) + (0.0358279645f * fVec43[((IOTA - 55) & 511)])) + (0.0276566632f * fVec43[((IOTA - 56) & 511)])) + (0.00849878509f * fVec43[((IOTA - 57) & 511)])) + (0.0126888016f * fVec43[((IOTA - 62) & 511)])) + (0.0288577788f * fVec43[((IOTA - 63) & 511)])) + (0.0333647877f * fVec43[((IOTA - 64) & 511)])) + (0.0290881563f * fVec43[((IOTA - 65) & 511)])) + (0.0181284063f * fVec43[((IOTA - 66) & 511)])) + (0.00926920585f * fVec43[((IOTA - 67) & 511)])) + (0.00754708471f * fVec43[((IOTA - 68) & 511)])) + (0.00917694997f * fVec43[((IOTA - 69) & 511)])) + (0.0144044235f * fVec43[((IOTA - 70) & 511)])) + (0.0172906071f * fVec43[((IOTA - 71) & 511)])) + (0.0105753485f * fVec43[((IOTA - 72) & 511)])) + (0.00291947648f * fVec43[((IOTA - 73) & 511)])) + (0.00204825308f * fVec43[((IOTA - 78) & 511)])) + (0.00417368347f * fVec43[((IOTA - 79) & 511)])) + (0.00196586223f * fVec43[((IOTA - 80) & 511)])) + (0.00329840137f * fVec43[((IOTA - 81) & 511)])) + (0.00555614568f * fVec43[((IOTA - 82) & 511)])) + (0.00993849523f * fVec43[((IOTA - 83) & 511)])) + (0.0174154975f * fVec43[((IOTA - 84) & 511)])) + (0.022051122f * fVec43[((IOTA - 85) & 511)])) + (0.0249641985f * fVec43[((IOTA - 86) & 511)])) + (0.0262111463f * fVec43[((IOTA - 87) & 511)])) + (0.0209079143f * fVec43[((IOTA - 88) & 511)])) + (0.0146293566f * fVec43[((IOTA - 89) & 511)])) + (0.00977681577f * fVec43[((IOTA - 90) & 511)])) + (0.00202789484f * fVec43[((IOTA - 91) & 511)])) + (0.00222336221f * fVec43[((IOTA - 96) & 511)])) + (0.00561025878f * fVec43[((IOTA - 97) & 511)])) + (0.00566635188f * fVec43[((IOTA - 98) & 511)])) + (0.00396745931f * fVec43[((IOTA - 99) & 511)])) + (0.0010373909f * fVec43[((IOTA - 100) & 511)])) + (0.000766593497f * fVec43[((IOTA - 101) & 511)])) + (0.00538166333f * fVec43[((IOTA - 102) & 511)])) + (0.0137548f * fVec43[((IOTA - 103) & 511)])) + (0.0212121028f * fVec43[((IOTA - 104) & 511)])) + (0.0227288585f * fVec43[((IOTA - 105) & 511)])) + (0.017670786f * fVec43[((IOTA - 106) & 511)])) + (0.00833067112f * fVec43[((IOTA - 107) & 511)])) + (0.00529056136f * fVec43[((IOTA - 113) & 511)])) + (0.011006671f * fVec43[((IOTA - 114) & 511)])) + (0.0147546418f * fVec43[((IOTA - 115) & 511)])) + (0.0167889036f * fVec43[((IOTA - 116) & 511)])) + (0.0149511658f * fVec43[((IOTA - 117) & 511)])) + (0.00984119065f * fVec43[((IOTA - 118) & 511)])) + (0.00481657544f * fVec43[((IOTA - 119) & 511)])) + (0.0028866129f * fVec43[((IOTA - 120) & 511)])) + (0.00455267448f * fVec43[((IOTA - 121) & 511)])) + (0.00646696426f * fVec43[((IOTA - 122) & 511)])) + (0.00777175371f * fVec43[((IOTA - 123) & 511)])) + (0.00891872402f * fVec43[((IOTA - 124) & 511)])) + (0.00790377054f * fVec43[((IOTA - 125) & 511)])) + (0.00562061928f * fVec43[((IOTA - 126) & 511)])) + (0.00324653182f * fVec43[((IOTA - 127) & 511)])) + (0.00175894517f * fVec43[((IOTA - 135) & 511)])) + (0.00467310939f * fVec43[((IOTA - 136) & 511)])) + (0.00414197473f * fVec43[((IOTA - 137) & 511)])) + (0.0038614762f * fVec43[((IOTA - 139) & 511)]))))))))))))))))))))))))) + (0.00536005106f * fVec43[((IOTA - 439) & 511)])))))))))))))))))))))))))) + (0.00255473983f * fVec43[((IOTA - 457) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00333482912f * fVec43[((IOTA - 505) & 511)]))))))))))))))))))))))))))))))))))))))))))))) + (0.00427016336f * fVec43[((IOTA - 506) & 511)])) + (0.00504203653f * fVec43[((IOTA - 507) & 511)])) + (0.00496733375f * fVec43[((IOTA - 508) & 511)])) + (0.00430421531f * fVec43[((IOTA - 509) & 511)])) + (0.00351501955f * fVec43[((IOTA - 510) & 511)])) + (0.00294623617f * fVec43[((IOTA - 511) & 511)]))) : (iSlow128 ? (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((6.67083077e-05f * fVec42[((IOTA - 216) & 511)]) + ((0.000830319244f * fVec42[((IOTA - 215) & 511)]) + ((0.00296436762f * fVec42[((IOTA - 214) & 511)]) + ((0.00582778081f * fVec42[((IOTA - 213) & 511)]) + ((0.00792788062f * fVec42[((IOTA - 212) & 511)]) + ((0.00848354679f * fVec42[((IOTA - 211) & 511)]) + ((0.00755367056f * fVec42[((IOTA - 210) & 511)]) + ((0.00563797029f * fVec42[((IOTA - 209) & 511)]) + ((0.0040727579f * fVec42[((IOTA - 208) & 511)]) + ((0.00320911407f * fVec42[((IOTA - 207) & 511)]) + ((0.00294697704f * fVec42[((IOTA - 206) & 511)]) + ((0.0034583793f * fVec42[((IOTA - 205) & 511)]) + ((0.00377928792f * fVec42[((IOTA - 204) & 511)]) + ((0.00273965718f * fVec42[((IOTA - 203) & 511)]) + ((0.001013292f * fVec42[((IOTA - 202) & 511)]) + ((0.000931243878f * fVec42[((IOTA - 199) & 511)]) + ((0.00246690772f * fVec42[((IOTA - 198) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.201862112f * fVec42[((IOTA - 1) & 511)]) + ((fSlow132 * fTemp0) + ((((0.0589428991f * fVec42[((IOTA - 13) & 511)]) + (((0.240893736f * fVec42[((IOTA - 2) & 511)]) + ((0.240510017f * fVec42[((IOTA - 3) & 511)]) + ((0.0694207773f * fVec42[((IOTA - 11) & 511)]) + ((0.155030236f * fVec42[((IOTA - 4) & 511)]) + (0.0882938206f * fVec42[((IOTA - 12) & 511)]))))) + (0.0217009019f * fVec42[((IOTA - 14) & 511)]))) + (0.0131967841f * fVec42[((IOTA - 15) & 511)])) + (0.0186305866f * fVec42[((IOTA - 16) & 511)])))) + (0.0198657345f * fVec42[((IOTA - 17) & 511)])) + (0.0188388564f * fVec42[((IOTA - 18) & 511)])) + (0.006258443f * fVec42[((IOTA - 19) & 511)])) + (0.00487257633f * fVec42[((IOTA - 23) & 511)])) + (0.0282356329f * fVec42[((IOTA - 24) & 511)])) + (0.03822482f * fVec42[((IOTA - 25) & 511)])) + (0.0286942683f * fVec42[((IOTA - 26) & 511)])) + (0.0184913129f * fVec42[((IOTA - 27) & 511)])) + (0.00687011611f * fVec42[((IOTA - 28) & 511)])) + (0.0279405266f * fVec42[((IOTA - 36) & 511)])) + (0.051389914f * fVec42[((IOTA - 37) & 511)])) + (0.0589270554f * fVec42[((IOTA - 38) & 511)])) + (0.0416318886f * fVec42[((IOTA - 39) & 511)])) + (0.0149555225f * fVec42[((IOTA - 40) & 511)])) + (0.0125235748f * fVec42[((IOTA - 48) & 511)])) + (0.0283409581f * fVec42[((IOTA - 49) & 511)])) + (0.0240329355f * fVec42[((IOTA - 50) & 511)])) + (0.0034890878f * fVec42[((IOTA - 51) & 511)])) + (0.00841707643f * fVec42[((IOTA - 58) & 511)])) + (0.0233152248f * fVec42[((IOTA - 59) & 511)])) + (0.0280928519f * fVec42[((IOTA - 60) & 511)])) + (0.0153481634f * fVec42[((IOTA - 61) & 511)])) + (0.00453353394f * fVec42[((IOTA - 72) & 511)])) + (0.0150025217f * fVec42[((IOTA - 73) & 511)])) + (0.0160322525f * fVec42[((IOTA - 74) & 511)])) + (0.00629048934f * fVec42[((IOTA - 75) & 511)])) + (0.000206517056f * fVec42[((IOTA - 80) & 511)])) + (0.00390577829f * fVec42[((IOTA - 81) & 511)])) + (0.00455330312f * fVec42[((IOTA - 82) & 511)])) + (0.00543802325f * fVec42[((IOTA - 96) & 511)])) + (0.0156577453f * fVec42[((IOTA - 97) & 511)])) + (0.0171383545f * fVec42[((IOTA - 98) & 511)])) + (0.0129934177f * fVec42[((IOTA - 99) & 511)])) + (0.0042323349f * fVec42[((IOTA - 100) & 511)])) + (4.37591225e-05f * fVec42[((IOTA - 108) & 511)])) + (0.0033359318f * fVec42[((IOTA - 109) & 511)])) + (0.00152002694f * fVec42[((IOTA - 110) & 511)])) + (0.00463927491f * fVec42[((IOTA - 128) & 511)])) + (0.0109945703f * fVec42[((IOTA - 129) & 511)])) + (0.0129098538f * fVec42[((IOTA - 130) & 511)])) + (0.011710884f * fVec42[((IOTA - 131) & 511)])) + (0.00748800253f * fVec42[((IOTA - 132) & 511)])) + (0.00306172529f * fVec42[((IOTA - 133) & 511)])) + (0.00290883658f * fVec42[((IOTA - 144) & 511)])) + (0.0056616338f * fVec42[((IOTA - 145) & 511)])) + (0.00459828041f * fVec42[((IOTA - 146) & 511)])) + (0.00268475059f * fVec42[((IOTA - 147) & 511)])) + (0.000629658345f * fVec42[((IOTA - 148) & 511)])) + (0.000468386803f * fVec42[((IOTA - 152) & 511)])) + (0.00373130757f * fVec42[((IOTA - 153) & 511)])) + (0.00580379041f * fVec42[((IOTA - 154) & 511)])) + (0.00562052056f * fVec42[((IOTA - 155) & 511)])) + (0.00349854119f * fVec42[((IOTA - 156) & 511)])) + (0.0027598422f * fVec42[((IOTA - 164) & 511)])) + (0.00552426279f * fVec42[((IOTA - 165) & 511)])) + (0.00683283806f * fVec42[((IOTA - 166) & 511)])) + (0.00663645798f * fVec42[((IOTA - 167) & 511)])) + (0.00447387109f * fVec42[((IOTA - 168) & 511)])) + (0.00165543566f * fVec42[((IOTA - 169) & 511)])) + (0.000278903637f * fVec42[((IOTA - 175) & 511)])) + (0.000749757513f * fVec42[((IOTA - 176) & 511)])) + (0.00127070211f * fVec42[((IOTA - 177) & 511)])) + (0.00260308944f * fVec42[((IOTA - 178) & 511)])) + (0.00429767603f * fVec42[((IOTA - 179) & 511)])) + (0.00533275818f * fVec42[((IOTA - 180) & 511)])) + (0.0059592356f * fVec42[((IOTA - 181) & 511)])) + (0.00628255215f * fVec42[((IOTA - 182) & 511)])) + (0.00520079769f * fVec42[((IOTA - 183) & 511)])) + (0.00247469591f * fVec42[((IOTA - 184) & 511)])) + (0.000664944761f * fVec42[((IOTA - 185) & 511)])) + (0.000701182522f * fVec42[((IOTA - 186) & 511)])) + (0.00232106447f * fVec42[((IOTA - 187) & 511)])) + (0.00500447722f * fVec42[((IOTA - 188) & 511)])) + (0.00721620396f * fVec42[((IOTA - 189) & 511)])) + (0.00850028358f * fVec42[((IOTA - 190) & 511)])) + (0.00839858595f * fVec42[((IOTA - 191) & 511)])) + (0.00751541136f * fVec42[((IOTA - 192) & 511)])) + (0.00708528375f * fVec42[((IOTA - 193) & 511)])) + (0.00673857192f * fVec42[((IOTA - 194) & 511)])) + (0.00629664306f * fVec42[((IOTA - 195) & 511)])) + (0.00544447405f * fVec42[((IOTA - 196) & 511)])) + (0.00398375373f * fVec42[((IOTA - 197) & 511)])) + (0.00119323237f * fVec42[((IOTA - 217) & 511)]))))))))))))))))))) + (0.00400468195f * fVec42[((IOTA - 218) & 511)])) + (0.00697505428f * fVec42[((IOTA - 219) & 511)])) + (0.00890514255f * fVec42[((IOTA - 220) & 511)])) + (0.00952600129f * fVec42[((IOTA - 221) & 511)])) + (0.00876123179f * fVec42[((IOTA - 222) & 511)])) + (0.00680855056f * fVec42[((IOTA - 223) & 511)])) + (0.00482590403f * fVec42[((IOTA - 224) & 511)])) + (0.00385794695f * fVec42[((IOTA - 225) & 511)])) + (0.00427514268f * fVec42[((IOTA - 226) & 511)])) + (0.00586856669f * fVec42[((IOTA - 227) & 511)])) + (0.00743312528f * fVec42[((IOTA - 228) & 511)])) + (0.00799952354f * fVec42[((IOTA - 229) & 511)])) + (0.00775991986f * fVec42[((IOTA - 230) & 511)])) + (0.00725223357f * fVec42[((IOTA - 231) & 511)])) + (0.00688824989f * fVec42[((IOTA - 232) & 511)])) + (0.00684666121f * fVec42[((IOTA - 233) & 511)])) + (0.006777931f * fVec42[((IOTA - 234) & 511)])) + (0.00623748498f * fVec42[((IOTA - 235) & 511)])) + (0.00548594398f * fVec42[((IOTA - 236) & 511)])) + (0.00494383322f * fVec42[((IOTA - 237) & 511)])) + (0.00476906495f * fVec42[((IOTA - 238) & 511)])) + (0.00513453502f * fVec42[((IOTA - 239) & 511)])) + (0.00538573274f * fVec42[((IOTA - 240) & 511)])) + (0.00498884078f * fVec42[((IOTA - 241) & 511)])) + (0.0045860922f * fVec42[((IOTA - 242) & 511)])) + (0.00440445729f * fVec42[((IOTA - 243) & 511)])) + (0.00376923988f * fVec42[((IOTA - 244) & 511)])) + (0.00258376636f * fVec42[((IOTA - 245) & 511)])) + (0.00141838845f * fVec42[((IOTA - 246) & 511)])) + (0.00105065946f * fVec42[((IOTA - 247) & 511)])) + (0.00181510206f * fVec42[((IOTA - 248) & 511)])) + (0.00326957973f * fVec42[((IOTA - 249) & 511)])) + (0.0049938052f * fVec42[((IOTA - 250) & 511)])) + (0.00653936807f * fVec42[((IOTA - 251) & 511)])) + (0.00741154328f * fVec42[((IOTA - 252) & 511)])) + (0.00753523968f * fVec42[((IOTA - 253) & 511)])) + (0.00702871243f * fVec42[((IOTA - 254) & 511)])) + (0.00660815742f * fVec42[((IOTA - 255) & 511)])) + (0.00705689425f * fVec42[((IOTA - 256) & 511)])) + (0.00858048815f * fVec42[((IOTA - 257) & 511)])) + (0.010527283f * fVec42[((IOTA - 258) & 511)])) + (0.0117690312f * fVec42[((IOTA - 259) & 511)])) + (0.0116900746f * fVec42[((IOTA - 260) & 511)])) + (0.0100675179f * fVec42[((IOTA - 261) & 511)])) + (0.00728856074f * fVec42[((IOTA - 262) & 511)])) + (0.00433825422f * fVec42[((IOTA - 263) & 511)])) + (0.00243209675f * fVec42[((IOTA - 264) & 511)])) + (0.00181682641f * fVec42[((IOTA - 265) & 511)])) + (0.00255894382f * fVec42[((IOTA - 266) & 511)])) + (0.00490598986f * fVec42[((IOTA - 267) & 511)])) + (0.0080692349f * fVec42[((IOTA - 268) & 511)])) + (0.01073814f * fVec42[((IOTA - 269) & 511)])) + (0.0114407204f * fVec42[((IOTA - 270) & 511)])) + (0.00974797644f * fVec42[((IOTA - 271) & 511)])) + (0.006779477f * fVec42[((IOTA - 272) & 511)])) + (0.0038258112f * fVec42[((IOTA - 273) & 511)])) + (0.00202922942f * fVec42[((IOTA - 274) & 511)])) + (0.00194126554f * fVec42[((IOTA - 275) & 511)])) + (0.00316559291f * fVec42[((IOTA - 276) & 511)])) + (0.0049077142f * fVec42[((IOTA - 277) & 511)])) + (0.00583221018f * fVec42[((IOTA - 278) & 511)])) + (0.00533989258f * fVec42[((IOTA - 279) & 511)])) + (0.00394433504f * fVec42[((IOTA - 280) & 511)])) + (0.00247371523f * fVec42[((IOTA - 281) & 511)])) + (0.00191899994f * fVec42[((IOTA - 282) & 511)])) + (0.00241782749f * fVec42[((IOTA - 283) & 511)])) + (0.00360978162f * fVec42[((IOTA - 284) & 511)])) + (0.00487043615f * fVec42[((IOTA - 285) & 511)])) + (0.00542782666f * fVec42[((IOTA - 286) & 511)])) + (0.0051849531f * fVec42[((IOTA - 287) & 511)])) + (0.00471933093f * fVec42[((IOTA - 288) & 511)])) + (0.00431913929f * fVec42[((IOTA - 289) & 511)])) + (0.0037958757f * fVec42[((IOTA - 290) & 511)])) + (0.00331078237f * fVec42[((IOTA - 291) & 511)])) + (0.0032293587f * fVec42[((IOTA - 292) & 511)])) + (0.0035975338f * fVec42[((IOTA - 293) & 511)])) + (0.00398176163f * fVec42[((IOTA - 294) & 511)])) + (0.00422317907f * fVec42[((IOTA - 295) & 511)])) + (0.00469905697f * fVec42[((IOTA - 296) & 511)])) + (0.00552236009f * fVec42[((IOTA - 297) & 511)])) + (0.00625490537f * fVec42[((IOTA - 298) & 511)])) + (0.00665170839f * fVec42[((IOTA - 299) & 511)])) + (0.00638481462f * fVec42[((IOTA - 300) & 511)])) + (0.00569029106f * fVec42[((IOTA - 301) & 511)])) + (0.00521982322f * fVec42[((IOTA - 302) & 511)])) + (0.00508447411f * fVec42[((IOTA - 303) & 511)])) + (0.00531111658f * fVec42[((IOTA - 304) & 511)])) + (0.00587103423f * fVec42[((IOTA - 305) & 511)])) + (0.00643868092f * fVec42[((IOTA - 306) & 511)])) + (0.00700070895f * fVec42[((IOTA - 307) & 511)])) + (0.00726644322f * fVec42[((IOTA - 308) & 511)])) + (0.00667028781f * fVec42[((IOTA - 309) & 511)])) + (0.00544188777f * fVec42[((IOTA - 310) & 511)])) + (0.00415587565f * fVec42[((IOTA - 311) & 511)])) + (0.00318390504f * fVec42[((IOTA - 312) & 511)])) + (0.002700774f * fVec42[((IOTA - 313) & 511)])) + (0.00230281148f * fVec42[((IOTA - 314) & 511)])) + (0.00167868286f * fVec42[((IOTA - 315) & 511)])) + (0.00116329687f * fVec42[((IOTA - 316) & 511)])) + (0.000763223972f * fVec42[((IOTA - 317) & 511)])) + (0.000632958021f * fVec42[((IOTA - 318) & 511)])) + (0.000715273432f * fVec42[((IOTA - 319) & 511)])) + (0.0004839045f * fVec42[((IOTA - 320) & 511)])) + (0.000319362618f * fVec42[((IOTA - 321) & 511)])) + (0.000175213907f * fVec42[((IOTA - 322) & 511)])) + (0.000832548365f * fVec42[((IOTA - 329) & 511)])) + (0.00136969471f * fVec42[((IOTA - 330) & 511)])) + (0.00116074039f * fVec42[((IOTA - 331) & 511)])) + (0.0013033431f * fVec42[((IOTA - 332) & 511)])) + (0.00219787378f * fVec42[((IOTA - 333) & 511)])) + (0.00299284654f * fVec42[((IOTA - 334) & 511)])) + (0.00363302836f * fVec42[((IOTA - 335) & 511)])) + (0.00425528456f * fVec42[((IOTA - 336) & 511)])) + (0.00450591743f * fVec42[((IOTA - 337) & 511)])) + (0.00486829551f * fVec42[((IOTA - 338) & 511)])) + (0.00498027913f * fVec42[((IOTA - 339) & 511)])) + (0.00432240916f * fVec42[((IOTA - 340) & 511)])) + (0.00347163761f * fVec42[((IOTA - 341) & 511)])) + (0.00229065306f * fVec42[((IOTA - 342) & 511)])) + (0.0008964031f * fVec42[((IOTA - 343) & 511)])) + (0.000175392255f * fVec42[((IOTA - 344) & 511)])) + (0.000130236149f * fVec42[((IOTA - 346) & 511)])) + (0.00170677528f * fVec42[((IOTA - 347) & 511)])) + (0.00366483675f * fVec42[((IOTA - 348) & 511)])) + (0.00523427082f * fVec42[((IOTA - 349) & 511)])) + (0.00629884284f * fVec42[((IOTA - 350) & 511)])) + (0.00592344394f * fVec42[((IOTA - 351) & 511)])) + (0.00458832178f * fVec42[((IOTA - 352) & 511)])) + (0.0027450379f * fVec42[((IOTA - 353) & 511)])) + (1.59041956e-05f * fVec42[((IOTA - 354) & 511)])) + (0.000751838554f * fVec42[((IOTA - 359) & 511)])) + (0.00133494334f * fVec42[((IOTA - 360) & 511)])) + (0.000966054853f * fVec42[((IOTA - 361) & 511)])) + (0.000165106729f * fVec42[((IOTA - 362) & 511)])) + (0.000106424559f * fVec42[((IOTA - 375) & 511)])) + (0.00101998029f * fVec42[((IOTA - 376) & 511)])) + (0.00139011769f * fVec42[((IOTA - 377) & 511)])) + (0.00143616553f * fVec42[((IOTA - 378) & 511)])) + (0.000702579971f * fVec42[((IOTA - 379) & 511)])) + (0.00056184968f * fVec42[((IOTA - 385) & 511)])) + (0.00103317946f * fVec42[((IOTA - 386) & 511)])) + (0.00118395733f * fVec42[((IOTA - 387) & 511)])) + (0.00107586803f * fVec42[((IOTA - 388) & 511)])) + (0.000529447105f * fVec42[((IOTA - 389) & 511)])) + (0.000600287691f * fVec42[((IOTA - 401) & 511)])) + (0.000152502209f * fVec42[((IOTA - 402) & 511)])) + (0.000144237652f * fVec42[((IOTA - 424) & 511)])) + (0.00131339114f * fVec42[((IOTA - 425) & 511)])) + (0.00188198918f * fVec42[((IOTA - 426) & 511)])) + (0.00139499316f * fVec42[((IOTA - 427) & 511)])) + (0.000328251161f * fVec42[((IOTA - 428) & 511)])) + (0.00067835208f * fVec42[((IOTA - 473) & 511)])) + (0.000591726042f * fVec42[((IOTA - 474) & 511)])) + (0.000427273568f * fVec42[((IOTA - 494) & 511)])) + (0.00178287737f * fVec42[((IOTA - 495) & 511)])) + (0.00265520159f * fVec42[((IOTA - 496) & 511)])) + (0.00244294712f * fVec42[((IOTA - 497) & 511)])) + (0.000961595681f * fVec42[((IOTA - 498) & 511)])) - ((((0.00446854997f * fVec42[((IOTA - 508) & 511)]) + ((0.00381739857f * fVec42[((IOTA - 507) & 511)]) + ((0.00329380808f * fVec42[((IOTA - 506) & 511)]) + ((0.00330980122f * fVec42[((IOTA - 505) & 511)]) + ((0.0042327214f * fVec42[((IOTA - 504) & 511)]) + ((0.00532520749f * fVec42[((IOTA - 503) & 511)]) + ((0.00560078118f * fVec42[((IOTA - 502) & 511)]) + ((0.00478437496f * fVec42[((IOTA - 501) & 511)]) + ((0.0030754297f * fVec42[((IOTA - 500) & 511)]) + ((0.00103077153f * fVec42[((IOTA - 499) & 511)]) + ((0.000911593903f * fVec42[((IOTA - 493) & 511)]) + ((0.00173106231f * fVec42[((IOTA - 492) & 511)]) + ((0.00202595955f * fVec42[((IOTA - 491) & 511)]) + ((0.00215298496f * fVec42[((IOTA - 490) & 511)]) + ((0.00195158133f * fVec42[((IOTA - 489) & 511)]) + ((0.00175552815f * fVec42[((IOTA - 488) & 511)]) + ((0.00216520298f * fVec42[((IOTA - 487) & 511)]) + ((0.0024159546f * fVec42[((IOTA - 486) & 511)]) + ((0.00244351197f * fVec42[((IOTA - 485) & 511)]) + ((0.00258822553f * fVec42[((IOTA - 484) & 511)]) + ((0.00249711052f * fVec42[((IOTA - 483) & 511)]) + ((0.00255885487f * fVec42[((IOTA - 482) & 511)]) + ((0.00291127432f * fVec42[((IOTA - 481) & 511)]) + ((0.00355564756f * fVec42[((IOTA - 480) & 511)]) + ((0.00478609884f * fVec42[((IOTA - 479) & 511)]) + ((0.00544982497f * fVec42[((IOTA - 478) & 511)]) + ((0.0047712652f * fVec42[((IOTA - 477) & 511)]) + ((0.00319193164f * fVec42[((IOTA - 476) & 511)]) + ((0.00095716631f * fVec42[((IOTA - 475) & 511)]) + ((0.000143583864f * fVec42[((IOTA - 472) & 511)]) + ((0.00165460352f * fVec42[((IOTA - 471) & 511)]) + ((0.00306035765f * fVec42[((IOTA - 470) & 511)]) + ((0.00390545139f * fVec42[((IOTA - 469) & 511)]) + ((0.00418997323f * fVec42[((IOTA - 468) & 511)]) + ((0.00346899219f * fVec42[((IOTA - 467) & 511)]) + ((0.0022543557f * fVec42[((IOTA - 466) & 511)]) + ((0.00169699499f * fVec42[((IOTA - 465) & 511)]) + ((0.00173668098f * fVec42[((IOTA - 464) & 511)]) + ((0.0021849419f * fVec42[((IOTA - 463) & 511)]) + ((0.00319954194f * fVec42[((IOTA - 462) & 511)]) + ((0.00412796158f * fVec42[((IOTA - 461) & 511)]) + ((0.00493830396f * fVec42[((IOTA - 460) & 511)]) + ((0.00572358584f * fVec42[((IOTA - 459) & 511)]) + ((0.00560116768f * fVec42[((IOTA - 458) & 511)]) + ((0.00466460269f * fVec42[((IOTA - 457) & 511)]) + ((0.00375396013f * fVec42[((IOTA - 456) & 511)]) + ((0.00306006055f * fVec42[((IOTA - 455) & 511)]) + ((0.00290943123f * fVec42[((IOTA - 454) & 511)]) + ((0.00323140994f * fVec42[((IOTA - 453) & 511)]) + ((0.00319540966f * fVec42[((IOTA - 452) & 511)]) + ((0.00283924444f * fVec42[((IOTA - 451) & 511)]) + ((0.00249577314f * fVec42[((IOTA - 450) & 511)]) + ((0.00195972668f * fVec42[((IOTA - 449) & 511)]) + ((0.0017796671f * fVec42[((IOTA - 448) & 511)]) + ((0.00218592305f * fVec42[((IOTA - 447) & 511)]) + ((0.00308387214f * fVec42[((IOTA - 446) & 511)]) + ((0.00480102235f * fVec42[((IOTA - 445) & 511)]) + ((0.00671874359f * fVec42[((IOTA - 444) & 511)]) + ((0.00824715383f * fVec42[((IOTA - 443) & 511)]) + ((0.00901433174f * fVec42[((IOTA - 442) & 511)]) + ((0.0081741726f * fVec42[((IOTA - 441) & 511)]) + ((0.00656317966f * fVec42[((IOTA - 440) & 511)]) + ((0.00512187136f * fVec42[((IOTA - 439) & 511)]) + ((0.00389275746f * fVec42[((IOTA - 438) & 511)]) + ((0.00348465843f * fVec42[((IOTA - 437) & 511)]) + ((0.00369061064f * fVec42[((IOTA - 436) & 511)]) + ((0.00412727799f * fVec42[((IOTA - 435) & 511)]) + ((0.00511009898f * fVec42[((IOTA - 434) & 511)]) + ((0.00574843772f * fVec42[((IOTA - 433) & 511)]) + ((0.00551115302f * fVec42[((IOTA - 432) & 511)]) + ((0.00462785969f * fVec42[((IOTA - 431) & 511)]) + ((0.00281804893f * fVec42[((IOTA - 430) & 511)]) + ((0.000944472849f * fVec42[((IOTA - 429) & 511)]) + ((0.00144826481f * fVec42[((IOTA - 423) & 511)]) + ((0.00285375165f * fVec42[((IOTA - 422) & 511)]) + ((0.00343438936f * fVec42[((IOTA - 421) & 511)]) + ((0.00379757024f * fVec42[((IOTA - 420) & 511)]) + ((0.00391005911f * fVec42[((IOTA - 419) & 511)]) + ((0.00368445693f * fVec42[((IOTA - 418) & 511)]) + ((0.00370080722f * fVec42[((IOTA - 417) & 511)]) + ((0.00373814488f * fVec42[((IOTA - 416) & 511)]) + ((0.00370247196f * fVec42[((IOTA - 415) & 511)]) + ((0.00393642718f * fVec42[((IOTA - 414) & 511)]) + ((0.00391246704f * fVec42[((IOTA - 413) & 511)]) + ((0.00352407712f * fVec42[((IOTA - 412) & 511)]) + ((0.0031815269f * fVec42[((IOTA - 411) & 511)]) + ((0.00275232131f * fVec42[((IOTA - 410) & 511)]) + ((0.00282640243f * fVec42[((IOTA - 409) & 511)]) + ((0.00357636763f * fVec42[((IOTA - 408) & 511)]) + ((0.00397305191f * fVec42[((IOTA - 407) & 511)]) + ((0.00380975846f * fVec42[((IOTA - 406) & 511)]) + ((0.00185050769f * fVec42[((IOTA - 404) & 511)]) + ((0.000770596322f * fVec42[((IOTA - 403) & 511)]) + ((0.000242636073f * fVec42[((IOTA - 400) & 511)]) + ((0.00193591462f * fVec42[((IOTA - 399) & 511)]) + ((0.00361789716f * fVec42[((IOTA - 398) & 511)]) + ((0.00457473658f * fVec42[((IOTA - 397) & 511)]) + ((0.00429137377f * fVec42[((IOTA - 396) & 511)]) + ((0.00360680884f * fVec42[((IOTA - 395) & 511)]) + ((0.00347214332f * fVec42[((IOTA - 394) & 511)]) + ((0.0036893622f * fVec42[((IOTA - 393) & 511)]) + ((0.00371445203f * fVec42[((IOTA - 392) & 511)]) + ((0.00277081179f * fVec42[((IOTA - 391) & 511)]) + ((0.000946286134f * fVec42[((IOTA - 390) & 511)]) + ((0.00024661934f * fVec42[((IOTA - 384) & 511)]) + ((0.0013408591f * fVec42[((IOTA - 383) & 511)]) + ((0.00193820382f * fVec42[((IOTA - 382) & 511)]) + ((0.00154731655f * fVec42[((IOTA - 381) & 511)]) + ((0.00052730646f * fVec42[((IOTA - 380) & 511)]) + ((0.00119031919f * fVec42[((IOTA - 374) & 511)]) + ((0.0024913433f * fVec42[((IOTA - 373) & 511)]) + ((0.00351022417f * fVec42[((IOTA - 372) & 511)]) + ((0.00384914735f * fVec42[((IOTA - 371) & 511)]) + ((0.00378249818f * fVec42[((IOTA - 370) & 511)]) + ((0.00360422255f * fVec42[((IOTA - 369) & 511)]) + ((0.00306451973f * fVec42[((IOTA - 368) & 511)]) + ((0.00237451447f * fVec42[((IOTA - 367) & 511)]) + ((0.0017101937f * fVec42[((IOTA - 366) & 511)]) + ((0.00118484907f * fVec42[((IOTA - 365) & 511)]) + ((0.00112358108f * fVec42[((IOTA - 364) & 511)]) + ((0.000774877146f * fVec42[((IOTA - 363) & 511)]) + ((0.000910137314f * fVec42[((IOTA - 358) & 511)]) + ((0.00244993297f * fVec42[((IOTA - 357) & 511)]) + ((0.00298624719f * fVec42[((IOTA - 356) & 511)]) + ((0.00224739965f * fVec42[((IOTA - 355) & 511)]) + ((0.000110348687f * fVec42[((IOTA - 345) & 511)]) + ((0.000100300647f * fVec42[((IOTA - 328) & 511)]) + ((0.000802939758f * fVec42[((IOTA - 327) & 511)]) + ((0.00100030098f * fVec42[((IOTA - 326) & 511)]) + ((0.000636822544f * fVec42[((IOTA - 325) & 511)]) + ((0.000377568882f * fVec42[((IOTA - 324) & 511)]) + ((0.000221559312f * fVec42[((IOTA - 323) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.14616023f * fVec42[((IOTA - 6) & 511)]) + ((0.0104920268f * fVec42[((IOTA - 5) & 511)]) + ((0.113924518f * fVec42[((IOTA - 9) & 511)]) + (((0.226641566f * fVec42[((IOTA - 7) & 511)]) + (0.21455431f * fVec42[((IOTA - 8) & 511)])) + (0.00350644859f * fVec42[((IOTA - 10) & 511)]))))) + (0.0154338386f * fVec42[((IOTA - 20) & 511)])) + (0.0232045501f * fVec42[((IOTA - 21) & 511)])) + (0.0139688365f * fVec42[((IOTA - 22) & 511)])) + (0.0132544851f * fVec42[((IOTA - 29) & 511)])) + (0.043420177f * fVec42[((IOTA - 30) & 511)])) + (0.070484072f * fVec42[((IOTA - 31) & 511)])) + (0.0771709159f * fVec42[((IOTA - 32) & 511)])) + (0.065376766f * fVec42[((IOTA - 33) & 511)])) + (0.0384334475f * fVec42[((IOTA - 34) & 511)])) + (0.00145001849f * fVec42[((IOTA - 35) & 511)])) + (0.0133437868f * fVec42[((IOTA - 41) & 511)])) + (0.0317637548f * fVec42[((IOTA - 42) & 511)])) + (0.0481766686f * fVec42[((IOTA - 43) & 511)])) + (0.0638793334f * fVec42[((IOTA - 44) & 511)])) + (0.0587479472f * fVec42[((IOTA - 45) & 511)])) + (0.034059044f * fVec42[((IOTA - 46) & 511)])) + (0.00901349913f * fVec42[((IOTA - 47) & 511)])) + (0.0122482982f * fVec42[((IOTA - 52) & 511)])) + (0.0315267965f * fVec42[((IOTA - 53) & 511)])) + (0.0472052619f * fVec42[((IOTA - 54) & 511)])) + (0.0442548059f * fVec42[((IOTA - 55) & 511)])) + (0.0363470204f * fVec42[((IOTA - 56) & 511)])) + (0.0159067735f * fVec42[((IOTA - 57) & 511)])) + (0.00298782252f * fVec42[((IOTA - 62) & 511)])) + (0.013625009f * fVec42[((IOTA - 63) & 511)])) + (0.016714856f * fVec42[((IOTA - 64) & 511)])) + (0.0191077124f * fVec42[((IOTA - 65) & 511)])) + (0.0247569196f * fVec42[((IOTA - 66) & 511)])) + (0.0302302893f * fVec42[((IOTA - 67) & 511)])) + (0.0364833511f * fVec42[((IOTA - 68) & 511)])) + (0.0373951234f * fVec42[((IOTA - 69) & 511)])) + (0.0273086093f * fVec42[((IOTA - 70) & 511)])) + (0.0113115245f * fVec42[((IOTA - 71) & 511)])) + (0.00602853065f * fVec42[((IOTA - 76) & 511)])) + (0.0133562423f * fVec42[((IOTA - 77) & 511)])) + (0.0171895158f * fVec42[((IOTA - 78) & 511)])) + (0.0110304803f * fVec42[((IOTA - 79) & 511)])) + (0.00142846629f * fVec42[((IOTA - 83) & 511)])) + (0.0140276682f * fVec42[((IOTA - 84) & 511)])) + (0.0229336135f * fVec42[((IOTA - 85) & 511)])) + (0.0272849761f * fVec42[((IOTA - 86) & 511)])) + (0.0251292568f * fVec42[((IOTA - 87) & 511)])) + (0.017508788f * fVec42[((IOTA - 88) & 511)])) + (0.0108713489f * fVec42[((IOTA - 89) & 511)])) + (0.00828006212f * fVec42[((IOTA - 90) & 511)])) + (0.00865899865f * fVec42[((IOTA - 91) & 511)])) + (0.0138702309f * fVec42[((IOTA - 92) & 511)])) + (0.019550385f * fVec42[((IOTA - 93) & 511)])) + (0.0155414222f * fVec42[((IOTA - 94) & 511)])) + (0.00615606131f * fVec42[((IOTA - 95) & 511)])) + (0.00881798193f * fVec42[((IOTA - 101) & 511)])) + (0.0190590788f * fVec42[((IOTA - 102) & 511)])) + (0.0237686876f * fVec42[((IOTA - 103) & 511)])) + (0.0235240906f * fVec42[((IOTA - 104) & 511)])) + (0.0196486935f * fVec42[((IOTA - 105) & 511)])) + (0.0129978769f * fVec42[((IOTA - 106) & 511)])) + (0.00615273183f * fVec42[((IOTA - 107) & 511)])) + (0.00193844177f * fVec42[((IOTA - 111) & 511)])) + (0.00678292522f * fVec42[((IOTA - 112) & 511)])) + (0.0114239845f * fVec42[((IOTA - 113) & 511)])) + (0.0134527376f * fVec42[((IOTA - 114) & 511)])) + (0.0127029214f * fVec42[((IOTA - 115) & 511)])) + (0.00885992683f * fVec42[((IOTA - 116) & 511)])) + (0.00415926473f * fVec42[((IOTA - 117) & 511)])) + (0.00199322961f * fVec42[((IOTA - 118) & 511)])) + (0.00206876686f * fVec42[((IOTA - 119) & 511)])) + (0.00394629687f * fVec42[((IOTA - 120) & 511)])) + (0.00879155379f * fVec42[((IOTA - 121) & 511)])) + (0.0141170286f * fVec42[((IOTA - 122) & 511)])) + (0.0181140415f * fVec42[((IOTA - 123) & 511)])) + (0.0207484029f * fVec42[((IOTA - 124) & 511)])) + (0.0190067571f * fVec42[((IOTA - 125) & 511)])) + (0.0124776158f * fVec42[((IOTA - 126) & 511)])) + (0.00419208407f * fVec42[((IOTA - 127) & 511)])) + (0.000476353802f * fVec42[((IOTA - 134) & 511)])) + (0.00294578774f * fVec42[((IOTA - 135) & 511)])) + (0.00215521455f * fVec42[((IOTA - 136) & 511)])) + (0.00166149996f * fVec42[((IOTA - 137) & 511)])) + (0.0037967083f * fVec42[((IOTA - 138) & 511)])) + (0.0067718965f * fVec42[((IOTA - 139) & 511)])) + (0.00954636466f * fVec42[((IOTA - 140) & 511)])) + (0.0103347087f * fVec42[((IOTA - 141) & 511)])) + (0.00758643029f * fVec42[((IOTA - 142) & 511)])) + (0.00255180942f * fVec42[((IOTA - 143) & 511)])) + (0.00228967192f * fVec42[((IOTA - 149) & 511)])) + (0.00343055418f * fVec42[((IOTA - 150) & 511)])) + (0.00208740635f * fVec42[((IOTA - 151) & 511)])) + (0.000708525535f * fVec42[((IOTA - 157) & 511)])) + (0.00601244811f * fVec42[((IOTA - 158) & 511)])) + (0.0106595112f * fVec42[((IOTA - 159) & 511)])) + (0.0129900891f * fVec42[((IOTA - 160) & 511)])) + (0.0113383094f * fVec42[((IOTA - 161) & 511)])) + (0.00684065605f * fVec42[((IOTA - 162) & 511)])) + (0.00179652264f * fVec42[((IOTA - 163) & 511)])) + (0.000222302508f * fVec42[((IOTA - 170) & 511)])) + (0.00143096317f * fVec42[((IOTA - 171) & 511)])) + (0.00195779419f * fVec42[((IOTA - 172) & 511)])) + (0.00117159076f * fVec42[((IOTA - 173) & 511)])) + (0.00025164336f * fVec42[((IOTA - 174) & 511)])) + (0.000149529427f * fVec42[((IOTA - 200) & 511)])) + (8.51992518e-05f * fVec42[((IOTA - 201) & 511)])) + (0.00310004409f * fVec42[((IOTA - 405) & 511)])) + (0.00510885054f * fVec42[((IOTA - 509) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00531325676f * fVec42[((IOTA - 510) & 511)])) + (0.00524089998f * fVec42[((IOTA - 511) & 511)]))) : ((((((((((((((((((((0.00502944971f * fVec41[((IOTA - 359) & 511)]) + ((0.00290575437f * fVec41[((IOTA - 358) & 511)]) + ((0.000321154017f * fVec41[((IOTA - 353) & 511)]) + ((0.00482691871f * fVec41[((IOTA - 352) & 511)]) + ((0.0081290165f * fVec41[((IOTA - 351) & 511)]) + ((0.00945152901f * fVec41[((IOTA - 350) & 511)]) + ((0.0086883707f * fVec41[((IOTA - 349) & 511)]) + ((0.00672962749f * fVec41[((IOTA - 348) & 511)]) + ((0.00414779549f * fVec41[((IOTA - 347) & 511)]) + ((0.00172057422f * fVec41[((IOTA - 346) & 511)]) + ((0.000249337405f * fVec41[((IOTA - 345) & 511)]) + ((0.000136346556f * fVec41[((IOTA - 344) & 511)]) + ((0.00164576666f * fVec41[((IOTA - 343) & 511)]) + ((0.00424239505f * fVec41[((IOTA - 342) & 511)]) + ((0.00663057389f * fVec41[((IOTA - 341) & 511)]) + ((0.00792301726f * fVec41[((IOTA - 340) & 511)]) + ((0.0082619898f * fVec41[((IOTA - 339) & 511)]) + ((0.00720714265f * fVec41[((IOTA - 338) & 511)]) + ((0.00525985425f * fVec41[((IOTA - 337) & 511)]) + ((0.00336067751f * fVec41[((IOTA - 336) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00400524447f * fVec41[((IOTA - 166) & 511)]) + ((0.00102500059f * fVec41[((IOTA - 158) & 511)]) + ((0.00440276507f * fVec41[((IOTA - 157) & 511)]) + ((0.00560525479f * fVec41[((IOTA - 156) & 511)]) + ((0.00457344484f * fVec41[((IOTA - 155) & 511)]) + ((0.00016431557f * fVec41[((IOTA - 154) & 511)]) + ((0.000319594983f * fVec41[((IOTA - 149) & 511)]) + ((0.00520509295f * fVec41[((IOTA - 148) & 511)]) + ((0.00888323318f * fVec41[((IOTA - 147) & 511)]) + ((0.0104397461f * fVec41[((IOTA - 146) & 511)]) + ((0.00718836905f * fVec41[((IOTA - 145) & 511)]) + ((((((((((((((((((((((((0.0373307988f * fVec41[((IOTA - 27) & 511)]) + ((0.042344559f * fVec41[((IOTA - 26) & 511)]) + ((0.0368441828f * fVec41[((IOTA - 25) & 511)]) + ((0.0218242127f * fVec41[((IOTA - 24) & 511)]) + ((0.00783191808f * fVec41[((IOTA - 23) & 511)]) + ((4.22243029e-05f * fVec41[((IOTA - 19) & 511)]) + ((0.0170227811f * fVec41[((IOTA - 18) & 511)]) + ((0.0274168998f * fVec41[((IOTA - 17) & 511)]) + ((0.0363758951f * fVec41[((IOTA - 16) & 511)]) + ((0.0408625044f * fVec41[((IOTA - 15) & 511)]) + ((0.0511242524f * fVec41[((IOTA - 14) & 511)]) + ((0.0634776503f * fVec41[((IOTA - 13) & 511)]) + ((0.0432408825f * fVec41[((IOTA - 12) & 511)]) + ((0.00102815079f * fVec41[((IOTA - 11) & 511)]) + ((0.077781938f * fVec41[((IOTA - 5) & 511)]) + ((0.20306851f * fVec41[((IOTA - 4) & 511)]) + ((0.257845759f * fVec41[((IOTA - 3) & 511)]) + ((0.251120508f * fVec41[((IOTA - 2) & 511)]) + ((0.204312399f * fVec41[((IOTA - 1) & 511)]) + ((fSlow130 * fTemp0) + (0.0116085391f * fVec41[((IOTA - 28) & 511)]))))))))))))))))))))) + (0.0124191083f * fVec41[((IOTA - 36) & 511)])) + (0.0403262191f * fVec41[((IOTA - 37) & 511)])) + (0.0477275252f * fVec41[((IOTA - 38) & 511)])) + (0.0377314985f * fVec41[((IOTA - 39) & 511)])) + (0.0181215722f * fVec41[((IOTA - 40) & 511)])) + (0.00195753388f * fVec41[((IOTA - 74) & 511)])) + (0.00817073137f * fVec41[((IOTA - 80) & 511)])) + (0.00558320386f * fVec41[((IOTA - 81) & 511)])) + (0.00083987508f * fVec41[((IOTA - 98) & 511)])) + (0.00690651219f * fVec41[((IOTA - 99) & 511)])) + (0.00918854121f * fVec41[((IOTA - 100) & 511)])) + (0.00570309954f * fVec41[((IOTA - 101) & 511)])) + (0.00150970696f * fVec41[((IOTA - 128) & 511)])) + (0.0099317804f * fVec41[((IOTA - 129) & 511)])) + (0.0143731739f * fVec41[((IOTA - 130) & 511)])) + (0.0142495558f * fVec41[((IOTA - 131) & 511)])) + (0.0101380982f * fVec41[((IOTA - 132) & 511)])) + (0.00525740441f * fVec41[((IOTA - 133) & 511)])) + (0.00295940181f * fVec41[((IOTA - 134) & 511)])) + (0.00204013754f * fVec41[((IOTA - 135) & 511)])) + (0.00147222355f * fVec41[((IOTA - 136) & 511)])) + (0.00652954681f * fVec41[((IOTA - 167) & 511)]))))))))))))) + (0.00776706962f * fVec41[((IOTA - 168) & 511)])) + (0.00911993906f * fVec41[((IOTA - 169) & 511)])) + (0.0101013463f * fVec41[((IOTA - 170) & 511)])) + (0.00907119084f * fVec41[((IOTA - 171) & 511)])) + (0.00483388733f * fVec41[((IOTA - 172) & 511)])) + (0.000296812039f * fVec41[((IOTA - 178) & 511)])) + (0.00712737115f * fVec41[((IOTA - 179) & 511)])) + (0.0123177636f * fVec41[((IOTA - 180) & 511)])) + (0.0130092651f * fVec41[((IOTA - 181) & 511)])) + (0.0107028298f * fVec41[((IOTA - 182) & 511)])) + (0.0071470039f * fVec41[((IOTA - 183) & 511)])) + (0.00333697163f * fVec41[((IOTA - 184) & 511)])) + (0.0012210086f * fVec41[((IOTA - 185) & 511)])) + (0.0011245003f * fVec41[((IOTA - 186) & 511)])) + (0.00300226267f * fVec41[((IOTA - 187) & 511)])) + (0.00619016029f * fVec41[((IOTA - 188) & 511)])) + (0.00869336631f * fVec41[((IOTA - 189) & 511)])) + (0.0104015954f * fVec41[((IOTA - 190) & 511)])) + (0.0114866383f * fVec41[((IOTA - 191) & 511)])) + (0.0118527859f * fVec41[((IOTA - 192) & 511)])) + (0.0122519284f * fVec41[((IOTA - 193) & 511)])) + (0.0124278273f * fVec41[((IOTA - 194) & 511)])) + (0.0116053894f * fVec41[((IOTA - 195) & 511)])) + (0.00960461237f * fVec41[((IOTA - 196) & 511)])) + (0.00597394723f * fVec41[((IOTA - 197) & 511)])) + (0.00126091018f * fVec41[((IOTA - 198) & 511)])) + (0.00047665555f * fVec41[((IOTA - 202) & 511)])) + (0.00460325973f * fVec41[((IOTA - 203) & 511)])) + (0.00836616755f * fVec41[((IOTA - 204) & 511)])) + (0.0110400841f * fVec41[((IOTA - 205) & 511)])) + (0.0108665731f * fVec41[((IOTA - 206) & 511)])) + (0.00784327742f * fVec41[((IOTA - 207) & 511)])) + (0.00435468601f * fVec41[((IOTA - 208) & 511)])) + (0.00308709359f * fVec41[((IOTA - 209) & 511)])) + (0.00482125487f * fVec41[((IOTA - 210) & 511)])) + (0.00810155645f * fVec41[((IOTA - 211) & 511)])) + (0.0113768931f * fVec41[((IOTA - 212) & 511)])) + (0.0136242397f * fVec41[((IOTA - 213) & 511)])) + (0.0136567913f * fVec41[((IOTA - 214) & 511)])) + (0.0109647047f * fVec41[((IOTA - 215) & 511)])) + (0.00641006464f * fVec41[((IOTA - 216) & 511)])) + (0.00234293146f * fVec41[((IOTA - 217) & 511)])) + (0.00044257706f * fVec41[((IOTA - 218) & 511)])) + (0.00123166805f * fVec41[((IOTA - 219) & 511)])) + (0.00401708111f * fVec41[((IOTA - 220) & 511)])) + (0.00665526558f * fVec41[((IOTA - 221) & 511)])) + (0.00806130469f * fVec41[((IOTA - 222) & 511)])) + (0.00839881413f * fVec41[((IOTA - 223) & 511)])) + (0.00807062723f * fVec41[((IOTA - 224) & 511)])) + (0.00827369932f * fVec41[((IOTA - 225) & 511)])) + (0.00917536765f * fVec41[((IOTA - 226) & 511)])) + (0.0107999742f * fVec41[((IOTA - 227) & 511)])) + (0.0128108384f * fVec41[((IOTA - 228) & 511)])) + (0.0138276294f * fVec41[((IOTA - 229) & 511)])) + (0.0133926887f * fVec41[((IOTA - 230) & 511)])) + (0.0122606475f * fVec41[((IOTA - 231) & 511)])) + (0.0110195614f * fVec41[((IOTA - 232) & 511)])) + (0.00975422747f * fVec41[((IOTA - 233) & 511)])) + (0.00880817138f * fVec41[((IOTA - 234) & 511)])) + (0.00793943554f * fVec41[((IOTA - 235) & 511)])) + (0.00689470721f * fVec41[((IOTA - 236) & 511)])) + (0.00632685702f * fVec41[((IOTA - 237) & 511)])) + (0.0067462055f * fVec41[((IOTA - 238) & 511)])) + (0.00846697111f * fVec41[((IOTA - 239) & 511)])) + (0.0107646864f * fVec41[((IOTA - 240) & 511)])) + (0.0115427691f * fVec41[((IOTA - 241) & 511)])) + (0.0101368893f * fVec41[((IOTA - 242) & 511)])) + (0.00692197634f * fVec41[((IOTA - 243) & 511)])) + (0.00341973407f * fVec41[((IOTA - 244) & 511)])) + (0.00112984609f * fVec41[((IOTA - 245) & 511)])) + (0.000680522993f * fVec41[((IOTA - 248) & 511)])) + (0.0030034082f * fVec41[((IOTA - 249) & 511)])) + (0.00675731059f * fVec41[((IOTA - 250) & 511)])) + (0.0103837438f * fVec41[((IOTA - 251) & 511)])) + (0.0123263225f * fVec41[((IOTA - 252) & 511)])) + (0.0127506359f * fVec41[((IOTA - 253) & 511)])) + (0.0119404476f * fVec41[((IOTA - 254) & 511)])) + (0.0098284306f * fVec41[((IOTA - 255) & 511)])) + (0.00783554465f * fVec41[((IOTA - 256) & 511)])) + (0.00758805359f * fVec41[((IOTA - 257) & 511)])) + (0.00940335449f * fVec41[((IOTA - 258) & 511)])) + (0.0127476128f * fVec41[((IOTA - 259) & 511)])) + (0.0153572876f * fVec41[((IOTA - 260) & 511)])) + (0.0152793927f * fVec41[((IOTA - 261) & 511)])) + (0.0124998353f * fVec41[((IOTA - 262) & 511)])) + (0.00804924499f * fVec41[((IOTA - 263) & 511)])) + (0.00401539495f * fVec41[((IOTA - 264) & 511)])) + (0.00257422728f * fVec41[((IOTA - 265) & 511)])) + (0.00398586644f * fVec41[((IOTA - 266) & 511)])) + (0.00726931775f * fVec41[((IOTA - 267) & 511)])) + (0.011415299f * fVec41[((IOTA - 268) & 511)])) + (0.0147160292f * fVec41[((IOTA - 269) & 511)])) + (0.0161338728f * fVec41[((IOTA - 270) & 511)])) + (0.0154065751f * fVec41[((IOTA - 271) & 511)])) + (0.0125800837f * fVec41[((IOTA - 272) & 511)])) + (0.00926592574f * fVec41[((IOTA - 273) & 511)])) + (0.00728494115f * fVec41[((IOTA - 274) & 511)])) + (0.00648235856f * fVec41[((IOTA - 275) & 511)])) + (0.00587559305f * fVec41[((IOTA - 276) & 511)])) + (0.00521756615f * fVec41[((IOTA - 277) & 511)])) + (0.00456014415f * fVec41[((IOTA - 278) & 511)])) + (0.00421662116f * fVec41[((IOTA - 279) & 511)])) + (0.00446439954f * fVec41[((IOTA - 280) & 511)])) + (0.0050134128f * fVec41[((IOTA - 281) & 511)])) + (0.00574010564f * fVec41[((IOTA - 282) & 511)])) + (0.00680949446f * fVec41[((IOTA - 283) & 511)])) + (0.00828095432f * fVec41[((IOTA - 284) & 511)])) + (0.00960015785f * fVec41[((IOTA - 285) & 511)])) + (0.00990110636f * fVec41[((IOTA - 286) & 511)])) + (0.00850229058f * fVec41[((IOTA - 287) & 511)])) + (0.00620839279f * fVec41[((IOTA - 288) & 511)])) + (0.00434020814f * fVec41[((IOTA - 289) & 511)])) + (0.00292405067f * fVec41[((IOTA - 290) & 511)])) + (0.0020235274f * fVec41[((IOTA - 291) & 511)])) + (0.00190907298f * fVec41[((IOTA - 292) & 511)])) + (0.00273609301f * fVec41[((IOTA - 293) & 511)])) + (0.0041759559f * fVec41[((IOTA - 294) & 511)])) + (0.00567198033f * fVec41[((IOTA - 295) & 511)])) + (0.00651869643f * fVec41[((IOTA - 296) & 511)])) + (0.00653759716f * fVec41[((IOTA - 297) & 511)])) + (0.00650905492f * fVec41[((IOTA - 298) & 511)])) + (0.006737296f * fVec41[((IOTA - 299) & 511)])) + (0.00780671695f * fVec41[((IOTA - 300) & 511)])) + (0.0102996137f * fVec41[((IOTA - 301) & 511)])) + (0.0126997251f * fVec41[((IOTA - 302) & 511)])) + (0.0132128131f * fVec41[((IOTA - 303) & 511)])) + (0.0120136328f * fVec41[((IOTA - 304) & 511)])) + (0.010147484f * fVec41[((IOTA - 305) & 511)])) + (0.00780983502f * fVec41[((IOTA - 306) & 511)])) + (0.00525517715f * fVec41[((IOTA - 307) & 511)])) + (0.00345884031f * fVec41[((IOTA - 308) & 511)])) + (0.00264136633f * fVec41[((IOTA - 309) & 511)])) + (0.00282948324f * fVec41[((IOTA - 310) & 511)])) + (0.00426435051f * fVec41[((IOTA - 311) & 511)])) + (0.00612798519f * fVec41[((IOTA - 312) & 511)])) + (0.00818406418f * fVec41[((IOTA - 313) & 511)])) + (0.00984134898f * fVec41[((IOTA - 314) & 511)])) + (0.00997807831f * fVec41[((IOTA - 315) & 511)])) + (0.00840361789f * fVec41[((IOTA - 316) & 511)])) + (0.00534878997f * fVec41[((IOTA - 317) & 511)])) + (0.00210670382f * fVec41[((IOTA - 318) & 511)])) + (0.000284338836f * fVec41[((IOTA - 327) & 511)])) + (0.000966198277f * fVec41[((IOTA - 328) & 511)])) + (0.0012209448f * fVec41[((IOTA - 329) & 511)])) + (0.00141991209f * fVec41[((IOTA - 330) & 511)])) + (0.00139483856f * fVec41[((IOTA - 331) & 511)])) + (0.00117235677f * fVec41[((IOTA - 332) & 511)])) + (0.00131315785f * fVec41[((IOTA - 333) & 511)])) + (0.00139490189f * fVec41[((IOTA - 334) & 511)])) + (0.00181816472f * fVec41[((IOTA - 335) & 511)])) + (0.00521572074f * fVec41[((IOTA - 360) & 511)])))))))))))))))))))))) + (0.00399356661f * fVec41[((IOTA - 361) & 511)])) + (0.0024274122f * fVec41[((IOTA - 362) & 511)])) + (0.00120659452f * fVec41[((IOTA - 363) & 511)])) + (0.000372796785f * fVec41[((IOTA - 364) & 511)])) + (0.000245900825f * fVec41[((IOTA - 377) & 511)])) + (1.78208575e-06f * fVec41[((IOTA - 386) & 511)])) + (0.00125995558f * fVec41[((IOTA - 387) & 511)])) + (0.000783300027f * fVec41[((IOTA - 388) & 511)])) + (0.000461477786f * fVec41[((IOTA - 427) & 511)])) + (0.00125531014f * fVec41[((IOTA - 428) & 511)])) + (0.00106585678f * fVec41[((IOTA - 429) & 511)])) + (0.000153465196f * fVec41[((IOTA - 471) & 511)])) + (0.000181021169f * fVec41[((IOTA - 472) & 511)])) + (0.00058643287f * fVec41[((IOTA - 494) & 511)])) + (0.00172347017f * fVec41[((IOTA - 495) & 511)])) + (0.00182440132f * fVec41[((IOTA - 496) & 511)])) + (0.000910895877f * fVec41[((IOTA - 497) & 511)])) - (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00287584402f * fVec41[((IOTA - 410) & 511)]) + ((0.00199594023f * fVec41[((IOTA - 409) & 511)]) + ((0.00220193947f * fVec41[((IOTA - 408) & 511)]) + ((0.00281319162f * fVec41[((IOTA - 407) & 511)]) + ((0.00351742003f * fVec41[((IOTA - 406) & 511)]) + ((0.00361039676f * fVec41[((IOTA - 405) & 511)]) + ((0.00287838979f * fVec41[((IOTA - 404) & 511)]) + ((0.00239801081f * fVec41[((IOTA - 403) & 511)]) + ((0.00278274016f * fVec41[((IOTA - 402) & 511)]) + ((0.00389254f * fVec41[((IOTA - 401) & 511)]) + ((0.00557865389f * fVec41[((IOTA - 400) & 511)]) + ((0.00697562424f * fVec41[((IOTA - 399) & 511)]) + ((0.00701094372f * fVec41[((IOTA - 398) & 511)]) + ((0.00609944295f * fVec41[((IOTA - 397) & 511)]) + ((0.0049638059f * fVec41[((IOTA - 396) & 511)]) + ((0.00406446029f * fVec41[((IOTA - 395) & 511)]) + ((0.00360174151f * fVec41[((IOTA - 394) & 511)]) + ((0.00350539247f * fVec41[((IOTA - 393) & 511)]) + ((0.00377232581f * fVec41[((IOTA - 392) & 511)]) + ((0.00365303457f * fVec41[((IOTA - 391) & 511)]) + ((0.00257451367f * fVec41[((IOTA - 390) & 511)]) + ((0.000874494668f * fVec41[((IOTA - 389) & 511)]) + ((0.00193933304f * fVec41[((IOTA - 385) & 511)]) + ((0.00343402103f * fVec41[((IOTA - 384) & 511)]) + ((0.00421916693f * fVec41[((IOTA - 383) & 511)]) + ((0.00382559188f * fVec41[((IOTA - 382) & 511)]) + ((0.00258020917f * fVec41[((IOTA - 381) & 511)]) + ((0.00155256735f * fVec41[((IOTA - 380) & 511)]) + ((0.000805446412f * fVec41[((IOTA - 379) & 511)]) + ((4.9829483e-05f * fVec41[((IOTA - 378) & 511)]) + ((0.000124637038f * fVec41[((IOTA - 376) & 511)]) + ((0.000969952904f * fVec41[((IOTA - 375) & 511)]) + ((0.00216763793f * fVec41[((IOTA - 374) & 511)]) + ((0.00367333554f * fVec41[((IOTA - 373) & 511)]) + ((0.00555348443f * fVec41[((IOTA - 372) & 511)]) + ((0.00745581184f * fVec41[((IOTA - 371) & 511)]) + ((0.00851740502f * fVec41[((IOTA - 370) & 511)]) + ((0.00816649944f * fVec41[((IOTA - 369) & 511)]) + ((0.00649155444f * fVec41[((IOTA - 368) & 511)]) + ((0.00444158493f * fVec41[((IOTA - 367) & 511)]) + ((0.00259300089f * fVec41[((IOTA - 366) & 511)]) + ((0.00082985172f * fVec41[((IOTA - 365) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00837358087f * fVec41[((IOTA - 22) & 511)]) + ((0.0186466239f * fVec41[((IOTA - 21) & 511)]) + ((0.0142263593f * fVec41[((IOTA - 20) & 511)]) + ((0.0665427297f * fVec41[((IOTA - 10) & 511)]) + ((0.142920181f * fVec41[((IOTA - 9) & 511)]) + ((0.185233921f * fVec41[((IOTA - 8) & 511)]) + ((0.159383044f * fVec41[((IOTA - 7) & 511)]) + ((0.0582488887f * fVec41[((IOTA - 6) & 511)]) + ((0.0943766534f * fVec41[((IOTA - 32) & 511)]) + ((0.0205535349f * fVec41[((IOTA - 29) & 511)]) + (((0.0403686352f * fVec41[((IOTA - 30) & 511)]) + (0.0691986978f * fVec41[((IOTA - 31) & 511)])) + (0.0856619328f * fVec41[((IOTA - 33) & 511)])))))))))))) + (0.0546820499f * fVec41[((IOTA - 34) & 511)])) + (0.019982757f * fVec41[((IOTA - 35) & 511)])) + (0.00543603906f * fVec41[((IOTA - 41) & 511)])) + (0.0221215673f * fVec41[((IOTA - 42) & 511)])) + (0.0346963368f * fVec41[((IOTA - 43) & 511)])) + (0.0491328947f * fVec41[((IOTA - 44) & 511)])) + (0.0512137935f * fVec41[((IOTA - 45) & 511)])) + (0.045003809f * fVec41[((IOTA - 46) & 511)])) + (0.0395688526f * fVec41[((IOTA - 47) & 511)])) + (0.0263684802f * fVec41[((IOTA - 48) & 511)])) + (0.0137725174f * fVec41[((IOTA - 49) & 511)])) + (0.0108592231f * fVec41[((IOTA - 50) & 511)])) + (0.0117027573f * fVec41[((IOTA - 51) & 511)])) + (0.010698216f * fVec41[((IOTA - 52) & 511)])) + (0.00958984904f * fVec41[((IOTA - 53) & 511)])) + (0.00883655436f * fVec41[((IOTA - 54) & 511)])) + (0.0080443453f * fVec41[((IOTA - 55) & 511)])) + (0.00898231938f * fVec41[((IOTA - 56) & 511)])) + (0.00617024116f * fVec41[((IOTA - 57) & 511)])) + (0.010124065f * fVec41[((IOTA - 58) & 511)])) + (0.0212154426f * fVec41[((IOTA - 59) & 511)])) + (0.0254903883f * fVec41[((IOTA - 60) & 511)])) + (0.0258725733f * fVec41[((IOTA - 61) & 511)])) + (0.0229376405f * fVec41[((IOTA - 62) & 511)])) + (0.0136708226f * fVec41[((IOTA - 63) & 511)])) + (0.00353963021f * fVec41[((IOTA - 64) & 511)])) + (0.000198394526f * fVec41[((IOTA - 65) & 511)])) + (0.0086554382f * fVec41[((IOTA - 66) & 511)])) + (0.0236911569f * fVec41[((IOTA - 67) & 511)])) + (0.0366201736f * fVec41[((IOTA - 68) & 511)])) + (0.0446025319f * fVec41[((IOTA - 69) & 511)])) + (0.0390073024f * fVec41[((IOTA - 70) & 511)])) + (0.0234610699f * fVec41[((IOTA - 71) & 511)])) + (0.010919393f * fVec41[((IOTA - 72) & 511)])) + (0.00166590838f * fVec41[((IOTA - 73) & 511)])) + (0.00365029834f * fVec41[((IOTA - 75) & 511)])) + (0.0111578163f * fVec41[((IOTA - 76) & 511)])) + (0.0149118779f * fVec41[((IOTA - 77) & 511)])) + (0.0123490421f * fVec41[((IOTA - 78) & 511)])) + (0.000618316233f * fVec41[((IOTA - 79) & 511)])) + (0.0031276634f * fVec41[((IOTA - 82) & 511)])) + (0.013395871f * fVec41[((IOTA - 83) & 511)])) + (0.0213112198f * fVec41[((IOTA - 84) & 511)])) + (0.0243492164f * fVec41[((IOTA - 85) & 511)])) + (0.0221265629f * fVec41[((IOTA - 86) & 511)])) + (0.0182881467f * fVec41[((IOTA - 87) & 511)])) + (0.0153490771f * fVec41[((IOTA - 88) & 511)])) + (0.0156085975f * fVec41[((IOTA - 89) & 511)])) + (0.0186985228f * fVec41[((IOTA - 90) & 511)])) + (0.0183552857f * fVec41[((IOTA - 91) & 511)])) + (0.0187049508f * fVec41[((IOTA - 92) & 511)])) + (0.0198100731f * fVec41[((IOTA - 93) & 511)])) + (0.0169637892f * fVec41[((IOTA - 94) & 511)])) + (0.0143761653f * fVec41[((IOTA - 95) & 511)])) + (0.0112788901f * fVec41[((IOTA - 96) & 511)])) + (0.0058910572f * fVec41[((IOTA - 97) & 511)])) + (0.00238044653f * fVec41[((IOTA - 102) & 511)])) + (0.0107258037f * fVec41[((IOTA - 103) & 511)])) + (0.0161562748f * fVec41[((IOTA - 104) & 511)])) + (0.0199629646f * fVec41[((IOTA - 105) & 511)])) + (0.0208187178f * fVec41[((IOTA - 106) & 511)])) + (0.0200716592f * fVec41[((IOTA - 107) & 511)])) + (0.0180551969f * fVec41[((IOTA - 108) & 511)])) + (0.0133247226f * fVec41[((IOTA - 109) & 511)])) + (0.00933147408f * fVec41[((IOTA - 110) & 511)])) + (0.0062812278f * fVec41[((IOTA - 111) & 511)])) + (0.00469432678f * fVec41[((IOTA - 112) & 511)])) + (0.00709733367f * fVec41[((IOTA - 113) & 511)])) + (0.00942998752f * fVec41[((IOTA - 114) & 511)])) + (0.0104184281f * fVec41[((IOTA - 115) & 511)])) + (0.0111192511f * fVec41[((IOTA - 116) & 511)])) + (0.00930220075f * fVec41[((IOTA - 117) & 511)])) + (0.00724468939f * fVec41[((IOTA - 118) & 511)])) + (0.00668921694f * fVec41[((IOTA - 119) & 511)])) + (0.00797122344f * fVec41[((IOTA - 120) & 511)])) + (0.0144406632f * fVec41[((IOTA - 121) & 511)])) + (0.0223449059f * fVec41[((IOTA - 122) & 511)])) + (0.0257467907f * fVec41[((IOTA - 123) & 511)])) + (0.0256165862f * fVec41[((IOTA - 124) & 511)])) + (0.0218452774f * fVec41[((IOTA - 125) & 511)])) + (0.0157172289f * fVec41[((IOTA - 126) & 511)])) + (0.00813579373f * fVec41[((IOTA - 127) & 511)])) + (2.56146304e-05f * fVec41[((IOTA - 137) & 511)])) + (0.00358287292f * fVec41[((IOTA - 138) & 511)])) + (0.008237998f * fVec41[((IOTA - 139) & 511)])) + (0.0121075325f * fVec41[((IOTA - 140) & 511)])) + (0.014304826f * fVec41[((IOTA - 141) & 511)])) + (0.0135757467f * fVec41[((IOTA - 142) & 511)])) + (0.00861197244f * fVec41[((IOTA - 143) & 511)])) + (0.000521234702f * fVec41[((IOTA - 144) & 511)])) + (0.00466171186f * fVec41[((IOTA - 150) & 511)])) + (0.00765608344f * fVec41[((IOTA - 151) & 511)])) + (0.00825489406f * fVec41[((IOTA - 152) & 511)])) + (0.00550511898f * fVec41[((IOTA - 153) & 511)])) + (0.00410035299f * fVec41[((IOTA - 159) & 511)])) + (0.0089596957f * fVec41[((IOTA - 160) & 511)])) + (0.0113921352f * fVec41[((IOTA - 161) & 511)])) + (0.0112768849f * fVec41[((IOTA - 162) & 511)])) + (0.00886411034f * fVec41[((IOTA - 163) & 511)])) + (0.00482901884f * fVec41[((IOTA - 164) & 511)])) + (0.000422276091f * fVec41[((IOTA - 165) & 511)])) + (0.000941633713f * fVec41[((IOTA - 173) & 511)])) + (0.00584991463f * fVec41[((IOTA - 174) & 511)])) + (0.00812713895f * fVec41[((IOTA - 175) & 511)])) + (0.00771383569f * fVec41[((IOTA - 176) & 511)])) + (0.00489319861f * fVec41[((IOTA - 177) & 511)])) + (0.00222924026f * fVec41[((IOTA - 199) & 511)])) + (0.00340843853f * fVec41[((IOTA - 200) & 511)])) + (0.00264667999f * fVec41[((IOTA - 201) & 511)])) + (7.53803179e-05f * fVec41[((IOTA - 246) & 511)])) + (0.000246569049f * fVec41[((IOTA - 247) & 511)])) + (0.000167561229f * fVec41[((IOTA - 319) & 511)])) + (0.0010540518f * fVec41[((IOTA - 320) & 511)])) + (0.000788136385f * fVec41[((IOTA - 321) & 511)])) + (0.000334263779f * fVec41[((IOTA - 322) & 511)])) + (0.000420112628f * fVec41[((IOTA - 323) & 511)])) + (0.000732229557f * fVec41[((IOTA - 324) & 511)])) + (0.000815596897f * fVec41[((IOTA - 325) & 511)])) + (0.000464818906f * fVec41[((IOTA - 326) & 511)])) + (0.00357558625f * fVec41[((IOTA - 354) & 511)])) + (0.00494302809f * fVec41[((IOTA - 355) & 511)])) + (0.00357199041f * fVec41[((IOTA - 356) & 511)])) + (0.000406907406f * fVec41[((IOTA - 357) & 511)])) + (0.00454178452f * fVec41[((IOTA - 411) & 511)])))))))))))))))))))))))))))))))))))))))))))) + (0.00612343475f * fVec41[((IOTA - 412) & 511)])) + (0.00759158563f * fVec41[((IOTA - 413) & 511)])) + (0.00826806761f * fVec41[((IOTA - 414) & 511)])) + (0.00768968463f * fVec41[((IOTA - 415) & 511)])) + (0.00652588764f * fVec41[((IOTA - 416) & 511)])) + (0.00460580504f * fVec41[((IOTA - 417) & 511)])) + (0.00244806288f * fVec41[((IOTA - 418) & 511)])) + (0.000947138295f * fVec41[((IOTA - 419) & 511)])) + (0.000243769027f * fVec41[((IOTA - 420) & 511)])) + (0.000659713056f * fVec41[((IOTA - 421) & 511)])) + (0.00175032578f * fVec41[((IOTA - 422) & 511)])) + (0.00243205763f * fVec41[((IOTA - 423) & 511)])) + (0.00231989427f * fVec41[((IOTA - 424) & 511)])) + (0.00168089569f * fVec41[((IOTA - 425) & 511)])) + (0.000722270459f * fVec41[((IOTA - 426) & 511)])) + (0.000286693685f * fVec41[((IOTA - 430) & 511)])) + (0.00242493022f * fVec41[((IOTA - 431) & 511)])) + (0.00462604221f * fVec41[((IOTA - 432) & 511)])) + (0.00661297748f * fVec41[((IOTA - 433) & 511)])) + (0.00812341645f * fVec41[((IOTA - 434) & 511)])) + (0.00870004855f * fVec41[((IOTA - 435) & 511)])) + (0.00812834874f * fVec41[((IOTA - 436) & 511)])) + (0.00737635838f * fVec41[((IOTA - 437) & 511)])) + (0.00739398645f * fVec41[((IOTA - 438) & 511)])) + (0.00839152746f * fVec41[((IOTA - 439) & 511)])) + (0.0101884361f * fVec41[((IOTA - 440) & 511)])) + (0.0115610007f * fVec41[((IOTA - 441) & 511)])) + (0.0114573017f * fVec41[((IOTA - 442) & 511)])) + (0.010321728f * fVec41[((IOTA - 443) & 511)])) + (0.00864407793f * fVec41[((IOTA - 444) & 511)])) + (0.00671311328f * fVec41[((IOTA - 445) & 511)])) + (0.00547269499f * fVec41[((IOTA - 446) & 511)])) + (0.00519223791f * fVec41[((IOTA - 447) & 511)])) + (0.00535661727f * fVec41[((IOTA - 448) & 511)])) + (0.00540940603f * fVec41[((IOTA - 449) & 511)])) + (0.0048437831f * fVec41[((IOTA - 450) & 511)])) + (0.00357421767f * fVec41[((IOTA - 451) & 511)])) + (0.00268234964f * fVec41[((IOTA - 452) & 511)])) + (0.00259968266f * fVec41[((IOTA - 453) & 511)])) + (0.00297203427f * fVec41[((IOTA - 454) & 511)])) + (0.00386784784f * fVec41[((IOTA - 455) & 511)])) + (0.00515660038f * fVec41[((IOTA - 456) & 511)])) + (0.00630076462f * fVec41[((IOTA - 457) & 511)])) + (0.00723068882f * fVec41[((IOTA - 458) & 511)])) + (0.00747493515f * fVec41[((IOTA - 459) & 511)])) + (0.00673987344f * fVec41[((IOTA - 460) & 511)])) + (0.00507221511f * fVec41[((IOTA - 461) & 511)])) + (0.0029005995f * fVec41[((IOTA - 462) & 511)])) + (0.00174606172f * fVec41[((IOTA - 463) & 511)])) + (0.0024577044f * fVec41[((IOTA - 464) & 511)])) + (0.00454779807f * fVec41[((IOTA - 465) & 511)])) + (0.00666560698f * fVec41[((IOTA - 466) & 511)])) + (0.00739468634f * fVec41[((IOTA - 467) & 511)])) + (0.0062338165f * fVec41[((IOTA - 468) & 511)])) + (0.00381560018f * fVec41[((IOTA - 469) & 511)])) + (0.00132238539f * fVec41[((IOTA - 470) & 511)])) + (0.000839461572f * fVec41[((IOTA - 473) & 511)])) + (0.00213177735f * fVec41[((IOTA - 474) & 511)])) + (0.0030645337f * fVec41[((IOTA - 475) & 511)])) + (0.00279263593f * fVec41[((IOTA - 476) & 511)])) + (0.00172903854f * fVec41[((IOTA - 477) & 511)])) + (0.00136947818f * fVec41[((IOTA - 478) & 511)])) + (0.00184944319f * fVec41[((IOTA - 479) & 511)])) + (0.00342721166f * fVec41[((IOTA - 480) & 511)])) + (0.00560054556f * fVec41[((IOTA - 481) & 511)])) + (0.00706732785f * fVec41[((IOTA - 482) & 511)])) + (0.00759406714f * fVec41[((IOTA - 483) & 511)])) + (0.00693257246f * fVec41[((IOTA - 484) & 511)])) + (0.0052247257f * fVec41[((IOTA - 485) & 511)])) + (0.00356600853f * fVec41[((IOTA - 486) & 511)])) + (0.00235785497f * fVec41[((IOTA - 487) & 511)])) + (0.00209613983f * fVec41[((IOTA - 488) & 511)])) + (0.00314032752f * fVec41[((IOTA - 489) & 511)])) + (0.00414407253f * fVec41[((IOTA - 490) & 511)])) + (0.00416450063f * fVec41[((IOTA - 491) & 511)])) + (0.00313510885f * fVec41[((IOTA - 492) & 511)])) + (0.00126237376f * fVec41[((IOTA - 493) & 511)])) + (0.000236927997f * fVec41[((IOTA - 498) & 511)])) + (0.00128455227f * fVec41[((IOTA - 499) & 511)])) + (0.00227646064f * fVec41[((IOTA - 500) & 511)])) + (0.00315722357f * fVec41[((IOTA - 501) & 511)])) + (0.003976034f * fVec41[((IOTA - 502) & 511)])) + (0.00483547803f * fVec41[((IOTA - 503) & 511)])) + (0.0059468369f * fVec41[((IOTA - 504) & 511)])) + (0.00731831975f * fVec41[((IOTA - 505) & 511)])) + (0.00844870694f * fVec41[((IOTA - 506) & 511)])) + (0.00905540865f * fVec41[((IOTA - 507) & 511)])) + (0.00894954521f * fVec41[((IOTA - 508) & 511)])) + (0.0080011338f * fVec41[((IOTA - 509) & 511)])) + (0.00666360231f * fVec41[((IOTA - 510) & 511)])) + (0.00579827186f * fVec41[((IOTA - 511) & 511)]))))) : (iSlow116 ? (iSlow122 ? (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0125516001f * fVec40[((IOTA - 260) & 511)]) + ((0.0128473695f * fVec40[((IOTA - 259) & 511)]) + ((0.0136032533f * fVec40[((IOTA - 258) & 511)]) + ((0.014215054f * fVec40[((IOTA - 257) & 511)]) + ((0.0140682384f * fVec40[((IOTA - 256) & 511)]) + ((0.0138124544f * fVec40[((IOTA - 255) & 511)]) + ((0.0132955406f * fVec40[((IOTA - 254) & 511)]) + ((0.0116046667f * fVec40[((IOTA - 253) & 511)]) + ((0.00919447932f * fVec40[((IOTA - 252) & 511)]) + ((0.00702664768f * fVec40[((IOTA - 251) & 511)]) + ((0.0059369388f * fVec40[((IOTA - 250) & 511)]) + ((0.0062641101f * fVec40[((IOTA - 249) & 511)]) + ((0.00690454897f * fVec40[((IOTA - 248) & 511)]) + ((0.00680645416f * fVec40[((IOTA - 247) & 511)]) + ((0.00548371766f * fVec40[((IOTA - 246) & 511)]) + ((0.00346650463f * fVec40[((IOTA - 245) & 511)]) + ((0.00273741782f * fVec40[((IOTA - 244) & 511)]) + ((0.00446524797f * fVec40[((IOTA - 243) & 511)]) + ((0.00848419778f * fVec40[((IOTA - 242) & 511)]) + ((0.0136757996f * fVec40[((IOTA - 241) & 511)]) + ((0.0175956134f * fVec40[((IOTA - 240) & 511)]) + ((0.0188209973f * fVec40[((IOTA - 239) & 511)]) + ((0.017123647f * fVec40[((IOTA - 238) & 511)]) + ((0.0128005203f * fVec40[((IOTA - 237) & 511)]) + ((0.0083170021f * fVec40[((IOTA - 236) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0155770928f * fVec40[((IOTA - 55) & 511)]) + ((0.0292595476f * fVec40[((IOTA - 54) & 511)]) + ((0.0359609537f * fVec40[((IOTA - 53) & 511)]) + ((0.0264629815f * fVec40[((IOTA - 52) & 511)]) + ((0.00949423015f * fVec40[((IOTA - 43) & 511)]) + ((0.0191470403f * fVec40[((IOTA - 42) & 511)]) + ((0.0204968099f * fVec40[((IOTA - 41) & 511)]) + ((0.0117956866f * fVec40[((IOTA - 40) & 511)]) + ((0.00542118307f * fVec40[((IOTA - 39) & 511)]) + ((0.00235311873f * fVec40[((IOTA - 38) & 511)]) + ((0.00752238045f * fVec40[((IOTA - 28) & 511)]) + ((0.0405346937f * fVec40[((IOTA - 27) & 511)]) + ((0.0620948635f * fVec40[((IOTA - 26) & 511)]) + ((0.0548633821f * fVec40[((IOTA - 25) & 511)]) + ((0.0362151042f * fVec40[((IOTA - 24) & 511)]) + ((0.0144464765f * fVec40[((IOTA - 23) & 511)]) + ((0.0266865026f * fVec40[((IOTA - 18) & 511)]) + ((0.0439813845f * fVec40[((IOTA - 17) & 511)]) + ((0.0491647869f * fVec40[((IOTA - 16) & 511)]) + ((0.0517476946f * fVec40[((IOTA - 15) & 511)]) + ((0.045969069f * fVec40[((IOTA - 14) & 511)]) + ((0.0272477996f * fVec40[((IOTA - 13) & 511)]) + ((0.000772727653f * fVec40[((IOTA - 12) & 511)]) + ((0.0409886874f * fVec40[((IOTA - 6) & 511)]) + ((0.137071669f * fVec40[((IOTA - 5) & 511)]) + ((0.203701183f * fVec40[((IOTA - 4) & 511)]) + ((0.237498343f * fVec40[((IOTA - 3) & 511)]) + ((0.24073337f * fVec40[((IOTA - 2) & 511)]) + ((0.192505717f * fVec40[((IOTA - 1) & 511)]) + ((fSlow126 * fTemp0) + (0.00840217434f * fVec40[((IOTA - 65) & 511)]))))))))))))))))))))))))))))))) + (0.00888673682f * fVec40[((IOTA - 66) & 511)])) + (0.00178858265f * fVec40[((IOTA - 75) & 511)])) + (0.000287392642f * fVec40[((IOTA - 76) & 511)])) + (0.0100210961f * fVec40[((IOTA - 100) & 511)])) + (0.0180400405f * fVec40[((IOTA - 101) & 511)])) + (0.0170331579f * fVec40[((IOTA - 102) & 511)])) + (0.00589968543f * fVec40[((IOTA - 103) & 511)])) + (0.0035877414f * fVec40[((IOTA - 128) & 511)])) + (0.0135977566f * fVec40[((IOTA - 129) & 511)])) + (0.0167062841f * fVec40[((IOTA - 130) & 511)])) + (0.0134799071f * fVec40[((IOTA - 131) & 511)])) + (0.00500114588f * fVec40[((IOTA - 132) & 511)])) + (0.00114285573f * fVec40[((IOTA - 135) & 511)])) + (0.00877862982f * fVec40[((IOTA - 136) & 511)])) + (0.0125684738f * fVec40[((IOTA - 137) & 511)])) + (0.00887122937f * fVec40[((IOTA - 138) & 511)])) + (0.00146955159f * fVec40[((IOTA - 139) & 511)])) + (0.00235409895f * fVec40[((IOTA - 145) & 511)])) + (0.00321416697f * fVec40[((IOTA - 146) & 511)])) + (0.00551601034f * fVec40[((IOTA - 153) & 511)])) + (0.00920692645f * fVec40[((IOTA - 154) & 511)])) + (0.00681396993f * fVec40[((IOTA - 155) & 511)])) + (0.00124715967f * fVec40[((IOTA - 156) & 511)])) + (0.00118979393f * fVec40[((IOTA - 167) & 511)])) + (0.00420637522f * fVec40[((IOTA - 168) & 511)])) + (0.00782884471f * fVec40[((IOTA - 169) & 511)])) + (0.0099764755f * fVec40[((IOTA - 170) & 511)])) + (0.00990015641f * fVec40[((IOTA - 171) & 511)])) + (0.00724589033f * fVec40[((IOTA - 172) & 511)])) + (0.0034356676f * fVec40[((IOTA - 173) & 511)])) + (0.000404767692f * fVec40[((IOTA - 174) & 511)])) + (0.000749288127f * fVec40[((IOTA - 179) & 511)])) + (0.0065059308f * fVec40[((IOTA - 180) & 511)])) + (0.010403851f * fVec40[((IOTA - 181) & 511)])) + (0.0120384879f * fVec40[((IOTA - 182) & 511)])) + (0.0106908567f * fVec40[((IOTA - 183) & 511)])) + (0.00765680755f * fVec40[((IOTA - 184) & 511)])) + (0.00558175333f * fVec40[((IOTA - 185) & 511)])) + (0.0046270364f * fVec40[((IOTA - 186) & 511)])) + (0.00516320113f * fVec40[((IOTA - 187) & 511)])) + (0.0070001781f * fVec40[((IOTA - 188) & 511)])) + (0.00994647108f * fVec40[((IOTA - 189) & 511)])) + (0.0142103303f * fVec40[((IOTA - 190) & 511)])) + (0.0169370528f * fVec40[((IOTA - 191) & 511)])) + (0.0159688778f * fVec40[((IOTA - 192) & 511)])) + (0.01337694f * fVec40[((IOTA - 193) & 511)])) + (0.0103231054f * fVec40[((IOTA - 194) & 511)])) + (0.00865730457f * fVec40[((IOTA - 195) & 511)])) + (0.00949464552f * fVec40[((IOTA - 196) & 511)])) + (0.00946282875f * fVec40[((IOTA - 197) & 511)])) + (0.00747820502f * fVec40[((IOTA - 198) & 511)])) + (0.00398959778f * fVec40[((IOTA - 199) & 511)])) + (0.00493171858f * fVec40[((IOTA - 203) & 511)])) + (0.0105114523f * fVec40[((IOTA - 204) & 511)])) + (0.0146038681f * fVec40[((IOTA - 205) & 511)])) + (0.0152104702f * fVec40[((IOTA - 206) & 511)])) + (0.0118396543f * fVec40[((IOTA - 207) & 511)])) + (0.00666718418f * fVec40[((IOTA - 208) & 511)])) + (0.00336297322f * fVec40[((IOTA - 209) & 511)])) + (0.00375255989f * fVec40[((IOTA - 210) & 511)])) + (0.00727987615f * fVec40[((IOTA - 211) & 511)])) + (0.012882039f * fVec40[((IOTA - 212) & 511)])) + (0.0186002105f * fVec40[((IOTA - 213) & 511)])) + (0.0228526611f * fVec40[((IOTA - 214) & 511)])) + (0.0238328986f * fVec40[((IOTA - 215) & 511)])) + (0.0201141145f * fVec40[((IOTA - 216) & 511)])) + (0.0118870679f * fVec40[((IOTA - 217) & 511)])) + (0.00131171476f * fVec40[((IOTA - 218) & 511)])) + (0.00377923762f * fVec40[((IOTA - 222) & 511)])) + (0.010604199f * fVec40[((IOTA - 223) & 511)])) + (0.0149845723f * fVec40[((IOTA - 224) & 511)])) + (0.0171046928f * fVec40[((IOTA - 225) & 511)])) + (0.017268829f * fVec40[((IOTA - 226) & 511)])) + (0.0159470141f * fVec40[((IOTA - 227) & 511)])) + (0.0150769334f * fVec40[((IOTA - 228) & 511)])) + (0.0160358697f * fVec40[((IOTA - 229) & 511)])) + (0.0180943161f * fVec40[((IOTA - 230) & 511)])) + (0.0186355319f * fVec40[((IOTA - 231) & 511)])) + (0.0161682777f * fVec40[((IOTA - 232) & 511)])) + (0.0120536685f * fVec40[((IOTA - 233) & 511)])) + (0.0081266053f * fVec40[((IOTA - 234) & 511)])) + (0.00644081132f * fVec40[((IOTA - 235) & 511)])) + (0.0121318297f * fVec40[((IOTA - 261) & 511)]))))))))))))))))))))))))))) + (0.0109300334f * fVec40[((IOTA - 262) & 511)])) + (0.00925003272f * fVec40[((IOTA - 263) & 511)])) + (0.00824876316f * fVec40[((IOTA - 264) & 511)])) + (0.00889499579f * fVec40[((IOTA - 265) & 511)])) + (0.0106063681f * fVec40[((IOTA - 266) & 511)])) + (0.0123982783f * fVec40[((IOTA - 267) & 511)])) + (0.0147134904f * fVec40[((IOTA - 268) & 511)])) + (0.0178734101f * fVec40[((IOTA - 269) & 511)])) + (0.0208235942f * fVec40[((IOTA - 270) & 511)])) + (0.0221296363f * fVec40[((IOTA - 271) & 511)])) + (0.0206692629f * fVec40[((IOTA - 272) & 511)])) + (0.0169202089f * fVec40[((IOTA - 273) & 511)])) + (0.0126003204f * fVec40[((IOTA - 274) & 511)])) + (0.0088288663f * fVec40[((IOTA - 275) & 511)])) + (0.0066615399f * fVec40[((IOTA - 276) & 511)])) + (0.00678135082f * fVec40[((IOTA - 277) & 511)])) + (0.00824606046f * fVec40[((IOTA - 278) & 511)])) + (0.00968533941f * fVec40[((IOTA - 279) & 511)])) + (0.0109156258f * fVec40[((IOTA - 280) & 511)])) + (0.0115713943f * fVec40[((IOTA - 281) & 511)])) + (0.0112423804f * fVec40[((IOTA - 282) & 511)])) + (0.0106575247f * fVec40[((IOTA - 283) & 511)])) + (0.0104159415f * fVec40[((IOTA - 284) & 511)])) + (0.0104032271f * fVec40[((IOTA - 285) & 511)])) + (0.00981807336f * fVec40[((IOTA - 286) & 511)])) + (0.00848185085f * fVec40[((IOTA - 287) & 511)])) + (0.00687433593f * fVec40[((IOTA - 288) & 511)])) + (0.0053478647f * fVec40[((IOTA - 289) & 511)])) + (0.00436860882f * fVec40[((IOTA - 290) & 511)])) + (0.00417853892f * fVec40[((IOTA - 291) & 511)])) + (0.00469681993f * fVec40[((IOTA - 292) & 511)])) + (0.00554758962f * fVec40[((IOTA - 293) & 511)])) + (0.00544441445f * fVec40[((IOTA - 294) & 511)])) + (0.00418691663f * fVec40[((IOTA - 295) & 511)])) + (0.00307002524f * fVec40[((IOTA - 296) & 511)])) + (0.00303648505f * fVec40[((IOTA - 297) & 511)])) + (0.00456848228f * fVec40[((IOTA - 298) & 511)])) + (0.00823367201f * fVec40[((IOTA - 299) & 511)])) + (0.0136196222f * fVec40[((IOTA - 300) & 511)])) + (0.0181240253f * fVec40[((IOTA - 301) & 511)])) + (0.0200505108f * fVec40[((IOTA - 302) & 511)])) + (0.019857619f * fVec40[((IOTA - 303) & 511)])) + (0.0176187269f * fVec40[((IOTA - 304) & 511)])) + (0.0141610149f * fVec40[((IOTA - 305) & 511)])) + (0.00969656929f * fVec40[((IOTA - 306) & 511)])) + (0.0044989367f * fVec40[((IOTA - 307) & 511)])) + (0.000575794838f * fVec40[((IOTA - 308) & 511)])) + (0.000968947075f * fVec40[((IOTA - 310) & 511)])) + (0.00509828981f * fVec40[((IOTA - 311) & 511)])) + (0.00988227222f * fVec40[((IOTA - 312) & 511)])) + (0.0137864016f * fVec40[((IOTA - 313) & 511)])) + (0.0156631563f * fVec40[((IOTA - 314) & 511)])) + (0.0155899562f * fVec40[((IOTA - 315) & 511)])) + (0.0139735304f * fVec40[((IOTA - 316) & 511)])) + (0.0111459792f * fVec40[((IOTA - 317) & 511)])) + (0.00764932157f * fVec40[((IOTA - 318) & 511)])) + (0.00418347027f * fVec40[((IOTA - 319) & 511)])) + (0.00115375873f * fVec40[((IOTA - 320) & 511)])) + (0.00028662011f * fVec40[((IOTA - 324) & 511)])) + (0.00231155753f * fVec40[((IOTA - 325) & 511)])) + (0.00394456089f * fVec40[((IOTA - 326) & 511)])) + (0.0048982976f * fVec40[((IOTA - 327) & 511)])) + (0.00430441042f * fVec40[((IOTA - 328) & 511)])) + (0.00204712898f * fVec40[((IOTA - 329) & 511)])) + (0.000840757973f * fVec40[((IOTA - 334) & 511)])) + (0.00413272949f * fVec40[((IOTA - 335) & 511)])) + (0.00660188682f * fVec40[((IOTA - 336) & 511)])) + (0.00695404178f * fVec40[((IOTA - 337) & 511)])) + (0.00654829387f * fVec40[((IOTA - 338) & 511)])) + (0.00661733467f * fVec40[((IOTA - 339) & 511)])) + (0.00723819621f * fVec40[((IOTA - 340) & 511)])) + (0.00855341647f * fVec40[((IOTA - 341) & 511)])) + (0.00944426097f * fVec40[((IOTA - 342) & 511)])) + (0.00890702754f * fVec40[((IOTA - 343) & 511)])) + (0.00684739137f * fVec40[((IOTA - 344) & 511)])) + (0.00346885156f * fVec40[((IOTA - 345) & 511)])) + (0.000483077019f * fVec40[((IOTA - 346) & 511)])) + (0.000266745687f * fVec40[((IOTA - 347) & 511)])) + (0.00353911007f * fVec40[((IOTA - 348) & 511)])) + (0.00907383673f * fVec40[((IOTA - 349) & 511)])) + (0.014156797f * fVec40[((IOTA - 350) & 511)])) + (0.0163127445f * fVec40[((IOTA - 351) & 511)])) + (0.0148955388f * fVec40[((IOTA - 352) & 511)])) + (0.00982856005f * fVec40[((IOTA - 353) & 511)])) + (0.00260492135f * fVec40[((IOTA - 354) & 511)])) + (0.00195239112f * fVec40[((IOTA - 359) & 511)])) + (0.00682044635f * fVec40[((IOTA - 360) & 511)])) + (0.00857857894f * fVec40[((IOTA - 361) & 511)])) + (0.00688375346f * fVec40[((IOTA - 362) & 511)])) + (0.00407970138f * fVec40[((IOTA - 363) & 511)])) + (0.00219771732f * fVec40[((IOTA - 364) & 511)])) + (0.000657699071f * fVec40[((IOTA - 365) & 511)])) + (0.00233648205f * fVec40[((IOTA - 392) & 511)])) + (0.00417146878f * fVec40[((IOTA - 393) & 511)])) + (0.00323014986f * fVec40[((IOTA - 394) & 511)])) + (0.000306940172f * fVec40[((IOTA - 395) & 511)])) + (0.00118156523f * fVec40[((IOTA - 420) & 511)])) + (0.00102453027f * fVec40[((IOTA - 421) & 511)])) + (0.00142273214f * fVec40[((IOTA - 428) & 511)])) + (0.00101710297f * fVec40[((IOTA - 429) & 511)])) + (0.000206944067f * fVec40[((IOTA - 471) & 511)])) + (0.00047472911f * fVec40[((IOTA - 472) & 511)])) + (0.000313535333f * fVec40[((IOTA - 476) & 511)])) + (0.000804633368f * fVec40[((IOTA - 477) & 511)])) - ((((((((((((((((((((((((((((0.0103304125f * fVec40[((IOTA - 484) & 511)]) + ((0.0123596881f * fVec40[((IOTA - 483) & 511)]) + ((0.0126089361f * fVec40[((IOTA - 482) & 511)]) + ((0.0112407468f * fVec40[((IOTA - 481) & 511)]) + ((0.00830357429f * fVec40[((IOTA - 480) & 511)]) + ((0.00454507302f * fVec40[((IOTA - 479) & 511)]) + ((0.00105192047f * fVec40[((IOTA - 478) & 511)]) + ((0.00080160331f * fVec40[((IOTA - 475) & 511)]) + ((0.000967847649f * fVec40[((IOTA - 474) & 511)]) + ((0.000304385088f * fVec40[((IOTA - 473) & 511)]) + ((0.00153232412f * fVec40[((IOTA - 470) & 511)]) + ((0.00377454376f * fVec40[((IOTA - 469) & 511)]) + ((0.00599971134f * fVec40[((IOTA - 468) & 511)]) + ((0.00757493312f * fVec40[((IOTA - 467) & 511)]) + ((0.00725117838f * fVec40[((IOTA - 466) & 511)]) + ((0.00523164775f * fVec40[((IOTA - 465) & 511)]) + ((0.00269166753f * fVec40[((IOTA - 464) & 511)]) + ((0.00124567421f * fVec40[((IOTA - 463) & 511)]) + ((0.00188441994f * fVec40[((IOTA - 462) & 511)]) + ((0.004072126f * fVec40[((IOTA - 461) & 511)]) + ((0.00682208035f * fVec40[((IOTA - 460) & 511)]) + ((0.0091256164f * fVec40[((IOTA - 459) & 511)]) + ((0.0101335403f * fVec40[((IOTA - 458) & 511)]) + ((0.00964948256f * fVec40[((IOTA - 457) & 511)]) + ((0.00825699233f * fVec40[((IOTA - 456) & 511)]) + ((0.00693458319f * fVec40[((IOTA - 455) & 511)]) + ((0.00624679029f * fVec40[((IOTA - 454) & 511)]) + ((0.00610297546f * fVec40[((IOTA - 453) & 511)]) + ((0.00654921494f * fVec40[((IOTA - 452) & 511)]) + ((0.00735405646f * fVec40[((IOTA - 451) & 511)]) + ((0.00781327859f * fVec40[((IOTA - 450) & 511)]) + ((0.00744326878f * fVec40[((IOTA - 449) & 511)]) + ((0.00630397769f * fVec40[((IOTA - 448) & 511)]) + ((0.00554524269f * fVec40[((IOTA - 447) & 511)]) + ((0.00664439844f * fVec40[((IOTA - 446) & 511)]) + ((0.00980375521f * fVec40[((IOTA - 445) & 511)]) + ((0.013734472f * fVec40[((IOTA - 444) & 511)]) + ((0.0166853704f * fVec40[((IOTA - 443) & 511)]) + ((0.0179280136f * fVec40[((IOTA - 442) & 511)]) + ((0.0174406283f * fVec40[((IOTA - 441) & 511)]) + (((0.0131544881f * fVec40[((IOTA - 439) & 511)]) + ((0.0101615246f * fVec40[((IOTA - 438) & 511)]) + ((0.00803650171f * fVec40[((IOTA - 437) & 511)]) + ((0.007798573f * fVec40[((IOTA - 436) & 511)]) + ((0.00910895132f * fVec40[((IOTA - 435) & 511)]) + ((0.0105516762f * fVec40[((IOTA - 434) & 511)]) + ((0.0105223544f * fVec40[((IOTA - 433) & 511)]) + ((0.00836545601f * fVec40[((IOTA - 432) & 511)]) + ((0.00489880284f * fVec40[((IOTA - 431) & 511)]) + ((0.00147525547f * fVec40[((IOTA - 430) & 511)]) + ((7.77747482e-05f * fVec40[((IOTA - 427) & 511)]) + ((0.00185278105f * fVec40[((IOTA - 426) & 511)]) + ((0.00311636925f * fVec40[((IOTA - 425) & 511)]) + ((0.00316217868f * fVec40[((IOTA - 424) & 511)]) + ((0.00195084652f * fVec40[((IOTA - 423) & 511)]) + ((0.000352838542f * fVec40[((IOTA - 422) & 511)]) + ((3.06582078e-05f * fVec40[((IOTA - 419) & 511)]) + ((0.00190851279f * fVec40[((IOTA - 418) & 511)]) + ((0.00429737009f * fVec40[((IOTA - 417) & 511)]) + ((0.00624248246f * fVec40[((IOTA - 416) & 511)]) + ((0.00725640729f * fVec40[((IOTA - 415) & 511)]) + ((0.00836946629f * fVec40[((IOTA - 414) & 511)]) + ((0.00894986559f * fVec40[((IOTA - 413) & 511)]) + ((0.00867854524f * fVec40[((IOTA - 412) & 511)]) + ((0.00818212889f * fVec40[((IOTA - 411) & 511)]) + ((0.00711348327f * fVec40[((IOTA - 410) & 511)]) + ((0.0058247922f * fVec40[((IOTA - 409) & 511)]) + ((0.00441605225f * fVec40[((IOTA - 408) & 511)]) + ((0.00247209799f * fVec40[((IOTA - 407) & 511)]) + ((0.00128821563f * fVec40[((IOTA - 406) & 511)]) + ((0.00180622935f * fVec40[((IOTA - 405) & 511)]) + ((0.0032369527f * fVec40[((IOTA - 404) & 511)]) + ((0.00514552509f * fVec40[((IOTA - 403) & 511)]) + ((0.0071538859f * fVec40[((IOTA - 402) & 511)]) + ((0.00936613046f * fVec40[((IOTA - 401) & 511)]) + ((0.0117676724f * fVec40[((IOTA - 400) & 511)]) + ((0.0128908921f * fVec40[((IOTA - 399) & 511)]) + ((0.0114177447f * fVec40[((IOTA - 398) & 511)]) + ((0.00774313835f * fVec40[((IOTA - 397) & 511)]) + ((0.00343433116f * fVec40[((IOTA - 396) & 511)]) + ((0.00124035683f * fVec40[((IOTA - 391) & 511)]) + ((0.00482512731f * fVec40[((IOTA - 390) & 511)]) + ((0.00721995579f * fVec40[((IOTA - 389) & 511)]) + ((0.00779049238f * fVec40[((IOTA - 388) & 511)]) + ((0.0062449188f * fVec40[((IOTA - 387) & 511)]) + ((0.0033944929f * fVec40[((IOTA - 386) & 511)]) + ((0.000925336033f * fVec40[((IOTA - 385) & 511)]) + ((0.000325715635f * fVec40[((IOTA - 384) & 511)]) + ((0.00207327167f * fVec40[((IOTA - 383) & 511)]) + ((0.00426846417f * fVec40[((IOTA - 382) & 511)]) + ((0.0052803685f * fVec40[((IOTA - 381) & 511)]) + ((0.00481184805f * fVec40[((IOTA - 380) & 511)]) + ((0.00268156733f * fVec40[((IOTA - 379) & 511)]) + ((0.000832796562f * fVec40[((IOTA - 378) & 511)]) + ((0.000712390989f * fVec40[((IOTA - 377) & 511)]) + ((0.00228972221f * fVec40[((IOTA - 376) & 511)]) + ((0.00525033381f * fVec40[((IOTA - 375) & 511)]) + ((0.00834338274f * fVec40[((IOTA - 374) & 511)]) + ((0.0110638076f * fVec40[((IOTA - 373) & 511)]) + ((0.0130433217f * fVec40[((IOTA - 372) & 511)]) + ((0.0131270681f * fVec40[((IOTA - 371) & 511)]) + ((0.0114180129f * fVec40[((IOTA - 370) & 511)]) + ((0.00877797697f * fVec40[((IOTA - 369) & 511)]) + ((0.00568736438f * fVec40[((IOTA - 368) & 511)]) + ((0.00272015762f * fVec40[((IOTA - 367) & 511)]) + ((0.000801930204f * fVec40[((IOTA - 366) & 511)]) + ((0.00393404439f * fVec40[((IOTA - 358) & 511)]) + ((0.00811647531f * fVec40[((IOTA - 357) & 511)]) + ((0.00840235315f * fVec40[((IOTA - 356) & 511)]) + ((0.00423884578f * fVec40[((IOTA - 355) & 511)]) + ((0.00211729854f * fVec40[((IOTA - 333) & 511)]) + ((0.0036864602f * fVec40[((IOTA - 332) & 511)]) + ((0.00294804526f * fVec40[((IOTA - 331) & 511)]) + ((0.000662541483f * fVec40[((IOTA - 330) & 511)]) + ((0.00152061926f * fVec40[((IOTA - 323) & 511)]) + ((0.00206293352f * fVec40[((IOTA - 322) & 511)]) + ((0.00106921047f * fVec40[((IOTA - 321) & 511)]) + ((0.000798603054f * fVec40[((IOTA - 309) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0564717278f * fVec40[((IOTA - 7) & 511)]) + (0.102280818f * fVec40[((IOTA - 8) & 511)])) + (0.0930648595f * fVec40[((IOTA - 9) & 511)])) + (0.0520133115f * fVec40[((IOTA - 10) & 511)])) + (0.0219030846f * fVec40[((IOTA - 11) & 511)])) + (0.00818245672f * fVec40[((IOTA - 19) & 511)])) + (0.0278859809f * fVec40[((IOTA - 20) & 511)])) + (0.0230086558f * fVec40[((IOTA - 21) & 511)])) + (0.00882634148f * fVec40[((IOTA - 22) & 511)])) + (0.0253021233f * fVec40[((IOTA - 29) & 511)])) + (0.0499668047f * fVec40[((IOTA - 30) & 511)])) + (0.0612414479f * fVec40[((IOTA - 31) & 511)])) + (0.0771341249f * fVec40[((IOTA - 32) & 511)])) + (0.0834551901f * fVec40[((IOTA - 33) & 511)])) + (0.0640944913f * fVec40[((IOTA - 34) & 511)])) + (0.0387813747f * fVec40[((IOTA - 35) & 511)])) + (0.0222978108f * fVec40[((IOTA - 36) & 511)])) + (0.00756156491f * fVec40[((IOTA - 37) & 511)])) + (0.0119795185f * fVec40[((IOTA - 44) & 511)])) + (0.0431698598f * fVec40[((IOTA - 45) & 511)])) + (0.0790434405f * fVec40[((IOTA - 46) & 511)])) + (0.101637349f * fVec40[((IOTA - 47) & 511)])) + (0.0987637788f * fVec40[((IOTA - 48) & 511)])) + (0.0764840916f * fVec40[((IOTA - 49) & 511)])) + (0.0392310023f * fVec40[((IOTA - 50) & 511)])) + (0.0010664775f * fVec40[((IOTA - 51) & 511)])) + (0.00331615377f * fVec40[((IOTA - 56) & 511)])) + (0.0209633987f * fVec40[((IOTA - 57) & 511)])) + (0.0404504426f * fVec40[((IOTA - 58) & 511)])) + (0.0587070547f * fVec40[((IOTA - 59) & 511)])) + (0.0648521557f * fVec40[((IOTA - 60) & 511)])) + (0.060147699f * fVec40[((IOTA - 61) & 511)])) + (0.041724164f * fVec40[((IOTA - 62) & 511)])) + (0.0175793637f * fVec40[((IOTA - 63) & 511)])) + (0.000816962216f * fVec40[((IOTA - 64) & 511)])) + (0.0110112838f * fVec40[((IOTA - 67) & 511)])) + (0.0360473432f * fVec40[((IOTA - 68) & 511)])) + (0.0501107089f * fVec40[((IOTA - 69) & 511)])) + (0.0548434779f * fVec40[((IOTA - 70) & 511)])) + (0.0476318374f * fVec40[((IOTA - 71) & 511)])) + (0.0329425596f * fVec40[((IOTA - 72) & 511)])) + (0.0186184794f * fVec40[((IOTA - 73) & 511)])) + (0.00640545925f * fVec40[((IOTA - 74) & 511)])) + (0.00924848765f * fVec40[((IOTA - 77) & 511)])) + (0.0127724465f * fVec40[((IOTA - 78) & 511)])) + (0.0109354705f * fVec40[((IOTA - 79) & 511)])) + (0.00970087759f * fVec40[((IOTA - 80) & 511)])) + (0.0117926858f * fVec40[((IOTA - 81) & 511)])) + (0.0156253986f * fVec40[((IOTA - 82) & 511)])) + (0.0161217544f * fVec40[((IOTA - 83) & 511)])) + (0.0145264501f * fVec40[((IOTA - 84) & 511)])) + (0.0108789662f * fVec40[((IOTA - 85) & 511)])) + (0.00899225846f * fVec40[((IOTA - 86) & 511)])) + (0.00894873682f * fVec40[((IOTA - 87) & 511)])) + (0.00860270113f * fVec40[((IOTA - 88) & 511)])) + (0.0136816222f * fVec40[((IOTA - 89) & 511)])) + (0.0206088983f * fVec40[((IOTA - 90) & 511)])) + (0.0229382198f * fVec40[((IOTA - 91) & 511)])) + (0.0256158952f * fVec40[((IOTA - 92) & 511)])) + (0.0311630089f * fVec40[((IOTA - 93) & 511)])) + (0.0331450477f * fVec40[((IOTA - 94) & 511)])) + (0.030874934f * fVec40[((IOTA - 95) & 511)])) + (0.0297639538f * fVec40[((IOTA - 96) & 511)])) + (0.0257264674f * fVec40[((IOTA - 97) & 511)])) + (0.0185516961f * fVec40[((IOTA - 98) & 511)])) + (0.00559541909f * fVec40[((IOTA - 99) & 511)])) + (0.00924450718f * fVec40[((IOTA - 104) & 511)])) + (0.0221530162f * fVec40[((IOTA - 105) & 511)])) + (0.0315326937f * fVec40[((IOTA - 106) & 511)])) + (0.0354474857f * fVec40[((IOTA - 107) & 511)])) + (0.0332207158f * fVec40[((IOTA - 108) & 511)])) + (0.0246557128f * fVec40[((IOTA - 109) & 511)])) + (0.0164088793f * fVec40[((IOTA - 110) & 511)])) + (0.00975479651f * fVec40[((IOTA - 111) & 511)])) + (0.00583715038f * fVec40[((IOTA - 112) & 511)])) + (0.00666156923f * fVec40[((IOTA - 113) & 511)])) + (0.0063483906f * fVec40[((IOTA - 114) & 511)])) + (0.00795180537f * fVec40[((IOTA - 115) & 511)])) + (0.0132438485f * fVec40[((IOTA - 116) & 511)])) + (0.0176849142f * fVec40[((IOTA - 117) & 511)])) + (0.0214989409f * fVec40[((IOTA - 118) & 511)])) + (0.0227644295f * fVec40[((IOTA - 119) & 511)])) + (0.0206853356f * fVec40[((IOTA - 120) & 511)])) + (0.0200213082f * fVec40[((IOTA - 121) & 511)])) + (0.0227972269f * fVec40[((IOTA - 122) & 511)])) + (0.0284598749f * fVec40[((IOTA - 123) & 511)])) + (0.0318485163f * fVec40[((IOTA - 124) & 511)])) + (0.02867065f * fVec40[((IOTA - 125) & 511)])) + (0.0213316865f * fVec40[((IOTA - 126) & 511)])) + (0.010234992f * fVec40[((IOTA - 127) & 511)])) + (0.0029194369f * fVec40[((IOTA - 133) & 511)])) + (0.00397875439f * fVec40[((IOTA - 134) & 511)])) + (0.00604249025f * fVec40[((IOTA - 140) & 511)])) + (0.0108675882f * fVec40[((IOTA - 141) & 511)])) + (0.0128048584f * fVec40[((IOTA - 142) & 511)])) + (0.0105642425f * fVec40[((IOTA - 143) & 511)])) + (0.00359751564f * fVec40[((IOTA - 144) & 511)])) + (0.000817645341f * fVec40[((IOTA - 147) & 511)])) + (0.00619376218f * fVec40[((IOTA - 148) & 511)])) + (0.00994400494f * fVec40[((IOTA - 149) & 511)])) + (0.0105716102f * fVec40[((IOTA - 150) & 511)])) + (0.00711725606f * fVec40[((IOTA - 151) & 511)])) + (0.00132811302f * fVec40[((IOTA - 152) & 511)])) + (0.00569796981f * fVec40[((IOTA - 157) & 511)])) + (0.0114217559f * fVec40[((IOTA - 158) & 511)])) + (0.0126339495f * fVec40[((IOTA - 159) & 511)])) + (0.00959523581f * fVec40[((IOTA - 160) & 511)])) + (0.00535303354f * fVec40[((IOTA - 161) & 511)])) + (0.00209385948f * fVec40[((IOTA - 162) & 511)])) + (0.00170436129f * fVec40[((IOTA - 163) & 511)])) + (0.00366946775f * fVec40[((IOTA - 164) & 511)])) + (0.00369308516f * fVec40[((IOTA - 165) & 511)])) + (0.00104476092f * fVec40[((IOTA - 166) & 511)])) + (0.00215550279f * fVec40[((IOTA - 175) & 511)])) + (0.00417066645f * fVec40[((IOTA - 176) & 511)])) + (0.00510800444f * fVec40[((IOTA - 177) & 511)])) + (0.00387347024f * fVec40[((IOTA - 178) & 511)])) + (0.000285431743f * fVec40[((IOTA - 200) & 511)])) + (0.00228238432f * fVec40[((IOTA - 201) & 511)])) + (8.46371986e-05f * fVec40[((IOTA - 202) & 511)])) + (0.00676611112f * fVec40[((IOTA - 219) & 511)])) + (0.00845024176f * fVec40[((IOTA - 220) & 511)])) + (0.00384655548f * fVec40[((IOTA - 221) & 511)])) + (0.0156967863f * fVec40[((IOTA - 440) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00690754922f * fVec40[((IOTA - 485) & 511)])))))))))))))))))))))))))))))))))))))))))) + (0.00359291071f * fVec40[((IOTA - 486) & 511)])) + (0.00158865005f * fVec40[((IOTA - 487) & 511)])) + (0.00112191215f * fVec40[((IOTA - 488) & 511)])) + (0.00182345975f * fVec40[((IOTA - 489) & 511)])) + (0.00230944809f * fVec40[((IOTA - 490) & 511)])) + (0.0022159284f * fVec40[((IOTA - 491) & 511)])) + (0.00190444291f * fVec40[((IOTA - 492) & 511)])) + (0.0010871538f * fVec40[((IOTA - 493) & 511)])) + (0.000492910389f * fVec40[((IOTA - 494) & 511)])) + (0.000771925319f * fVec40[((IOTA - 495) & 511)])) + (0.00124234706f * fVec40[((IOTA - 496) & 511)])) + (0.00194698432f * fVec40[((IOTA - 497) & 511)])) + (0.0027172165f * fVec40[((IOTA - 498) & 511)])) + (0.00239417469f * fVec40[((IOTA - 499) & 511)])) + (0.00143663539f * fVec40[((IOTA - 500) & 511)])) + (0.00125642866f * fVec40[((IOTA - 501) & 511)])) + (0.00215508696f * fVec40[((IOTA - 502) & 511)])) + (0.00458779233f * fVec40[((IOTA - 503) & 511)])) + (0.00847682916f * fVec40[((IOTA - 504) & 511)])) + (0.012284141f * fVec40[((IOTA - 505) & 511)])) + (0.0148018114f * fVec40[((IOTA - 506) & 511)])) + (0.0156810395f * fVec40[((IOTA - 507) & 511)])) + (0.0145289153f * fVec40[((IOTA - 508) & 511)])) + (0.0115849106f * fVec40[((IOTA - 509) & 511)])) + (0.00804853346f * fVec40[((IOTA - 510) & 511)])) + (0.00573941227f * fVec40[((IOTA - 511) & 511)]))) : ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.101427898f * fVec39[((IOTA - 4) & 511)]) + ((0.216104388f * fVec39[((IOTA - 3) & 511)]) + ((0.263774544f * fVec39[((IOTA - 2) & 511)]) + ((0.2275296f * fVec39[((IOTA - 1) & 511)]) + ((fSlow124 * fTemp0) + ((0.0535004884f * fVec39[((IOTA - 10) & 511)]) + (((0.0315723978f * fVec39[((IOTA - 13) & 511)]) + ((0.101404071f * fVec39[((IOTA - 11) & 511)]) + ((0.0809069574f * fVec39[((IOTA - 12) & 511)]) + (0.00737914164f * fVec39[((IOTA - 15) & 511)])))) + (0.0268315226f * fVec39[((IOTA - 16) & 511)])))))))) + (0.0277486183f * fVec39[((IOTA - 17) & 511)])) + (0.0140897818f * fVec39[((IOTA - 18) & 511)])) + (0.0156392474f * fVec39[((IOTA - 23) & 511)])) + (0.0345276147f * fVec39[((IOTA - 24) & 511)])) + (0.0384755135f * fVec39[((IOTA - 25) & 511)])) + (0.0263536088f * fVec39[((IOTA - 26) & 511)])) + (0.0123162009f * fVec39[((IOTA - 27) & 511)])) + (0.0174069032f * fVec39[((IOTA - 35) & 511)])) + (0.025054656f * fVec39[((IOTA - 36) & 511)])) + (0.0254948437f * fVec39[((IOTA - 37) & 511)])) + (0.0270134509f * fVec39[((IOTA - 38) & 511)])) + (0.0192961693f * fVec39[((IOTA - 39) & 511)])) + (0.0125633944f * fVec39[((IOTA - 40) & 511)])) + (0.00568947848f * fVec39[((IOTA - 41) & 511)])) + (0.0096931681f * fVec39[((IOTA - 48) & 511)])) + (0.0212991051f * fVec39[((IOTA - 49) & 511)])) + (0.0187704042f * fVec39[((IOTA - 50) & 511)])) + (0.00778479362f * fVec39[((IOTA - 51) & 511)])) + (0.0223701335f * fVec39[((IOTA - 59) & 511)])) + (0.0316648111f * fVec39[((IOTA - 60) & 511)])) + (0.0226220787f * fVec39[((IOTA - 61) & 511)])) + (0.00594415842f * fVec39[((IOTA - 62) & 511)])) + (0.015642209f * fVec39[((IOTA - 73) & 511)])) + (0.0202042479f * fVec39[((IOTA - 74) & 511)])) + (0.0179519393f * fVec39[((IOTA - 75) & 511)])) + (0.00539655099f * fVec39[((IOTA - 76) & 511)])) + (0.000110966619f * fVec39[((IOTA - 96) & 511)])) + (0.0108164418f * fVec39[((IOTA - 97) & 511)])) + (0.0161522515f * fVec39[((IOTA - 98) & 511)])) + (0.0124754421f * fVec39[((IOTA - 99) & 511)])) + (0.00263061794f * fVec39[((IOTA - 100) & 511)])) + (0.000480519608f * fVec39[((IOTA - 107) & 511)])) + (0.00149406353f * fVec39[((IOTA - 108) & 511)])) + (0.00197647093f * fVec39[((IOTA - 109) & 511)])) + (0.000698904973f * fVec39[((IOTA - 110) & 511)])) + (0.000630547758f * fVec39[((IOTA - 111) & 511)])) + (0.00101292552f * fVec39[((IOTA - 128) & 511)])) + (0.00363654504f * fVec39[((IOTA - 129) & 511)])) + (0.00498705823f * fVec39[((IOTA - 130) & 511)])) + (0.00645765243f * fVec39[((IOTA - 131) & 511)])) + (0.00599311525f * fVec39[((IOTA - 132) & 511)])) + (0.00356405368f * fVec39[((IOTA - 133) & 511)])) + (0.00184551766f * fVec39[((IOTA - 134) & 511)])) + (9.47238877e-05f * fVec39[((IOTA - 135) & 511)])) + (0.00259113358f * fVec39[((IOTA - 145) & 511)])) + (0.00402979506f * fVec39[((IOTA - 146) & 511)])) + (0.0036062724f * fVec39[((IOTA - 147) & 511)])) + (0.0022374657f * fVec39[((IOTA - 148) & 511)])) + (0.000123075675f * fVec39[((IOTA - 149) & 511)])) + (0.000452037435f * fVec39[((IOTA - 152) & 511)])) + (0.00280707749f * fVec39[((IOTA - 153) & 511)])) + (0.00515079033f * fVec39[((IOTA - 154) & 511)])) + (0.00502524059f * fVec39[((IOTA - 155) & 511)])) + (0.00261896476f * fVec39[((IOTA - 156) & 511)])) + (0.00197484344f * fVec39[((IOTA - 165) & 511)])) + (0.00344322389f * fVec39[((IOTA - 166) & 511)])) + (0.00340562733f * fVec39[((IOTA - 167) & 511)])) + (0.00254116766f * fVec39[((IOTA - 168) & 511)])) + (0.00086172577f * fVec39[((IOTA - 169) & 511)])) + (0.000839786138f * fVec39[((IOTA - 171) & 511)])) + (0.00158130052f * fVec39[((IOTA - 172) & 511)])) + (0.00203805789f * fVec39[((IOTA - 173) & 511)])) + (0.00219397759f * fVec39[((IOTA - 174) & 511)])) + (0.00163172232f * fVec39[((IOTA - 175) & 511)])) + (0.00105475355f * fVec39[((IOTA - 176) & 511)])) + (0.000250708777f * fVec39[((IOTA - 177) & 511)])) + (5.73224388e-05f * fVec39[((IOTA - 179) & 511)])) + (0.00113014225f * fVec39[((IOTA - 180) & 511)])) + (0.00358908577f * fVec39[((IOTA - 181) & 511)])) + (0.0066236956f * fVec39[((IOTA - 182) & 511)])) + (0.00814992003f * fVec39[((IOTA - 183) & 511)])) + (0.0076816068f * fVec39[((IOTA - 184) & 511)])) + (0.00584373856f * fVec39[((IOTA - 185) & 511)])) + (0.00383761339f * fVec39[((IOTA - 186) & 511)])) + (0.00196719402f * fVec39[((IOTA - 187) & 511)])) + (0.000327073503f * fVec39[((IOTA - 188) & 511)])) + (2.9718969e-05f * fVec39[((IOTA - 189) & 511)])) + (0.00154588465f * fVec39[((IOTA - 190) & 511)])) + (0.00423542038f * fVec39[((IOTA - 191) & 511)])) + (0.00707530975f * fVec39[((IOTA - 192) & 511)])) + (0.00889914855f * fVec39[((IOTA - 193) & 511)])) + (0.00850189477f * fVec39[((IOTA - 194) & 511)])) + (0.00660621561f * fVec39[((IOTA - 195) & 511)])) + (0.00444801198f * fVec39[((IOTA - 196) & 511)])) + (0.00222454313f * fVec39[((IOTA - 197) & 511)])) + (0.00111425715f * fVec39[((IOTA - 198) & 511)])) + (0.00133078732f * fVec39[((IOTA - 199) & 511)])) + (0.00181531021f * fVec39[((IOTA - 200) & 511)])) + (0.00212243013f * fVec39[((IOTA - 201) & 511)])) + (0.00237258524f * fVec39[((IOTA - 202) & 511)])) + (0.00241106097f * fVec39[((IOTA - 203) & 511)])) + (0.00230917567f * fVec39[((IOTA - 204) & 511)])) + (0.00226790085f * fVec39[((IOTA - 205) & 511)])) + (0.00233017141f * fVec39[((IOTA - 206) & 511)])) + (0.00324192783f * fVec39[((IOTA - 207) & 511)])) + (0.00479464838f * fVec39[((IOTA - 208) & 511)])) + (0.00563671347f * fVec39[((IOTA - 209) & 511)])) + (0.00544036506f * fVec39[((IOTA - 210) & 511)])) + (0.00461617066f * fVec39[((IOTA - 211) & 511)])) + (0.00352502521f * fVec39[((IOTA - 212) & 511)])) + (0.00222857948f * fVec39[((IOTA - 213) & 511)])) + (0.000739658717f * fVec39[((IOTA - 214) & 511)])) + (0.000611049589f * fVec39[((IOTA - 216) & 511)])) + (0.00331946462f * fVec39[((IOTA - 217) & 511)])) + (0.00661819428f * fVec39[((IOTA - 218) & 511)])) + (0.00937026087f * fVec39[((IOTA - 219) & 511)])) + (0.0104058422f * fVec39[((IOTA - 220) & 511)])) + (0.00944682118f * fVec39[((IOTA - 221) & 511)])) + (0.0073052831f * fVec39[((IOTA - 222) & 511)])) + (0.00515687745f * fVec39[((IOTA - 223) & 511)])) + (0.00369048212f * fVec39[((IOTA - 224) & 511)])) + (0.00331285689f * fVec39[((IOTA - 225) & 511)])) + (0.00393761043f * fVec39[((IOTA - 226) & 511)])) + (0.0045253532f * fVec39[((IOTA - 227) & 511)])) + (0.00466893613f * fVec39[((IOTA - 228) & 511)])) + (0.00464566192f * fVec39[((IOTA - 229) & 511)])) + (0.00479917321f * fVec39[((IOTA - 230) & 511)])) + (0.00577918952f * fVec39[((IOTA - 231) & 511)])) + (0.00686236052f * fVec39[((IOTA - 232) & 511)])) + (0.00684335036f * fVec39[((IOTA - 233) & 511)])) + (0.0056186798f * fVec39[((IOTA - 234) & 511)])) + (0.00401137117f * fVec39[((IOTA - 235) & 511)])) + (0.00284073548f * fVec39[((IOTA - 236) & 511)])) + (0.00255116075f * fVec39[((IOTA - 237) & 511)])) + (0.00309570832f * fVec39[((IOTA - 238) & 511)])) + (0.00423076563f * fVec39[((IOTA - 239) & 511)])) + (0.00547473878f * fVec39[((IOTA - 240) & 511)])) + (0.0060145664f * fVec39[((IOTA - 241) & 511)])) + (0.00572440587f * fVec39[((IOTA - 242) & 511)])) + (0.00492514577f * fVec39[((IOTA - 243) & 511)])) + (0.00414404972f * fVec39[((IOTA - 244) & 511)])) + (0.00366177224f * fVec39[((IOTA - 245) & 511)])) + (0.00282953773f * fVec39[((IOTA - 246) & 511)])) + (0.00189017784f * fVec39[((IOTA - 247) & 511)])) + (0.00154230418f * fVec39[((IOTA - 248) & 511)])) + (0.00155753829f * fVec39[((IOTA - 249) & 511)])) + (0.00208431296f * fVec39[((IOTA - 250) & 511)])) + (0.00335087674f * fVec39[((IOTA - 251) & 511)])) + (0.0049804179f * fVec39[((IOTA - 252) & 511)])) + (0.00649036607f * fVec39[((IOTA - 253) & 511)])) + (0.00730059575f * fVec39[((IOTA - 254) & 511)])) + (0.00746621611f * fVec39[((IOTA - 255) & 511)])) + (0.00777506083f * fVec39[((IOTA - 256) & 511)])) + (0.00863281544f * fVec39[((IOTA - 257) & 511)])) + (0.00960876234f * fVec39[((IOTA - 258) & 511)])) + (0.00983564369f * fVec39[((IOTA - 259) & 511)])) + (0.00903436542f * fVec39[((IOTA - 260) & 511)])) + (0.00748838345f * fVec39[((IOTA - 261) & 511)])) + (0.00575949624f * fVec39[((IOTA - 262) & 511)])) + (0.0045260042f * fVec39[((IOTA - 263) & 511)])) + (0.00418773293f * fVec39[((IOTA - 264) & 511)])) + (0.00449179299f * fVec39[((IOTA - 265) & 511)])) + (0.0046896385f * fVec39[((IOTA - 266) & 511)])) + (0.00469826488f * fVec39[((IOTA - 267) & 511)])) + (0.00465874746f * fVec39[((IOTA - 268) & 511)])) + (0.00469058286f * fVec39[((IOTA - 269) & 511)])) + (0.00512159197f * fVec39[((IOTA - 270) & 511)])) + (0.00570207601f * fVec39[((IOTA - 271) & 511)])) + (0.00598217826f * fVec39[((IOTA - 272) & 511)])) + (0.00542955799f * fVec39[((IOTA - 273) & 511)])) + (0.0038113445f * fVec39[((IOTA - 274) & 511)])) + (0.00192136178f * fVec39[((IOTA - 275) & 511)])) + (0.000978844706f * fVec39[((IOTA - 276) & 511)])) + (0.00158074731f * fVec39[((IOTA - 277) & 511)])) + (0.00321458513f * fVec39[((IOTA - 278) & 511)])) + (0.00509317499f * fVec39[((IOTA - 279) & 511)])) + (0.00614698464f * fVec39[((IOTA - 280) & 511)])) + (0.00545231113f * fVec39[((IOTA - 281) & 511)])) + (0.00354618346f * fVec39[((IOTA - 282) & 511)])) + (0.00152303418f * fVec39[((IOTA - 283) & 511)])) + (0.000114482362f * fVec39[((IOTA - 284) & 511)])) + (0.00087500643f * fVec39[((IOTA - 286) & 511)])) + (0.00267410651f * fVec39[((IOTA - 287) & 511)])) + (0.00459953723f * fVec39[((IOTA - 288) & 511)])) + (0.00585578242f * fVec39[((IOTA - 289) & 511)])) + (0.00622113608f * fVec39[((IOTA - 290) & 511)])) + (0.00582931843f * fVec39[((IOTA - 291) & 511)])) + (0.0051089297f * fVec39[((IOTA - 292) & 511)])) + (0.00425205426f * fVec39[((IOTA - 293) & 511)])) + (0.00333424285f * fVec39[((IOTA - 294) & 511)])) + (0.00274366792f * fVec39[((IOTA - 295) & 511)])) + (0.00289870892f * fVec39[((IOTA - 296) & 511)])) + (0.00380245829f * fVec39[((IOTA - 297) & 511)])) + (0.004886996f * fVec39[((IOTA - 298) & 511)])) + (0.00593094295f * fVec39[((IOTA - 299) & 511)])) + (0.00641260156f * fVec39[((IOTA - 300) & 511)])) + (0.00601088814f * fVec39[((IOTA - 301) & 511)])) + (0.00504552014f * fVec39[((IOTA - 302) & 511)])) + (0.00369894551f * fVec39[((IOTA - 303) & 511)])) + (0.00273448881f * fVec39[((IOTA - 304) & 511)])) + (0.00286049396f * fVec39[((IOTA - 305) & 511)])) + (0.00414785789f * fVec39[((IOTA - 306) & 511)])) + (0.00629704539f * fVec39[((IOTA - 307) & 511)])) + (0.00827735662f * fVec39[((IOTA - 308) & 511)])) + (0.00884950813f * fVec39[((IOTA - 309) & 511)])) + (0.00779781397f * fVec39[((IOTA - 310) & 511)])) + (0.00550156087f * fVec39[((IOTA - 311) & 511)])) + (0.00270330487f * fVec39[((IOTA - 312) & 511)])) + (0.000517172273f * fVec39[((IOTA - 313) & 511)])) + (0.000998896081f * fVec39[((IOTA - 320) & 511)])) + (0.00232652575f * fVec39[((IOTA - 321) & 511)])) + (0.00306843035f * fVec39[((IOTA - 322) & 511)])) + (0.00241903588f * fVec39[((IOTA - 323) & 511)])) + (0.000543863978f * fVec39[((IOTA - 324) & 511)])) + (0.000810425263f * fVec39[((IOTA - 329) & 511)])) + (0.00140161812f * fVec39[((IOTA - 330) & 511)])) + (0.00167670799f * fVec39[((IOTA - 331) & 511)])) + (0.00187914306f * fVec39[((IOTA - 332) & 511)])) + (0.00242557889f * fVec39[((IOTA - 333) & 511)])) + (0.00331428926f * fVec39[((IOTA - 334) & 511)])) + (0.0041282298f * fVec39[((IOTA - 335) & 511)])) + (0.00428620027f * fVec39[((IOTA - 336) & 511)])) + (0.0036729374f * fVec39[((IOTA - 337) & 511)])) + (0.00284483703f * fVec39[((IOTA - 338) & 511)])) + (0.00210374594f * fVec39[((IOTA - 339) & 511)])) + (0.00152062532f * fVec39[((IOTA - 340) & 511)])) + (0.00147381658f * fVec39[((IOTA - 341) & 511)])) + (0.00215862691f * fVec39[((IOTA - 342) & 511)])) + (0.00282146549f * fVec39[((IOTA - 343) & 511)])) + (0.00292973034f * fVec39[((IOTA - 344) & 511)])) + (0.00257837353f * fVec39[((IOTA - 345) & 511)])) + (0.00193929765f * fVec39[((IOTA - 346) & 511)])) + (0.00153826782f * fVec39[((IOTA - 347) & 511)])) + (0.00150998076f * fVec39[((IOTA - 348) & 511)])) + (0.00171420677f * fVec39[((IOTA - 349) & 511)])) + (0.00233381707f * fVec39[((IOTA - 350) & 511)])) + (0.00295749633f * fVec39[((IOTA - 351) & 511)])) + (0.00328622991f * fVec39[((IOTA - 352) & 511)])) + (0.00322949328f * fVec39[((IOTA - 353) & 511)])) + (0.00230924087f * fVec39[((IOTA - 354) & 511)])) + (0.000934802927f * fVec39[((IOTA - 355) & 511)])) + (9.57003795e-05f * fVec39[((IOTA - 367) & 511)])) + (0.00100400671f * fVec39[((IOTA - 368) & 511)])) + (0.000672310591f * fVec39[((IOTA - 369) & 511)])) + (0.000661633909f * fVec39[((IOTA - 376) & 511)])) + (0.00172263756f * fVec39[((IOTA - 377) & 511)])) + (0.00195586588f * fVec39[((IOTA - 378) & 511)])) + (0.00142193027f * fVec39[((IOTA - 379) & 511)])) + (0.000230396632f * fVec39[((IOTA - 380) & 511)])) + (0.000540055335f * fVec39[((IOTA - 385) & 511)])) + (0.0010236674f * fVec39[((IOTA - 386) & 511)])) + (0.000987079926f * fVec39[((IOTA - 387) & 511)])) + (0.000359071419f * fVec39[((IOTA - 388) & 511)])) + (2.1353364e-05f * fVec39[((IOTA - 401) & 511)])) + (0.000399630051f * fVec39[((IOTA - 424) & 511)])) + (0.00153872371f * fVec39[((IOTA - 425) & 511)])) + (0.0018493589f * fVec39[((IOTA - 426) & 511)])) + (0.00140220439f * fVec39[((IOTA - 427) & 511)])) + (0.0004646671f * fVec39[((IOTA - 428) & 511)])) + (0.000226555858f * fVec39[((IOTA - 492) & 511)])) + (0.000302204397f * fVec39[((IOTA - 493) & 511)])) + (0.000214609317f * fVec39[((IOTA - 494) & 511)])) + (6.94640912e-05f * fVec39[((IOTA - 495) & 511)])) + (0.00021666009f * fVec39[((IOTA - 496) & 511)])) + (7.78622925e-05f * fVec39[((IOTA - 497) & 511)])) - ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00534857064f * fVec39[((IOTA - 434) & 511)]) + ((0.00535345357f * fVec39[((IOTA - 433) & 511)]) + ((0.00482410751f * fVec39[((IOTA - 432) & 511)]) + ((0.00380011462f * fVec39[((IOTA - 431) & 511)]) + ((0.00211907737f * fVec39[((IOTA - 430) & 511)]) + ((0.000596954953f * fVec39[((IOTA - 429) & 511)]) + ((0.00143107725f * fVec39[((IOTA - 423) & 511)]) + ((0.00294782873f * fVec39[((IOTA - 422) & 511)]) + ((0.00351607334f * fVec39[((IOTA - 421) & 511)]) + ((0.00370942708f * fVec39[((IOTA - 420) & 511)]) + ((0.00376626151f * fVec39[((IOTA - 419) & 511)]) + ((0.00351887289f * (fVec39[((IOTA - 392) & 511)] + fVec39[((IOTA - 418) & 511)])) + ((0.0032263035f * fVec39[((IOTA - 417) & 511)]) + ((0.00275909714f * fVec39[((IOTA - 416) & 511)]) + ((0.00221682852f * fVec39[((IOTA - 415) & 511)]) + ((0.00220094342f * fVec39[((IOTA - 414) & 511)]) + ((0.00231630448f * fVec39[((IOTA - 413) & 511)]) + ((0.00218984345f * fVec39[((IOTA - 412) & 511)]) + ((0.00229433272f * fVec39[((IOTA - 411) & 511)]) + ((0.00272003608f * fVec39[((IOTA - 410) & 511)]) + ((0.00347798876f * fVec39[((IOTA - 409) & 511)]) + ((0.0040522553f * fVec39[((IOTA - 408) & 511)]) + ((0.00405873312f * fVec39[((IOTA - 407) & 511)]) + ((0.00373019464f * fVec39[((IOTA - 406) & 511)]) + ((0.00304466812f * fVec39[((IOTA - 405) & 511)]) + ((0.00209778873f * fVec39[((IOTA - 404) & 511)]) + ((0.00118173566f * fVec39[((IOTA - 403) & 511)]) + ((0.000393282622f * fVec39[((IOTA - 402) & 511)]) + ((3.22237611e-06f * fVec39[((IOTA - 400) & 511)]) + ((0.000275317114f * fVec39[((IOTA - 399) & 511)]) + ((0.00125103677f * fVec39[((IOTA - 398) & 511)]) + ((0.00266766129f * fVec39[((IOTA - 397) & 511)]) + ((0.00351148378f * fVec39[((IOTA - 396) & 511)]) + ((0.00409561349f * fVec39[((IOTA - 395) & 511)]) + ((0.00437262328f * fVec39[((IOTA - 394) & 511)]) + ((0.00400137808f * fVec39[((IOTA - 393) & 511)]) + ((0.00273087574f * fVec39[((IOTA - 391) & 511)]) + ((0.00154100219f * fVec39[((IOTA - 390) & 511)]) + ((0.000485694967f * fVec39[((IOTA - 389) & 511)]) + ((0.000243612565f * fVec39[((IOTA - 384) & 511)]) + ((0.00110511016f * fVec39[((IOTA - 383) & 511)]) + ((0.00130487652f * fVec39[((IOTA - 382) & 511)]) + ((0.000785360578f * fVec39[((IOTA - 381) & 511)]) + ((0.00130995456f * fVec39[((IOTA - 375) & 511)]) + ((0.00301267067f * fVec39[((IOTA - 374) & 511)]) + ((0.00371863926f * fVec39[((IOTA - 373) & 511)]) + ((0.00337385759f * fVec39[((IOTA - 372) & 511)]) + ((0.00190394698f * fVec39[((IOTA - 371) & 511)]) + ((0.00034611579f * fVec39[((IOTA - 370) & 511)]) + ((0.00120302383f * fVec39[((IOTA - 366) & 511)]) + ((0.00182003016f * fVec39[((IOTA - 365) & 511)]) + ((0.00195970712f * fVec39[((IOTA - 364) & 511)]) + ((0.00158188632f * fVec39[((IOTA - 363) & 511)]) + ((0.000996519811f * fVec39[((IOTA - 362) & 511)]) + ((0.00101819867f * fVec39[((IOTA - 361) & 511)]) + ((0.0014553275f * fVec39[((IOTA - 360) & 511)]) + ((0.00208597304f * fVec39[((IOTA - 359) & 511)]) + ((0.00255317893f * fVec39[((IOTA - 358) & 511)]) + ((0.00187071227f * fVec39[((IOTA - 357) & 511)]) + ((0.000420657918f * fVec39[((IOTA - 356) & 511)]) + ((0.000263305847f * fVec39[((IOTA - 328) & 511)]) + ((0.00180775858f * fVec39[((IOTA - 327) & 511)]) + ((0.00253576413f * fVec39[((IOTA - 326) & 511)]) + ((0.00150041096f * fVec39[((IOTA - 325) & 511)]) + ((0.00078939693f * fVec39[((IOTA - 319) & 511)]) + ((0.00232551666f * fVec39[((IOTA - 318) & 511)]) + ((0.00272742519f * fVec39[((IOTA - 317) & 511)]) + ((0.00239166059f * fVec39[((IOTA - 316) & 511)]) + ((0.00171397859f * fVec39[((IOTA - 315) & 511)]) + ((0.000781194307f * fVec39[((IOTA - 314) & 511)]) + ((0.000103089493f * fVec39[((IOTA - 285) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.204976827f * fVec39[((IOTA - 6) & 511)]) + ((0.0772382244f * fVec39[((IOTA - 5) & 511)]) + ((0.195021555f * fVec39[((IOTA - 8) & 511)]) + (((0.243500963f * fVec39[((IOTA - 7) & 511)]) + (0.068247281f * fVec39[((IOTA - 9) & 511)])) + (0.00120806927f * fVec39[((IOTA - 14) & 511)]))))) + (0.00693794386f * fVec39[((IOTA - 19) & 511)])) + (0.0282775424f * fVec39[((IOTA - 20) & 511)])) + (0.0263788998f * fVec39[((IOTA - 21) & 511)])) + (0.0053601265f * fVec39[((IOTA - 22) & 511)])) + (0.00820707902f * fVec39[((IOTA - 28) & 511)])) + (0.0306973588f * fVec39[((IOTA - 29) & 511)])) + (0.0540279448f * fVec39[((IOTA - 30) & 511)])) + (0.0717208087f * fVec39[((IOTA - 31) & 511)])) + (0.0601540953f * fVec39[((IOTA - 32) & 511)])) + (0.0317720324f * fVec39[((IOTA - 33) & 511)])) + (0.00526777888f * fVec39[((IOTA - 34) & 511)])) + (0.00845423993f * fVec39[((IOTA - 42) & 511)])) + (0.0281407945f * fVec39[((IOTA - 43) & 511)])) + (0.0555849634f * fVec39[((IOTA - 44) & 511)])) + (0.0619261488f * fVec39[((IOTA - 45) & 511)])) + (0.0371840782f * fVec39[((IOTA - 46) & 511)])) + (0.0104102362f * fVec39[((IOTA - 47) & 511)])) + (0.00325667346f * fVec39[((IOTA - 52) & 511)])) + (0.0151642617f * fVec39[((IOTA - 53) & 511)])) + (0.0296936128f * fVec39[((IOTA - 54) & 511)])) + (0.0401199944f * fVec39[((IOTA - 55) & 511)])) + (0.0435741246f * fVec39[((IOTA - 56) & 511)])) + (0.0294582024f * fVec39[((IOTA - 57) & 511)])) + (0.00125588709f * fVec39[((IOTA - 58) & 511)])) + (0.0076065762f * fVec39[((IOTA - 63) & 511)])) + (0.0167773645f * fVec39[((IOTA - 64) & 511)])) + (0.0199197829f * fVec39[((IOTA - 65) & 511)])) + (0.0218567364f * fVec39[((IOTA - 66) & 511)])) + (0.0242887605f * fVec39[((IOTA - 67) & 511)])) + (0.0274406523f * fVec39[((IOTA - 68) & 511)])) + (0.0318577737f * fVec39[((IOTA - 69) & 511)])) + (0.031976942f * fVec39[((IOTA - 70) & 511)])) + (0.0221328996f * fVec39[((IOTA - 71) & 511)])) + (0.000973310787f * fVec39[((IOTA - 72) & 511)])) + (0.00685389712f * fVec39[((IOTA - 77) & 511)])) + (0.0120840799f * fVec39[((IOTA - 78) & 511)])) + (0.0109706363f * fVec39[((IOTA - 79) & 511)])) + (0.00388816511f * fVec39[((IOTA - 80) & 511)])) + (0.00201416528f * fVec39[((IOTA - 81) & 511)])) + (0.00445849309f * fVec39[((IOTA - 82) & 511)])) + (0.009033259f * fVec39[((IOTA - 83) & 511)])) + (0.016623266f * fVec39[((IOTA - 84) & 511)])) + (0.021739684f * fVec39[((IOTA - 85) & 511)])) + (0.0237142984f * fVec39[((IOTA - 86) & 511)])) + (0.0232877173f * fVec39[((IOTA - 87) & 511)])) + (0.0188799053f * fVec39[((IOTA - 88) & 511)])) + (0.0102135297f * fVec39[((IOTA - 89) & 511)])) + (0.00449042581f * fVec39[((IOTA - 90) & 511)])) + (0.00298936386f * fVec39[((IOTA - 91) & 511)])) + (0.00376639143f * fVec39[((IOTA - 92) & 511)])) + (0.00769885862f * fVec39[((IOTA - 93) & 511)])) + (0.0086878268f * fVec39[((IOTA - 94) & 511)])) + (0.00641807029f * fVec39[((IOTA - 95) & 511)])) + (0.012199603f * fVec39[((IOTA - 101) & 511)])) + (0.0250618178f * fVec39[((IOTA - 102) & 511)])) + (0.0279662553f * fVec39[((IOTA - 103) & 511)])) + (0.0232417863f * fVec39[((IOTA - 104) & 511)])) + (0.0133088157f * fVec39[((IOTA - 105) & 511)])) + (0.00319118099f * fVec39[((IOTA - 106) & 511)])) + (0.000878977589f * fVec39[((IOTA - 112) & 511)])) + (0.00519001437f * fVec39[((IOTA - 113) & 511)])) + (0.00854603387f * fVec39[((IOTA - 114) & 511)])) + (0.0111691654f * fVec39[((IOTA - 115) & 511)])) + (0.0123836799f * fVec39[((IOTA - 116) & 511)])) + (0.0107176164f * fVec39[((IOTA - 117) & 511)])) + (0.00790858548f * fVec39[((IOTA - 118) & 511)])) + (0.00621403987f * fVec39[((IOTA - 119) & 511)])) + (0.00663004303f * fVec39[((IOTA - 120) & 511)])) + (0.00856644381f * fVec39[((IOTA - 121) & 511)])) + (0.0108356792f * fVec39[((IOTA - 122) & 511)])) + (0.0109102866f * fVec39[((IOTA - 123) & 511)])) + (0.00928933918f * fVec39[((IOTA - 124) & 511)])) + (0.00750303129f * fVec39[((IOTA - 125) & 511)])) + (0.00439798087f * fVec39[((IOTA - 126) & 511)])) + (0.00161433965f * fVec39[((IOTA - 127) & 511)])) + (0.00104576955f * fVec39[((IOTA - 136) & 511)])) + (0.00215433026f * fVec39[((IOTA - 137) & 511)])) + (0.00472150603f * fVec39[((IOTA - 138) & 511)])) + (0.00692853658f * fVec39[((IOTA - 139) & 511)])) + (0.00788475759f * fVec39[((IOTA - 140) & 511)])) + (0.00774713187f * fVec39[((IOTA - 141) & 511)])) + (0.0057034106f * fVec39[((IOTA - 142) & 511)])) + (0.00266124867f * fVec39[((IOTA - 143) & 511)])) + (6.5818429e-05f * fVec39[((IOTA - 144) & 511)])) + (0.00115048653f * fVec39[((IOTA - 150) & 511)])) + (0.000843269285f * fVec39[((IOTA - 151) & 511)])) + (0.00128300209f * fVec39[((IOTA - 157) & 511)])) + (0.00602612225f * fVec39[((IOTA - 158) & 511)])) + (0.00896900333f * fVec39[((IOTA - 159) & 511)])) + (0.00914035179f * fVec39[((IOTA - 160) & 511)])) + (0.00808094442f * fVec39[((IOTA - 161) & 511)])) + (0.00546487607f * fVec39[((IOTA - 162) & 511)])) + (0.00216884818f * fVec39[((IOTA - 163) & 511)])) + (1.82306394e-06f * fVec39[((IOTA - 164) & 511)])) + (3.52202915e-05f * fVec39[((IOTA - 170) & 511)])) + (0.00034224242f * fVec39[((IOTA - 178) & 511)])) + (0.00027534971f * fVec39[((IOTA - 215) & 511)])) + (0.00481860619f * fVec39[((IOTA - 435) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00451028207f * fVec39[((IOTA - 436) & 511)])) + (0.00431604963f * fVec39[((IOTA - 437) & 511)])) + (0.00396283763f * fVec39[((IOTA - 438) & 511)])) + (0.00385825057f * fVec39[((IOTA - 439) & 511)])) + (0.00382648082f * fVec39[((IOTA - 440) & 511)])) + (0.00375678902f * fVec39[((IOTA - 441) & 511)])) + (0.00377413863f * fVec39[((IOTA - 442) & 511)])) + (0.00376557792f * fVec39[((IOTA - 443) & 511)])) + (0.00407823129f * fVec39[((IOTA - 444) & 511)])) + (0.00437083328f * fVec39[((IOTA - 445) & 511)])) + (0.00405902602f * fVec39[((IOTA - 446) & 511)])) + (0.00371789047f * fVec39[((IOTA - 447) & 511)])) + (0.00345429126f * fVec39[((IOTA - 448) & 511)])) + (0.00310420431f * fVec39[((IOTA - 449) & 511)])) + (0.00300817844f * fVec39[((IOTA - 450) & 511)])) + (0.00273500942f * fVec39[((IOTA - 451) & 511)])) + (0.00242261635f * fVec39[((IOTA - 452) & 511)])) + (0.00253267167f * fVec39[((IOTA - 453) & 511)])) + (0.00273400033f * fVec39[((IOTA - 454) & 511)])) + (0.00323541788f * fVec39[((IOTA - 455) & 511)])) + (0.00396778528f * fVec39[((IOTA - 456) & 511)])) + (0.00418682164f * fVec39[((IOTA - 457) & 511)])) + (0.00392367831f * fVec39[((IOTA - 458) & 511)])) + (0.00348658208f * fVec39[((IOTA - 459) & 511)])) + (0.00314951548f * fVec39[((IOTA - 460) & 511)])) + (0.00311764795f * fVec39[((IOTA - 461) & 511)])) + (0.00313649513f * fVec39[((IOTA - 462) & 511)])) + (0.00295619434f * fVec39[((IOTA - 463) & 511)])) + (0.0028477665f * fVec39[((IOTA - 464) & 511)])) + (0.00246376125f * fVec39[((IOTA - 465) & 511)])) + (0.00158364419f * fVec39[((IOTA - 466) & 511)])) + (0.000918722712f * fVec39[((IOTA - 467) & 511)])) + (0.0007139761f * fVec39[((IOTA - 468) & 511)])) + (0.00100140227f * fVec39[((IOTA - 469) & 511)])) + (0.0016685701f * fVec39[((IOTA - 470) & 511)])) + (0.00221106689f * fVec39[((IOTA - 471) & 511)])) + (0.00251424778f * fVec39[((IOTA - 472) & 511)])) + (0.00291911839f * fVec39[((IOTA - 473) & 511)])) + (0.00330911344f * fVec39[((IOTA - 474) & 511)])) + (0.0034413035f * fVec39[((IOTA - 475) & 511)])) + (0.00323645957f * fVec39[((IOTA - 476) & 511)])) + (0.00269461377f * fVec39[((IOTA - 477) & 511)])) + (0.00233192928f * fVec39[((IOTA - 478) & 511)])) + (0.00201540207f * fVec39[((IOTA - 479) & 511)])) + (0.00151138054f * fVec39[((IOTA - 480) & 511)])) + (0.00123137608f * fVec39[((IOTA - 481) & 511)])) + (0.00104993628f * fVec39[((IOTA - 482) & 511)])) + (0.00114325993f * fVec39[((IOTA - 483) & 511)])) + (0.00150890695f * fVec39[((IOTA - 484) & 511)])) + (0.00176583277f * fVec39[((IOTA - 485) & 511)])) + (0.00234120619f * fVec39[((IOTA - 486) & 511)])) + (0.00291312905f * fVec39[((IOTA - 487) & 511)])) + (0.00278533343f * fVec39[((IOTA - 488) & 511)])) + (0.00217955746f * fVec39[((IOTA - 489) & 511)])) + (0.00117545342f * fVec39[((IOTA - 490) & 511)])) + (0.000174473971f * fVec39[((IOTA - 491) & 511)])) + (0.000755576417f * fVec39[((IOTA - 498) & 511)])) + (0.00181980245f * fVec39[((IOTA - 499) & 511)])) + (0.00291075278f * fVec39[((IOTA - 500) & 511)])) + (0.00361545198f * fVec39[((IOTA - 501) & 511)])) + (0.00350494077f * fVec39[((IOTA - 502) & 511)])) + (0.00321670109f * fVec39[((IOTA - 503) & 511)])) + (0.00307721924f * fVec39[((IOTA - 504) & 511)])) + (0.0030289134f * fVec39[((IOTA - 505) & 511)])) + (0.00348996744f * fVec39[((IOTA - 506) & 511)])) + (0.00410713675f * fVec39[((IOTA - 507) & 511)])) + (0.0042919945f * fVec39[((IOTA - 508) & 511)])) + (0.00401371485f * fVec39[((IOTA - 509) & 511)])) + (0.00329208933f * fVec39[((IOTA - 510) & 511)])) + (0.0028045713f * fVec39[((IOTA - 511) & 511)])))) : (iSlow117 ? (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00482667936f * fVec38[((IOTA - 241) & 511)]) + ((0.0047503598f * fVec38[((IOTA - 240) & 511)]) + ((0.00380432699f * fVec38[((IOTA - 239) & 511)]) + ((0.00322403526f * fVec38[((IOTA - 238) & 511)]) + ((0.00279071368f * fVec38[((IOTA - 237) & 511)]) + ((0.00344271865f * fVec38[((IOTA - 236) & 511)]) + ((0.00515321316f * fVec38[((IOTA - 235) & 511)]) + ((0.00654101186f * fVec38[((IOTA - 234) & 511)]) + ((0.00795845222f * fVec38[((IOTA - 233) & 511)]) + ((0.00906125735f * fVec38[((IOTA - 232) & 511)]) + ((0.00836957246f * fVec38[((IOTA - 231) & 511)]) + ((0.00615962269f * fVec38[((IOTA - 230) & 511)]) + ((0.0032718638f * fVec38[((IOTA - 229) & 511)]) + ((0.000538839959f * fVec38[((IOTA - 228) & 511)]) + ((0.00303824153f * fVec38[((IOTA - 225) & 511)]) + ((0.00679290947f * fVec38[((IOTA - 224) & 511)]) + ((0.00950302277f * fVec38[((IOTA - 223) & 511)]) + ((0.00981004164f * fVec38[((IOTA - 222) & 511)]) + ((0.00830216892f * fVec38[((IOTA - 221) & 511)]) + ((0.00599470222f * fVec38[((IOTA - 220) & 511)]) + ((0.0035607256f * fVec38[((IOTA - 219) & 511)]) + ((0.00175773259f * fVec38[((IOTA - 218) & 511)]) + ((0.00118848309f * fVec38[((IOTA - 217) & 511)]) + ((0.001042163f * fVec38[((IOTA - 216) & 511)]) + ((0.00102530466f * fVec38[((IOTA - 215) & 511)]) + ((0.00207452383f * fVec38[((IOTA - 214) & 511)]) + ((0.00324115902f * fVec38[((IOTA - 213) & 511)]) + ((0.00395841198f * fVec38[((IOTA - 212) & 511)]) + ((0.00505646318f * fVec38[((IOTA - 211) & 511)]) + ((0.00616827281f * fVec38[((IOTA - 210) & 511)]) + ((0.00618510135f * fVec38[((IOTA - 209) & 511)]) + ((0.00524913613f * fVec38[((IOTA - 208) & 511)]) + ((0.00427248655f * fVec38[((IOTA - 207) & 511)]) + ((0.00348614808f * fVec38[((IOTA - 206) & 511)]) + ((0.00325689558f * fVec38[((IOTA - 205) & 511)]) + ((0.00349659938f * fVec38[((IOTA - 204) & 511)]) + ((0.00304901786f * fVec38[((IOTA - 203) & 511)]) + ((0.00225984491f * fVec38[((IOTA - 202) & 511)]) + ((0.00204195874f * fVec38[((IOTA - 201) & 511)]) + ((0.00223091152f * fVec38[((IOTA - 200) & 511)]) + ((0.00304249302f * fVec38[((IOTA - 199) & 511)]) + ((0.00401899498f * fVec38[((IOTA - 198) & 511)]) + ((0.00395265454f * fVec38[((IOTA - 197) & 511)]) + ((0.00362367043f * fVec38[((IOTA - 196) & 511)]) + ((0.00389874401f * fVec38[((IOTA - 195) & 511)]) + ((0.00504052034f * fVec38[((IOTA - 194) & 511)]) + ((0.00711085182f * fVec38[((IOTA - 193) & 511)]) + ((0.00842265598f * fVec38[((IOTA - 192) & 511)]) + ((0.00779341394f * fVec38[((IOTA - 191) & 511)]) + ((0.00582293235f * fVec38[((IOTA - 190) & 511)]) + ((0.00192761282f * fVec38[((IOTA - 189) & 511)]) + ((0.00246128626f * fVec38[((IOTA - 185) & 511)]) + ((0.00768644921f * fVec38[((IOTA - 184) & 511)]) + ((0.00982031599f * fVec38[((IOTA - 183) & 511)]) + ((0.00832378119f * fVec38[((IOTA - 182) & 511)]) + ((0.00435707252f * fVec38[((IOTA - 181) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((fSlow121 * fTemp0) + (0.230884403f * fVec38[((IOTA - 1) & 511)])) + (0.207404837f * fVec38[((IOTA - 2) & 511)])) + (0.178782552f * fVec38[((IOTA - 3) & 511)])) + (0.0701977685f * fVec38[((IOTA - 4) & 511)])) + (0.101718388f * fVec38[((IOTA - 10) & 511)])) + (0.14352335f * fVec38[((IOTA - 11) & 511)])) + (0.128290102f * fVec38[((IOTA - 12) & 511)])) + (0.0461520851f * fVec38[((IOTA - 13) & 511)])) + (0.013605807f * fVec38[((IOTA - 21) & 511)])) + (0.0575259179f * fVec38[((IOTA - 22) & 511)])) + (0.0811626315f * fVec38[((IOTA - 23) & 511)])) + (0.0619351864f * fVec38[((IOTA - 24) & 511)])) + (0.00960210524f * fVec38[((IOTA - 25) & 511)])) + (0.00254643336f * fVec38[((IOTA - 30) & 511)])) + (0.0197741389f * fVec38[((IOTA - 31) & 511)])) + (0.00761984335f * fVec38[((IOTA - 32) & 511)])) + (0.000722212717f * fVec38[((IOTA - 33) & 511)])) + (0.00282708695f * fVec38[((IOTA - 34) & 511)])) + (0.00298595475f * fVec38[((IOTA - 35) & 511)])) + (0.0089398548f * fVec38[((IOTA - 36) & 511)])) + (0.0122318547f * fVec38[((IOTA - 37) & 511)])) + (0.00601253472f * fVec38[((IOTA - 38) & 511)])) + (0.00139751192f * fVec38[((IOTA - 53) & 511)])) + (0.00059348857f * fVec38[((IOTA - 55) & 511)])) + (0.00448340503f * fVec38[((IOTA - 61) & 511)])) + (0.0204925723f * fVec38[((IOTA - 62) & 511)])) + (0.0325685404f * fVec38[((IOTA - 63) & 511)])) + (0.0258381926f * fVec38[((IOTA - 64) & 511)])) + (0.00911876932f * fVec38[((IOTA - 71) & 511)])) + (0.0147657394f * fVec38[((IOTA - 72) & 511)])) + (0.00882500783f * fVec38[((IOTA - 73) & 511)])) + (0.0040023434f * fVec38[((IOTA - 74) & 511)])) + (0.00126955565f * fVec38[((IOTA - 83) & 511)])) + (0.00321694976f * fVec38[((IOTA - 84) & 511)])) + (0.00470704865f * fVec38[((IOTA - 94) & 511)])) + (0.0114268269f * fVec38[((IOTA - 95) & 511)])) + (0.0137068368f * fVec38[((IOTA - 96) & 511)])) + (0.0134675754f * fVec38[((IOTA - 97) & 511)])) + (0.00802892633f * fVec38[((IOTA - 98) & 511)])) + (0.00459290901f * fVec38[((IOTA - 107) & 511)])) + (0.00924096908f * fVec38[((IOTA - 108) & 511)])) + (0.0111202514f * fVec38[((IOTA - 109) & 511)])) + (0.00756557845f * fVec38[((IOTA - 110) & 511)])) + (0.000667357352f * fVec38[((IOTA - 129) & 511)])) + (0.00379635533f * fVec38[((IOTA - 130) & 511)])) + (0.00407514907f * fVec38[((IOTA - 131) & 511)])) + (0.00157991052f * fVec38[((IOTA - 132) & 511)])) + (0.00214812672f * fVec38[((IOTA - 148) & 511)])) + (0.00383922411f * fVec38[((IOTA - 149) & 511)])) + (0.00481720176f * fVec38[((IOTA - 150) & 511)])) + (0.00438579917f * fVec38[((IOTA - 151) & 511)])) + (0.00137365656f * fVec38[((IOTA - 152) & 511)])) + (3.22991982e-05f * fVec38[((IOTA - 157) & 511)])) + (0.00091606658f * fVec38[((IOTA - 162) & 511)])) + (0.00198589312f * fVec38[((IOTA - 163) & 511)])) + (0.00170839811f * fVec38[((IOTA - 164) & 511)])) + (0.000645244028f * fVec38[((IOTA - 165) & 511)])) + (0.000138968695f * fVec38[((IOTA - 169) & 511)])) + (0.00110014761f * fVec38[((IOTA - 170) & 511)])) + (0.00138531858f * fVec38[((IOTA - 171) & 511)])) + (0.0022274279f * fVec38[((IOTA - 172) & 511)])) + (0.00291621964f * fVec38[((IOTA - 173) & 511)])) + (0.00291958544f * fVec38[((IOTA - 174) & 511)])) + (0.00305731408f * fVec38[((IOTA - 175) & 511)])) + (0.002300411f * fVec38[((IOTA - 176) & 511)])) + (9.66610387e-05f * fVec38[((IOTA - 177) & 511)])) + (0.00414836826f * fVec38[((IOTA - 242) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00365738664f * fVec38[((IOTA - 243) & 511)])) + (0.00244661281f * fVec38[((IOTA - 244) & 511)])) + (0.000946771353f * fVec38[((IOTA - 245) & 511)])) + (0.00050913915f * fVec38[((IOTA - 246) & 511)])) + (0.000887871254f * fVec38[((IOTA - 247) & 511)])) + (0.00198751688f * fVec38[((IOTA - 248) & 511)])) + (0.00386346318f * fVec38[((IOTA - 249) & 511)])) + (0.00589562021f * fVec38[((IOTA - 250) & 511)])) + (0.00760109536f * fVec38[((IOTA - 251) & 511)])) + (0.0082427077f * fVec38[((IOTA - 252) & 511)])) + (0.0078939721f * fVec38[((IOTA - 253) & 511)])) + (0.00707182102f * fVec38[((IOTA - 254) & 511)])) + (0.00565759884f * fVec38[((IOTA - 255) & 511)])) + (0.00439258991f * fVec38[((IOTA - 256) & 511)])) + (0.00462074997f * fVec38[((IOTA - 257) & 511)])) + (0.00572349597f * fVec38[((IOTA - 258) & 511)])) + (0.00667986227f * fVec38[((IOTA - 259) & 511)])) + (0.00766191492f * fVec38[((IOTA - 260) & 511)])) + (0.00810657348f * fVec38[((IOTA - 261) & 511)])) + (0.00751656853f * fVec38[((IOTA - 262) & 511)])) + (0.00635140948f * fVec38[((IOTA - 263) & 511)])) + (0.00495070871f * fVec38[((IOTA - 264) & 511)])) + (0.00427966099f * fVec38[((IOTA - 265) & 511)])) + (0.00450852979f * fVec38[((IOTA - 266) & 511)])) + (0.00515846815f * fVec38[((IOTA - 267) & 511)])) + (0.00648893183f * fVec38[((IOTA - 268) & 511)])) + (0.00785567984f * fVec38[((IOTA - 269) & 511)])) + (0.00855329912f * fVec38[((IOTA - 270) & 511)])) + (0.00863360427f * fVec38[((IOTA - 271) & 511)])) + (0.00774632348f * fVec38[((IOTA - 272) & 511)])) + (0.00556326983f * fVec38[((IOTA - 273) & 511)])) + (0.00298388815f * fVec38[((IOTA - 274) & 511)])) + (0.00103681907f * fVec38[((IOTA - 275) & 511)])) + (2.12569721e-05f * fVec38[((IOTA - 276) & 511)])) + (0.000205988064f * fVec38[((IOTA - 277) & 511)])) + (0.00124200992f * fVec38[((IOTA - 278) & 511)])) + (0.00245018536f * fVec38[((IOTA - 279) & 511)])) + (0.00333740702f * fVec38[((IOTA - 280) & 511)])) + (0.0034116297f * fVec38[((IOTA - 281) & 511)])) + (0.0030985591f * fVec38[((IOTA - 282) & 511)])) + (0.00278067542f * fVec38[((IOTA - 283) & 511)])) + (0.00278333249f * fVec38[((IOTA - 284) & 511)])) + (0.00338842394f * fVec38[((IOTA - 285) & 511)])) + (0.00395383546f * fVec38[((IOTA - 286) & 511)])) + (0.00407768833f * fVec38[((IOTA - 287) & 511)])) + (0.00380190602f * fVec38[((IOTA - 288) & 511)])) + (0.00249083992f * fVec38[((IOTA - 289) & 511)])) + (0.000950579997f * fVec38[((IOTA - 290) & 511)])) + (0.00109997066f * fVec38[((IOTA - 291) & 511)])) + (0.0026502097f * fVec38[((IOTA - 292) & 511)])) + (0.00439471565f * fVec38[((IOTA - 293) & 511)])) + (0.0057015596f * fVec38[((IOTA - 294) & 511)])) + (0.00604607351f * fVec38[((IOTA - 295) & 511)])) + (0.00515976734f * fVec38[((IOTA - 296) & 511)])) + (0.00406708941f * fVec38[((IOTA - 297) & 511)])) + (0.00350040803f * fVec38[((IOTA - 298) & 511)])) + (0.00398082053f * fVec38[((IOTA - 299) & 511)])) + (0.0050954055f * fVec38[((IOTA - 300) & 511)])) + (0.0061412584f * fVec38[((IOTA - 301) & 511)])) + (0.00680150092f * fVec38[((IOTA - 302) & 511)])) + (0.00656055659f * fVec38[((IOTA - 303) & 511)])) + (0.00563536724f * fVec38[((IOTA - 304) & 511)])) + (0.00462765899f * fVec38[((IOTA - 305) & 511)])) + (0.00350185484f * fVec38[((IOTA - 306) & 511)])) + (0.0029595308f * fVec38[((IOTA - 307) & 511)])) + (0.0031358772f * fVec38[((IOTA - 308) & 511)])) + (0.0035980437f * fVec38[((IOTA - 309) & 511)])) + (0.00477459887f * fVec38[((IOTA - 310) & 511)])) + (0.00573601387f * fVec38[((IOTA - 311) & 511)])) + (0.00570377382f * fVec38[((IOTA - 312) & 511)])) + (0.00546953175f * fVec38[((IOTA - 313) & 511)])) + (0.00426678872f * fVec38[((IOTA - 314) & 511)])) + (0.00197175099f * fVec38[((IOTA - 315) & 511)])) + (0.000331818592f * fVec38[((IOTA - 316) & 511)])) + (0.00042325398f * fVec38[((IOTA - 319) & 511)])) + (0.000964161009f * fVec38[((IOTA - 320) & 511)])) + (0.0012242659f * fVec38[((IOTA - 321) & 511)])) + (0.00128541002f * fVec38[((IOTA - 322) & 511)])) + (0.000455936883f * fVec38[((IOTA - 323) & 511)])) + (1.35810114e-05f * fVec38[((IOTA - 325) & 511)])) + (0.00058076391f * fVec38[((IOTA - 326) & 511)])) + (0.00196888717f * fVec38[((IOTA - 327) & 511)])) + (0.00295554521f * fVec38[((IOTA - 328) & 511)])) + (0.00324467244f * fVec38[((IOTA - 329) & 511)])) + (0.00341635384f * fVec38[((IOTA - 330) & 511)])) + (0.00259588566f * fVec38[((IOTA - 331) & 511)])) + (0.00168014411f * fVec38[((IOTA - 332) & 511)])) + (0.00158808846f * fVec38[((IOTA - 333) & 511)])) + (0.00140675297f * fVec38[((IOTA - 334) & 511)])) + (0.00143143488f * fVec38[((IOTA - 335) & 511)])) + (0.00206357054f * fVec38[((IOTA - 336) & 511)])) + (0.00263149152f * fVec38[((IOTA - 337) & 511)])) + (0.00374681456f * fVec38[((IOTA - 338) & 511)])) + (0.00489724101f * fVec38[((IOTA - 339) & 511)])) + (0.00529386476f * fVec38[((IOTA - 340) & 511)])) + (0.00508690253f * fVec38[((IOTA - 341) & 511)])) + (0.00366704073f * fVec38[((IOTA - 342) & 511)])) + (0.0013525472f * fVec38[((IOTA - 343) & 511)])) + (0.00121118687f * fVec38[((IOTA - 347) & 511)])) + (0.0032701809f * fVec38[((IOTA - 348) & 511)])) + (0.00410207501f * fVec38[((IOTA - 349) & 511)])) + (0.00343079073f * fVec38[((IOTA - 350) & 511)])) + (0.00121694431f * fVec38[((IOTA - 351) & 511)])) + (7.66441226e-05f * fVec38[((IOTA - 358) & 511)])) + (0.000315108337f * fVec38[((IOTA - 359) & 511)])) + (1.5059486e-06f * fVec38[((IOTA - 360) & 511)])) - (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00339063862f * fVec38[((IOTA - 415) & 511)]) + ((0.00245036231f * fVec38[((IOTA - 414) & 511)]) + ((0.00125913369f * fVec38[((IOTA - 413) & 511)]) + ((0.000100174453f * fVec38[((IOTA - 412) & 511)]) + ((0.00021472713f * fVec38[((IOTA - 411) & 511)]) + ((0.000885361806f * fVec38[((IOTA - 410) & 511)]) + ((0.00216241647f * fVec38[((IOTA - 409) & 511)]) + ((0.00397913763f * fVec38[((IOTA - 408) & 511)]) + ((0.00475018285f * fVec38[((IOTA - 407) & 511)]) + ((0.0045638578f * fVec38[((IOTA - 406) & 511)]) + ((0.0040899408f * fVec38[((IOTA - 405) & 511)]) + ((0.00299956556f * fVec38[((IOTA - 404) & 511)]) + ((0.0019254284f * fVec38[((IOTA - 403) & 511)]) + ((0.001076499f * fVec38[((IOTA - 402) & 511)]) + ((0.000752888154f * fVec38[((IOTA - 401) & 511)]) + ((0.00157831609f * fVec38[((IOTA - 400) & 511)]) + ((0.00275431061f * fVec38[((IOTA - 399) & 511)]) + ((0.00383317145f * fVec38[((IOTA - 398) & 511)]) + ((0.00490497658f * fVec38[((IOTA - 397) & 511)]) + ((0.00507358741f * fVec38[((IOTA - 396) & 511)]) + ((0.00453790603f * fVec38[((IOTA - 395) & 511)]) + ((0.00361865107f * fVec38[((IOTA - 394) & 511)]) + ((0.00216897065f * fVec38[((IOTA - 393) & 511)]) + ((0.00121735735f * fVec38[((IOTA - 392) & 511)]) + ((0.00088911131f * fVec38[((IOTA - 391) & 511)]) + ((0.000555166509f * fVec38[((IOTA - 390) & 511)]) + ((0.000713030808f * fVec38[((IOTA - 389) & 511)]) + ((0.000852708239f * fVec38[((IOTA - 388) & 511)]) + ((0.000611468684f * fVec38[((IOTA - 387) & 511)]) + ((0.00077718636f * fVec38[((IOTA - 386) & 511)]) + ((0.000723924953f * fVec38[((IOTA - 385) & 511)]) + ((0.000253107864f * fVec38[((IOTA - 384) & 511)]) + ((0.000293083489f * fVec38[((IOTA - 383) & 511)]) + ((0.000282779336f * fVec38[((IOTA - 382) & 511)]) + ((0.000169112813f * fVec38[((IOTA - 381) & 511)]) + ((0.000413865317f * fVec38[((IOTA - 380) & 511)]) + ((0.000904197805f * fVec38[((IOTA - 379) & 511)]) + ((0.00166116003f * fVec38[((IOTA - 378) & 511)]) + ((0.00230974052f * fVec38[((IOTA - 377) & 511)]) + ((0.00225718785f * fVec38[((IOTA - 376) & 511)]) + ((0.00225963816f * fVec38[((IOTA - 375) & 511)]) + ((0.00242638914f * fVec38[((IOTA - 374) & 511)]) + ((0.00240005367f * fVec38[((IOTA - 373) & 511)]) + ((0.00235703774f * fVec38[((IOTA - 372) & 511)]) + ((0.00169089064f * fVec38[((IOTA - 371) & 511)]) + ((0.0011343658f * fVec38[((IOTA - 370) & 511)]) + ((0.00137495575f * fVec38[((IOTA - 369) & 511)]) + ((0.00143282255f * fVec38[((IOTA - 368) & 511)]) + ((0.0018776292f * fVec38[((IOTA - 367) & 511)]) + ((0.00290048309f * fVec38[((IOTA - 366) & 511)]) + (((0.00276485085f * fVec38[((IOTA - 364) & 511)]) + ((0.00223383447f * fVec38[((IOTA - 363) & 511)]) + ((0.00109881908f * fVec38[((IOTA - 362) & 511)]) + ((0.000361224636f * fVec38[((IOTA - 361) & 511)]) + ((0.000446341932f * fVec38[((IOTA - 357) & 511)]) + ((0.000932599884f * fVec38[((IOTA - 356) & 511)]) + ((0.00176777085f * fVec38[((IOTA - 355) & 511)]) + ((0.00228674104f * fVec38[((IOTA - 354) & 511)]) + ((0.00179499201f * fVec38[((IOTA - 353) & 511)]) + ((0.00070762774f * fVec38[((IOTA - 352) & 511)]) + ((0.00110909343f * fVec38[((IOTA - 346) & 511)]) + ((0.00163181359f * fVec38[((IOTA - 345) & 511)]) + ((0.000516490545f * fVec38[((IOTA - 344) & 511)]) + ((0.000110182911f * fVec38[((IOTA - 324) & 511)]) + ((0.000564968679f * fVec38[((IOTA - 318) & 511)]) + ((0.000573589467f * fVec38[((IOTA - 317) & 511)]) + ((((((((0.00214541052f * fVec38[((IOTA - 179) & 511)]) + ((0.00148764858f * fVec38[((IOTA - 178) & 511)]) + ((0.00123338867f * fVec38[((IOTA - 168) & 511)]) + ((0.00161085138f * fVec38[((IOTA - 167) & 511)]) + ((0.000715392642f * fVec38[((IOTA - 166) & 511)]) + ((0.0013514841f * fVec38[((IOTA - 161) & 511)]) + ((0.00247882353f * fVec38[((IOTA - 160) & 511)]) + ((0.00173960486f * fVec38[((IOTA - 159) & 511)]) + ((0.000491808634f * fVec38[((IOTA - 158) & 511)]) + ((0.000913025346f * fVec38[((IOTA - 156) & 511)]) + ((0.00212046271f * fVec38[((IOTA - 155) & 511)]) + ((0.00200966001f * fVec38[((IOTA - 154) & 511)]) + ((0.00110073807f * fVec38[((IOTA - 153) & 511)]) + ((0.000313336961f * fVec38[((IOTA - 147) & 511)]) + ((0.00166806858f * fVec38[((IOTA - 146) & 511)]) + ((0.00212300196f * fVec38[((IOTA - 145) & 511)]) + ((0.00273060286f * fVec38[((IOTA - 144) & 511)]) + ((0.0034913444f * fVec38[((IOTA - 143) & 511)]) + ((0.00542332698f * fVec38[((IOTA - 142) & 511)]) + ((0.00698147807f * fVec38[((IOTA - 141) & 511)]) + ((0.00593863614f * fVec38[((IOTA - 140) & 511)]) + ((0.00426687719f * fVec38[((IOTA - 139) & 511)]) + ((0.00287273107f * fVec38[((IOTA - 138) & 511)]) + ((0.00136592146f * fVec38[((IOTA - 137) & 511)]) + ((0.00184408994f * fVec38[((IOTA - 136) & 511)]) + ((0.00417919131f * fVec38[((IOTA - 135) & 511)]) + ((0.00421993434f * fVec38[((IOTA - 134) & 511)]) + ((0.00158404373f * fVec38[((IOTA - 133) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00145688467f * fVec38[((IOTA - 44) & 511)]) + ((0.002319247f * fVec38[((IOTA - 43) & 511)]) + ((0.00842823647f * fVec38[((IOTA - 42) & 511)]) + ((0.0211034212f * fVec38[((IOTA - 41) & 511)]) + ((0.0266366638f * fVec38[((IOTA - 40) & 511)]) + ((0.0120680854f * fVec38[((IOTA - 39) & 511)]) + ((0.0328290313f * fVec38[((IOTA - 29) & 511)]) + ((0.0645184964f * fVec38[((IOTA - 28) & 511)]) + ((0.0829019994f * fVec38[((IOTA - 27) & 511)]) + ((0.0524104051f * fVec38[((IOTA - 26) & 511)]) + ((0.0199185982f * fVec38[((IOTA - 20) & 511)]) + ((0.0282984152f * fVec38[((IOTA - 19) & 511)]) + ((0.0281535424f * fVec38[((IOTA - 18) & 511)]) + ((0.0349005423f * fVec38[((IOTA - 17) & 511)]) + ((0.0287132859f * fVec38[((IOTA - 16) & 511)]) + ((0.0305057671f * fVec38[((IOTA - 15) & 511)]) + ((0.0250721648f * fVec38[((IOTA - 14) & 511)]) + ((0.0116107902f * fVec38[((IOTA - 9) & 511)]) + ((0.163152114f * fVec38[((IOTA - 8) & 511)]) + ((0.239243522f * fVec38[((IOTA - 7) & 511)]) + ((0.235519618f * fVec38[((IOTA - 6) & 511)]) + ((0.134480163f * fVec38[((IOTA - 5) & 511)]) + ((0.000760239549f * fVec38[((IOTA - 45) & 511)]) + (0.00127377734f * fVec38[((IOTA - 46) & 511)])))))))))))))))))))))))) + (0.0105182603f * fVec38[((IOTA - 47) & 511)])) + (0.0130251311f * fVec38[((IOTA - 48) & 511)])) + (0.00130840903f * fVec38[((IOTA - 49) & 511)])) + (0.00475186575f * fVec38[((IOTA - 50) & 511)])) + (0.0126235178f * fVec38[((IOTA - 51) & 511)])) + (0.00307579618f * fVec38[((IOTA - 52) & 511)])) + (0.00205772463f * fVec38[((IOTA - 54) & 511)])) + (0.0080805039f * fVec38[((IOTA - 56) & 511)])) + (0.0190914571f * fVec38[((IOTA - 57) & 511)])) + (0.03136627f * fVec38[((IOTA - 58) & 511)])) + (0.0392394885f * fVec38[((IOTA - 59) & 511)])) + (0.0210674014f * fVec38[((IOTA - 60) & 511)])) + (0.0014753663f * fVec38[((IOTA - 65) & 511)])) + (0.0320909619f * fVec38[((IOTA - 66) & 511)])) + (0.0489506535f * fVec38[((IOTA - 67) & 511)])) + (0.0435870215f * fVec38[((IOTA - 68) & 511)])) + (0.0274547413f * fVec38[((IOTA - 69) & 511)])) + (0.00885219872f * fVec38[((IOTA - 70) & 511)])) + (0.000547165517f * fVec38[((IOTA - 75) & 511)])) + (0.00441718334f * fVec38[((IOTA - 76) & 511)])) + (0.00865025539f * fVec38[((IOTA - 77) & 511)])) + (0.0146381669f * fVec38[((IOTA - 78) & 511)])) + (0.0151964631f * fVec38[((IOTA - 79) & 511)])) + (0.0138010178f * fVec38[((IOTA - 80) & 511)])) + (0.0132001191f * fVec38[((IOTA - 81) & 511)])) + (0.00669586426f * fVec38[((IOTA - 82) & 511)])) + (0.000912759919f * fVec38[((IOTA - 85) & 511)])) + (0.0064542708f * fVec38[((IOTA - 86) & 511)])) + (0.0134964492f * fVec38[((IOTA - 87) & 511)])) + (0.0227378607f * fVec38[((IOTA - 88) & 511)])) + (0.0271202065f * fVec38[((IOTA - 89) & 511)])) + (0.0240096617f * fVec38[((IOTA - 90) & 511)])) + (0.018508302f * fVec38[((IOTA - 91) & 511)])) + (0.0134087345f * fVec38[((IOTA - 92) & 511)])) + (0.00564425392f * fVec38[((IOTA - 93) & 511)])) + (0.00154330069f * fVec38[((IOTA - 99) & 511)])) + (0.0110496003f * fVec38[((IOTA - 100) & 511)])) + (0.0176617354f * fVec38[((IOTA - 101) & 511)])) + (0.020130787f * fVec38[((IOTA - 102) & 511)])) + (0.0189149939f * fVec38[((IOTA - 103) & 511)])) + (0.0155395307f * fVec38[((IOTA - 104) & 511)])) + (0.0101815993f * fVec38[((IOTA - 105) & 511)])) + (0.0025996645f * fVec38[((IOTA - 106) & 511)])) + (0.000699095428f * fVec38[((IOTA - 111) & 511)])) + (0.00907852873f * fVec38[((IOTA - 112) & 511)])) + (0.0150943398f * fVec38[((IOTA - 113) & 511)])) + (0.0180110913f * fVec38[((IOTA - 114) & 511)])) + (0.0179119501f * fVec38[((IOTA - 115) & 511)])) + (0.0141727831f * fVec38[((IOTA - 116) & 511)])) + (0.00860242732f * fVec38[((IOTA - 117) & 511)])) + (0.0050711073f * fVec38[((IOTA - 118) & 511)])) + (0.00332899252f * fVec38[((IOTA - 119) & 511)])) + (0.00206613913f * fVec38[((IOTA - 120) & 511)])) + (0.00151424948f * fVec38[((IOTA - 121) & 511)])) + (0.00178766996f * fVec38[((IOTA - 122) & 511)])) + (0.00160178775f * fVec38[((IOTA - 123) & 511)])) + (0.00317859789f * fVec38[((IOTA - 124) & 511)])) + (0.00593618583f * fVec38[((IOTA - 125) & 511)])) + (0.00689901831f * fVec38[((IOTA - 126) & 511)])) + (0.0062247226f * fVec38[((IOTA - 127) & 511)])) + (0.00347495871f * fVec38[((IOTA - 128) & 511)])) + (0.00024667196f * fVec38[((IOTA - 180) & 511)])))))))))))))))))))))))))))))) + (0.00193331111f * fVec38[((IOTA - 186) & 511)])) + (0.00371085433f * fVec38[((IOTA - 187) & 511)])) + (0.0023189811f * fVec38[((IOTA - 188) & 511)])) + (5.01889735e-06f * fVec38[((IOTA - 226) & 511)])) + (0.000865049195f * fVec38[((IOTA - 227) & 511)])) + (0.00305867195f * fVec38[((IOTA - 365) & 511)])))))))))))))))))) + (0.0040599443f * fVec38[((IOTA - 416) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00307520572f * fVec38[((IOTA - 417) & 511)])) + (0.00155454967f * fVec38[((IOTA - 418) & 511)])) + (0.000791003462f * fVec38[((IOTA - 419) & 511)])) + (0.00011505466f * fVec38[((IOTA - 420) & 511)])) + (0.000462550204f * fVec38[((IOTA - 421) & 511)])) + (0.00166473258f * fVec38[((IOTA - 422) & 511)])) + (0.00209274003f * fVec38[((IOTA - 423) & 511)])) + (0.00239228923f * fVec38[((IOTA - 424) & 511)])) + (0.00271979719f * fVec38[((IOTA - 425) & 511)])) + (0.00246751588f * fVec38[((IOTA - 426) & 511)])) + (0.0023940308f * fVec38[((IOTA - 427) & 511)])) + (0.00248676538f * fVec38[((IOTA - 428) & 511)])) + (0.00258758944f * fVec38[((IOTA - 429) & 511)])) + (0.00312640006f * fVec38[((IOTA - 430) & 511)])) + (0.0033294945f * fVec38[((IOTA - 431) & 511)])) + (0.00291320821f * fVec38[((IOTA - 432) & 511)])) + (0.00259479322f * fVec38[((IOTA - 433) & 511)])) + (0.00212701736f * fVec38[((IOTA - 434) & 511)])) + (0.00194175495f * fVec38[((IOTA - 435) & 511)])) + (0.002438494f * fVec38[((IOTA - 436) & 511)])) + (0.0031830268f * fVec38[((IOTA - 437) & 511)])) + (0.00443962123f * fVec38[((IOTA - 438) & 511)])) + (0.00563229667f * fVec38[((IOTA - 439) & 511)])) + (0.00606387667f * fVec38[((IOTA - 440) & 511)])) + (0.00638993829f * fVec38[((IOTA - 441) & 511)])) + (0.00604645768f * fVec38[((IOTA - 442) & 511)])) + (0.00482983841f * fVec38[((IOTA - 443) & 511)])) + (0.00400379021f * fVec38[((IOTA - 444) & 511)])) + (0.00339624798f * fVec38[((IOTA - 445) & 511)])) + (0.00296331011f * fVec38[((IOTA - 446) & 511)])) + (0.00307089509f * fVec38[((IOTA - 447) & 511)])) + (0.00315208547f * fVec38[((IOTA - 448) & 511)])) + (0.00337525643f * fVec38[((IOTA - 449) & 511)])) + (0.00374935335f * fVec38[((IOTA - 450) & 511)])) + (0.00372898206f * fVec38[((IOTA - 451) & 511)])) + (0.00369638763f * fVec38[((IOTA - 452) & 511)])) + (0.00354472362f * fVec38[((IOTA - 453) & 511)])) + (0.00306944828f * fVec38[((IOTA - 454) & 511)])) + (0.00301137473f * fVec38[((IOTA - 455) & 511)])) + (0.00320744282f * fVec38[((IOTA - 456) & 511)])) + (0.00311435433f * fVec38[((IOTA - 457) & 511)])) + (0.00306159491f * fVec38[((IOTA - 458) & 511)])) + (0.00278327335f * fVec38[((IOTA - 459) & 511)])) + (0.00204263814f * fVec38[((IOTA - 460) & 511)])) + (0.00164695922f * fVec38[((IOTA - 461) & 511)])) + (0.00160482852f * fVec38[((IOTA - 462) & 511)])) + (0.00210342743f * fVec38[((IOTA - 463) & 511)])) + (0.00343542639f * fVec38[((IOTA - 464) & 511)])) + (0.00432409439f * fVec38[((IOTA - 465) & 511)])) + (0.00444213068f * fVec38[((IOTA - 466) & 511)])) + (0.00430912571f * fVec38[((IOTA - 467) & 511)])) + (0.00348877581f * fVec38[((IOTA - 468) & 511)])) + (0.00228514709f * fVec38[((IOTA - 469) & 511)])) + (0.00158150494f * fVec38[((IOTA - 470) & 511)])) + (0.00132086826f * fVec38[((IOTA - 471) & 511)])) + (0.00160223059f * fVec38[((IOTA - 472) & 511)])) + (0.00226923358f * fVec38[((IOTA - 473) & 511)])) + (0.00289085833f * fVec38[((IOTA - 474) & 511)])) + (0.0038283593f * fVec38[((IOTA - 475) & 511)])) + (0.00450002728f * fVec38[((IOTA - 476) & 511)])) + (0.00447794329f * fVec38[((IOTA - 477) & 511)])) + (0.00442544976f * fVec38[((IOTA - 478) & 511)])) + (0.00373033993f * fVec38[((IOTA - 479) & 511)])) + (0.00241472712f * fVec38[((IOTA - 480) & 511)])) + (0.00134738069f * fVec38[((IOTA - 481) & 511)])) + (0.000767827034f * fVec38[((IOTA - 482) & 511)])) + (0.000928112306f * fVec38[((IOTA - 483) & 511)])) + (0.00164772663f * fVec38[((IOTA - 484) & 511)])) + (0.00236350344f * fVec38[((IOTA - 485) & 511)])) + (0.00302407006f * fVec38[((IOTA - 486) & 511)])) + (0.00292569678f * fVec38[((IOTA - 487) & 511)])) + (0.0020886655f * fVec38[((IOTA - 488) & 511)])) + (0.00158513617f * fVec38[((IOTA - 489) & 511)])) + (0.0012313812f * fVec38[((IOTA - 490) & 511)])) + (0.00106079224f * fVec38[((IOTA - 491) & 511)])) + (0.00160474004f * fVec38[((IOTA - 492) & 511)])) + (0.0021654279f * fVec38[((IOTA - 493) & 511)])) + (0.00246149302f * fVec38[((IOTA - 494) & 511)])) + (0.00236663269f * fVec38[((IOTA - 495) & 511)])) + (0.00179915456f * fVec38[((IOTA - 496) & 511)])) + (0.00160518289f * fVec38[((IOTA - 497) & 511)])) + (0.00169216003f * fVec38[((IOTA - 498) & 511)])) + (0.00185510237f * fVec38[((IOTA - 499) & 511)])) + (0.0026313439f * fVec38[((IOTA - 500) & 511)])) + (0.00346063962f * fVec38[((IOTA - 501) & 511)])) + (0.00390957948f * fVec38[((IOTA - 502) & 511)])) + (0.00436820323f * fVec38[((IOTA - 503) & 511)])) + (0.00440915255f * fVec38[((IOTA - 504) & 511)])) + (0.00415194081f * fVec38[((IOTA - 505) & 511)])) + (0.00396260433f * fVec38[((IOTA - 506) & 511)])) + (0.00350504322f * fVec38[((IOTA - 507) & 511)])) + (0.00312421517f * fVec38[((IOTA - 508) & 511)])) + (0.00313230464f * fVec38[((IOTA - 509) & 511)])) + (0.00296316249f * fVec38[((IOTA - 510) & 511)])) + (0.00307998853f * fVec38[((IOTA - 511) & 511)]))) : ((((0.00229955558f * fVec37[((IOTA - 387) & 511)]) + ((0.00198942656f * fVec37[((IOTA - 386) & 511)]) + ((0.000799559522f * fVec37[((IOTA - 362) & 511)]) + ((0.00310497172f * fVec37[((IOTA - 361) & 511)]) + ((0.00376842543f * fVec37[((IOTA - 360) & 511)]) + ((0.00222215382f * fVec37[((IOTA - 359) & 511)]) + ((0.00169021403f * fVec37[((IOTA - 353) & 511)]) + ((0.00504715974f * fVec37[((IOTA - 352) & 511)]) + ((0.00628091069f * fVec37[((IOTA - 351) & 511)]) + ((0.00551811326f * fVec37[((IOTA - 350) & 511)]) + ((0.0025931038f * fVec37[((IOTA - 349) & 511)]) + ((0.000709949993f * fVec37[((IOTA - 345) & 511)]) + ((0.00369759556f * fVec37[((IOTA - 344) & 511)]) + ((0.00613768352f * fVec37[((IOTA - 343) & 511)]) + ((0.00700664334f * fVec37[((IOTA - 342) & 511)]) + ((0.00621475512f * fVec37[((IOTA - 341) & 511)]) + ((0.00475350162f * fVec37[((IOTA - 340) & 511)]) + ((0.00368854916f * fVec37[((IOTA - 339) & 511)]) + ((0.00350809237f * fVec37[((IOTA - 338) & 511)]) + ((0.0040866104f * fVec37[((IOTA - 337) & 511)]) + ((0.0047126147f * fVec37[((IOTA - 336) & 511)]) + ((0.00456639053f * fVec37[((IOTA - 335) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((fSlow119 * fTemp0) + (0.211201146f * fVec37[((IOTA - 1) & 511)])) + (0.222811937f * fVec37[((IOTA - 2) & 511)])) + (0.211391553f * fVec37[((IOTA - 3) & 511)])) + (0.144287497f * fVec37[((IOTA - 4) & 511)])) + (0.000967753585f * fVec37[((IOTA - 10) & 511)])) + (0.0713637844f * fVec37[((IOTA - 11) & 511)])) + (0.11935053f * fVec37[((IOTA - 12) & 511)])) + (0.11133112f * fVec37[((IOTA - 13) & 511)])) + (0.0577938147f * fVec37[((IOTA - 14) & 511)])) + (0.0170374736f * fVec37[((IOTA - 15) & 511)])) + (0.0198465064f * fVec37[((IOTA - 21) & 511)])) + (0.0574492067f * fVec37[((IOTA - 22) & 511)])) + (0.088863194f * fVec37[((IOTA - 23) & 511)])) + (0.0821845755f * fVec37[((IOTA - 24) & 511)])) + (0.0381616689f * fVec37[((IOTA - 25) & 511)])) + (0.0152651574f * fVec37[((IOTA - 32) & 511)])) + (0.027188547f * fVec37[((IOTA - 33) & 511)])) + (0.0274231154f * fVec37[((IOTA - 34) & 511)])) + (0.0123269772f * fVec37[((IOTA - 35) & 511)])) + (0.000963684171f * fVec37[((IOTA - 36) & 511)])) + (0.00613454916f * fVec37[((IOTA - 43) & 511)])) + (0.0069048251f * fVec37[((IOTA - 44) & 511)])) + (0.00523817539f * fVec37[((IOTA - 45) & 511)])) + (0.0100042699f * fVec37[((IOTA - 53) & 511)])) + (0.0132079804f * fVec37[((IOTA - 54) & 511)])) + (0.0175185204f * fVec37[((IOTA - 55) & 511)])) + (0.0106529314f * fVec37[((IOTA - 56) & 511)])) + (0.000244055409f * fVec37[((IOTA - 57) & 511)])) + (0.00357119599f * fVec37[((IOTA - 65) & 511)])) + (0.00221635215f * fVec37[((IOTA - 66) & 511)])) + (0.00727258576f * fVec37[((IOTA - 73) & 511)])) + (0.0222637448f * fVec37[((IOTA - 74) & 511)])) + (0.0221077874f * fVec37[((IOTA - 75) & 511)])) + (0.00905260257f * fVec37[((IOTA - 76) & 511)])) + (0.000983893406f * fVec37[((IOTA - 87) & 511)])) + (0.00227970304f * fVec37[((IOTA - 96) & 511)])) + (0.00248584151f * fVec37[((IOTA - 97) & 511)])) + (0.00171900215f * fVec37[((IOTA - 98) & 511)])) + (0.0017540874f * fVec37[((IOTA - 99) & 511)])) + (0.00312292669f * fVec37[((IOTA - 100) & 511)])) + (0.00434818119f * fVec37[((IOTA - 101) & 511)])) + (0.00123584038f * fVec37[((IOTA - 102) & 511)])) + (0.0050912085f * fVec37[((IOTA - 109) & 511)])) + (0.0120059606f * fVec37[((IOTA - 110) & 511)])) + (0.0102172829f * fVec37[((IOTA - 111) & 511)])) + (0.00175191509f * fVec37[((IOTA - 112) & 511)])) + (0.000301934779f * fVec37[((IOTA - 130) & 511)])) + (0.000137590803f * fVec37[((IOTA - 131) & 511)])) + (0.00109681999f * fVec37[((IOTA - 137) & 511)])) + (0.00152270775f * fVec37[((IOTA - 138) & 511)])) + (0.00290119788f * fVec37[((IOTA - 147) & 511)])) + (0.00556650665f * fVec37[((IOTA - 148) & 511)])) + (0.00576225156f * fVec37[((IOTA - 149) & 511)])) + (0.00418831874f * fVec37[((IOTA - 150) & 511)])) + (0.00164734758f * fVec37[((IOTA - 151) & 511)])) + (0.0004945728f * fVec37[((IOTA - 154) & 511)])) + (0.00211337907f * fVec37[((IOTA - 155) & 511)])) + (0.00368087785f * fVec37[((IOTA - 156) & 511)])) + (0.00332598528f * fVec37[((IOTA - 157) & 511)])) + (0.00135258911f * fVec37[((IOTA - 158) & 511)])) + (0.00106093753f * fVec37[((IOTA - 165) & 511)])) + (0.00195945567f * fVec37[((IOTA - 166) & 511)])) + (0.00268466584f * fVec37[((IOTA - 167) & 511)])) + (0.00429615844f * fVec37[((IOTA - 168) & 511)])) + (0.00691546639f * fVec37[((IOTA - 169) & 511)])) + (0.00843292195f * fVec37[((IOTA - 170) & 511)])) + (0.00708673941f * fVec37[((IOTA - 171) & 511)])) + (0.00402595429f * fVec37[((IOTA - 172) & 511)])) + (0.000113173854f * fVec37[((IOTA - 173) & 511)])) + (0.00191972405f * fVec37[((IOTA - 178) & 511)])) + (0.00380939478f * fVec37[((IOTA - 179) & 511)])) + (0.00462663453f * fVec37[((IOTA - 180) & 511)])) + (0.00563769415f * fVec37[((IOTA - 181) & 511)])) + (0.00682582892f * fVec37[((IOTA - 182) & 511)])) + (0.00754952664f * fVec37[((IOTA - 183) & 511)])) + (0.00794313289f * fVec37[((IOTA - 184) & 511)])) + (0.00729623251f * fVec37[((IOTA - 185) & 511)])) + (0.0051607741f * fVec37[((IOTA - 186) & 511)])) + (0.00276731933f * fVec37[((IOTA - 187) & 511)])) + (0.00147989625f * fVec37[((IOTA - 188) & 511)])) + (0.00192986988f * fVec37[((IOTA - 189) & 511)])) + (0.00415983284f * fVec37[((IOTA - 190) & 511)])) + (0.00682956818f * fVec37[((IOTA - 191) & 511)])) + (0.00883692224f * fVec37[((IOTA - 192) & 511)])) + (0.0097296387f * fVec37[((IOTA - 193) & 511)])) + (0.00945772976f * fVec37[((IOTA - 194) & 511)])) + (0.00796999782f * fVec37[((IOTA - 195) & 511)])) + (0.00560695352f * fVec37[((IOTA - 196) & 511)])) + (0.00397648849f * fVec37[((IOTA - 197) & 511)])) + (0.00443011941f * fVec37[((IOTA - 198) & 511)])) + (0.00534120342f * fVec37[((IOTA - 199) & 511)])) + (0.00555611309f * fVec37[((IOTA - 200) & 511)])) + (0.00499222288f * fVec37[((IOTA - 201) & 511)])) + (0.00307973009f * fVec37[((IOTA - 202) & 511)])) + (0.0012497534f * fVec37[((IOTA - 203) & 511)])) + (0.00165094947f * fVec37[((IOTA - 204) & 511)])) + (0.00414710212f * fVec37[((IOTA - 205) & 511)])) + (0.00712649897f * fVec37[((IOTA - 206) & 511)])) + (0.00922907144f * fVec37[((IOTA - 207) & 511)])) + (0.00978721585f * fVec37[((IOTA - 208) & 511)])) + (0.0086949598f * fVec37[((IOTA - 209) & 511)])) + (0.00579420198f * fVec37[((IOTA - 210) & 511)])) + (0.00313604204f * fVec37[((IOTA - 211) & 511)])) + (0.00275445124f * fVec37[((IOTA - 212) & 511)])) + (0.004602795f * fVec37[((IOTA - 213) & 511)])) + (0.00742128491f * fVec37[((IOTA - 214) & 511)])) + (0.00922472775f * fVec37[((IOTA - 215) & 511)])) + (0.00836541876f * fVec37[((IOTA - 216) & 511)])) + (0.00482565118f * fVec37[((IOTA - 217) & 511)])) + (0.00101944618f * fVec37[((IOTA - 218) & 511)])) + (0.00126625132f * fVec37[((IOTA - 220) & 511)])) + (0.00410275068f * fVec37[((IOTA - 221) & 511)])) + (0.00712952344f * fVec37[((IOTA - 222) & 511)])) + (0.00967129227f * fVec37[((IOTA - 223) & 511)])) + (0.00994897541f * fVec37[((IOTA - 224) & 511)])) + (0.00832648389f * fVec37[((IOTA - 225) & 511)])) + (0.00600124756f * fVec37[((IOTA - 226) & 511)])) + (0.00434823614f * fVec37[((IOTA - 227) & 511)])) + (0.00403082091f * fVec37[((IOTA - 228) & 511)])) + (0.00456102844f * fVec37[((IOTA - 229) & 511)])) + (0.00593971135f * fVec37[((IOTA - 230) & 511)])) + (0.00768057304f * fVec37[((IOTA - 231) & 511)])) + (0.00871739723f * fVec37[((IOTA - 232) & 511)])) + (0.00919629633f * fVec37[((IOTA - 233) & 511)])) + (0.0101487618f * fVec37[((IOTA - 234) & 511)])) + (0.0108889025f * fVec37[((IOTA - 235) & 511)])) + (0.0110257231f * fVec37[((IOTA - 236) & 511)])) + (0.010956075f * fVec37[((IOTA - 237) & 511)])) + (0.0101432353f * fVec37[((IOTA - 238) & 511)])) + (0.00876097754f * fVec37[((IOTA - 239) & 511)])) + (0.00762120914f * fVec37[((IOTA - 240) & 511)])) + (0.00627983827f * fVec37[((IOTA - 241) & 511)])) + (0.00539834052f * fVec37[((IOTA - 242) & 511)])) + (0.00549047999f * fVec37[((IOTA - 243) & 511)])) + (0.00552471261f * fVec37[((IOTA - 244) & 511)])) + (0.00540628657f * fVec37[((IOTA - 245) & 511)])) + (0.0048007397f * fVec37[((IOTA - 246) & 511)])) + (0.00373958191f * fVec37[((IOTA - 247) & 511)])) + (0.00348763494f * fVec37[((IOTA - 248) & 511)])) + (0.00375030562f * fVec37[((IOTA - 249) & 511)])) + (0.00433044601f * fVec37[((IOTA - 250) & 511)])) + (0.0058925557f * fVec37[((IOTA - 251) & 511)])) + (0.0071448111f * fVec37[((IOTA - 252) & 511)])) + (0.0082401745f * fVec37[((IOTA - 253) & 511)])) + (0.0103411525f * fVec37[((IOTA - 254) & 511)])) + (0.011719753f * fVec37[((IOTA - 255) & 511)])) + (0.011398159f * fVec37[((IOTA - 256) & 511)])) + (0.0108006671f * fVec37[((IOTA - 257) & 511)])) + (0.00952275842f * fVec37[((IOTA - 258) & 511)])) + (0.00805179775f * fVec37[((IOTA - 259) & 511)])) + (0.00864972919f * fVec37[((IOTA - 260) & 511)])) + (0.0103253424f * fVec37[((IOTA - 261) & 511)])) + (0.0115232375f * fVec37[((IOTA - 262) & 511)])) + (0.0123982197f * fVec37[((IOTA - 263) & 511)])) + (0.0118147526f * fVec37[((IOTA - 264) & 511)])) + (0.00950606726f * fVec37[((IOTA - 265) & 511)])) + (0.00694920402f * fVec37[((IOTA - 266) & 511)])) + (0.00530752074f * fVec37[((IOTA - 267) & 511)])) + (0.00568520743f * fVec37[((IOTA - 268) & 511)])) + (0.0079445634f * fVec37[((IOTA - 269) & 511)])) + (0.0108739454f * fVec37[((IOTA - 270) & 511)])) + (0.0134317167f * fVec37[((IOTA - 271) & 511)])) + (0.014282858f * fVec37[((IOTA - 272) & 511)])) + (0.0128506133f * fVec37[((IOTA - 273) & 511)])) + (0.00993720721f * fVec37[((IOTA - 274) & 511)])) + (0.00632935902f * fVec37[((IOTA - 275) & 511)])) + (0.00280089211f * fVec37[((IOTA - 276) & 511)])) + (0.000572661869f * fVec37[((IOTA - 277) & 511)])) + (0.000375981908f * fVec37[((IOTA - 278) & 511)])) + (0.0017188373f * fVec37[((IOTA - 279) & 511)])) + (0.00333181443f * fVec37[((IOTA - 280) & 511)])) + (0.00427377643f * fVec37[((IOTA - 281) & 511)])) + (0.00461200625f * fVec37[((IOTA - 282) & 511)])) + (0.00446613925f * fVec37[((IOTA - 283) & 511)])) + (0.00413214415f * fVec37[((IOTA - 284) & 511)])) + (0.00390092935f * fVec37[((IOTA - 285) & 511)])) + (0.00361095509f * fVec37[((IOTA - 286) & 511)])) + (0.0040779491f * fVec37[((IOTA - 287) & 511)])) + (0.00522745214f * fVec37[((IOTA - 288) & 511)])) + (0.0062050214f * fVec37[((IOTA - 289) & 511)])) + (0.0072404705f * fVec37[((IOTA - 290) & 511)])) + (0.00804569386f * fVec37[((IOTA - 291) & 511)])) + (0.00787007622f * fVec37[((IOTA - 292) & 511)])) + (0.00682423403f * fVec37[((IOTA - 293) & 511)])) + (0.00536127575f * fVec37[((IOTA - 294) & 511)])) + (0.00411600387f * fVec37[((IOTA - 295) & 511)])) + (0.00345321f * fVec37[((IOTA - 296) & 511)])) + (0.00344383391f * fVec37[((IOTA - 297) & 511)])) + (0.00427319901f * fVec37[((IOTA - 298) & 511)])) + (0.00597949838f * fVec37[((IOTA - 299) & 511)])) + (0.00738037052f * fVec37[((IOTA - 300) & 511)])) + (0.007903127f * fVec37[((IOTA - 301) & 511)])) + (0.00814198516f * fVec37[((IOTA - 302) & 511)])) + (0.00797571614f * fVec37[((IOTA - 303) & 511)])) + (0.00753951818f * fVec37[((IOTA - 304) & 511)])) + (0.00745928427f * fVec37[((IOTA - 305) & 511)])) + (0.00680229208f * fVec37[((IOTA - 306) & 511)])) + (0.00560986809f * fVec37[((IOTA - 307) & 511)])) + (0.00441928627f * fVec37[((IOTA - 308) & 511)])) + (0.00317142997f * fVec37[((IOTA - 309) & 511)])) + (0.00287015457f * fVec37[((IOTA - 310) & 511)])) + (0.00376611575f * fVec37[((IOTA - 311) & 511)])) + (0.00532544823f * fVec37[((IOTA - 312) & 511)])) + (0.00762624061f * fVec37[((IOTA - 313) & 511)])) + (0.00935167726f * fVec37[((IOTA - 314) & 511)])) + (0.00929005817f * fVec37[((IOTA - 315) & 511)])) + (0.00781134469f * fVec37[((IOTA - 316) & 511)])) + (0.00494894385f * fVec37[((IOTA - 317) & 511)])) + (0.00182909658f * fVec37[((IOTA - 318) & 511)])) + (4.88329679e-05f * fVec37[((IOTA - 319) & 511)])) + (0.000379143748f * fVec37[((IOTA - 323) & 511)])) + (0.000783089548f * fVec37[((IOTA - 324) & 511)])) + (0.00098782545f * fVec37[((IOTA - 325) & 511)])) + (0.00092043262f * fVec37[((IOTA - 326) & 511)])) + (0.000953125302f * fVec37[((IOTA - 327) & 511)])) + (0.00115255499f * fVec37[((IOTA - 328) & 511)])) + (0.00179777853f * fVec37[((IOTA - 329) & 511)])) + (0.00266393414f * fVec37[((IOTA - 330) & 511)])) + (0.00275376393f * fVec37[((IOTA - 331) & 511)])) + (0.00280804094f * fVec37[((IOTA - 332) & 511)])) + (0.00361560192f * fVec37[((IOTA - 333) & 511)])) + (0.00429159403f * fVec37[((IOTA - 334) & 511)])) + (0.000866760034f * fVec37[((IOTA - 388) & 511)])))))))))))))))))))))))) + (0.000154885463f * fVec37[((IOTA - 421) & 511)])) - ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.034467347f * fVec37[((IOTA - 60) & 511)]) + ((0.0302290395f * fVec37[((IOTA - 59) & 511)]) + ((0.0135082928f * fVec37[((IOTA - 58) & 511)]) + ((0.00169818755f * fVec37[((IOTA - 52) & 511)]) + ((0.0238320678f * fVec37[((IOTA - 51) & 511)]) + ((0.0347359292f * fVec37[((IOTA - 50) & 511)]) + ((0.033251714f * fVec37[((IOTA - 49) & 511)]) + ((0.0348257571f * fVec37[((IOTA - 48) & 511)]) + ((0.0281001814f * fVec37[((IOTA - 47) & 511)]) + ((0.00745441765f * fVec37[((IOTA - 46) & 511)]) + ((0.00120270764f * fVec37[((IOTA - 42) & 511)]) + ((0.0126223136f * fVec37[((IOTA - 41) & 511)]) + ((0.0233028233f * fVec37[((IOTA - 40) & 511)]) + ((0.0210485533f * fVec37[((IOTA - 39) & 511)]) + ((0.0138437729f * fVec37[((IOTA - 38) & 511)]) + ((0.00483552227f * fVec37[((IOTA - 37) & 511)]) + ((0.00419554999f * fVec37[((IOTA - 31) & 511)]) + ((0.0495878197f * fVec37[((IOTA - 30) & 511)]) + ((0.0851803869f * fVec37[((IOTA - 29) & 511)]) + ((0.08485654f * fVec37[((IOTA - 28) & 511)]) + ((0.0662475824f * fVec37[((IOTA - 27) & 511)]) + ((0.0191993304f * fVec37[((IOTA - 26) & 511)]) + ((0.0229969844f * fVec37[((IOTA - 20) & 511)]) + ((0.0618904084f * fVec37[((IOTA - 19) & 511)]) + ((0.0683811381f * fVec37[((IOTA - 18) & 511)]) + ((0.0552942269f * fVec37[((IOTA - 17) & 511)]) + ((0.017751934f * fVec37[((IOTA - 16) & 511)]) + ((0.101776198f * fVec37[((IOTA - 9) & 511)]) + ((0.192611814f * fVec37[((IOTA - 8) & 511)]) + ((0.210008562f * fVec37[((IOTA - 7) & 511)]) + ((0.139870331f * fVec37[((IOTA - 6) & 511)]) + ((0.00870532542f * fVec37[((IOTA - 5) & 511)]) + (0.0350413024f * fVec37[((IOTA - 61) & 511)]))))))))))))))))))))))))))))))))) + (0.0331946053f * fVec37[((IOTA - 62) & 511)])) + (0.0151301241f * fVec37[((IOTA - 63) & 511)])) + (0.000306856818f * fVec37[((IOTA - 64) & 511)])) + (0.00958660431f * fVec37[((IOTA - 67) & 511)])) + (0.0259557031f * fVec37[((IOTA - 68) & 511)])) + (0.0366890617f * fVec37[((IOTA - 69) & 511)])) + (0.0362484902f * fVec37[((IOTA - 70) & 511)])) + (0.0263615455f * fVec37[((IOTA - 71) & 511)])) + (0.0113933459f * fVec37[((IOTA - 72) & 511)])) + (0.010242166f * fVec37[((IOTA - 77) & 511)])) + (0.0230148286f * fVec37[((IOTA - 78) & 511)])) + (0.0263560191f * fVec37[((IOTA - 79) & 511)])) + (0.026540298f * fVec37[((IOTA - 80) & 511)])) + (0.0220218599f * fVec37[((IOTA - 81) & 511)])) + (0.0157372393f * fVec37[((IOTA - 82) & 511)])) + (0.0122778136f * fVec37[((IOTA - 83) & 511)])) + (0.00927177351f * fVec37[((IOTA - 84) & 511)])) + (0.00543963956f * fVec37[((IOTA - 85) & 511)])) + (0.00118703488f * fVec37[((IOTA - 86) & 511)])) + (0.00417426834f * fVec37[((IOTA - 88) & 511)])) + (0.0167574547f * fVec37[((IOTA - 89) & 511)])) + (0.0291064288f * fVec37[((IOTA - 90) & 511)])) + (0.0342734978f * fVec37[((IOTA - 91) & 511)])) + (0.0330175571f * fVec37[((IOTA - 92) & 511)])) + (0.0252277441f * fVec37[((IOTA - 93) & 511)])) + (0.011181049f * fVec37[((IOTA - 94) & 511)])) + (0.00118890451f * fVec37[((IOTA - 95) & 511)])) + (0.00639413996f * fVec37[((IOTA - 103) & 511)])) + (0.0155073982f * fVec37[((IOTA - 104) & 511)])) + (0.0239297077f * fVec37[((IOTA - 105) & 511)])) + (0.0260821022f * fVec37[((IOTA - 106) & 511)])) + (0.0195736066f * fVec37[((IOTA - 107) & 511)])) + (0.00789262354f * fVec37[((IOTA - 108) & 511)])) + (0.00884192623f * fVec37[((IOTA - 113) & 511)])) + (0.015612076f * fVec37[((IOTA - 114) & 511)])) + (0.0186407734f * fVec37[((IOTA - 115) & 511)])) + (0.0190639384f * fVec37[((IOTA - 116) & 511)])) + (0.0167257227f * fVec37[((IOTA - 117) & 511)])) + (0.0148843359f * fVec37[((IOTA - 118) & 511)])) + (0.0144016687f * fVec37[((IOTA - 119) & 511)])) + (0.0130580161f * fVec37[((IOTA - 120) & 511)])) + (0.0110575091f * fVec37[((IOTA - 121) & 511)])) + (0.00885380525f * fVec37[((IOTA - 122) & 511)])) + (0.00539897289f * fVec37[((IOTA - 123) & 511)])) + (0.0030954578f * fVec37[((IOTA - 124) & 511)])) + (0.00276665948f * fVec37[((IOTA - 125) & 511)])) + (0.00204958813f * fVec37[((IOTA - 126) & 511)])) + (0.00133325905f * fVec37[((IOTA - 127) & 511)])) + (0.00108560175f * fVec37[((IOTA - 128) & 511)])) + (0.00042500766f * fVec37[((IOTA - 129) & 511)])) + (0.00190693839f * fVec37[((IOTA - 132) & 511)])) + (0.00316626066f * fVec37[((IOTA - 133) & 511)])) + (0.00268923026f * fVec37[((IOTA - 134) & 511)])) + (0.0020873677f * fVec37[((IOTA - 135) & 511)])) + (0.000796975102f * fVec37[((IOTA - 136) & 511)])) + (0.000737803522f * fVec37[((IOTA - 139) & 511)])) + (0.0056801755f * fVec37[((IOTA - 140) & 511)])) + (0.0110900644f * fVec37[((IOTA - 141) & 511)])) + (0.0144849271f * fVec37[((IOTA - 142) & 511)])) + (0.0150847277f * fVec37[((IOTA - 143) & 511)])) + (0.0118141472f * fVec37[((IOTA - 144) & 511)])) + (0.00663503306f * fVec37[((IOTA - 145) & 511)])) + (0.00156667363f * fVec37[((IOTA - 146) & 511)])) + (0.000604914501f * fVec37[((IOTA - 152) & 511)])) + (0.000717841089f * fVec37[((IOTA - 153) & 511)])) + (0.00171157857f * fVec37[((IOTA - 159) & 511)])) + (0.0054288609f * fVec37[((IOTA - 160) & 511)])) + (0.00728006475f * fVec37[((IOTA - 161) & 511)])) + (0.00652843062f * fVec37[((IOTA - 162) & 511)])) + (0.00441169739f * fVec37[((IOTA - 163) & 511)])) + (0.00122352224f * fVec37[((IOTA - 164) & 511)])) + (0.00271994341f * fVec37[((IOTA - 174) & 511)])) + (0.00290862191f * fVec37[((IOTA - 175) & 511)])) + (0.00186228473f * fVec37[((IOTA - 176) & 511)])) + (0.00045228377f * fVec37[((IOTA - 177) & 511)])) + (0.00038502831f * fVec37[((IOTA - 219) & 511)])) + (0.000662381295f * fVec37[((IOTA - 320) & 511)])) + (0.000617947895f * fVec37[((IOTA - 321) & 511)])) + (6.50556758e-05f * fVec37[((IOTA - 322) & 511)])) + (0.00147302216f * fVec37[((IOTA - 346) & 511)])) + (0.00200504437f * fVec37[((IOTA - 347) & 511)])) + (0.000530702528f * fVec37[((IOTA - 348) & 511)])) + (0.00322452467f * fVec37[((IOTA - 354) & 511)])) + (0.00663412595f * fVec37[((IOTA - 355) & 511)])) + (0.00725309085f * fVec37[((IOTA - 356) & 511)])) + (0.00537774572f * fVec37[((IOTA - 357) & 511)])) + (0.00149430381f * fVec37[((IOTA - 358) & 511)])) + (0.00156920357f * fVec37[((IOTA - 363) & 511)])) + (0.00225250935f * fVec37[((IOTA - 364) & 511)])) + (0.0013759057f * fVec37[((IOTA - 365) & 511)])) + (0.000328578521f * fVec37[((IOTA - 366) & 511)])) + (0.000174710527f * fVec37[((IOTA - 367) & 511)])) + (0.00120433001f * fVec37[((IOTA - 368) & 511)])) + (0.00281227566f * fVec37[((IOTA - 369) & 511)])) + (0.00450603617f * fVec37[((IOTA - 370) & 511)])) + (0.00606083171f * fVec37[((IOTA - 371) & 511)])) + (0.00685054762f * fVec37[((IOTA - 372) & 511)])) + (0.00668161176f * fVec37[((IOTA - 373) & 511)])) + (0.00594160846f * fVec37[((IOTA - 374) & 511)])) + (0.00487525435f * fVec37[((IOTA - 375) & 511)])) + (0.00352610229f * fVec37[((IOTA - 376) & 511)])) + (0.00190253882f * fVec37[((IOTA - 377) & 511)])) + (0.000671895221f * fVec37[((IOTA - 378) & 511)])) + (0.000332840718f * fVec37[((IOTA - 379) & 511)])) + (0.000944326632f * fVec37[((IOTA - 380) & 511)])) + (0.00232416438f * fVec37[((IOTA - 381) & 511)])) + (0.00333417905f * fVec37[((IOTA - 382) & 511)])) + (0.00296545634f * fVec37[((IOTA - 383) & 511)])) + (0.00186646404f * fVec37[((IOTA - 384) & 511)])) + (6.86026178e-05f * fVec37[((IOTA - 385) & 511)])) + (0.00130733056f * fVec37[((IOTA - 389) & 511)])) + (0.00362033118f * fVec37[((IOTA - 390) & 511)])) + (0.00495930994f * fVec37[((IOTA - 391) & 511)])) + (0.00474558258f * fVec37[((IOTA - 392) & 511)])) + (0.00328878313f * fVec37[((IOTA - 393) & 511)])) + (0.00160266645f * fVec37[((IOTA - 394) & 511)])) + (0.00108004734f * fVec37[((IOTA - 395) & 511)])) + (0.00217898469f * fVec37[((IOTA - 396) & 511)])) + (0.00425631646f * fVec37[((IOTA - 397) & 511)])) + (0.0063118441f * fVec37[((IOTA - 398) & 511)])) + (0.00727162324f * fVec37[((IOTA - 399) & 511)])) + (0.00681527052f * fVec37[((IOTA - 400) & 511)])) + (0.00580814248f * fVec37[((IOTA - 401) & 511)])) + (0.0050327247f * fVec37[((IOTA - 402) & 511)])) + (0.00479144603f * fVec37[((IOTA - 403) & 511)])) + (0.00546067394f * fVec37[((IOTA - 404) & 511)])) + (0.00606765086f * fVec37[((IOTA - 405) & 511)])) + (0.00589453522f * fVec37[((IOTA - 406) & 511)])) + (0.00564311072f * fVec37[((IOTA - 407) & 511)])) + (0.00460697478f * fVec37[((IOTA - 408) & 511)])) + (0.00266596861f * fVec37[((IOTA - 409) & 511)])) + (0.00133991335f * fVec37[((IOTA - 410) & 511)])) + (0.000682343729f * fVec37[((IOTA - 411) & 511)])) + (0.000544285867f * fVec37[((IOTA - 412) & 511)])) + (0.00136479735f * fVec37[((IOTA - 413) & 511)])) + (0.00242001563f * fVec37[((IOTA - 414) & 511)])) + (0.00394877233f * fVec37[((IOTA - 415) & 511)])) + (0.0052471119f * fVec37[((IOTA - 416) & 511)])) + (0.00479433313f * fVec37[((IOTA - 417) & 511)])) + (0.00373386266f * fVec37[((IOTA - 418) & 511)])) + (0.00260641193f * fVec37[((IOTA - 419) & 511)])) + (0.00080005452f * fVec37[((IOTA - 420) & 511)])) + (0.000581515487f * fVec37[((IOTA - 422) & 511)])) + (0.00203515263f * fVec37[((IOTA - 423) & 511)])) + (0.00379152223f * fVec37[((IOTA - 424) & 511)])) + (0.00529979449f * fVec37[((IOTA - 425) & 511)])) + (0.00580685027f * fVec37[((IOTA - 426) & 511)])) + (0.00549603393f * fVec37[((IOTA - 427) & 511)])) + (0.0045690299f * fVec37[((IOTA - 428) & 511)])) + (0.00343959918f * fVec37[((IOTA - 429) & 511)])) + (0.00332648028f * fVec37[((IOTA - 430) & 511)])) + (0.00418496411f * fVec37[((IOTA - 431) & 511)])) + (0.00525923772f * fVec37[((IOTA - 432) & 511)])) + (0.00615764549f * fVec37[((IOTA - 433) & 511)])) + (0.00603446318f * fVec37[((IOTA - 434) & 511)])) + (0.00486200117f * fVec37[((IOTA - 435) & 511)])) + (0.00308965612f * fVec37[((IOTA - 436) & 511)])) + (0.00173209049f * fVec37[((IOTA - 437) & 511)])) + (0.00246398197f * fVec37[((IOTA - 438) & 511)])) + (0.00473650871f * fVec37[((IOTA - 439) & 511)])) + (0.00707618101f * fVec37[((IOTA - 440) & 511)])) + (0.00935692899f * fVec37[((IOTA - 441) & 511)])) + (0.0105434135f * fVec37[((IOTA - 442) & 511)])) + (0.00999511406f * fVec37[((IOTA - 443) & 511)])) + (0.00875451602f * fVec37[((IOTA - 444) & 511)])) + (0.00723780319f * fVec37[((IOTA - 445) & 511)])) + (0.0057321433f * fVec37[((IOTA - 446) & 511)])) + (0.00495191338f * fVec37[((IOTA - 447) & 511)])) + (0.00510866893f * fVec37[((IOTA - 448) & 511)])) + (0.00591086783f * fVec37[((IOTA - 449) & 511)])) + (0.00665510539f * fVec37[((IOTA - 450) & 511)])) + (0.00677196402f * fVec37[((IOTA - 451) & 511)])) + (0.00656076614f * fVec37[((IOTA - 452) & 511)])) + (0.00580701511f * fVec37[((IOTA - 453) & 511)])) + (0.00445805583f * fVec37[((IOTA - 454) & 511)])) + (0.00371159101f * fVec37[((IOTA - 455) & 511)])) + (0.00387145346f * fVec37[((IOTA - 456) & 511)])) + (0.00447155628f * fVec37[((IOTA - 457) & 511)])) + (0.00511287572f * fVec37[((IOTA - 458) & 511)])) + (0.00512802601f * fVec37[((IOTA - 459) & 511)])) + (0.00432618428f * fVec37[((IOTA - 460) & 511)])) + (0.00303194206f * fVec37[((IOTA - 461) & 511)])) + (0.00191268511f * fVec37[((IOTA - 462) & 511)])) + (0.00168119511f * fVec37[((IOTA - 463) & 511)])) + (0.00251916703f * fVec37[((IOTA - 464) & 511)])) + (0.00404434884f * fVec37[((IOTA - 465) & 511)])) + (0.00578424847f * fVec37[((IOTA - 466) & 511)])) + (0.00733896159f * fVec37[((IOTA - 467) & 511)])) + (0.00767977582f * fVec37[((IOTA - 468) & 511)])) + (0.00655095f * fVec37[((IOTA - 469) & 511)])) + (0.00482666865f * fVec37[((IOTA - 470) & 511)])) + (0.00306452485f * fVec37[((IOTA - 471) & 511)])) + (0.0020645461f * fVec37[((IOTA - 472) & 511)])) + (0.00219836971f * fVec37[((IOTA - 473) & 511)])) + (0.00300276838f * fVec37[((IOTA - 474) & 511)])) + (0.00430229027f * fVec37[((IOTA - 475) & 511)])) + (0.00533828884f * fVec37[((IOTA - 476) & 511)])) + (0.00588488439f * fVec37[((IOTA - 477) & 511)])) + (0.0063659288f * fVec37[((IOTA - 478) & 511)])) + (0.00604194216f * fVec37[((IOTA - 479) & 511)])) + (0.00498045422f * fVec37[((IOTA - 480) & 511)])) + (0.00406013196f * fVec37[((IOTA - 481) & 511)])) + (0.00310359662f * fVec37[((IOTA - 482) & 511)])) + (0.002446522f * fVec37[((IOTA - 483) & 511)])) + (0.00243137171f * fVec37[((IOTA - 484) & 511)])) + (0.00249241292f * fVec37[((IOTA - 485) & 511)])) + (0.00271389447f * fVec37[((IOTA - 486) & 511)])) + (0.00294535654f * fVec37[((IOTA - 487) & 511)])) + (0.00267361244f * fVec37[((IOTA - 488) & 511)])) + (0.00260572461f * fVec37[((IOTA - 489) & 511)])) + (0.0028395243f * fVec37[((IOTA - 490) & 511)])) + (0.00313018542f * fVec37[((IOTA - 491) & 511)])) + (0.00397640606f * fVec37[((IOTA - 492) & 511)])) + (0.00481226062f * fVec37[((IOTA - 493) & 511)])) + (0.00487030484f * fVec37[((IOTA - 494) & 511)])) + (0.00415647822f * fVec37[((IOTA - 495) & 511)])) + (0.00286614057f * fVec37[((IOTA - 496) & 511)])) + (0.00173132075f * fVec37[((IOTA - 497) & 511)])) + (0.0012531355f * fVec37[((IOTA - 498) & 511)])) + (0.00128071429f * fVec37[((IOTA - 499) & 511)])) + (0.00206682831f * fVec37[((IOTA - 500) & 511)])) + (0.00316837756f * fVec37[((IOTA - 501) & 511)])) + (0.0040647788f * fVec37[((IOTA - 502) & 511)])) + (0.00535814092f * fVec37[((IOTA - 503) & 511)])) + (0.006223334f * fVec37[((IOTA - 504) & 511)])) + (0.00620243698f * fVec37[((IOTA - 505) & 511)])) + (0.00628014095f * fVec37[((IOTA - 506) & 511)])) + (0.00595494406f * fVec37[((IOTA - 507) & 511)])) + (0.00519423652f * fVec37[((IOTA - 508) & 511)])) + (0.0049538929f * fVec37[((IOTA - 509) & 511)])) + (0.00482796086f * fVec37[((IOTA - 510) & 511)])) + (0.0050607156f * fVec37[((IOTA - 511) & 511)])))))) : (iSlow92 ? (iSlow104 ? (iSlow110 ? (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0128961932f * fVec36[((IOTA - 271) & 511)]) + ((0.0128173092f * fVec36[((IOTA - 270) & 511)]) + ((0.0126943812f * fVec36[((IOTA - 269) & 511)]) + ((0.0113456063f * fVec36[((IOTA - 268) & 511)]) + ((0.00981342793f * fVec36[((IOTA - 267) & 511)]) + ((0.00943159033f * fVec36[((IOTA - 266) & 511)]) + ((0.00997261982f * fVec36[((IOTA - 265) & 511)]) + ((0.0113341333f * fVec36[((IOTA - 264) & 511)]) + ((0.0139380582f * fVec36[((IOTA - 263) & 511)]) + ((0.0162156876f * fVec36[((IOTA - 262) & 511)]) + ((0.0163057521f * fVec36[((IOTA - 261) & 511)]) + ((0.014352045f * fVec36[((IOTA - 260) & 511)]) + ((0.0119297821f * fVec36[((IOTA - 259) & 511)]) + ((0.0111804539f * fVec36[((IOTA - 258) & 511)]) + ((0.0117645254f * fVec36[((IOTA - 257) & 511)]) + ((0.0112510566f * fVec36[((IOTA - 256) & 511)]) + ((0.00952925161f * fVec36[((IOTA - 255) & 511)]) + ((0.0076818564f * fVec36[((IOTA - 254) & 511)]) + ((0.00604041247f * fVec36[((IOTA - 253) & 511)]) + ((0.00556595018f * fVec36[((IOTA - 252) & 511)]) + ((0.00642019277f * fVec36[((IOTA - 251) & 511)]) + ((0.00757578108f * fVec36[((IOTA - 250) & 511)]) + ((0.00805789232f * fVec36[((IOTA - 249) & 511)]) + ((0.0066006151f * fVec36[((IOTA - 248) & 511)]) + ((0.00340201752f * fVec36[((IOTA - 247) & 511)]) + ((0.000996818766f * fVec36[((IOTA - 246) & 511)]) + ((0.000756370369f * fVec36[((IOTA - 245) & 511)]) + ((0.00379369268f * fVec36[((IOTA - 244) & 511)]) + ((0.00981585495f * fVec36[((IOTA - 243) & 511)]) + ((0.0150324591f * fVec36[((IOTA - 242) & 511)]) + ((0.0173690598f * fVec36[((IOTA - 241) & 511)]) + ((0.0164867565f * fVec36[((IOTA - 240) & 511)]) + ((0.0134308655f * fVec36[((IOTA - 239) & 511)]) + ((0.0108317938f * fVec36[((IOTA - 238) & 511)]) + ((0.00950688682f * fVec36[((IOTA - 237) & 511)]) + ((0.00935275946f * fVec36[((IOTA - 236) & 511)]) + ((0.0100301672f * fVec36[((IOTA - 235) & 511)]) + ((0.0101659652f * fVec36[((IOTA - 234) & 511)]) + ((0.00949472934f * fVec36[((IOTA - 233) & 511)]) + ((0.00846808124f * fVec36[((IOTA - 232) & 511)]) + ((0.00724650593f * fVec36[((IOTA - 231) & 511)]) + ((0.00722184684f * fVec36[((IOTA - 230) & 511)]) + ((0.00896274578f * fVec36[((IOTA - 229) & 511)]) + ((0.0112358648f * fVec36[((IOTA - 228) & 511)]) + ((0.0128342938f * fVec36[((IOTA - 227) & 511)]) + ((0.0124276644f * fVec36[((IOTA - 226) & 511)]) + ((0.00917631947f * fVec36[((IOTA - 225) & 511)]) + ((0.0049785031f * fVec36[((IOTA - 224) & 511)]) + ((0.00202591904f * fVec36[((IOTA - 223) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0598089211f * fVec36[((IOTA - 11) & 511)]) + ((0.0442371219f * fVec36[((IOTA - 5) & 511)]) + ((0.15629153f * fVec36[((IOTA - 4) & 511)]) + ((0.205787316f * fVec36[((IOTA - 3) & 511)]) + ((0.213716194f * fVec36[((IOTA - 2) & 511)]) + ((0.19912003f * fVec36[((IOTA - 1) & 511)]) + ((fSlow114 * fTemp0) + ((0.112545565f * fVec36[((IOTA - 12) & 511)]) + ((0.120969944f * fVec36[((IOTA - 13) & 511)]) + ((0.0897198468f * fVec36[((IOTA - 14) & 511)]) + (0.0411063321f * fVec36[((IOTA - 15) & 511)]))))))))))) + (0.0320297815f * fVec36[((IOTA - 21) & 511)])) + (0.0691740513f * fVec36[((IOTA - 22) & 511)])) + (0.0815215632f * fVec36[((IOTA - 23) & 511)])) + (0.0642294884f * fVec36[((IOTA - 24) & 511)])) + (0.0160264559f * fVec36[((IOTA - 25) & 511)])) + (0.00176128559f * fVec36[((IOTA - 31) & 511)])) + (0.00173259107f * fVec36[((IOTA - 37) & 511)])) + (0.00996059366f * fVec36[((IOTA - 43) & 511)])) + (0.0172555745f * fVec36[((IOTA - 44) & 511)])) + (0.0146592185f * fVec36[((IOTA - 45) & 511)])) + (0.0281741917f * fVec36[((IOTA - 54) & 511)])) + (0.0566175766f * fVec36[((IOTA - 55) & 511)])) + (0.0666113198f * fVec36[((IOTA - 56) & 511)])) + (0.0453018509f * fVec36[((IOTA - 57) & 511)])) + (0.00584522076f * fVec36[((IOTA - 58) & 511)])) + (0.00865586195f * fVec36[((IOTA - 73) & 511)])) + (0.0248660892f * fVec36[((IOTA - 74) & 511)])) + (0.0297748875f * fVec36[((IOTA - 75) & 511)])) + (0.0200028121f * fVec36[((IOTA - 76) & 511)])) + (0.00345225958f * fVec36[((IOTA - 87) & 511)])) + (0.00292534009f * fVec36[((IOTA - 88) & 511)])) + (0.00666496716f * fVec36[((IOTA - 101) & 511)])) + (0.00845212489f * fVec36[((IOTA - 102) & 511)])) + (0.00359818479f * fVec36[((IOTA - 103) & 511)])) + (0.0122924205f * fVec36[((IOTA - 128) & 511)])) + (0.0200293716f * fVec36[((IOTA - 129) & 511)])) + (0.0199518856f * fVec36[((IOTA - 130) & 511)])) + (0.011987119f * fVec36[((IOTA - 131) & 511)])) + (0.00172905717f * fVec36[((IOTA - 137) & 511)])) + (0.00305124791f * fVec36[((IOTA - 138) & 511)])) + (0.00154130301f * fVec36[((IOTA - 139) & 511)])) + (0.00393233914f * fVec36[((IOTA - 147) & 511)])) + (0.00923943147f * fVec36[((IOTA - 148) & 511)])) + (0.00933933537f * fVec36[((IOTA - 149) & 511)])) + (0.00475648977f * fVec36[((IOTA - 150) & 511)])) + (0.00411255052f * fVec36[((IOTA - 155) & 511)])) + (0.00946418755f * fVec36[((IOTA - 156) & 511)])) + (0.00913235545f * fVec36[((IOTA - 157) & 511)])) + (0.00358787272f * fVec36[((IOTA - 158) & 511)])) + (0.00144720171f * fVec36[((IOTA - 165) & 511)])) + (0.0022113258f * fVec36[((IOTA - 166) & 511)])) + (0.00188015169f * fVec36[((IOTA - 167) & 511)])) + (0.00363062462f * fVec36[((IOTA - 168) & 511)])) + (0.00684378017f * fVec36[((IOTA - 169) & 511)])) + (0.00936394185f * fVec36[((IOTA - 170) & 511)])) + (0.0108920056f * fVec36[((IOTA - 171) & 511)])) + (0.00982263312f * fVec36[((IOTA - 172) & 511)])) + (0.00503520668f * fVec36[((IOTA - 173) & 511)])) + (0.000362980645f * fVec36[((IOTA - 178) & 511)])) + (0.00276606949f * fVec36[((IOTA - 179) & 511)])) + (0.00525708823f * fVec36[((IOTA - 180) & 511)])) + (0.00799488463f * fVec36[((IOTA - 181) & 511)])) + (0.00912866183f * fVec36[((IOTA - 182) & 511)])) + (0.00891886f * fVec36[((IOTA - 183) & 511)])) + (0.00791423395f * fVec36[((IOTA - 184) & 511)])) + (0.00614472013f * fVec36[((IOTA - 185) & 511)])) + (0.00413657678f * fVec36[((IOTA - 186) & 511)])) + (0.00292560365f * fVec36[((IOTA - 187) & 511)])) + (0.0031415252f * fVec36[((IOTA - 188) & 511)])) + (0.00604964327f * fVec36[((IOTA - 189) & 511)])) + (0.0107773328f * fVec36[((IOTA - 190) & 511)])) + (0.0136766946f * fVec36[((IOTA - 191) & 511)])) + (0.0136214942f * fVec36[((IOTA - 192) & 511)])) + (0.010422634f * fVec36[((IOTA - 193) & 511)])) + (0.00502608111f * fVec36[((IOTA - 194) & 511)])) + (0.00141782174f * fVec36[((IOTA - 195) & 511)])) + (0.000955781434f * fVec36[((IOTA - 196) & 511)])) + (0.00399418548f * fVec36[((IOTA - 197) & 511)])) + (0.00945015717f * fVec36[((IOTA - 198) & 511)])) + (0.0125941616f * fVec36[((IOTA - 199) & 511)])) + (0.0122913923f * fVec36[((IOTA - 200) & 511)])) + (0.00949997734f * fVec36[((IOTA - 201) & 511)])) + (0.00481200637f * fVec36[((IOTA - 202) & 511)])) + (0.00158645492f * fVec36[((IOTA - 203) & 511)])) + (0.00232415227f * fVec36[((IOTA - 204) & 511)])) + (0.00636960845f * fVec36[((IOTA - 205) & 511)])) + (0.0101278815f * fVec36[((IOTA - 206) & 511)])) + (0.0106351264f * fVec36[((IOTA - 207) & 511)])) + (0.00825361069f * fVec36[((IOTA - 208) & 511)])) + (0.0054154885f * fVec36[((IOTA - 209) & 511)])) + (0.00404996565f * fVec36[((IOTA - 210) & 511)])) + (0.00502157118f * fVec36[((IOTA - 211) & 511)])) + (0.00836920645f * fVec36[((IOTA - 212) & 511)])) + (0.0121116554f * fVec36[((IOTA - 213) & 511)])) + (0.0140107172f * fVec36[((IOTA - 214) & 511)])) + (0.0144035798f * fVec36[((IOTA - 215) & 511)])) + (0.0134437364f * fVec36[((IOTA - 216) & 511)])) + (0.0106405327f * fVec36[((IOTA - 217) & 511)])) + (0.00711851474f * fVec36[((IOTA - 218) & 511)])) + (0.00409474829f * fVec36[((IOTA - 219) & 511)])) + (0.00186970783f * fVec36[((IOTA - 220) & 511)])) + (0.000437802635f * fVec36[((IOTA - 221) & 511)])) + (0.0140086338f * fVec36[((IOTA - 272) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.0150911137f * fVec36[((IOTA - 273) & 511)])) + (0.0147282649f * fVec36[((IOTA - 274) & 511)])) + (0.0124666709f * fVec36[((IOTA - 275) & 511)])) + (0.00880774762f * fVec36[((IOTA - 276) & 511)])) + (0.00492707454f * fVec36[((IOTA - 277) & 511)])) + (0.00242859218f * fVec36[((IOTA - 278) & 511)])) + (0.00276163872f * fVec36[((IOTA - 279) & 511)])) + (0.00532336533f * fVec36[((IOTA - 280) & 511)])) + (0.00825258158f * fVec36[((IOTA - 281) & 511)])) + (0.00953465886f * fVec36[((IOTA - 282) & 511)])) + (0.00757615035f * fVec36[((IOTA - 283) & 511)])) + (0.00357961794f * fVec36[((IOTA - 284) & 511)])) + (0.000661293045f * fVec36[((IOTA - 285) & 511)])) + (0.0013981997f * fVec36[((IOTA - 287) & 511)])) + (0.00506980903f * fVec36[((IOTA - 288) & 511)])) + (0.00874521583f * fVec36[((IOTA - 289) & 511)])) + (0.0114772636f * fVec36[((IOTA - 290) & 511)])) + (0.0127946539f * fVec36[((IOTA - 291) & 511)])) + (0.0124706011f * fVec36[((IOTA - 292) & 511)])) + (0.0112314345f * fVec36[((IOTA - 293) & 511)])) + (0.00917721633f * fVec36[((IOTA - 294) & 511)])) + (0.0072564492f * fVec36[((IOTA - 295) & 511)])) + (0.00591039006f * fVec36[((IOTA - 296) & 511)])) + (0.00387816783f * fVec36[((IOTA - 297) & 511)])) + (0.00224139215f * fVec36[((IOTA - 298) & 511)])) + (0.00286992919f * fVec36[((IOTA - 299) & 511)])) + (0.00517169014f * fVec36[((IOTA - 300) & 511)])) + (0.00803750567f * fVec36[((IOTA - 301) & 511)])) + (0.0105486736f * fVec36[((IOTA - 302) & 511)])) + (0.0116883051f * fVec36[((IOTA - 303) & 511)])) + (0.0114662917f * fVec36[((IOTA - 304) & 511)])) + (0.0102760755f * fVec36[((IOTA - 305) & 511)])) + (0.00864594523f * fVec36[((IOTA - 306) & 511)])) + (0.00762910908f * fVec36[((IOTA - 307) & 511)])) + (0.00732517894f * fVec36[((IOTA - 308) & 511)])) + (0.00646508113f * fVec36[((IOTA - 309) & 511)])) + (0.00496162428f * fVec36[((IOTA - 310) & 511)])) + (0.0034011472f * fVec36[((IOTA - 311) & 511)])) + (0.00330224587f * fVec36[((IOTA - 312) & 511)])) + (0.00560324267f * fVec36[((IOTA - 313) & 511)])) + (0.00878973491f * fVec36[((IOTA - 314) & 511)])) + (0.0115521904f * fVec36[((IOTA - 315) & 511)])) + (0.0130033223f * fVec36[((IOTA - 316) & 511)])) + (0.0116823185f * fVec36[((IOTA - 317) & 511)])) + (0.00829710066f * fVec36[((IOTA - 318) & 511)])) + (0.00455375528f * fVec36[((IOTA - 319) & 511)])) + (0.00111252023f * fVec36[((IOTA - 320) & 511)])) + (0.000417600386f * fVec36[((IOTA - 323) & 511)])) + (0.000600000843f * fVec36[((IOTA - 324) & 511)])) + (0.000762594398f * fVec36[((IOTA - 325) & 511)])) + (0.00118101249f * fVec36[((IOTA - 326) & 511)])) + (0.00160686811f * fVec36[((IOTA - 327) & 511)])) + (0.00198609475f * fVec36[((IOTA - 328) & 511)])) + (0.00248711556f * fVec36[((IOTA - 329) & 511)])) + (0.00210788846f * fVec36[((IOTA - 330) & 511)])) + (0.000653645024f * fVec36[((IOTA - 331) & 511)])) + (0.000272439793f * fVec36[((IOTA - 332) & 511)])) + (0.00174517138f * fVec36[((IOTA - 333) & 511)])) + (0.00395095907f * fVec36[((IOTA - 334) & 511)])) + (0.00667562196f * fVec36[((IOTA - 335) & 511)])) + (0.00917093921f * fVec36[((IOTA - 336) & 511)])) + (0.00962443464f * fVec36[((IOTA - 337) & 511)])) + (0.008353699f * fVec36[((IOTA - 338) & 511)])) + (0.00627740612f * fVec36[((IOTA - 339) & 511)])) + (0.00439793989f * fVec36[((IOTA - 340) & 511)])) + (0.00321605708f * fVec36[((IOTA - 341) & 511)])) + (0.00284234202f * fVec36[((IOTA - 342) & 511)])) + (0.00319084385f * fVec36[((IOTA - 343) & 511)])) + (0.0033976133f * fVec36[((IOTA - 344) & 511)])) + (0.00340127898f * fVec36[((IOTA - 345) & 511)])) + (0.00332687888f * fVec36[((IOTA - 346) & 511)])) + (0.0029814369f * fVec36[((IOTA - 347) & 511)])) + (0.00312430318f * fVec36[((IOTA - 348) & 511)])) + (0.00470326748f * fVec36[((IOTA - 349) & 511)])) + (0.006323718f * fVec36[((IOTA - 350) & 511)])) + (0.00662727887f * fVec36[((IOTA - 351) & 511)])) + (0.00543191936f * fVec36[((IOTA - 352) & 511)])) + (0.00212605996f * fVec36[((IOTA - 353) & 511)])) + (0.000392782968f * fVec36[((IOTA - 361) & 511)])) + (0.000248492695f * fVec36[((IOTA - 362) & 511)])) + (0.000424958766f * fVec36[((IOTA - 363) & 511)])) + (0.00169740897f * fVec36[((IOTA - 364) & 511)])) + (0.00301461481f * fVec36[((IOTA - 365) & 511)])) + (0.00336264167f * fVec36[((IOTA - 366) & 511)])) + (0.00239855237f * fVec36[((IOTA - 367) & 511)])) + (0.00040560076f * fVec36[((IOTA - 368) & 511)])) + (0.000872229692f * fVec36[((IOTA - 386) & 511)])) + (0.00181661779f * fVec36[((IOTA - 387) & 511)])) + (0.00119525427f * fVec36[((IOTA - 388) & 511)])) + (1.79340132e-05f * fVec36[((IOTA - 389) & 511)])) - (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00380123593f * fVec36[((IOTA - 397) & 511)]) + ((0.00260387175f * fVec36[((IOTA - 396) & 511)]) + ((0.00244272826f * fVec36[((IOTA - 395) & 511)]) + ((0.00271126488f * fVec36[((IOTA - 394) & 511)]) + ((0.00312264124f * fVec36[((IOTA - 393) & 511)]) + ((0.00353269931f * fVec36[((IOTA - 392) & 511)]) + ((0.00303217955f * fVec36[((IOTA - 391) & 511)]) + ((0.00152867008f * fVec36[((IOTA - 390) & 511)]) + ((0.00137026981f * fVec36[((IOTA - 385) & 511)]) + ((0.00372198271f * fVec36[((IOTA - 384) & 511)]) + ((0.00562236318f * fVec36[((IOTA - 383) & 511)]) + ((0.00600214396f * fVec36[((IOTA - 382) & 511)]) + ((0.00426227367f * fVec36[((IOTA - 381) & 511)]) + ((0.00224112812f * fVec36[((IOTA - 380) & 511)]) + ((0.000747851562f * fVec36[((IOTA - 379) & 511)]) + ((0.000350532122f * fVec36[((IOTA - 378) & 511)]) + ((0.00240799412f * fVec36[((IOTA - 377) & 511)]) + ((0.00596057903f * fVec36[((IOTA - 376) & 511)]) + ((0.00906370394f * fVec36[((IOTA - 375) & 511)]) + ((0.0110515654f * fVec36[((IOTA - 374) & 511)]) + ((0.0111478297f * fVec36[((IOTA - 373) & 511)]) + ((0.00996797718f * fVec36[((IOTA - 372) & 511)]) + ((0.00812179502f * fVec36[((IOTA - 371) & 511)]) + ((0.0052387584f * fVec36[((IOTA - 370) & 511)]) + ((0.00210860046f * fVec36[((IOTA - 369) & 511)]) + ((((((((((((((0.00314094499f * fVec36[((IOTA - 177) & 511)]) + ((0.00443905639f * fVec36[((IOTA - 176) & 511)]) + ((0.00285373582f * fVec36[((IOTA - 175) & 511)]) + ((6.95735216e-05f * fVec36[((IOTA - 174) & 511)]) + ((0.0010379618f * fVec36[((IOTA - 164) & 511)]) + ((0.00411334168f * fVec36[((IOTA - 163) & 511)]) + ((0.00806443207f * fVec36[((IOTA - 162) & 511)]) + ((0.011477448f * fVec36[((IOTA - 161) & 511)]) + ((0.0101331035f * fVec36[((IOTA - 160) & 511)]) + ((0.00385696348f * fVec36[((IOTA - 159) & 511)]) + ((0.00285515981f * fVec36[((IOTA - 154) & 511)]) + ((0.00765334629f * fVec36[((IOTA - 153) & 511)]) + ((0.00753727555f * fVec36[((IOTA - 152) & 511)]) + ((0.00214011688f * fVec36[((IOTA - 151) & 511)]) + ((0.00482732942f * fVec36[((IOTA - 146) & 511)]) + ((0.0129446937f * fVec36[((IOTA - 145) & 511)]) + ((0.0176740717f * fVec36[((IOTA - 144) & 511)]) + ((0.0184141695f * fVec36[((IOTA - 143) & 511)]) + ((0.0155150704f * fVec36[((IOTA - 142) & 511)]) + ((0.00917711109f * fVec36[((IOTA - 141) & 511)]) + ((0.00228984049f * fVec36[((IOTA - 140) & 511)]) + ((0.0039231875f * fVec36[((IOTA - 136) & 511)]) + ((0.0100145005f * fVec36[((IOTA - 135) & 511)]) + ((0.0131969582f * fVec36[((IOTA - 134) & 511)]) + ((0.0110785197f * fVec36[((IOTA - 133) & 511)]) + ((0.001158542f * fVec36[((IOTA - 132) & 511)]) + ((0.000818453729f * fVec36[((IOTA - 127) & 511)]) + ((0.0143493023f * fVec36[((IOTA - 126) & 511)]) + ((0.0223887861f * fVec36[((IOTA - 125) & 511)]) + ((0.0229659192f * fVec36[((IOTA - 124) & 511)]) + ((0.0195737146f * fVec36[((IOTA - 123) & 511)]) + ((0.016035635f * fVec36[((IOTA - 122) & 511)]) + ((0.0151345786f * fVec36[((IOTA - 121) & 511)]) + ((0.0181527268f * fVec36[((IOTA - 120) & 511)]) + ((0.0213410389f * fVec36[((IOTA - 119) & 511)]) + ((0.0203762371f * fVec36[((IOTA - 118) & 511)]) + ((0.0149152279f * fVec36[((IOTA - 117) & 511)]) + ((0.00958279055f * fVec36[((IOTA - 116) & 511)]) + ((0.00615089154f * fVec36[((IOTA - 115) & 511)]) + ((0.0044241026f * fVec36[((IOTA - 114) & 511)]) + ((0.0054617743f * fVec36[((IOTA - 113) & 511)]) + ((0.00747490209f * fVec36[((IOTA - 112) & 511)]) + ((0.00720718317f * fVec36[((IOTA - 111) & 511)]) + ((0.00669759093f * fVec36[((IOTA - 110) & 511)]) + ((0.0107156187f * fVec36[((IOTA - 109) & 511)]) + ((0.016279459f * fVec36[((IOTA - 108) & 511)]) + ((0.0194021799f * fVec36[((IOTA - 107) & 511)]) + ((0.0187563673f * fVec36[((IOTA - 106) & 511)]) + ((0.0126041304f * fVec36[((IOTA - 105) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0211058389f * fVec36[((IOTA - 10) & 511)]) + ((0.104717858f * fVec36[((IOTA - 9) & 511)]) + ((0.172695711f * fVec36[((IOTA - 8) & 511)]) + ((0.169511557f * fVec36[((IOTA - 7) & 511)]) + ((0.0790361911f * fVec36[((IOTA - 6) & 511)]) + (((((0.00548063125f * fVec36[((IOTA - 16) & 511)]) + (0.0571300983f * fVec36[((IOTA - 17) & 511)])) + (0.0813398212f * fVec36[((IOTA - 18) & 511)])) + (0.0724401921f * fVec36[((IOTA - 19) & 511)])) + (0.0283663236f * fVec36[((IOTA - 20) & 511)]))))))) + (0.0341765732f * fVec36[((IOTA - 26) & 511)])) + (0.0587594099f * fVec36[((IOTA - 27) & 511)])) + (0.0506727174f * fVec36[((IOTA - 28) & 511)])) + (0.0306102205f * fVec36[((IOTA - 29) & 511)])) + (0.0122714266f * fVec36[((IOTA - 30) & 511)])) + (0.00866875798f * fVec36[((IOTA - 32) & 511)])) + (0.0222048014f * fVec36[((IOTA - 33) & 511)])) + (0.0246953201f * fVec36[((IOTA - 34) & 511)])) + (0.0218268409f * fVec36[((IOTA - 35) & 511)])) + (0.00797731988f * fVec36[((IOTA - 36) & 511)])) + (0.00421480089f * fVec36[((IOTA - 38) & 511)])) + (0.0117259137f * fVec36[((IOTA - 39) & 511)])) + (0.0134425499f * fVec36[((IOTA - 40) & 511)])) + (0.0122780725f * fVec36[((IOTA - 41) & 511)])) + (0.00546815665f * fVec36[((IOTA - 42) & 511)])) + (0.00229445565f * fVec36[((IOTA - 46) & 511)])) + (0.0211514384f * fVec36[((IOTA - 47) & 511)])) + (0.0372610502f * fVec36[((IOTA - 48) & 511)])) + (0.0597119704f * fVec36[((IOTA - 49) & 511)])) + (0.072416082f * fVec36[((IOTA - 50) & 511)])) + (0.0641264468f * fVec36[((IOTA - 51) & 511)])) + (0.0442169979f * fVec36[((IOTA - 52) & 511)])) + (0.0101279598f * fVec36[((IOTA - 53) & 511)])) + (0.0294956956f * fVec36[((IOTA - 59) & 511)])) + (0.0574233457f * fVec36[((IOTA - 60) & 511)])) + (0.0707229525f * fVec36[((IOTA - 61) & 511)])) + (0.0592831373f * fVec36[((IOTA - 62) & 511)])) + (0.0358052514f * fVec36[((IOTA - 63) & 511)])) + (0.0195612386f * fVec36[((IOTA - 64) & 511)])) + (0.00806403719f * fVec36[((IOTA - 65) & 511)])) + (0.00508634513f * fVec36[((IOTA - 66) & 511)])) + (0.0165591519f * fVec36[((IOTA - 67) & 511)])) + (0.029966386f * fVec36[((IOTA - 68) & 511)])) + (0.0350144617f * fVec36[((IOTA - 69) & 511)])) + (0.0367300175f * fVec36[((IOTA - 70) & 511)])) + (0.0323095024f * fVec36[((IOTA - 71) & 511)])) + (0.0142230783f * fVec36[((IOTA - 72) & 511)])) + (0.00257989764f * fVec36[((IOTA - 77) & 511)])) + (0.0235478282f * fVec36[((IOTA - 78) & 511)])) + (0.0359903425f * fVec36[((IOTA - 79) & 511)])) + (0.0417710543f * fVec36[((IOTA - 80) & 511)])) + (0.0373217352f * fVec36[((IOTA - 81) & 511)])) + (0.0290343147f * fVec36[((IOTA - 82) & 511)])) + (0.0216778573f * fVec36[((IOTA - 83) & 511)])) + (0.0134449759f * fVec36[((IOTA - 84) & 511)])) + (0.00548361149f * fVec36[((IOTA - 85) & 511)])) + (0.00040974142f * fVec36[((IOTA - 86) & 511)])) + (0.00565166445f * fVec36[((IOTA - 89) & 511)])) + (0.017380638f * fVec36[((IOTA - 90) & 511)])) + (0.0281514041f * fVec36[((IOTA - 91) & 511)])) + (0.0376671515f * fVec36[((IOTA - 92) & 511)])) + (0.0384699926f * fVec36[((IOTA - 93) & 511)])) + (0.0284977425f * fVec36[((IOTA - 94) & 511)])) + (0.0189318042f * fVec36[((IOTA - 95) & 511)])) + (0.0125075243f * fVec36[((IOTA - 96) & 511)])) + (0.00887315441f * fVec36[((IOTA - 97) & 511)])) + (0.00800981279f * fVec36[((IOTA - 98) & 511)])) + (0.0059054317f * fVec36[((IOTA - 99) & 511)])) + (0.00362347718f * fVec36[((IOTA - 104) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000451569911f * (fVec36[((IOTA - 100) & 511)] - fVec36[((IOTA - 222) & 511)]))) + (0.000156844035f * fVec36[((IOTA - 286) & 511)])) + (0.000506137032f * fVec36[((IOTA - 321) & 511)])) + (0.000132580288f * fVec36[((IOTA - 322) & 511)])) + (0.00289704092f * fVec36[((IOTA - 354) & 511)])) + (0.0070978906f * fVec36[((IOTA - 355) & 511)])) + (0.00874173455f * fVec36[((IOTA - 356) & 511)])) + (0.00786111783f * fVec36[((IOTA - 357) & 511)])) + (0.00515336078f * fVec36[((IOTA - 358) & 511)])) + (0.00240269303f * fVec36[((IOTA - 359) & 511)])) + (0.000512809493f * fVec36[((IOTA - 360) & 511)])) + (0.00581101421f * fVec36[((IOTA - 398) & 511)]))))))))))))))))))))))))))) + (0.00721435668f * fVec36[((IOTA - 399) & 511)])) + (0.00789028779f * fVec36[((IOTA - 400) & 511)])) + (0.0086606089f * fVec36[((IOTA - 401) & 511)])) + (0.00913153775f * fVec36[((IOTA - 402) & 511)])) + (0.00949657522f * fVec36[((IOTA - 403) & 511)])) + (0.00994970091f * fVec36[((IOTA - 404) & 511)])) + (0.00943623204f * fVec36[((IOTA - 405) & 511)])) + (0.00817272253f * fVec36[((IOTA - 406) & 511)])) + (0.0068692835f * fVec36[((IOTA - 407) & 511)])) + (0.00467130262f * fVec36[((IOTA - 408) & 511)])) + (0.00226006471f * fVec36[((IOTA - 409) & 511)])) + (0.00120907417f * fVec36[((IOTA - 410) & 511)])) + (0.00091848895f * fVec36[((IOTA - 411) & 511)])) + (0.00110165402f * fVec36[((IOTA - 412) & 511)])) + (0.00238328241f * fVec36[((IOTA - 413) & 511)])) + (0.00378319621f * fVec36[((IOTA - 414) & 511)])) + (0.00490766345f * fVec36[((IOTA - 415) & 511)])) + (0.00519803772f * fVec36[((IOTA - 416) & 511)])) + (0.00412304699f * fVec36[((IOTA - 417) & 511)])) + (0.00287525635f * fVec36[((IOTA - 418) & 511)])) + (0.00163345272f * fVec36[((IOTA - 419) & 511)])) + (0.000507218298f * fVec36[((IOTA - 420) & 511)])) + (0.00074160099f * fVec36[((IOTA - 421) & 511)])) + (0.00213853456f * fVec36[((IOTA - 422) & 511)])) + (0.00424642302f * fVec36[((IOTA - 423) & 511)])) + (0.00618174858f * fVec36[((IOTA - 424) & 511)])) + (0.0068349978f * fVec36[((IOTA - 425) & 511)])) + (0.00665771402f * fVec36[((IOTA - 426) & 511)])) + (0.00604463229f * fVec36[((IOTA - 427) & 511)])) + (0.00500313612f * fVec36[((IOTA - 428) & 511)])) + (0.00404777657f * fVec36[((IOTA - 429) & 511)])) + (0.00390667748f * fVec36[((IOTA - 430) & 511)])) + (0.00434711762f * fVec36[((IOTA - 431) & 511)])) + (0.00525423978f * fVec36[((IOTA - 432) & 511)])) + (0.0070295562f * fVec36[((IOTA - 433) & 511)])) + (0.00861028768f * fVec36[((IOTA - 434) & 511)])) + (0.00923911482f * fVec36[((IOTA - 435) & 511)])) + (0.00881178305f * fVec36[((IOTA - 436) & 511)])) + (0.00737465592f * fVec36[((IOTA - 437) & 511)])) + (0.00591613958f * fVec36[((IOTA - 438) & 511)])) + (0.00507685076f * fVec36[((IOTA - 439) & 511)])) + (0.00527823996f * fVec36[((IOTA - 440) & 511)])) + (0.00700389501f * fVec36[((IOTA - 441) & 511)])) + (0.00932314247f * fVec36[((IOTA - 442) & 511)])) + (0.0104869064f * fVec36[((IOTA - 443) & 511)])) + (0.0102782641f * fVec36[((IOTA - 444) & 511)])) + (0.00914058276f * fVec36[((IOTA - 445) & 511)])) + (0.00766376406f * fVec36[((IOTA - 446) & 511)])) + (0.00691654533f * fVec36[((IOTA - 447) & 511)])) + (0.00720180292f * fVec36[((IOTA - 448) & 511)])) + (0.00809650309f * fVec36[((IOTA - 449) & 511)])) + (0.008924108f * fVec36[((IOTA - 450) & 511)])) + (0.00896076765f * fVec36[((IOTA - 451) & 511)])) + (0.00840810779f * fVec36[((IOTA - 452) & 511)])) + (0.00772096822f * fVec36[((IOTA - 453) & 511)])) + (0.00709488383f * fVec36[((IOTA - 454) & 511)])) + (0.00664165244f * fVec36[((IOTA - 455) & 511)])) + (0.00625920808f * fVec36[((IOTA - 456) & 511)])) + (0.00605589384f * fVec36[((IOTA - 457) & 511)])) + (0.00636797305f * fVec36[((IOTA - 458) & 511)])) + (0.00667192973f * fVec36[((IOTA - 459) & 511)])) + (0.00629188493f * fVec36[((IOTA - 460) & 511)])) + (0.00535295624f * fVec36[((IOTA - 461) & 511)])) + (0.00410743384f * fVec36[((IOTA - 462) & 511)])) + (0.00278352899f * fVec36[((IOTA - 463) & 511)])) + (0.00213070167f * fVec36[((IOTA - 464) & 511)])) + (0.00274932245f * fVec36[((IOTA - 465) & 511)])) + (0.00457139919f * fVec36[((IOTA - 466) & 511)])) + (0.0064400523f * fVec36[((IOTA - 467) & 511)])) + (0.0073970207f * fVec36[((IOTA - 468) & 511)])) + (0.00747798756f * fVec36[((IOTA - 469) & 511)])) + (0.00657664146f * fVec36[((IOTA - 470) & 511)])) + (0.00533177843f * fVec36[((IOTA - 471) & 511)])) + (0.00502616027f * fVec36[((IOTA - 472) & 511)])) + (0.0054203677f * fVec36[((IOTA - 473) & 511)])) + (0.0058219065f * fVec36[((IOTA - 474) & 511)])) + (0.00578659214f * fVec36[((IOTA - 475) & 511)])) + (0.00518574752f * fVec36[((IOTA - 476) & 511)])) + (0.0051810001f * fVec36[((IOTA - 477) & 511)])) + (0.00592544954f * fVec36[((IOTA - 478) & 511)])) + (0.0064385226f * fVec36[((IOTA - 479) & 511)])) + (0.00696027279f * fVec36[((IOTA - 480) & 511)])) + (0.00711358292f * fVec36[((IOTA - 481) & 511)])) + (0.00659713382f * fVec36[((IOTA - 482) & 511)])) + (0.00580618763f * fVec36[((IOTA - 483) & 511)])) + (0.00463720178f * fVec36[((IOTA - 484) & 511)])) + (0.00345909037f * fVec36[((IOTA - 485) & 511)])) + (0.00277838623f * fVec36[((IOTA - 486) & 511)])) + (0.00221739197f * fVec36[((IOTA - 487) & 511)])) + (0.00229100091f * fVec36[((IOTA - 488) & 511)])) + (0.00314938417f * fVec36[((IOTA - 489) & 511)])) + (0.00364444451f * fVec36[((IOTA - 490) & 511)])) + (0.0037654466f * fVec36[((IOTA - 491) & 511)])) + (0.00374516519f * fVec36[((IOTA - 492) & 511)])) + (0.00349501101f * fVec36[((IOTA - 493) & 511)])) + (0.00323185464f * fVec36[((IOTA - 494) & 511)])) + (0.0035333056f * fVec36[((IOTA - 495) & 511)])) + (0.00421108259f * fVec36[((IOTA - 496) & 511)])) + (0.00502486806f * fVec36[((IOTA - 497) & 511)])) + (0.00578152854f * fVec36[((IOTA - 498) & 511)])) + (0.00576071953f * fVec36[((IOTA - 499) & 511)])) + (0.00483001955f * fVec36[((IOTA - 500) & 511)])) + (0.00361279584f * fVec36[((IOTA - 501) & 511)])) + (0.00285072904f * fVec36[((IOTA - 502) & 511)])) + (0.00322818896f * fVec36[((IOTA - 503) & 511)])) + (0.00456388295f * fVec36[((IOTA - 504) & 511)])) + (0.00639869832f * fVec36[((IOTA - 505) & 511)])) + (0.00818772987f * fVec36[((IOTA - 506) & 511)])) + (0.00914625358f * fVec36[((IOTA - 507) & 511)])) + (0.00909738336f * fVec36[((IOTA - 508) & 511)])) + (0.00823683664f * fVec36[((IOTA - 509) & 511)])) + (0.00668959972f * fVec36[((IOTA - 510) & 511)])) + (0.00519096944f * fVec36[((IOTA - 511) & 511)]))) : (((((((((((((((((((((((((((((((((((((((((((((((((((((0.0048037665f * fVec35[((IOTA - 306) & 511)]) + ((0.00444108527f * fVec35[((IOTA - 305) & 511)]) + ((0.00407122076f * fVec35[((IOTA - 304) & 511)]) + ((0.00406831456f * fVec35[((IOTA - 303) & 511)]) + ((0.0038799867f * fVec35[((IOTA - 302) & 511)]) + ((0.00375271542f * fVec35[((IOTA - 301) & 511)]) + ((0.00394705078f * fVec35[((IOTA - 300) & 511)]) + ((0.00409675343f * fVec35[((IOTA - 299) & 511)]) + ((0.00436507491f * fVec35[((IOTA - 298) & 511)]) + ((0.0047639003f * fVec35[((IOTA - 297) & 511)]) + ((0.00497815292f * fVec35[((IOTA - 296) & 511)]) + ((0.00491912104f * fVec35[((IOTA - 295) & 511)]) + ((0.00426314026f * fVec35[((IOTA - 294) & 511)]) + ((0.00320209749f * fVec35[((IOTA - 293) & 511)]) + ((0.00223659026f * fVec35[((IOTA - 292) & 511)]) + ((0.00138356397f * fVec35[((IOTA - 291) & 511)]) + ((0.00108820759f * fVec35[((IOTA - 290) & 511)]) + ((0.00140573364f * fVec35[((IOTA - 289) & 511)]) + ((0.00161557831f * fVec35[((IOTA - 288) & 511)]) + ((0.00206817919f * fVec35[((IOTA - 287) & 511)]) + ((0.00291421823f * fVec35[((IOTA - 286) & 511)]) + ((0.00365159661f * fVec35[((IOTA - 285) & 511)]) + ((0.00432151929f * fVec35[((IOTA - 284) & 511)]) + ((0.00449476251f * fVec35[((IOTA - 283) & 511)]) + ((0.00392298726f * fVec35[((IOTA - 282) & 511)]) + ((0.00312517304f * fVec35[((IOTA - 281) & 511)]) + ((0.00221422454f * fVec35[((IOTA - 280) & 511)]) + ((((((((((((((((((((((((((((((0.00338853197f * fVec35[((IOTA - 251) & 511)]) + ((0.00369991921f * fVec35[((IOTA - 250) & 511)]) + ((0.00465125637f * fVec35[((IOTA - 249) & 511)]) + ((0.0051854183f * fVec35[((IOTA - 248) & 511)]) + ((0.00500202039f * fVec35[((IOTA - 247) & 511)]) + ((0.00406766171f * fVec35[((IOTA - 246) & 511)]) + ((0.00304224063f * fVec35[((IOTA - 245) & 511)]) + ((0.0027159648f * fVec35[((IOTA - 244) & 511)]) + ((0.00268631801f * fVec35[((IOTA - 243) & 511)]) + ((0.00297694001f * fVec35[((IOTA - 242) & 511)]) + ((0.00331807183f * fVec35[((IOTA - 241) & 511)]) + ((0.00281205494f * fVec35[((IOTA - 240) & 511)]) + ((0.00224034535f * fVec35[((IOTA - 239) & 511)]) + ((0.00202122796f * fVec35[((IOTA - 238) & 511)]) + ((0.00232654251f * fVec35[((IOTA - 237) & 511)]) + ((0.0039596539f * fVec35[((IOTA - 236) & 511)]) + ((0.00569199026f * fVec35[((IOTA - 235) & 511)]) + ((0.00616196124f * fVec35[((IOTA - 234) & 511)]) + ((0.00621851208f * fVec35[((IOTA - 233) & 511)]) + ((0.0059367707f * fVec35[((IOTA - 232) & 511)]) + ((0.00479968544f * fVec35[((IOTA - 231) & 511)]) + ((0.00410315255f * fVec35[((IOTA - 230) & 511)]) + ((0.00395276444f * fVec35[((IOTA - 229) & 511)]) + ((0.00333687896f * fVec35[((IOTA - 228) & 511)]) + ((0.00230287062f * fVec35[((IOTA - 227) & 511)]) + ((0.00114841526f * fVec35[((IOTA - 226) & 511)]) + ((0.000833272934f * fVec35[((IOTA - 225) & 511)]) + ((0.00230567856f * fVec35[((IOTA - 224) & 511)]) + ((0.00486204773f * fVec35[((IOTA - 223) & 511)]) + ((0.00761307916f * fVec35[((IOTA - 222) & 511)]) + ((0.00981470011f * fVec35[((IOTA - 221) & 511)]) + ((0.00983099267f * fVec35[((IOTA - 220) & 511)]) + ((0.00753680756f * fVec35[((IOTA - 219) & 511)]) + ((0.00407876307f * fVec35[((IOTA - 218) & 511)]) + ((0.000330161769f * fVec35[((IOTA - 217) & 511)]) + ((0.000132658985f * fVec35[((IOTA - 213) & 511)]) + ((0.00264873728f * fVec35[((IOTA - 212) & 511)]) + ((0.00463741273f * fVec35[((IOTA - 211) & 511)]) + ((0.00598502811f * fVec35[((IOTA - 210) & 511)]) + ((0.00576901296f * fVec35[((IOTA - 209) & 511)]) + ((0.00402355101f * fVec35[((IOTA - 208) & 511)]) + ((0.00264854124f * fVec35[((IOTA - 207) & 511)]) + ((0.00227867672f * fVec35[((IOTA - 206) & 511)]) + ((0.00268138759f * fVec35[((IOTA - 205) & 511)]) + ((0.00381622044f * fVec35[((IOTA - 204) & 511)]) + ((0.00504169054f * fVec35[((IOTA - 203) & 511)]) + ((0.00550519675f * fVec35[((IOTA - 202) & 511)]) + ((0.0044198297f * fVec35[((IOTA - 201) & 511)]) + ((0.00252045365f * fVec35[((IOTA - 200) & 511)]) + ((0.00140968431f * fVec35[((IOTA - 199) & 511)]) + ((0.000318472739f * fVec35[((IOTA - 198) & 511)]) + ((0.00137432385f * fVec35[((IOTA - 196) & 511)]) + ((0.00309213065f * fVec35[((IOTA - 195) & 511)]) + ((0.00440627988f * fVec35[((IOTA - 194) & 511)]) + ((0.00563730067f * fVec35[((IOTA - 193) & 511)]) + ((0.00610368f * fVec35[((IOTA - 192) & 511)]) + ((0.00567540387f * fVec35[((IOTA - 191) & 511)]) + ((0.00472599315f * fVec35[((IOTA - 190) & 511)]) + ((0.00282531092f * fVec35[((IOTA - 189) & 511)]) + ((0.000494360924f * fVec35[((IOTA - 188) & 511)]) + ((0.00102816336f * fVec35[((IOTA - 185) & 511)]) + ((0.00399560202f * fVec35[((IOTA - 184) & 511)]) + ((0.00552335056f * fVec35[((IOTA - 183) & 511)]) + ((0.00534788705f * fVec35[((IOTA - 182) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((0.00120761059f * fVec35[((IOTA - 45) & 511)]) + ((0.0154045932f * fVec35[((IOTA - 39) & 511)]) + ((0.032147985f * fVec35[((IOTA - 38) & 511)]) + ((0.0404803865f * fVec35[((IOTA - 37) & 511)]) + ((0.0146072684f * fVec35[((IOTA - 36) & 511)]) + ((0.0227517337f * fVec35[((IOTA - 31) & 511)]) + ((0.0152710192f * fVec35[((IOTA - 30) & 511)]) + ((0.0394863784f * fVec35[((IOTA - 24) & 511)]) + ((0.0677925795f * fVec35[((IOTA - 23) & 511)]) + ((0.0515356436f * fVec35[((IOTA - 22) & 511)]) + ((0.011295693f * fVec35[((IOTA - 21) & 511)]) + ((0.030989971f * fVec35[((IOTA - 13) & 511)]) + ((0.114462383f * fVec35[((IOTA - 12) & 511)]) + ((0.151498601f * fVec35[((IOTA - 11) & 511)]) + ((0.141660333f * fVec35[((IOTA - 10) & 511)]) + ((0.0156334396f * fVec35[((IOTA - 9) & 511)]) + ((0.0571070239f * fVec35[((IOTA - 4) & 511)]) + ((0.155267745f * fVec35[((IOTA - 3) & 511)]) + ((0.213068038f * fVec35[((IOTA - 2) & 511)]) + ((0.229848489f * fVec35[((IOTA - 1) & 511)]) + ((fSlow112 * fTemp0) + ((0.0182288922f * fVec35[((IOTA - 46) & 511)]) + (0.0189724416f * fVec35[((IOTA - 47) & 511)]))))))))))))))))))))))) + (0.0084957853f * fVec35[((IOTA - 48) & 511)])) + (0.00294246105f * fVec35[((IOTA - 49) & 511)])) + (0.00934881158f * fVec35[((IOTA - 61) & 511)])) + (0.0173349213f * fVec35[((IOTA - 62) & 511)])) + (0.0209335275f * fVec35[((IOTA - 63) & 511)])) + (0.0126596345f * fVec35[((IOTA - 64) & 511)])) + (0.00317121018f * fVec35[((IOTA - 72) & 511)])) + (0.00769241946f * fVec35[((IOTA - 73) & 511)])) + (0.00943487789f * fVec35[((IOTA - 74) & 511)])) + (0.00840015151f * fVec35[((IOTA - 75) & 511)])) + (0.00149421627f * fVec35[((IOTA - 76) & 511)])) + (0.0118600577f * fVec35[((IOTA - 94) & 511)])) + (0.0206906069f * fVec35[((IOTA - 95) & 511)])) + (0.0180034079f * fVec35[((IOTA - 96) & 511)])) + (0.00996499136f * fVec35[((IOTA - 97) & 511)])) + (0.0005770321f * fVec35[((IOTA - 98) & 511)])) + (0.00140828034f * fVec35[((IOTA - 106) & 511)])) + (0.0124429008f * fVec35[((IOTA - 107) & 511)])) + (0.0171269067f * fVec35[((IOTA - 108) & 511)])) + (0.0144465957f * fVec35[((IOTA - 109) & 511)])) + (0.00576682528f * fVec35[((IOTA - 110) & 511)])) + (0.00168744195f * fVec35[((IOTA - 121) & 511)])) + (0.00204437692f * fVec35[((IOTA - 122) & 511)])) + (0.00134092243f * fVec35[((IOTA - 128) & 511)])) + (0.00570299337f * fVec35[((IOTA - 129) & 511)])) + (0.00517111737f * fVec35[((IOTA - 130) & 511)])) + (0.000973408576f * fVec35[((IOTA - 131) & 511)])) + (4.26415354e-05f * fVec35[((IOTA - 137) & 511)])) + (0.00055303378f * fVec35[((IOTA - 143) & 511)])) + (0.00277098082f * fVec35[((IOTA - 149) & 511)])) + (0.00453071063f * fVec35[((IOTA - 150) & 511)])) + (0.00294755446f * fVec35[((IOTA - 151) & 511)])) + (0.000127108302f * fVec35[((IOTA - 152) & 511)])) + (0.000264109578f * fVec35[((IOTA - 156) & 511)])) + (0.00047983136f * fVec35[((IOTA - 157) & 511)])) + (0.00227048155f * fVec35[((IOTA - 162) & 511)])) + (0.00317672826f * fVec35[((IOTA - 163) & 511)])) + (0.00210220087f * fVec35[((IOTA - 164) & 511)])) + (0.00139179174f * fVec35[((IOTA - 170) & 511)])) + (0.00351446448f * fVec35[((IOTA - 171) & 511)])) + (0.00417217566f * fVec35[((IOTA - 172) & 511)])) + (0.00349396002f * fVec35[((IOTA - 173) & 511)])) + (0.00211934233f * fVec35[((IOTA - 174) & 511)])) + (0.00116705848f * fVec35[((IOTA - 175) & 511)])) + (0.00121978903f * fVec35[((IOTA - 176) & 511)])) + (0.00131330034f * fVec35[((IOTA - 177) & 511)])) + (0.00117169507f * fVec35[((IOTA - 178) & 511)])) + (0.00105898548f * fVec35[((IOTA - 179) & 511)])) + (0.00168554811f * fVec35[((IOTA - 180) & 511)])) + (0.00361476699f * fVec35[((IOTA - 181) & 511)])) + (0.00385641307f * fVec35[((IOTA - 252) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00475893775f * fVec35[((IOTA - 253) & 511)])) + (0.00601503393f * fVec35[((IOTA - 254) & 511)])) + (0.00649509393f * fVec35[((IOTA - 255) & 511)])) + (0.00627421355f * fVec35[((IOTA - 256) & 511)])) + (0.00655696681f * fVec35[((IOTA - 257) & 511)])) + (0.00681559136f * fVec35[((IOTA - 258) & 511)])) + (0.00679769879f * fVec35[((IOTA - 259) & 511)])) + (0.00668463018f * fVec35[((IOTA - 260) & 511)])) + (0.00576307019f * fVec35[((IOTA - 261) & 511)])) + (0.00444813771f * fVec35[((IOTA - 262) & 511)])) + (0.00353026763f * fVec35[((IOTA - 263) & 511)])) + (0.00324588176f * fVec35[((IOTA - 264) & 511)])) + (0.0042423089f * fVec35[((IOTA - 265) & 511)])) + (0.00576450676f * fVec35[((IOTA - 266) & 511)])) + (0.00689480128f * fVec35[((IOTA - 267) & 511)])) + (0.00769950496f * fVec35[((IOTA - 268) & 511)])) + (0.00732013909f * fVec35[((IOTA - 269) & 511)])) + (0.00583561976f * fVec35[((IOTA - 270) & 511)])) + (0.00461168401f * fVec35[((IOTA - 271) & 511)])) + (0.00381928962f * fVec35[((IOTA - 272) & 511)])) + (0.00349764945f * fVec35[((IOTA - 273) & 511)])) + (0.00356729329f * fVec35[((IOTA - 274) & 511)])) + (0.00321159884f * fVec35[((IOTA - 275) & 511)])) + (0.00269379513f * fVec35[((IOTA - 276) & 511)])) + (0.00216044951f * fVec35[((IOTA - 277) & 511)])) + (0.0014546765f * fVec35[((IOTA - 278) & 511)])) + (0.00139273889f * fVec35[((IOTA - 279) & 511)])) + (0.00492767524f * fVec35[((IOTA - 307) & 511)]))))))))))))))))))))))))))))) + (0.00502996938f * fVec35[((IOTA - 308) & 511)])) + (0.0042918399f * fVec35[((IOTA - 309) & 511)])) + (0.00316660665f * fVec35[((IOTA - 310) & 511)])) + (0.00279919058f * fVec35[((IOTA - 311) & 511)])) + (0.00268070213f * fVec35[((IOTA - 312) & 511)])) + (0.00277182972f * fVec35[((IOTA - 313) & 511)])) + (0.00273434678f * fVec35[((IOTA - 314) & 511)])) + (0.00171046052f * fVec35[((IOTA - 315) & 511)])) + (0.00026153028f * fVec35[((IOTA - 316) & 511)])) + (0.000101477839f * fVec35[((IOTA - 321) & 511)])) + (0.0010974803f * fVec35[((IOTA - 322) & 511)])) + (0.00102212327f * fVec35[((IOTA - 323) & 511)])) + (0.000619510189f * fVec35[((IOTA - 324) & 511)])) + (0.000108334236f * fVec35[((IOTA - 325) & 511)])) + (0.000224896707f * fVec35[((IOTA - 327) & 511)])) + (0.00141624687f * fVec35[((IOTA - 328) & 511)])) + (0.00216841605f * fVec35[((IOTA - 329) & 511)])) + (0.00279501127f * fVec35[((IOTA - 330) & 511)])) + (0.00243889261f * fVec35[((IOTA - 331) & 511)])) + (0.00135120749f * fVec35[((IOTA - 332) & 511)])) + (0.000606254209f * fVec35[((IOTA - 333) & 511)])) + (2.93832272e-06f * fVec35[((IOTA - 334) & 511)])) + (0.000737149734f * fVec35[((IOTA - 336) & 511)])) + (0.0017117667f * fVec35[((IOTA - 337) & 511)])) + (0.00272226613f * fVec35[((IOTA - 338) & 511)])) + (0.00339770643f * fVec35[((IOTA - 339) & 511)])) + (0.00323102577f * fVec35[((IOTA - 340) & 511)])) + (0.00311563909f * fVec35[((IOTA - 341) & 511)])) + (0.0029053702f * fVec35[((IOTA - 342) & 511)])) + (0.00208763871f * fVec35[((IOTA - 343) & 511)])) + (0.00173582975f * fVec35[((IOTA - 344) & 511)])) + (0.00135225197f * fVec35[((IOTA - 345) & 511)])) + (0.000617322512f * fVec35[((IOTA - 346) & 511)])) + (0.000680468511f * fVec35[((IOTA - 347) & 511)])) + (0.00104563171f * fVec35[((IOTA - 348) & 511)])) + (0.00121531589f * fVec35[((IOTA - 349) & 511)])) + (0.00146421045f * fVec35[((IOTA - 350) & 511)])) + (0.00129031437f * fVec35[((IOTA - 351) & 511)])) + (0.00108108995f * fVec35[((IOTA - 352) & 511)])) + (0.00101239327f * fVec35[((IOTA - 353) & 511)])) + (0.000589014497f * fVec35[((IOTA - 354) & 511)])) + (0.000193617307f * fVec35[((IOTA - 355) & 511)])) + (8.40094872e-05f * fVec35[((IOTA - 373) & 511)])) + (7.18636438e-05f * fVec35[((IOTA - 382) & 511)])) + (0.000242658425f * fVec35[((IOTA - 383) & 511)])) + (0.00030319253f * fVec35[((IOTA - 384) & 511)])) + (8.78297724e-05f * fVec35[((IOTA - 389) & 511)])) + (0.000166778453f * fVec35[((IOTA - 390) & 511)])) + (0.000302865636f * fVec35[((IOTA - 400) & 511)])) + (0.000561653636f * fVec35[((IOTA - 401) & 511)])) - ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00174232759f * fVec35[((IOTA - 418) & 511)]) + ((0.00233555399f * fVec35[((IOTA - 417) & 511)]) + ((0.00243121991f * fVec35[((IOTA - 416) & 511)]) + ((0.00206367346f * fVec35[((IOTA - 415) & 511)]) + ((0.00172355352f * fVec35[((IOTA - 414) & 511)]) + ((0.00116487127f * fVec35[((IOTA - 413) & 511)]) + ((0.000900630839f * fVec35[((IOTA - 412) & 511)]) + ((0.00117989024f * fVec35[((IOTA - 411) & 511)]) + ((0.00154345343f * fVec35[((IOTA - 410) & 511)]) + ((0.00237907702f * fVec35[((IOTA - 409) & 511)]) + ((0.00354913948f * fVec35[((IOTA - 408) & 511)]) + ((0.00426105037f * fVec35[((IOTA - 407) & 511)]) + ((0.00447040517f * fVec35[((IOTA - 406) & 511)]) + ((0.00395416887f * fVec35[((IOTA - 405) & 511)]) + ((0.00272853486f * fVec35[((IOTA - 404) & 511)]) + ((0.00148602109f * fVec35[((IOTA - 403) & 511)]) + ((0.000244519208f * fVec35[((IOTA - 402) & 511)]) + ((0.000580264255f * fVec35[((IOTA - 399) & 511)]) + ((0.00219770381f * fVec35[((IOTA - 398) & 511)]) + ((0.0039795707f * fVec35[((IOTA - 397) & 511)]) + ((0.00462667039f * fVec35[((IOTA - 396) & 511)]) + ((0.00454843976f * fVec35[((IOTA - 395) & 511)]) + ((0.00384439761f * fVec35[((IOTA - 394) & 511)]) + ((0.00232383236f * fVec35[((IOTA - 393) & 511)]) + ((0.00110316183f * fVec35[((IOTA - 392) & 511)]) + ((0.00042429287f * fVec35[((IOTA - 391) & 511)]) + ((0.000260158908f * fVec35[((IOTA - 388) & 511)]) + ((0.000203836709f * fVec35[((IOTA - 387) & 511)]) + ((0.00020909356f * fVec35[((IOTA - 386) & 511)]) + ((6.01094216e-05f * fVec35[((IOTA - 385) & 511)]) + ((0.000245270319f * fVec35[((IOTA - 381) & 511)]) + ((0.000811201055f * fVec35[((IOTA - 380) & 511)]) + ((0.00122690713f * fVec35[((IOTA - 379) & 511)]) + ((0.00169482082f * fVec35[((IOTA - 378) & 511)]) + ((0.00168084633f * fVec35[((IOTA - 377) & 511)]) + ((0.00111530768f * fVec35[((IOTA - 376) & 511)]) + ((0.000803005882f * fVec35[((IOTA - 375) & 511)]) + ((0.000288075302f * fVec35[((IOTA - 374) & 511)]) + ((0.000233320519f * fVec35[((IOTA - 372) & 511)]) + ((0.000310865231f * fVec35[((IOTA - 371) & 511)]) + ((0.000242135953f * fVec35[((IOTA - 370) & 511)]) + ((0.000427851919f * fVec35[((IOTA - 369) & 511)]) + ((0.000700058881f * fVec35[((IOTA - 368) & 511)]) + ((0.00143031962f * fVec35[((IOTA - 367) & 511)]) + ((((0.00251594791f * fVec35[((IOTA - 364) & 511)]) + ((0.00214761775f * fVec35[((IOTA - 363) & 511)]) + ((0.001363941f * fVec35[((IOTA - 362) & 511)]) + ((0.00102940435f * fVec35[((IOTA - 361) & 511)]) + ((0.00107080489f * fVec35[((IOTA - 360) & 511)]) + ((0.00109568471f * fVec35[((IOTA - 359) & 511)]) + ((0.00125057856f * fVec35[((IOTA - 358) & 511)]) + ((0.000896614511f * fVec35[((IOTA - 357) & 511)]) + ((0.000161750242f * fVec35[((IOTA - 356) & 511)]) + ((0.000108399428f * fVec35[((IOTA - 335) & 511)]) + ((0.000453417189f * fVec35[((IOTA - 326) & 511)]) + ((0.000770616345f * fVec35[((IOTA - 320) & 511)]) + ((0.00139381643f * fVec35[((IOTA - 319) & 511)]) + ((0.00178163871f * fVec35[((IOTA - 318) & 511)]) + ((0.00105059426f * fVec35[((IOTA - 317) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.149007961f * fVec35[((IOTA - 5) & 511)]) + (0.264579713f * fVec35[((IOTA - 6) & 511)])) + (0.241291329f * fVec35[((IOTA - 7) & 511)])) + (0.150076345f * fVec35[((IOTA - 8) & 511)])) + (0.0403939933f * fVec35[((IOTA - 14) & 511)])) + (0.0385781042f * fVec35[((IOTA - 15) & 511)])) + (0.0227236543f * fVec35[((IOTA - 16) & 511)])) + (0.0288144387f * fVec35[((IOTA - 17) & 511)])) + (0.0251799487f * fVec35[((IOTA - 18) & 511)])) + (0.0238036346f * fVec35[((IOTA - 19) & 511)])) + (0.0176303107f * fVec35[((IOTA - 20) & 511)])) + (0.012487404f * fVec35[((IOTA - 25) & 511)])) + (0.0536979213f * fVec35[((IOTA - 26) & 511)])) + (0.0576244034f * fVec35[((IOTA - 27) & 511)])) + (0.0263063256f * fVec35[((IOTA - 28) & 511)])) + (0.0027885465f * fVec35[((IOTA - 29) & 511)])) + (0.00605140673f * fVec35[((IOTA - 32) & 511)])) + (0.0327786282f * fVec35[((IOTA - 33) & 511)])) + (0.0332365185f * fVec35[((IOTA - 34) & 511)])) + (0.0198468529f * fVec35[((IOTA - 35) & 511)])) + (0.0098568853f * fVec35[((IOTA - 40) & 511)])) + (0.0342194624f * fVec35[((IOTA - 41) & 511)])) + (0.0351753384f * fVec35[((IOTA - 42) & 511)])) + (0.0250427518f * fVec35[((IOTA - 43) & 511)])) + (0.0143915787f * fVec35[((IOTA - 44) & 511)])) + (0.0107950959f * fVec35[((IOTA - 50) & 511)])) + (0.0219307374f * fVec35[((IOTA - 51) & 511)])) + (0.0120432265f * fVec35[((IOTA - 52) & 511)])) + (0.00584479468f * fVec35[((IOTA - 53) & 511)])) + (0.00791894831f * fVec35[((IOTA - 54) & 511)])) + (0.00571824145f * fVec35[((IOTA - 55) & 511)])) + (0.0110120922f * fVec35[((IOTA - 56) & 511)])) + (0.0174727719f * fVec35[((IOTA - 57) & 511)])) + (0.0211154558f * fVec35[((IOTA - 58) & 511)])) + (0.0201624203f * fVec35[((IOTA - 59) & 511)])) + (0.00565633597f * fVec35[((IOTA - 60) & 511)])) + (0.0062976568f * fVec35[((IOTA - 65) & 511)])) + (0.0232154038f * fVec35[((IOTA - 66) & 511)])) + (0.0316764489f * fVec35[((IOTA - 67) & 511)])) + (0.0299400296f * fVec35[((IOTA - 68) & 511)])) + (0.0202218443f * fVec35[((IOTA - 69) & 511)])) + (0.01361058f * fVec35[((IOTA - 70) & 511)])) + (0.00656222366f * fVec35[((IOTA - 71) & 511)])) + (0.00630768016f * fVec35[((IOTA - 77) & 511)])) + (0.012918422f * fVec35[((IOTA - 78) & 511)])) + (0.0141560063f * fVec35[((IOTA - 79) & 511)])) + (0.0117532574f * fVec35[((IOTA - 80) & 511)])) + (0.00682871649f * fVec35[((IOTA - 81) & 511)])) + (0.00237711798f * fVec35[((IOTA - 82) & 511)])) + (0.00285956124f * fVec35[((IOTA - 83) & 511)])) + (0.00851312187f * fVec35[((IOTA - 84) & 511)])) + (0.0109638348f * fVec35[((IOTA - 85) & 511)])) + (0.0116136763f * fVec35[((IOTA - 86) & 511)])) + (0.0116131548f * fVec35[((IOTA - 87) & 511)])) + (0.0119870342f * fVec35[((IOTA - 88) & 511)])) + (0.0153731834f * fVec35[((IOTA - 89) & 511)])) + (0.0194423795f * fVec35[((IOTA - 90) & 511)])) + (0.0200657099f * fVec35[((IOTA - 91) & 511)])) + (0.0145871881f * fVec35[((IOTA - 92) & 511)])) + (0.00267665321f * fVec35[((IOTA - 93) & 511)])) + (0.00897042453f * fVec35[((IOTA - 99) & 511)])) + (0.0148797687f * fVec35[((IOTA - 100) & 511)])) + (0.0180139858f * fVec35[((IOTA - 101) & 511)])) + (0.0209609531f * fVec35[((IOTA - 102) & 511)])) + (0.0212073009f * fVec35[((IOTA - 103) & 511)])) + (0.016603943f * fVec35[((IOTA - 104) & 511)])) + (0.00953867286f * fVec35[((IOTA - 105) & 511)])) + (0.00520197209f * fVec35[((IOTA - 111) & 511)])) + (0.0125856809f * fVec35[((IOTA - 112) & 511)])) + (0.0167236067f * fVec35[((IOTA - 113) & 511)])) + (0.0159642883f * fVec35[((IOTA - 114) & 511)])) + (0.0125642298f * fVec35[((IOTA - 115) & 511)])) + (0.0102685429f * fVec35[((IOTA - 116) & 511)])) + (0.00842480268f * fVec35[((IOTA - 117) & 511)])) + (0.00652095303f * fVec35[((IOTA - 118) & 511)])) + (0.00455565564f * fVec35[((IOTA - 119) & 511)])) + (0.00115233334f * fVec35[((IOTA - 120) & 511)])) + (0.00059231231f * fVec35[((IOTA - 123) & 511)])) + (0.00538168009f * fVec35[((IOTA - 124) & 511)])) + (0.0086479038f * fVec35[((IOTA - 125) & 511)])) + (0.00835969765f * fVec35[((IOTA - 126) & 511)])) + (0.0046905349f * fVec35[((IOTA - 127) & 511)])) + (0.00422043307f * fVec35[((IOTA - 132) & 511)])) + (0.00717412587f * fVec35[((IOTA - 133) & 511)])) + (0.00673817704f * fVec35[((IOTA - 134) & 511)])) + (0.00372238271f * fVec35[((IOTA - 135) & 511)])) + (0.000480386429f * fVec35[((IOTA - 136) & 511)])) + (0.00234606722f * fVec35[((IOTA - 138) & 511)])) + (0.00476226816f * fVec35[((IOTA - 139) & 511)])) + (0.00529767061f * fVec35[((IOTA - 140) & 511)])) + (0.00303045381f * fVec35[((IOTA - 141) & 511)])) + (0.000173863955f * fVec35[((IOTA - 142) & 511)])) + (0.000776069239f * fVec35[((IOTA - 144) & 511)])) + (0.00327660609f * fVec35[((IOTA - 145) & 511)])) + (0.00474577956f * fVec35[((IOTA - 146) & 511)])) + (0.00322475703f * fVec35[((IOTA - 147) & 511)])) + (0.000380018726f * fVec35[((IOTA - 148) & 511)])) + (0.00130925141f * fVec35[((IOTA - 153) & 511)])) + (0.0015559257f * fVec35[((IOTA - 154) & 511)])) + (0.000800100155f * fVec35[((IOTA - 155) & 511)])) + (0.000178630929f * fVec35[((IOTA - 158) & 511)])) + (0.00136270048f * fVec35[((IOTA - 159) & 511)])) + (0.00178738497f * fVec35[((IOTA - 160) & 511)])) + (0.000140168704f * fVec35[((IOTA - 161) & 511)])) + (0.000874869525f * fVec35[((IOTA - 165) & 511)])) + (0.00407585688f * fVec35[((IOTA - 166) & 511)])) + (0.00532816583f * fVec35[((IOTA - 167) & 511)])) + (0.00413531344f * fVec35[((IOTA - 168) & 511)])) + (0.00163363386f * fVec35[((IOTA - 169) & 511)])) + (0.00104337884f * fVec35[((IOTA - 186) & 511)])) + (0.000995709095f * fVec35[((IOTA - 187) & 511)])) + (5.11957332e-05f * fVec35[((IOTA - 197) & 511)])) + (0.00211614277f * fVec35[((IOTA - 214) & 511)])) + (0.0031511304f * fVec35[((IOTA - 215) & 511)])) + (0.0023846277f * fVec35[((IOTA - 216) & 511)])) + (0.00261775218f * fVec35[((IOTA - 365) & 511)]))))))))))))))))) + (0.00238492154f * fVec35[((IOTA - 366) & 511)])) + (0.00125916582f * fVec35[((IOTA - 419) & 511)])))))))))))))))))))))))))))))))))))))))))))))) + (0.000653368887f * fVec35[((IOTA - 420) & 511)])) + (0.000328235328f * fVec35[((IOTA - 421) & 511)])) + (0.000668290071f * fVec35[((IOTA - 422) & 511)])) + (0.000798793975f * fVec35[((IOTA - 423) & 511)])) + (0.000930669252f * fVec35[((IOTA - 424) & 511)])) + (0.00153140537f * fVec35[((IOTA - 425) & 511)])) + (0.0022088699f * fVec35[((IOTA - 426) & 511)])) + (0.00277375616f * fVec35[((IOTA - 427) & 511)])) + (0.00297984574f * fVec35[((IOTA - 428) & 511)])) + (0.00289707677f * fVec35[((IOTA - 429) & 511)])) + (0.00306728389f * fVec35[((IOTA - 430) & 511)])) + (0.00301954895f * fVec35[((IOTA - 431) & 511)])) + (0.00260537723f * fVec35[((IOTA - 432) & 511)])) + (0.00254402729f * fVec35[((IOTA - 433) & 511)])) + (0.00261892751f * fVec35[((IOTA - 434) & 511)])) + (0.00273855869f * fVec35[((IOTA - 435) & 511)])) + (0.00318779657f * fVec35[((IOTA - 436) & 511)])) + (0.00362524763f * fVec35[((IOTA - 437) & 511)])) + (0.00426265039f * fVec35[((IOTA - 438) & 511)])) + (0.00499098469f * fVec35[((IOTA - 439) & 511)])) + (0.00507434132f * fVec35[((IOTA - 440) & 511)])) + (0.00490266504f * fVec35[((IOTA - 441) & 511)])) + (0.00451347139f * fVec35[((IOTA - 442) & 511)])) + (0.00362021942f * fVec35[((IOTA - 443) & 511)])) + (0.00294677075f * fVec35[((IOTA - 444) & 511)])) + (0.00257974677f * fVec35[((IOTA - 445) & 511)])) + (0.00232605264f * fVec35[((IOTA - 446) & 511)])) + (0.00234126765f * fVec35[((IOTA - 447) & 511)])) + (0.00221673865f * fVec35[((IOTA - 448) & 511)])) + (0.00226734718f * fVec35[((IOTA - 449) & 511)])) + (0.00284836208f * fVec35[((IOTA - 450) & 511)])) + (0.0033189212f * fVec35[((IOTA - 451) & 511)])) + (0.00356389768f * fVec35[((IOTA - 452) & 511)])) + (0.0035478659f * fVec35[((IOTA - 453) & 511)])) + (0.00310130557f * fVec35[((IOTA - 454) & 511)])) + (0.00299228542f * fVec35[((IOTA - 455) & 511)])) + (0.00321953278f * fVec35[((IOTA - 456) & 511)])) + (0.0032346826f * fVec35[((IOTA - 457) & 511)])) + (0.00330612203f * fVec35[((IOTA - 458) & 511)])) + (0.00316353748f * fVec35[((IOTA - 459) & 511)])) + (0.00248907646f * fVec35[((IOTA - 460) & 511)])) + (0.00199432392f * fVec35[((IOTA - 461) & 511)])) + (0.00183969131f * fVec35[((IOTA - 462) & 511)])) + (0.00188745884f * fVec35[((IOTA - 463) & 511)])) + (0.00226848992f * fVec35[((IOTA - 464) & 511)])) + (0.00242501637f * fVec35[((IOTA - 465) & 511)])) + (0.00222529331f * fVec35[((IOTA - 466) & 511)])) + (0.00195671059f * fVec35[((IOTA - 467) & 511)])) + (0.00156934513f * fVec35[((IOTA - 468) & 511)])) + (0.00148154795f * fVec35[((IOTA - 469) & 511)])) + (0.00202449271f * fVec35[((IOTA - 470) & 511)])) + (0.00269412156f * fVec35[((IOTA - 471) & 511)])) + (0.00321359048f * fVec35[((IOTA - 472) & 511)])) + (0.00334272301f * fVec35[((IOTA - 473) & 511)])) + (0.00313199684f * fVec35[((IOTA - 474) & 511)])) + (0.00303655956f * fVec35[((IOTA - 475) & 511)])) + (0.00284888456f * fVec35[((IOTA - 476) & 511)])) + (0.00264726812f * fVec35[((IOTA - 477) & 511)])) + (0.00286547095f * fVec35[((IOTA - 478) & 511)])) + (0.00284019951f * fVec35[((IOTA - 479) & 511)])) + (0.00254324358f * fVec35[((IOTA - 480) & 511)])) + (0.00253472198f * fVec35[((IOTA - 481) & 511)])) + (0.00250984216f * fVec35[((IOTA - 482) & 511)])) + (0.00256178901f * fVec35[((IOTA - 483) & 511)])) + (0.0027185767f * fVec35[((IOTA - 484) & 511)])) + (0.00251114834f * fVec35[((IOTA - 485) & 511)])) + (0.00233904738f * fVec35[((IOTA - 486) & 511)])) + (0.00189454388f * fVec35[((IOTA - 487) & 511)])) + (0.00084894523f * fVec35[((IOTA - 488) & 511)])) + (0.000379692297f * fVec35[((IOTA - 489) & 511)])) + (0.000268746167f * fVec35[((IOTA - 490) & 511)])) + (7.17006624e-05f * fVec35[((IOTA - 491) & 511)])) + (0.000448127743f * fVec35[((IOTA - 492) & 511)])) + (0.000793504529f * fVec35[((IOTA - 493) & 511)])) + (0.000861319713f * fVec35[((IOTA - 494) & 511)])) + (0.00124055473f * fVec35[((IOTA - 495) & 511)])) + (0.00155279133f * fVec35[((IOTA - 496) & 511)])) + (0.0021511442f * fVec35[((IOTA - 497) & 511)])) + (0.00307374867f * fVec35[((IOTA - 498) & 511)])) + (0.00344207836f * fVec35[((IOTA - 499) & 511)])) + (0.0035756845f * fVec35[((IOTA - 500) & 511)])) + (0.00358688366f * fVec35[((IOTA - 501) & 511)])) + (0.00304926047f * fVec35[((IOTA - 502) & 511)])) + (0.00271518109f * fVec35[((IOTA - 503) & 511)])) + (0.00275370851f * fVec35[((IOTA - 504) & 511)])) + (0.00301625114f * fVec35[((IOTA - 505) & 511)])) + (0.00365051907f * fVec35[((IOTA - 506) & 511)])) + (0.00382454647f * fVec35[((IOTA - 507) & 511)])) + (0.00343303429f * fVec35[((IOTA - 508) & 511)])) + (0.00303541683f * fVec35[((IOTA - 509) & 511)])) + (0.00233741477f * fVec35[((IOTA - 510) & 511)])) + (0.00204878487f * fVec35[((IOTA - 511) & 511)])))) : (iSlow105 ? ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00250938535f * fVec34[((IOTA - 25) & 511)]) + ((((0.142843127f * fVec34[((IOTA - 12) & 511)]) + ((0.0709786117f * fVec34[((IOTA - 22) & 511)]) + ((0.0224584471f * fVec34[((IOTA - 21) & 511)]) + (((0.00609278632f * fVec34[((IOTA - 14) & 511)]) + ((((0.071105659f * fVec34[((IOTA - 4) & 511)]) + ((0.166550472f * fVec34[((IOTA - 3) & 511)]) + ((0.0899370834f * fVec34[((IOTA - 10) & 511)]) + (((0.205251753f * fVec34[((IOTA - 2) & 511)]) + (((fSlow109 * fTemp0) + (0.214976981f * fVec34[((IOTA - 1) & 511)])) + (0.144461244f * fVec34[((IOTA - 11) & 511)]))) + (0.0790281519f * fVec34[((IOTA - 13) & 511)]))))) + (0.0889683813f * fVec34[((IOTA - 23) & 511)])) + (0.0616821647f * fVec34[((IOTA - 24) & 511)]))) + (0.00963774603f * fVec34[((IOTA - 30) & 511)]))))) + (0.0260041803f * fVec34[((IOTA - 31) & 511)])) + (0.0109775681f * fVec34[((IOTA - 32) & 511)]))) + (0.00344736688f * fVec34[((IOTA - 36) & 511)])) + (0.0183876716f * fVec34[((IOTA - 37) & 511)])) + (0.0151254144f * fVec34[((IOTA - 38) & 511)])) + (0.000169795007f * fVec34[((IOTA - 45) & 511)])) + (0.00162447849f * fVec34[((IOTA - 53) & 511)])) + (0.00752316462f * fVec34[((IOTA - 61) & 511)])) + (0.00943598803f * fVec34[((IOTA - 62) & 511)])) + (0.00781634636f * fVec34[((IOTA - 63) & 511)])) + (0.00159384916f * fVec34[((IOTA - 64) & 511)])) + (0.00309497258f * fVec34[((IOTA - 71) & 511)])) + (0.0110217147f * fVec34[((IOTA - 72) & 511)])) + (0.0147396624f * fVec34[((IOTA - 73) & 511)])) + (0.0156896412f * fVec34[((IOTA - 74) & 511)])) + (0.0101800244f * fVec34[((IOTA - 75) & 511)])) + (0.0035453625f * fVec34[((IOTA - 82) & 511)])) + (0.00195386959f * fVec34[((IOTA - 83) & 511)])) + (0.0086374823f * fVec34[((IOTA - 94) & 511)])) + (0.0138765806f * fVec34[((IOTA - 95) & 511)])) + (0.0141714979f * fVec34[((IOTA - 96) & 511)])) + (0.00937689934f * fVec34[((IOTA - 97) & 511)])) + (0.00176913152f * fVec34[((IOTA - 98) & 511)])) + (0.0010655215f * fVec34[((IOTA - 107) & 511)])) + (0.0102522885f * fVec34[((IOTA - 108) & 511)])) + (0.0135828722f * fVec34[((IOTA - 109) & 511)])) + (0.00953674316f * fVec34[((IOTA - 110) & 511)])) + (0.000807216857f * fVec34[((IOTA - 111) & 511)])) + (0.00256205676f * fVec34[((IOTA - 128) & 511)])) + (0.00836532004f * fVec34[((IOTA - 129) & 511)])) + (0.0104094353f * fVec34[((IOTA - 130) & 511)])) + (0.00759322802f * fVec34[((IOTA - 131) & 511)])) + (0.00313936686f * fVec34[((IOTA - 132) & 511)])) + (0.00033906335f * fVec34[((IOTA - 143) & 511)])) + (0.00138111692f * fVec34[((IOTA - 144) & 511)])) + (0.000659587793f * fVec34[((IOTA - 145) & 511)])) + (0.000324492808f * fVec34[((IOTA - 147) & 511)])) + (0.00145815546f * fVec34[((IOTA - 148) & 511)])) + (0.00309534464f * fVec34[((IOTA - 149) & 511)])) + (0.00474487245f * fVec34[((IOTA - 150) & 511)])) + (0.00386070972f * fVec34[((IOTA - 151) & 511)])) + (0.000809945166f * fVec34[((IOTA - 152) & 511)])) + (0.000208609272f * fVec34[((IOTA - 156) & 511)])) + (0.000762853771f * fVec34[((IOTA - 157) & 511)])) + (0.00066144811f * fVec34[((IOTA - 163) & 511)])) + (0.00133597851f * fVec34[((IOTA - 164) & 511)])) + (0.000726054888f * fVec34[((IOTA - 165) & 511)])) + (0.000100723933f * fVec34[((IOTA - 166) & 511)])) + (0.000824267976f * fVec34[((IOTA - 168) & 511)])) + (0.00287061464f * fVec34[((IOTA - 169) & 511)])) + (0.00399937946f * fVec34[((IOTA - 170) & 511)])) + (0.00335504441f * fVec34[((IOTA - 171) & 511)])) + (0.00243132375f * fVec34[((IOTA - 172) & 511)])) + (0.0015383563f * fVec34[((IOTA - 173) & 511)])) + (0.000233658124f * fVec34[((IOTA - 174) & 511)])) + (2.66591087e-06f * fVec34[((IOTA - 176) & 511)])) + (0.000704973936f * fVec34[((IOTA - 180) & 511)])) + (0.00418901537f * fVec34[((IOTA - 181) & 511)])) + (0.00697189616f * fVec34[((IOTA - 182) & 511)])) + (0.00821992382f * fVec34[((IOTA - 183) & 511)])) + (0.00757450331f * fVec34[((IOTA - 184) & 511)])) + (0.0046882946f * fVec34[((IOTA - 185) & 511)])) + (0.00139159523f * fVec34[((IOTA - 186) & 511)])) + (0.00131185958f * fVec34[((IOTA - 189) & 511)])) + (0.00396292144f * fVec34[((IOTA - 190) & 511)])) + (0.00617484748f * fVec34[((IOTA - 191) & 511)])) + (0.00767091801f * fVec34[((IOTA - 192) & 511)])) + (0.00771993119f * fVec34[((IOTA - 193) & 511)])) + (0.00618501613f * fVec34[((IOTA - 194) & 511)])) + (0.00354644749f * fVec34[((IOTA - 195) & 511)])) + (0.0007013469f * fVec34[((IOTA - 196) & 511)])) + (0.000487622805f * fVec34[((IOTA - 199) & 511)])) + (0.00232356228f * fVec34[((IOTA - 200) & 511)])) + (0.00397550827f * fVec34[((IOTA - 201) & 511)])) + (0.00412651664f * fVec34[((IOTA - 202) & 511)])) + (0.00326805376f * fVec34[((IOTA - 203) & 511)])) + (0.00270915916f * fVec34[((IOTA - 204) & 511)])) + (0.00265859533f * fVec34[((IOTA - 205) & 511)])) + (0.00370573299f * fVec34[((IOTA - 206) & 511)])) + (0.00484562712f * fVec34[((IOTA - 207) & 511)])) + (0.00535780285f * fVec34[((IOTA - 208) & 511)])) + (0.00535278069f * fVec34[((IOTA - 209) & 511)])) + (0.0043212059f * fVec34[((IOTA - 210) & 511)])) + (0.00286987051f * fVec34[((IOTA - 211) & 511)])) + (0.00186272524f * fVec34[((IOTA - 212) & 511)])) + (0.00125249149f * fVec34[((IOTA - 213) & 511)])) + (0.000860663597f * fVec34[((IOTA - 214) & 511)])) + (0.000238928478f * fVec34[((IOTA - 215) & 511)])) + (0.000453365967f * fVec34[((IOTA - 217) & 511)])) + (0.00222107116f * fVec34[((IOTA - 218) & 511)])) + (0.00470360927f * fVec34[((IOTA - 219) & 511)])) + (0.0074749575f * fVec34[((IOTA - 220) & 511)])) + (0.00905330572f * fVec34[((IOTA - 221) & 511)])) + (0.00804051757f * fVec34[((IOTA - 222) & 511)])) + (0.00511627039f * fVec34[((IOTA - 223) & 511)])) + (0.00157279894f * fVec34[((IOTA - 224) & 511)])) + (0.00278309733f * fVec34[((IOTA - 228) & 511)])) + (0.0063628098f * fVec34[((IOTA - 229) & 511)])) + (0.00877736136f * fVec34[((IOTA - 230) & 511)])) + (0.00975635741f * fVec34[((IOTA - 231) & 511)])) + (0.00938756391f * fVec34[((IOTA - 232) & 511)])) + (0.00687315641f * fVec34[((IOTA - 233) & 511)])) + (0.003518329f * fVec34[((IOTA - 234) & 511)])) + (0.000660889782f * fVec34[((IOTA - 235) & 511)])) + (0.0025309003f * fVec34[((IOTA - 239) & 511)])) + (0.00573329302f * fVec34[((IOTA - 240) & 511)])) + (0.00817757472f * fVec34[((IOTA - 241) & 511)])) + (0.00876737945f * fVec34[((IOTA - 242) & 511)])) + (0.00739109842f * fVec34[((IOTA - 243) & 511)])) + (0.0044564656f * fVec34[((IOTA - 244) & 511)])) + (0.000842589885f * fVec34[((IOTA - 245) & 511)])) + (0.00224103639f * fVec34[((IOTA - 249) & 511)])) + (0.00565067399f * fVec34[((IOTA - 250) & 511)])) + (0.00859479327f * fVec34[((IOTA - 251) & 511)])) + (0.0098421704f * fVec34[((IOTA - 252) & 511)])) + (0.00943434518f * fVec34[((IOTA - 253) & 511)])) + (0.00806903839f * fVec34[((IOTA - 254) & 511)])) + (0.0057392763f * fVec34[((IOTA - 255) & 511)])) + (0.00360727217f * fVec34[((IOTA - 256) & 511)])) + (0.00271356106f * fVec34[((IOTA - 257) & 511)])) + (0.00259333756f * fVec34[((IOTA - 258) & 511)])) + (0.00381461019f * fVec34[((IOTA - 259) & 511)])) + (0.00608016877f * fVec34[((IOTA - 260) & 511)])) + (0.00743574044f * fVec34[((IOTA - 261) & 511)])) + (0.0073665143f * fVec34[((IOTA - 262) & 511)])) + (0.00647230679f * fVec34[((IOTA - 263) & 511)])) + (0.00465825433f * fVec34[((IOTA - 264) & 511)])) + (0.00263035297f * fVec34[((IOTA - 265) & 511)])) + (0.00188699923f * fVec34[((IOTA - 266) & 511)])) + (0.00259126024f * fVec34[((IOTA - 267) & 511)])) + (0.00422469806f * fVec34[((IOTA - 268) & 511)])) + (0.0060797967f * fVec34[((IOTA - 269) & 511)])) + (0.00701216701f * fVec34[((IOTA - 270) & 511)])) + (0.00643898034f * fVec34[((IOTA - 271) & 511)])) + (0.00485396665f * fVec34[((IOTA - 272) & 511)])) + (0.00306952046f * fVec34[((IOTA - 273) & 511)])) + (0.00166809745f * fVec34[((IOTA - 274) & 511)])) + (0.000654286705f * fVec34[((IOTA - 275) & 511)])) + (0.000351959839f * fVec34[((IOTA - 276) & 511)])) + (0.00102432072f * fVec34[((IOTA - 277) & 511)])) + (0.00159174111f * fVec34[((IOTA - 278) & 511)])) + (0.00203162106f * fVec34[((IOTA - 279) & 511)])) + (0.00279667601f * fVec34[((IOTA - 280) & 511)])) + (0.00317353057f * fVec34[((IOTA - 281) & 511)])) + (0.00317052333f * fVec34[((IOTA - 282) & 511)])) + (0.00314373802f * fVec34[((IOTA - 283) & 511)])) + (0.00274434546f * fVec34[((IOTA - 284) & 511)])) + (0.0019027791f * fVec34[((IOTA - 285) & 511)])) + (0.00138427876f * fVec34[((IOTA - 286) & 511)])) + (0.00168155227f * fVec34[((IOTA - 287) & 511)])) + (0.00256537413f * fVec34[((IOTA - 288) & 511)])) + (0.00348441349f * fVec34[((IOTA - 289) & 511)])) + (0.00406042114f * fVec34[((IOTA - 290) & 511)])) + (0.0045100362f * fVec34[((IOTA - 291) & 511)])) + (0.0042819269f * fVec34[((IOTA - 292) & 511)])) + (0.00348602561f * fVec34[((IOTA - 293) & 511)])) + (0.00313428231f * fVec34[((IOTA - 294) & 511)])) + (0.00331486622f * fVec34[((IOTA - 295) & 511)])) + (0.0040295748f * fVec34[((IOTA - 296) & 511)])) + (0.00477051083f * fVec34[((IOTA - 297) & 511)])) + (0.0052388194f * fVec34[((IOTA - 298) & 511)])) + (0.00566549273f * fVec34[((IOTA - 299) & 511)])) + (0.00539060263f * fVec34[((IOTA - 300) & 511)])) + (0.00468581449f * fVec34[((IOTA - 301) & 511)])) + (0.00428391108f * fVec34[((IOTA - 302) & 511)])) + (0.00388098462f * fVec34[((IOTA - 303) & 511)])) + (0.00377641665f * fVec34[((IOTA - 304) & 511)])) + (0.00426162081f * fVec34[((IOTA - 305) & 511)])) + (0.00414933357f * fVec34[((IOTA - 306) & 511)])) + (0.00368834147f * fVec34[((IOTA - 307) & 511)])) + (0.00349008664f * fVec34[((IOTA - 308) & 511)])) + (0.00274769403f * fVec34[((IOTA - 309) & 511)])) + (0.00188002409f * fVec34[((IOTA - 310) & 511)])) + (0.00173062785f * fVec34[((IOTA - 311) & 511)])) + (0.00179963699f * fVec34[((IOTA - 312) & 511)])) + (0.00250414619f * fVec34[((IOTA - 313) & 511)])) + (0.00347452378f * fVec34[((IOTA - 314) & 511)])) + (0.00355729787f * fVec34[((IOTA - 315) & 511)])) + (0.00308325421f * fVec34[((IOTA - 316) & 511)])) + (0.00181411486f * fVec34[((IOTA - 317) & 511)])) + (0.000257436652f * fVec34[((IOTA - 318) & 511)])) + (0.000182815827f * fVec34[((IOTA - 322) & 511)])) + (0.000492892694f * fVec34[((IOTA - 323) & 511)])) + (0.000879791565f * fVec34[((IOTA - 324) & 511)])) + (0.00126932515f * fVec34[((IOTA - 325) & 511)])) + (0.00126842642f * fVec34[((IOTA - 326) & 511)])) + (0.00143722957f * fVec34[((IOTA - 327) & 511)])) + (0.00157506205f * fVec34[((IOTA - 328) & 511)])) + (0.00151588023f * fVec34[((IOTA - 329) & 511)])) + (0.00151172606f * fVec34[((IOTA - 330) & 511)])) + (0.00115133356f * fVec34[((IOTA - 331) & 511)])) + (0.000844636001f * fVec34[((IOTA - 332) & 511)])) + (0.00131145632f * fVec34[((IOTA - 333) & 511)])) + (0.00209210534f * fVec34[((IOTA - 334) & 511)])) + (0.00279611815f * fVec34[((IOTA - 335) & 511)])) + (0.00346268155f * fVec34[((IOTA - 336) & 511)])) + (0.00369891291f * fVec34[((IOTA - 337) & 511)])) + (0.00375942793f * fVec34[((IOTA - 338) & 511)])) + (0.00346754864f * fVec34[((IOTA - 339) & 511)])) + (0.00259346142f * fVec34[((IOTA - 340) & 511)])) + (0.00162187451f * fVec34[((IOTA - 341) & 511)])) + (0.000184644945f * fVec34[((IOTA - 342) & 511)])) + (0.000859702472f * fVec34[((IOTA - 347) & 511)])) + (0.00198539812f * fVec34[((IOTA - 348) & 511)])) + (0.00246217009f * fVec34[((IOTA - 349) & 511)])) + (0.00239185849f * fVec34[((IOTA - 350) & 511)])) + (0.00145871332f * fVec34[((IOTA - 351) & 511)])) + (0.000165021047f * fVec34[((IOTA - 352) & 511)])) + (7.98907131e-05f * fVec34[((IOTA - 359) & 511)])) + (0.000164710917f * fVec34[((IOTA - 384) & 511)])) + (0.000774727669f * fVec34[((IOTA - 385) & 511)])) + (0.000945669599f * fVec34[((IOTA - 386) & 511)])) + (5.80656342e-05f * fVec34[((IOTA - 387) & 511)])) + (0.000135941431f * fVec34[((IOTA - 470) & 511)])) + (0.000892315991f * fVec34[((IOTA - 495) & 511)])) + (0.0013993145f * fVec34[((IOTA - 496) & 511)])) + (0.000555949751f * fVec34[((IOTA - 497) & 511)])) - ((((0.00311031844f * fVec34[((IOTA - 508) & 511)]) + ((0.00281006889f * fVec34[((IOTA - 507) & 511)]) + ((0.00242645619f * fVec34[((IOTA - 506) & 511)]) + ((0.00230372138f * fVec34[((IOTA - 505) & 511)]) + ((0.0025967476f * fVec34[((IOTA - 504) & 511)]) + ((0.00294625852f * fVec34[((IOTA - 503) & 511)]) + ((0.00365687488f * fVec34[((IOTA - 502) & 511)]) + ((0.00446917582f * fVec34[((IOTA - 501) & 511)]) + ((0.00411498407f * fVec34[((IOTA - 500) & 511)]) + ((0.0028442326f * fVec34[((IOTA - 499) & 511)]) + ((0.0012244354f * fVec34[((IOTA - 498) & 511)]) + ((0.000289491843f * fVec34[((IOTA - 494) & 511)]) + ((0.00162016926f * fVec34[((IOTA - 493) & 511)]) + ((0.00235679606f * fVec34[((IOTA - 492) & 511)]) + ((0.0023517427f * fVec34[((IOTA - 491) & 511)]) + ((0.00217416603f * fVec34[((IOTA - 490) & 511)]) + ((0.00173521601f * fVec34[((IOTA - 489) & 511)]) + ((0.00146336388f * fVec34[((IOTA - 488) & 511)]) + ((0.00195529545f * fVec34[((IOTA - 487) & 511)]) + ((0.00241278484f * fVec34[((IOTA - 486) & 511)]) + ((0.00257572858f * fVec34[((IOTA - 485) & 511)]) + ((0.00243535358f * fVec34[((IOTA - 484) & 511)]) + ((0.00187862897f * fVec34[((IOTA - 483) & 511)]) + ((0.00152356876f * fVec34[((IOTA - 482) & 511)]) + ((0.00142597593f * fVec34[((IOTA - 481) & 511)]) + ((0.00175418891f * fVec34[((IOTA - 480) & 511)]) + ((0.00263187243f * fVec34[((IOTA - 479) & 511)]) + ((0.0031465902f * fVec34[((IOTA - 478) & 511)]) + ((0.00340430578f * fVec34[((IOTA - 477) & 511)]) + ((0.0037778737f * fVec34[((IOTA - 476) & 511)]) + ((0.00343096675f * fVec34[((IOTA - 475) & 511)]) + ((0.00264383899f * fVec34[((IOTA - 474) & 511)]) + ((0.00176696153f * fVec34[((IOTA - 473) & 511)]) + ((0.000762109645f * fVec34[((IOTA - 472) & 511)]) + ((4.47039492e-05f * fVec34[((IOTA - 471) & 511)]) + ((0.000557438005f * fVec34[((IOTA - 469) & 511)]) + ((0.00210574595f * fVec34[((IOTA - 468) & 511)]) + ((0.00357906101f * fVec34[((IOTA - 467) & 511)]) + ((0.00442769611f * fVec34[((IOTA - 466) & 511)]) + ((0.00453914655f * fVec34[((IOTA - 465) & 511)]) + ((0.00350413052f * fVec34[((IOTA - 464) & 511)]) + ((0.00173304556f * fVec34[((IOTA - 463) & 511)]) + ((0.000563049223f * fVec34[((IOTA - 462) & 511)]) + ((0.000312990975f * fVec34[((IOTA - 461) & 511)]) + ((0.0011235564f * fVec34[((IOTA - 460) & 511)]) + ((0.00262074266f * fVec34[((IOTA - 459) & 511)]) + ((0.00353832496f * fVec34[((IOTA - 458) & 511)]) + ((0.00377148716f * fVec34[((IOTA - 457) & 511)]) + ((0.00355754606f * fVec34[((IOTA - 456) & 511)]) + ((0.00270553166f * fVec34[((IOTA - 455) & 511)]) + ((0.00214195577f * fVec34[((IOTA - 454) & 511)]) + ((0.00213339925f * fVec34[((IOTA - 453) & 511)]) + ((0.00230356632f * fVec34[((IOTA - 452) & 511)]) + ((0.00283725699f * fVec34[((IOTA - 451) & 511)]) + ((0.00321625033f * fVec34[((IOTA - 450) & 511)]) + ((0.00291020377f * fVec34[((IOTA - 449) & 511)]) + ((0.00229172362f * fVec34[((IOTA - 448) & 511)]) + ((0.00132264802f * fVec34[((IOTA - 447) & 511)]) + ((0.000586052425f * fVec34[((IOTA - 446) & 511)]) + ((0.000752840191f * fVec34[((IOTA - 445) & 511)]) + ((0.001588176f * fVec34[((IOTA - 444) & 511)]) + ((0.00307255844f * fVec34[((IOTA - 443) & 511)]) + ((0.00496609928f * fVec34[((IOTA - 442) & 511)]) + ((0.00636625057f * fVec34[((IOTA - 441) & 511)]) + ((0.00693996437f * fVec34[((IOTA - 440) & 511)]) + ((0.00637865113f * fVec34[((IOTA - 439) & 511)]) + ((0.00494049164f * fVec34[((IOTA - 438) & 511)]) + ((0.00351969292f * fVec34[((IOTA - 437) & 511)]) + ((0.0023447983f * fVec34[((IOTA - 436) & 511)]) + ((0.00179656781f * fVec34[((IOTA - 435) & 511)]) + ((0.00213250006f * fVec34[((IOTA - 434) & 511)]) + ((0.00266535394f * fVec34[((IOTA - 433) & 511)]) + ((0.00301148556f * fVec34[((IOTA - 432) & 511)]) + ((0.00316267973f * fVec34[((IOTA - 431) & 511)]) + ((0.0027399743f * fVec34[((IOTA - 430) & 511)]) + ((0.00209384132f * fVec34[((IOTA - 429) & 511)]) + ((0.00172576029f * fVec34[((IOTA - 428) & 511)]) + ((0.00142089184f * fVec34[((IOTA - 427) & 511)]) + ((0.00108238636f * fVec34[((IOTA - 426) & 511)]) + ((0.000994807109f * fVec34[((IOTA - 425) & 511)]) + ((0.000951590948f * fVec34[((IOTA - 424) & 511)]) + ((0.000980980229f * fVec34[((IOTA - 423) & 511)]) + ((0.00110808667f * fVec34[((IOTA - 422) & 511)]) + ((0.00106341345f * fVec34[((IOTA - 421) & 511)]) + ((0.0014799186f * fVec34[((IOTA - 420) & 511)]) + ((0.00203128019f * fVec34[((IOTA - 419) & 511)]) + ((0.00222265255f * fVec34[((IOTA - 418) & 511)]) + ((0.00286543742f * fVec34[((IOTA - 417) & 511)]) + ((0.00351017574f * fVec34[((IOTA - 416) & 511)]) + ((0.00342501467f * fVec34[((IOTA - 415) & 511)]) + ((0.00216579577f * fVec34[((IOTA - 413) & 511)]) + ((0.00112628425f * fVec34[((IOTA - 412) & 511)]) + ((0.000612031668f * fVec34[((IOTA - 411) & 511)]) + ((0.000465642661f * fVec34[((IOTA - 410) & 511)]) + ((0.00132342288f * fVec34[((IOTA - 409) & 511)]) + ((0.00285306806f * fVec34[((IOTA - 408) & 511)]) + ((0.00367662264f * fVec34[((IOTA - 407) & 511)]) + ((0.00385361025f * fVec34[((IOTA - 406) & 511)]) + ((0.00343040889f * fVec34[((IOTA - 405) & 511)]) + ((0.002232573f * fVec34[((IOTA - 404) & 511)]) + ((0.00112585025f * fVec34[((IOTA - 403) & 511)]) + ((0.000331095885f * fVec34[((IOTA - 402) & 511)]) + ((0.000167408027f * fVec34[((IOTA - 401) & 511)]) + ((0.00134149706f * fVec34[((IOTA - 400) & 511)]) + ((0.00301359361f * fVec34[((IOTA - 399) & 511)]) + ((0.00416781055f * fVec34[((IOTA - 398) & 511)]) + ((0.00441938778f * fVec34[((IOTA - 397) & 511)]) + ((0.00351321371f * fVec34[((IOTA - 396) & 511)]) + ((0.00217097299f * fVec34[((IOTA - 395) & 511)]) + ((0.00123714563f * fVec34[((IOTA - 394) & 511)]) + ((0.00101461727f * fVec34[((IOTA - 393) & 511)]) + ((0.00189168053f * fVec34[((IOTA - 392) & 511)]) + ((0.00302149914f * fVec34[((IOTA - 391) & 511)]) + ((0.00327639328f * fVec34[((IOTA - 390) & 511)]) + ((0.00296222419f * fVec34[((IOTA - 389) & 511)]) + ((0.00180434901f * fVec34[((IOTA - 388) & 511)]) + ((0.000996140298f * fVec34[((IOTA - 383) & 511)]) + ((0.00197160244f * fVec34[((IOTA - 382) & 511)]) + ((0.00222181529f * fVec34[((IOTA - 381) & 511)]) + ((0.00195479952f * fVec34[((IOTA - 380) & 511)]) + ((0.00122536533f * fVec34[((IOTA - 379) & 511)]) + ((0.000843953807f * fVec34[((IOTA - 378) & 511)]) + ((0.000707857311f * fVec34[((IOTA - 377) & 511)]) + ((0.000455474015f * fVec34[((IOTA - 376) & 511)]) + ((0.00107767433f * fVec34[((IOTA - 375) & 511)]) + ((0.00214347476f * fVec34[((IOTA - 374) & 511)]) + ((0.00300159631f * fVec34[((IOTA - 373) & 511)]) + ((0.00382942893f * fVec34[((IOTA - 372) & 511)]) + ((0.00378745329f * fVec34[((IOTA - 371) & 511)]) + ((0.00307934778f * fVec34[((IOTA - 370) & 511)]) + ((0.00243550865f * fVec34[((IOTA - 369) & 511)]) + ((0.00156058464f * fVec34[((IOTA - 368) & 511)]) + ((0.00106328959f * fVec34[((IOTA - 367) & 511)]) + ((0.00123141054f * fVec34[((IOTA - 366) & 511)]) + ((0.00169457309f * fVec34[((IOTA - 365) & 511)]) + ((0.00240825862f * fVec34[((IOTA - 364) & 511)]) + ((0.00254233973f * fVec34[((IOTA - 363) & 511)]) + ((0.00158439344f * fVec34[((IOTA - 362) & 511)]) + ((0.000584998168f * fVec34[((IOTA - 361) & 511)]) + ((2.20118091e-06f * fVec34[((IOTA - 360) & 511)]) + ((0.000651837327f * fVec34[((IOTA - 358) & 511)]) + ((0.00163849117f * fVec34[((IOTA - 357) & 511)]) + ((0.00251133833f * fVec34[((IOTA - 356) & 511)]) + ((0.00293605914f * fVec34[((IOTA - 355) & 511)]) + ((0.00223229406f * fVec34[((IOTA - 354) & 511)]) + ((0.000980422366f * fVec34[((IOTA - 353) & 511)]) + ((0.000607133377f * fVec34[((IOTA - 346) & 511)]) + ((0.00143443933f * fVec34[((IOTA - 345) & 511)]) + ((0.00169835519f * fVec34[((IOTA - 344) & 511)]) + ((0.00130314799f * fVec34[((IOTA - 343) & 511)]) + ((0.000613333657f * fVec34[((IOTA - 321) & 511)]) + ((0.000827646814f * fVec34[((IOTA - 320) & 511)]) + ((0.000450172927f * fVec34[((IOTA - 319) & 511)]) + ((0.00084782904f * fVec34[((IOTA - 248) & 511)]) + ((0.00264966721f * fVec34[((IOTA - 247) & 511)]) + ((0.00199243519f * fVec34[((IOTA - 246) & 511)]) + ((0.000208361074f * fVec34[((IOTA - 238) & 511)]) + ((0.00181085942f * fVec34[((IOTA - 237) & 511)]) + ((0.00149343535f * fVec34[((IOTA - 236) & 511)]) + ((0.000127168372f * fVec34[((IOTA - 227) & 511)]) + ((0.00173031772f * fVec34[((IOTA - 226) & 511)]) + ((0.00125810271f * fVec34[((IOTA - 225) & 511)]) + ((0.000234681182f * fVec34[((IOTA - 216) & 511)]) + ((0.000729465391f * fVec34[((IOTA - 198) & 511)]) + ((0.000986932777f * fVec34[((IOTA - 197) & 511)]) + ((0.000588811468f * fVec34[((IOTA - 188) & 511)]) + ((0.000460992102f * fVec34[((IOTA - 187) & 511)]) + ((0.00129514979f * fVec34[((IOTA - 179) & 511)]) + ((0.00153925549f * fVec34[((IOTA - 178) & 511)]) + ((0.000842868816f * fVec34[((IOTA - 177) & 511)]) + ((3.93409282e-05f * fVec34[((IOTA - 175) & 511)]) + (((0.000126020983f * fVec34[((IOTA - 167) & 511)]) + ((0.00113639096f * fVec34[((IOTA - 162) & 511)]) + ((0.00272707781f * fVec34[((IOTA - 161) & 511)]) + ((0.00361015555f * fVec34[((IOTA - 160) & 511)]) + ((0.00289315265f * fVec34[((IOTA - 159) & 511)]) + ((0.000617146958f * fVec34[((IOTA - 158) & 511)]) + ((0.000873467419f * fVec34[((IOTA - 155) & 511)]) + ((0.00109134568f * fVec34[((IOTA - 154) & 511)]) + ((0.000960085541f * fVec34[((IOTA - 153) & 511)]) + ((0.000153984409f * fVec34[((IOTA - 146) & 511)]) + ((0.00226403959f * fVec34[((IOTA - 142) & 511)]) + ((0.00549978996f * fVec34[((IOTA - 141) & 511)]) + ((0.0069009955f * fVec34[((IOTA - 140) & 511)]) + ((0.00600799732f * fVec34[((IOTA - 139) & 511)]) + ((0.00462027732f * fVec34[((IOTA - 138) & 511)]) + ((0.00249403948f * fVec34[((IOTA - 137) & 511)]) + ((0.00139615266f * fVec34[((IOTA - 136) & 511)]) + ((0.00283970637f * fVec34[((IOTA - 135) & 511)]) + ((0.0032552192f * fVec34[((IOTA - 134) & 511)]) + ((0.00079552969f * fVec34[((IOTA - 133) & 511)]) + ((0.00347201293f * fVec34[((IOTA - 127) & 511)]) + ((0.00917870738f * fVec34[((IOTA - 126) & 511)]) + ((0.0116890222f * fVec34[((IOTA - 125) & 511)]) + ((0.00854822993f * fVec34[((IOTA - 124) & 511)]) + ((0.00457851822f * fVec34[((IOTA - 123) & 511)]) + ((0.00276781386f * fVec34[((IOTA - 122) & 511)]) + ((0.0015419526f * fVec34[((IOTA - 121) & 511)]) + ((0.00182744535f * fVec34[((IOTA - 120) & 511)]) + ((0.00346819963f * fVec34[((IOTA - 119) & 511)]) + ((0.00456456747f * fVec34[((IOTA - 118) & 511)]) + ((0.00626003975f * fVec34[((IOTA - 117) & 511)]) + ((0.00944879185f * fVec34[((IOTA - 116) & 511)]) + ((0.0123856571f * fVec34[((IOTA - 115) & 511)]) + ((0.0147969536f * fVec34[((IOTA - 114) & 511)]) + ((0.0141706914f * fVec34[((IOTA - 113) & 511)]) + ((0.00815878808f * fVec34[((IOTA - 112) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((0.0244831238f * fVec34[((IOTA - 41) & 511)]) + ((0.0218407735f * fVec34[((IOTA - 40) & 511)]) + ((0.00394428987f * fVec34[((IOTA - 39) & 511)]) + (((0.0599852651f * fVec34[((IOTA - 26) & 511)]) + ((0.0485411547f * fVec34[((IOTA - 18) & 511)]) + ((0.0464022681f * fVec34[((IOTA - 17) & 511)]) + ((0.0263230931f * fVec34[((IOTA - 16) & 511)]) + ((0.00367941288f * fVec34[((IOTA - 33) & 511)]) + ((0.0358887613f * fVec34[((IOTA - 19) & 511)]) + ((0.0188116468f * fVec34[((IOTA - 20) & 511)]) + ((0.061930269f * fVec34[((IOTA - 28) & 511)]) + ((0.0824952945f * fVec34[((IOTA - 27) & 511)]) + ((0.028135132f * fVec34[((IOTA - 29) & 511)]) + (((((0.239402473f * fVec34[((IOTA - 6) & 511)]) + ((0.251217425f * fVec34[((IOTA - 7) & 511)]) + ((0.122236244f * fVec34[((IOTA - 5) & 511)]) + ((0.184815034f * fVec34[((IOTA - 8) & 511)]) + (0.0383519866f * fVec34[((IOTA - 9) & 511)]))))) + (0.0172871482f * fVec34[((IOTA - 15) & 511)])) + (0.0131192142f * fVec34[((IOTA - 34) & 511)])) + (0.0120653184f * fVec34[((IOTA - 35) & 511)])))))))))))) + (0.0144384829f * fVec34[((IOTA - 42) & 511)]))))) + (0.00269499142f * fVec34[((IOTA - 43) & 511)])) + (0.000148900319f * fVec34[((IOTA - 44) & 511)])) + (0.00249741878f * fVec34[((IOTA - 46) & 511)])) + (0.01417094f * fVec34[((IOTA - 47) & 511)])) + (0.0168999713f * fVec34[((IOTA - 48) & 511)])) + (0.00726783648f * fVec34[((IOTA - 49) & 511)])) + (0.00655024452f * fVec34[((IOTA - 50) & 511)])) + (0.0101358779f * fVec34[((IOTA - 51) & 511)])) + (0.00183597067f * fVec34[((IOTA - 52) & 511)])) + (0.00394484773f * fVec34[((IOTA - 54) & 511)])) + (0.00434997538f * fVec34[((IOTA - 55) & 511)])) + (0.0102209765f * fVec34[((IOTA - 56) & 511)])) + (0.0147182718f * fVec34[((IOTA - 57) & 511)])) + (0.0124101788f * fVec34[((IOTA - 58) & 511)])) + (0.011656316f * fVec34[((IOTA - 59) & 511)])) + (0.00371571584f * fVec34[((IOTA - 60) & 511)])) + (0.0126996096f * fVec34[((IOTA - 65) & 511)])) + (0.0296239778f * fVec34[((IOTA - 66) & 511)])) + (0.0362276696f * fVec34[((IOTA - 67) & 511)])) + (0.0313408412f * fVec34[((IOTA - 68) & 511)])) + (0.0233010054f * fVec34[((IOTA - 69) & 511)])) + (0.0115147009f * fVec34[((IOTA - 70) & 511)])) + (0.000374777243f * fVec34[((IOTA - 76) & 511)])) + (0.0123227546f * fVec34[((IOTA - 77) & 511)])) + (0.0188139416f * fVec34[((IOTA - 78) & 511)])) + (0.0142374383f * fVec34[((IOTA - 79) & 511)])) + (0.00679518748f * fVec34[((IOTA - 80) & 511)])) + (0.00220296672f * fVec34[((IOTA - 81) & 511)])) + (0.00555556174f * fVec34[((IOTA - 84) & 511)])) + (0.0118625071f * fVec34[((IOTA - 85) & 511)])) + (0.0163618475f * fVec34[((IOTA - 86) & 511)])) + (0.0167112648f * fVec34[((IOTA - 87) & 511)])) + (0.0173440371f * fVec34[((IOTA - 88) & 511)])) + (0.0183657836f * fVec34[((IOTA - 89) & 511)])) + (0.0153150195f * fVec34[((IOTA - 90) & 511)])) + (0.0126986783f * fVec34[((IOTA - 91) & 511)])) + (0.0104332138f * fVec34[((IOTA - 92) & 511)])) + (0.00176600041f * fVec34[((IOTA - 93) & 511)])) + (0.00389068807f * fVec34[((IOTA - 99) & 511)])) + (0.00784105435f * fVec34[((IOTA - 100) & 511)])) + (0.00990668405f * fVec34[((IOTA - 101) & 511)])) + (0.0118741011f * fVec34[((IOTA - 102) & 511)])) + (0.0159941688f * fVec34[((IOTA - 103) & 511)])) + (0.0184080377f * fVec34[((IOTA - 104) & 511)])) + (0.0163298845f * fVec34[((IOTA - 105) & 511)])) + (0.0093190819f * fVec34[((IOTA - 106) & 511)])) + (0.00305281067f * fVec34[((IOTA - 414) & 511)])))))))))))))))))))))))))))))))))))))) + (0.00334561989f * fVec34[((IOTA - 509) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00331815239f * fVec34[((IOTA - 510) & 511)])) + (0.00311224023f * fVec34[((IOTA - 511) & 511)]))) : (((0.00326913875f * (fVec33[((IOTA - 335) & 511)] - fVec33[((IOTA - 487) & 511)])) + ((0.00144061493f * fVec33[((IOTA - 386) & 511)]) + ((0.00107827736f * fVec33[((IOTA - 385) & 511)]) + ((0.000316531863f * fVec33[((IOTA - 362) & 511)]) + ((0.00139563065f * fVec33[((IOTA - 361) & 511)]) + ((0.00228767423f * fVec33[((IOTA - 360) & 511)]) + ((0.00234161131f * fVec33[((IOTA - 359) & 511)]) + ((0.000807879958f * fVec33[((IOTA - 358) & 511)]) + ((0.0030377293f * fVec33[((IOTA - 351) & 511)]) + ((0.00559470616f * fVec33[((IOTA - 350) & 511)]) + ((0.00585563062f * fVec33[((IOTA - 349) & 511)]) + ((0.00415368052f * fVec33[((IOTA - 348) & 511)]) + ((0.00173020503f * fVec33[((IOTA - 347) & 511)]) + ((4.81600873e-05f * fVec33[((IOTA - 346) & 511)]) + ((0.00029566884f * fVec33[((IOTA - 344) & 511)]) + ((0.00154503901f * fVec33[((IOTA - 343) & 511)]) + ((0.00293185376f * fVec33[((IOTA - 342) & 511)]) + ((0.00321292924f * fVec33[((IOTA - 341) & 511)]) + ((0.0028851172f * fVec33[((IOTA - 340) & 511)]) + ((0.00282143289f * fVec33[((IOTA - 339) & 511)]) + ((0.0029273089f * fVec33[((IOTA - 338) & 511)]) + ((0.00321854185f * fVec33[((IOTA - 337) & 511)]) + ((((((0.00131064514f * fVec33[((IOTA - 330) & 511)]) + ((0.000650065951f * fVec33[((IOTA - 329) & 511)]) + ((0.000305278692f * fVec33[((IOTA - 328) & 511)]) + ((0.00054509379f * fVec33[((IOTA - 327) & 511)]) + ((0.00148078008f * fVec33[((IOTA - 326) & 511)]) + ((0.00248858333f * fVec33[((IOTA - 325) & 511)]) + ((0.00281379418f * fVec33[((IOTA - 324) & 511)]) + ((0.0025162911f * fVec33[((IOTA - 323) & 511)]) + ((0.00141668506f * fVec33[((IOTA - 322) & 511)]) + ((0.00182222668f * fVec33[((IOTA - 317) & 511)]) + ((0.00459670462f * fVec33[((IOTA - 316) & 511)]) + ((0.00612988835f * fVec33[((IOTA - 315) & 511)]) + ((0.00707773119f * fVec33[((IOTA - 314) & 511)]) + ((0.00667279214f * fVec33[((IOTA - 313) & 511)]) + ((0.00548502477f * fVec33[((IOTA - 312) & 511)]) + ((0.00487339962f * fVec33[((IOTA - 311) & 511)]) + ((0.0037819799f * fVec33[((IOTA - 310) & 511)]) + ((0.00263670506f * fVec33[((IOTA - 309) & 511)]) + ((0.00222883653f * fVec33[((IOTA - 308) & 511)]) + ((0.00238278974f * fVec33[((IOTA - 307) & 511)]) + ((0.00374674285f * fVec33[((IOTA - 306) & 511)]) + ((0.0059348112f * fVec33[((IOTA - 305) & 511)]) + ((0.00770123908f * fVec33[((IOTA - 304) & 511)]) + ((0.00889757648f * fVec33[((IOTA - 303) & 511)]) + ((0.00936017558f * fVec33[((IOTA - 302) & 511)]) + ((0.00908315275f * fVec33[((IOTA - 301) & 511)]) + ((0.00846079551f * fVec33[((IOTA - 300) & 511)]) + ((0.00747240335f * fVec33[((IOTA - 299) & 511)]) + ((0.00687408447f * fVec33[((IOTA - 298) & 511)]) + ((0.00678263744f * fVec33[((IOTA - 297) & 511)]) + ((0.00562112732f * fVec33[((IOTA - 296) & 511)]) + ((0.00362164667f * fVec33[((IOTA - 295) & 511)]) + ((0.00200906303f * fVec33[((IOTA - 294) & 511)]) + ((0.00120304478f * fVec33[((IOTA - 293) & 511)]) + ((0.00175224571f * fVec33[((IOTA - 292) & 511)]) + ((0.00395017071f * fVec33[((IOTA - 291) & 511)]) + ((0.00659741694f * fVec33[((IOTA - 290) & 511)]) + ((0.00801224075f * fVec33[((IOTA - 289) & 511)]) + ((0.00745290937f * fVec33[((IOTA - 288) & 511)]) + ((0.00560749229f * fVec33[((IOTA - 287) & 511)]) + ((0.00375906331f * fVec33[((IOTA - 286) & 511)]) + ((0.00281582028f * fVec33[((IOTA - 285) & 511)]) + ((0.00331499893f * fVec33[((IOTA - 284) & 511)]) + ((0.00445789192f * fVec33[((IOTA - 283) & 511)]) + ((0.0048950566f * fVec33[((IOTA - 282) & 511)]) + ((0.00452045351f * fVec33[((IOTA - 281) & 511)]) + ((0.00368757593f * fVec33[((IOTA - 280) & 511)]) + ((0.00254884502f * fVec33[((IOTA - 279) & 511)]) + ((0.00181535492f * fVec33[((IOTA - 278) & 511)]) + ((0.00145140197f * fVec33[((IOTA - 277) & 511)]) + ((0.00177135644f * fVec33[((IOTA - 276) & 511)]) + ((0.00299468916f * fVec33[((IOTA - 275) & 511)]) + ((0.00447990466f * fVec33[((IOTA - 274) & 511)]) + ((0.00648543565f * fVec33[((IOTA - 273) & 511)]) + ((0.00924203452f * fVec33[((IOTA - 272) & 511)]) + ((0.0119275572f * fVec33[((IOTA - 271) & 511)]) + ((0.0133813955f * fVec33[((IOTA - 270) & 511)]) + ((0.0122830216f * fVec33[((IOTA - 269) & 511)]) + ((0.00879090652f * fVec33[((IOTA - 268) & 511)]) + ((0.00484960666f * fVec33[((IOTA - 267) & 511)]) + ((0.00244395528f * fVec33[((IOTA - 266) & 511)]) + ((0.0023191059f * fVec33[((IOTA - 265) & 511)]) + ((0.00426941272f * fVec33[((IOTA - 264) & 511)]) + ((0.00735790329f * fVec33[((IOTA - 263) & 511)]) + ((0.00953502022f * fVec33[((IOTA - 262) & 511)]) + ((0.00983531587f * fVec33[((IOTA - 261) & 511)]) + ((0.00830029696f * fVec33[((IOTA - 260) & 511)]) + ((0.00645570178f * fVec33[((IOTA - 259) & 511)]) + ((0.00573280733f * fVec33[((IOTA - 258) & 511)]) + ((0.00609788205f * fVec33[((IOTA - 257) & 511)]) + ((0.00701013207f * fVec33[((IOTA - 256) & 511)]) + ((0.00857422687f * fVec33[((IOTA - 255) & 511)]) + ((0.00998420455f * fVec33[((IOTA - 254) & 511)]) + ((0.0105870413f * fVec33[((IOTA - 253) & 511)]) + ((0.0101850592f * fVec33[((IOTA - 252) & 511)]) + ((0.00905749854f * fVec33[((IOTA - 251) & 511)]) + ((0.00696867984f * fVec33[((IOTA - 250) & 511)]) + ((0.00321876118f * fVec33[((IOTA - 249) & 511)]) + ((0.00165291363f * fVec33[((IOTA - 245) & 511)]) + ((0.00565099809f * fVec33[((IOTA - 244) & 511)]) + ((0.00855273381f * fVec33[((IOTA - 243) & 511)]) + ((0.00921870768f * fVec33[((IOTA - 242) & 511)]) + ((0.00736808823f * fVec33[((IOTA - 241) & 511)]) + ((0.00443412643f * fVec33[((IOTA - 240) & 511)]) + ((0.00278770179f * fVec33[((IOTA - 239) & 511)]) + ((0.00286523998f * fVec33[((IOTA - 238) & 511)]) + ((0.00411304971f * fVec33[((IOTA - 237) & 511)]) + ((0.0065729674f * fVec33[((IOTA - 236) & 511)]) + ((0.00844343659f * fVec33[((IOTA - 235) & 511)]) + ((0.00886871852f * fVec33[((IOTA - 234) & 511)]) + ((0.00916340202f * fVec33[((IOTA - 233) & 511)]) + ((0.00945775583f * fVec33[((IOTA - 232) & 511)]) + ((0.00932209194f * fVec33[((IOTA - 231) & 511)]) + ((0.00842917152f * fVec33[((IOTA - 230) & 511)]) + ((0.006308374f * fVec33[((IOTA - 229) & 511)]) + ((0.00415669242f * fVec33[((IOTA - 228) & 511)]) + ((0.0030183997f * fVec33[((IOTA - 227) & 511)]) + ((0.00395947974f * fVec33[((IOTA - 226) & 511)]) + ((0.00727825705f * fVec33[((IOTA - 225) & 511)]) + ((0.0107049365f * fVec33[((IOTA - 224) & 511)]) + ((0.0121939294f * fVec33[((IOTA - 223) & 511)]) + ((0.0102561358f * fVec33[((IOTA - 222) & 511)]) + ((0.00551467668f * fVec33[((IOTA - 221) & 511)]) + ((2.97888182e-05f * fVec33[((IOTA - 220) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0323079973f * fVec33[((IOTA - 64) & 511)]) + ((0.00986135378f * fVec33[((IOTA - 63) & 511)]) + ((0.00212120824f * fVec33[((IOTA - 57) & 511)]) + ((0.0205024146f * fVec33[((IOTA - 56) & 511)]) + ((0.0233878866f * fVec33[((IOTA - 55) & 511)]) + ((0.0127130412f * fVec33[((IOTA - 54) & 511)]) + ((0.00552217849f * fVec33[((IOTA - 53) & 511)]) + ((0.00140932016f * fVec33[((IOTA - 52) & 511)]) + ((0.00589724677f * fVec33[((IOTA - 43) & 511)]) + ((0.00818505883f * fVec33[((IOTA - 42) & 511)]) + ((0.0051319967f * fVec33[((IOTA - 41) & 511)]) + ((0.00281406799f * fVec33[((IOTA - 33) & 511)]) + ((0.00105944043f * fVec33[((IOTA - 31) & 511)]) + ((0.0343970358f * fVec33[((IOTA - 25) & 511)]) + ((0.0692298114f * fVec33[((IOTA - 24) & 511)]) + ((0.0800160319f * fVec33[((IOTA - 23) & 511)]) + ((0.0594568923f * fVec33[((IOTA - 22) & 511)]) + ((0.0169228222f * fVec33[((IOTA - 21) & 511)]) + ((0.0445577241f * fVec33[((IOTA - 15) & 511)]) + ((0.0917818919f * fVec33[((IOTA - 14) & 511)]) + ((0.137057945f * fVec33[((IOTA - 13) & 511)]) + ((0.12961562f * fVec33[((IOTA - 12) & 511)]) + ((0.0529295653f * fVec33[((IOTA - 11) & 511)]) + ((0.0193313211f * fVec33[((IOTA - 5) & 511)]) + ((0.170655444f * fVec33[((IOTA - 4) & 511)]) + ((0.210966393f * fVec33[((IOTA - 3) & 511)]) + ((0.191403806f * fVec33[((IOTA - 2) & 511)]) + ((0.175587922f * fVec33[((IOTA - 1) & 511)]) + ((fSlow107 * fTemp0) + (0.0280218273f * fVec33[((IOTA - 65) & 511)])))))))))))))))))))))))))))))) + (0.00780251529f * fVec33[((IOTA - 66) & 511)])) + (0.0128440233f * fVec33[((IOTA - 73) & 511)])) + (0.0221831445f * fVec33[((IOTA - 74) & 511)])) + (0.0195713546f * fVec33[((IOTA - 75) & 511)])) + (0.00851700455f * fVec33[((IOTA - 76) & 511)])) + (0.000382104889f * fVec33[((IOTA - 83) & 511)])) + (0.00497204671f * fVec33[((IOTA - 84) & 511)])) + (0.00696618808f * fVec33[((IOTA - 85) & 511)])) + (0.00230270578f * fVec33[((IOTA - 86) & 511)])) + (0.00562123675f * fVec33[((IOTA - 95) & 511)])) + (0.0101902606f * fVec33[((IOTA - 96) & 511)])) + (0.00974753872f * fVec33[((IOTA - 97) & 511)])) + (0.00625558663f * fVec33[((IOTA - 98) & 511)])) + (0.00392448902f * fVec33[((IOTA - 99) & 511)])) + (0.00198384654f * fVec33[((IOTA - 100) & 511)])) + (1.59349293e-05f * fVec33[((IOTA - 101) & 511)])) + (0.00240483042f * fVec33[((IOTA - 109) & 511)])) + (0.00547059579f * fVec33[((IOTA - 110) & 511)])) + (0.00310995569f * fVec33[((IOTA - 111) & 511)])) + (0.00528041972f * fVec33[((IOTA - 129) & 511)])) + (0.0103586158f * fVec33[((IOTA - 130) & 511)])) + (0.0118562616f * fVec33[((IOTA - 131) & 511)])) + (0.00976024196f * fVec33[((IOTA - 132) & 511)])) + (0.00587134622f * fVec33[((IOTA - 133) & 511)])) + (0.00112630054f * fVec33[((IOTA - 134) & 511)])) + (0.00358180981f * fVec33[((IOTA - 145) & 511)])) + (0.00626725052f * fVec33[((IOTA - 146) & 511)])) + (0.00670561986f * fVec33[((IOTA - 147) & 511)])) + (0.00532658119f * fVec33[((IOTA - 148) & 511)])) + (0.00210105721f * fVec33[((IOTA - 149) & 511)])) + (0.00192024466f * fVec33[((IOTA - 154) & 511)])) + (0.0040277089f * fVec33[((IOTA - 155) & 511)])) + (0.00580029702f * fVec33[((IOTA - 156) & 511)])) + (0.00499800267f * fVec33[((IOTA - 157) & 511)])) + (0.000110283494f * fVec33[((IOTA - 158) & 511)])) + (0.00296613248f * fVec33[((IOTA - 164) & 511)])) + (0.00413602125f * fVec33[((IOTA - 165) & 511)])) + (0.00351453898f * fVec33[((IOTA - 166) & 511)])) + (0.00225000037f * fVec33[((IOTA - 167) & 511)])) + (0.00219031377f * fVec33[((IOTA - 168) & 511)])) + (0.00296563981f * fVec33[((IOTA - 169) & 511)])) + (0.00352894049f * fVec33[((IOTA - 170) & 511)])) + (0.00352245197f * fVec33[((IOTA - 171) & 511)])) + (0.0024684323f * fVec33[((IOTA - 172) & 511)])) + (0.000398368109f * fVec33[((IOTA - 173) & 511)])) + (0.000386512838f * fVec33[((IOTA - 177) & 511)])) + (0.00259410311f * fVec33[((IOTA - 178) & 511)])) + (0.0034245709f * fVec33[((IOTA - 179) & 511)])) + (0.00381434197f * fVec33[((IOTA - 180) & 511)])) + (0.00585820433f * fVec33[((IOTA - 181) & 511)])) + (0.00709711574f * fVec33[((IOTA - 182) & 511)])) + (0.00737194903f * fVec33[((IOTA - 183) & 511)])) + (0.00719349086f * fVec33[((IOTA - 184) & 511)])) + (0.00456248038f * fVec33[((IOTA - 185) & 511)])) + (0.00170236034f * fVec33[((IOTA - 186) & 511)])) + (0.000252710655f * fVec33[((IOTA - 187) & 511)])) + (0.000603904482f * fVec33[((IOTA - 188) & 511)])) + (0.00357712805f * fVec33[((IOTA - 189) & 511)])) + (0.00732994918f * fVec33[((IOTA - 190) & 511)])) + (0.0103074163f * fVec33[((IOTA - 191) & 511)])) + (0.0118523743f * fVec33[((IOTA - 192) & 511)])) + (0.0108355898f * fVec33[((IOTA - 193) & 511)])) + (0.00836543273f * fVec33[((IOTA - 194) & 511)])) + (0.0059490758f * fVec33[((IOTA - 195) & 511)])) + (0.00368806906f * fVec33[((IOTA - 196) & 511)])) + (0.00264311209f * fVec33[((IOTA - 197) & 511)])) + (0.00319965044f * fVec33[((IOTA - 198) & 511)])) + (0.00344069721f * fVec33[((IOTA - 199) & 511)])) + (0.00292128511f * fVec33[((IOTA - 200) & 511)])) + (0.00223844638f * fVec33[((IOTA - 201) & 511)])) + (0.00155393733f * fVec33[((IOTA - 202) & 511)])) + (0.00193585083f * fVec33[((IOTA - 203) & 511)])) + (0.00346490042f * fVec33[((IOTA - 204) & 511)])) + (0.00511581544f * fVec33[((IOTA - 205) & 511)])) + (0.00641753525f * fVec33[((IOTA - 206) & 511)])) + (0.0067000892f * fVec33[((IOTA - 207) & 511)])) + (0.00639097719f * fVec33[((IOTA - 208) & 511)])) + (0.00632915506f * fVec33[((IOTA - 209) & 511)])) + (0.00629665563f * fVec33[((IOTA - 210) & 511)])) + (0.00712107262f * fVec33[((IOTA - 211) & 511)])) + (0.00895082951f * fVec33[((IOTA - 212) & 511)])) + (0.0106584737f * fVec33[((IOTA - 213) & 511)])) + (0.0114761554f * fVec33[((IOTA - 214) & 511)])) + (0.00947095267f * fVec33[((IOTA - 215) & 511)])) + (0.00473431265f * fVec33[((IOTA - 216) & 511)])) + (0.000173913315f * fVec33[((IOTA - 217) & 511)])) + (0.00167021714f * fVec33[((IOTA - 331) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00207893504f * fVec33[((IOTA - 332) & 511)])) + (0.00280267838f * fVec33[((IOTA - 333) & 511)])) + (0.00309719704f * fVec33[((IOTA - 334) & 511)])) + (0.00352661358f * fVec33[((IOTA - 336) & 511)])))))))))))))))))))))))) - ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00322045851f * fVec33[((IOTA - 379) & 511)]) + ((0.00185357593f * fVec33[((IOTA - 378) & 511)]) + ((0.00109927729f * fVec33[((IOTA - 377) & 511)]) + ((0.00128019974f * fVec33[((IOTA - 376) & 511)]) + ((0.00204161694f * fVec33[((IOTA - 375) & 511)]) + ((0.00269819889f * fVec33[((IOTA - 374) & 511)]) + ((0.0032431013f * fVec33[((IOTA - 373) & 511)]) + ((0.00425813254f * fVec33[((IOTA - 372) & 511)]) + ((0.00543700159f * fVec33[((IOTA - 371) & 511)]) + ((0.00644316198f * fVec33[((IOTA - 370) & 511)]) + ((0.00716411276f * fVec33[((IOTA - 369) & 511)]) + ((0.00688336603f * fVec33[((IOTA - 368) & 511)]) + ((0.00564382458f * fVec33[((IOTA - 367) & 511)]) + ((0.00400238298f * fVec33[((IOTA - 366) & 511)]) + ((0.00245961593f * fVec33[((IOTA - 365) & 511)]) + ((0.00162734138f * fVec33[((IOTA - 364) & 511)]) + ((0.000828167889f * fVec33[((IOTA - 363) & 511)]) + ((0.00191496033f * fVec33[((IOTA - 357) & 511)]) + ((0.00501273246f * fVec33[((IOTA - 356) & 511)]) + ((0.00747582596f * fVec33[((IOTA - 355) & 511)]) + ((0.00766047137f * fVec33[((IOTA - 354) & 511)]) + ((0.00501927594f * fVec33[((IOTA - 353) & 511)]) + ((0.000924789347f * fVec33[((IOTA - 352) & 511)]) + ((0.000282937195f * fVec33[((IOTA - 345) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.113026477f * fVec33[((IOTA - 6) & 511)]) + (0.201239362f * fVec33[((IOTA - 7) & 511)])) + (0.221864983f * fVec33[((IOTA - 8) & 511)])) + (0.15931952f * fVec33[((IOTA - 9) & 511)])) + (0.0546875335f * fVec33[((IOTA - 10) & 511)])) + (0.0068824077f * fVec33[((IOTA - 16) & 511)])) + (0.0579272658f * fVec33[((IOTA - 17) & 511)])) + (0.071683459f * fVec33[((IOTA - 18) & 511)])) + (0.0551379472f * fVec33[((IOTA - 19) & 511)])) + (0.0250955857f * fVec33[((IOTA - 20) & 511)])) + (0.0179765671f * fVec33[((IOTA - 26) & 511)])) + (0.0551499948f * fVec33[((IOTA - 27) & 511)])) + (0.0681824461f * fVec33[((IOTA - 28) & 511)])) + (0.0547846742f * fVec33[((IOTA - 29) & 511)])) + (0.017766295f * fVec33[((IOTA - 30) & 511)])) + (0.000731820241f * fVec33[((IOTA - 32) & 511)])) + (0.00484602014f * fVec33[((IOTA - 34) & 511)])) + (0.0156704932f * fVec33[((IOTA - 35) & 511)])) + (0.0140743647f * fVec33[((IOTA - 36) & 511)])) + (0.00770192361f * fVec33[((IOTA - 37) & 511)])) + (0.00678340439f * fVec33[((IOTA - 38) & 511)])) + (0.00682307687f * fVec33[((IOTA - 39) & 511)])) + (0.00273466809f * fVec33[((IOTA - 40) & 511)])) + (0.00355692208f * fVec33[((IOTA - 44) & 511)])) + (0.0127072632f * fVec33[((IOTA - 45) & 511)])) + (0.0292139202f * fVec33[((IOTA - 46) & 511)])) + (0.0417253673f * fVec33[((IOTA - 47) & 511)])) + (0.0337027237f * fVec33[((IOTA - 48) & 511)])) + (0.0235306695f * fVec33[((IOTA - 49) & 511)])) + (0.0194733646f * fVec33[((IOTA - 50) & 511)])) + (0.00886704773f * fVec33[((IOTA - 51) & 511)])) + (0.0229757745f * fVec33[((IOTA - 58) & 511)])) + (0.0499174632f * fVec33[((IOTA - 59) & 511)])) + (0.0594893917f * fVec33[((IOTA - 60) & 511)])) + (0.0495015718f * fVec33[((IOTA - 61) & 511)])) + (0.0262355767f * fVec33[((IOTA - 62) & 511)])) + (0.0203081034f * fVec33[((IOTA - 67) & 511)])) + (0.0440815724f * fVec33[((IOTA - 68) & 511)])) + (0.0514968634f * fVec33[((IOTA - 69) & 511)])) + (0.041532781f * fVec33[((IOTA - 70) & 511)])) + (0.0227976441f * fVec33[((IOTA - 71) & 511)])) + (0.00412649289f * fVec33[((IOTA - 72) & 511)])) + (0.00728307571f * fVec33[((IOTA - 77) & 511)])) + (0.0184655599f * fVec33[((IOTA - 78) & 511)])) + (0.0236851722f * fVec33[((IOTA - 79) & 511)])) + (0.0254378542f * fVec33[((IOTA - 80) & 511)])) + (0.0178972781f * fVec33[((IOTA - 81) & 511)])) + (0.00607102318f * fVec33[((IOTA - 82) & 511)])) + (0.00536740338f * fVec33[((IOTA - 87) & 511)])) + (0.016515363f * fVec33[((IOTA - 88) & 511)])) + (0.0300561339f * fVec33[((IOTA - 89) & 511)])) + (0.0353324488f * fVec33[((IOTA - 90) & 511)])) + (0.0343813449f * fVec33[((IOTA - 91) & 511)])) + (0.0299980361f * fVec33[((IOTA - 92) & 511)])) + (0.0158675425f * fVec33[((IOTA - 93) & 511)])) + (0.00107397884f * fVec33[((IOTA - 94) & 511)])) + (0.00397114316f * fVec33[((IOTA - 102) & 511)])) + (0.00992126018f * fVec33[((IOTA - 103) & 511)])) + (0.0163341407f * fVec33[((IOTA - 104) & 511)])) + (0.0221058801f * fVec33[((IOTA - 105) & 511)])) + (0.0214738306f * fVec33[((IOTA - 106) & 511)])) + (0.0150925452f * fVec33[((IOTA - 107) & 511)])) + (0.00622650981f * fVec33[((IOTA - 108) & 511)])) + (0.00176527817f * fVec33[((IOTA - 112) & 511)])) + (0.00618872652f * fVec33[((IOTA - 113) & 511)])) + (0.00864171702f * fVec33[((IOTA - 114) & 511)])) + (0.0109371673f * fVec33[((IOTA - 115) & 511)])) + (0.0123162325f * fVec33[((IOTA - 116) & 511)])) + (0.0128673231f * fVec33[((IOTA - 117) & 511)])) + (0.0125906561f * fVec33[((IOTA - 118) & 511)])) + (0.0112800375f * fVec33[((IOTA - 119) & 511)])) + (0.00937901251f * fVec33[((IOTA - 120) & 511)])) + (0.00710702734f * fVec33[((IOTA - 121) & 511)])) + (0.00649170578f * fVec33[((IOTA - 122) & 511)])) + (0.00743010221f * fVec33[((IOTA - 123) & 511)])) + (0.00936628133f * fVec33[((IOTA - 124) & 511)])) + (0.0112873483f * fVec33[((IOTA - 125) & 511)])) + (0.010395797f * fVec33[((IOTA - 126) & 511)])) + (0.00697713997f * fVec33[((IOTA - 127) & 511)])) + (0.0015172218f * fVec33[((IOTA - 128) & 511)])) + (0.00263029849f * fVec33[((IOTA - 135) & 511)])) + (0.00392941711f * fVec33[((IOTA - 136) & 511)])) + (0.00365165435f * fVec33[((IOTA - 137) & 511)])) + (0.00375922769f * fVec33[((IOTA - 138) & 511)])) + (0.00580957858f * fVec33[((IOTA - 139) & 511)])) + (0.00843472965f * fVec33[((IOTA - 140) & 511)])) + (0.00990587287f * fVec33[((IOTA - 141) & 511)])) + (0.00966581143f * fVec33[((IOTA - 142) & 511)])) + (0.00590039557f * fVec33[((IOTA - 143) & 511)])) + (0.000688095577f * fVec33[((IOTA - 144) & 511)])) + (0.0017803642f * fVec33[((IOTA - 150) & 511)])) + (0.00429766811f * fVec33[((IOTA - 151) & 511)])) + (0.00480566313f * fVec33[((IOTA - 152) & 511)])) + (0.00197867211f * fVec33[((IOTA - 153) & 511)])) + (0.00447886437f * fVec33[((IOTA - 159) & 511)])) + (0.00727798324f * fVec33[((IOTA - 160) & 511)])) + (0.00761871831f * fVec33[((IOTA - 161) & 511)])) + (0.00447563361f * fVec33[((IOTA - 162) & 511)])) + (0.000269494019f * fVec33[((IOTA - 163) & 511)])) + (0.00125402492f * fVec33[((IOTA - 174) & 511)])) + (0.00136020174f * fVec33[((IOTA - 175) & 511)])) + (0.000796517357f * fVec33[((IOTA - 176) & 511)])) + (0.00314743817f * fVec33[((IOTA - 218) & 511)])) + (0.00363287237f * fVec33[((IOTA - 219) & 511)])) + (0.00133876363f * fVec33[((IOTA - 246) & 511)])) + (0.0023068944f * fVec33[((IOTA - 247) & 511)])) + (0.000705563463f * fVec33[((IOTA - 248) & 511)])) + (0.000850618817f * fVec33[((IOTA - 318) & 511)])) + (0.00208799727f * fVec33[((IOTA - 319) & 511)])) + (0.00233755959f * fVec33[((IOTA - 320) & 511)])) + (0.000835642684f * fVec33[((IOTA - 321) & 511)])) + (0.00451541552f * fVec33[((IOTA - 380) & 511)])))))))))))))))))))))))))) + (0.00507762143f * fVec33[((IOTA - 381) & 511)])) + (0.00457063969f * fVec33[((IOTA - 382) & 511)])) + (0.00289694499f * fVec33[((IOTA - 383) & 511)])) + (0.000661017373f * fVec33[((IOTA - 384) & 511)])) + (0.000163919758f * fVec33[((IOTA - 387) & 511)])) + (0.00257674465f * fVec33[((IOTA - 388) & 511)])) + (0.00410913443f * fVec33[((IOTA - 389) & 511)])) + (0.00447243033f * fVec33[((IOTA - 390) & 511)])) + (0.00362701342f * fVec33[((IOTA - 391) & 511)])) + (0.00183167262f * fVec33[((IOTA - 392) & 511)])) + (0.000451949425f * fVec33[((IOTA - 393) & 511)])) + (0.000526065007f * fVec33[((IOTA - 394) & 511)])) + (0.00206850329f * fVec33[((IOTA - 395) & 511)])) + (0.00432157051f * fVec33[((IOTA - 396) & 511)])) + (0.00665110769f * fVec33[((IOTA - 397) & 511)])) + (0.00816706941f * fVec33[((IOTA - 398) & 511)])) + (0.00785480998f * fVec33[((IOTA - 399) & 511)])) + (0.00598658575f * fVec33[((IOTA - 400) & 511)])) + (0.00364185264f * fVec33[((IOTA - 401) & 511)])) + (0.00186726591f * fVec33[((IOTA - 402) & 511)])) + (0.00137764262f * fVec33[((IOTA - 403) & 511)])) + (0.00184013275f * fVec33[((IOTA - 404) & 511)])) + (0.00248833699f * fVec33[((IOTA - 405) & 511)])) + (0.00330360932f * fVec33[((IOTA - 406) & 511)])) + (0.00421687216f * fVec33[((IOTA - 407) & 511)])) + (0.00431664195f * fVec33[((IOTA - 408) & 511)])) + (0.00386411743f * fVec33[((IOTA - 409) & 511)])) + (0.00365628162f * fVec33[((IOTA - 410) & 511)])) + (0.00309747085f * fVec33[((IOTA - 411) & 511)])) + (0.00232118648f * fVec33[((IOTA - 412) & 511)])) + (0.00253485423f * fVec33[((IOTA - 413) & 511)])) + (0.00308027677f * fVec33[((IOTA - 414) & 511)])) + (0.00362980599f * fVec33[((IOTA - 415) & 511)])) + (0.00431034481f * fVec33[((IOTA - 416) & 511)])) + (0.00400104141f * fVec33[((IOTA - 417) & 511)])) + (0.00295071816f * fVec33[((IOTA - 418) & 511)])) + (0.00203296496f * fVec33[((IOTA - 419) & 511)])) + (0.00101270434f * fVec33[((IOTA - 420) & 511)])) + (0.00076327892f * fVec33[((IOTA - 421) & 511)])) + (0.00186556811f * fVec33[((IOTA - 422) & 511)])) + (0.00289954618f * fVec33[((IOTA - 423) & 511)])) + (0.00327721564f * fVec33[((IOTA - 424) & 511)])) + (0.0031767888f * fVec33[((IOTA - 425) & 511)])) + (0.00252417661f * fVec33[((IOTA - 426) & 511)])) + (0.00171186123f * fVec33[((IOTA - 427) & 511)])) + (0.00120832911f * fVec33[((IOTA - 428) & 511)])) + (0.00155177433f * fVec33[((IOTA - 429) & 511)])) + (0.00290439231f * fVec33[((IOTA - 430) & 511)])) + (0.00409815554f * fVec33[((IOTA - 431) & 511)])) + (0.00486565102f * fVec33[((IOTA - 432) & 511)])) + (0.00546380598f * fVec33[((IOTA - 433) & 511)])) + (0.00538930669f * fVec33[((IOTA - 434) & 511)])) + (0.00492254505f * fVec33[((IOTA - 435) & 511)])) + (0.00467706285f * fVec33[((IOTA - 436) & 511)])) + (0.00471558515f * fVec33[((IOTA - 437) & 511)])) + (0.00559974369f * fVec33[((IOTA - 438) & 511)])) + (0.00700167194f * fVec33[((IOTA - 439) & 511)])) + (0.00784837548f * fVec33[((IOTA - 440) & 511)])) + (0.00855035242f * fVec33[((IOTA - 441) & 511)])) + (0.00886247586f * fVec33[((IOTA - 442) & 511)])) + (0.00781237194f * fVec33[((IOTA - 443) & 511)])) + (0.00605330896f * fVec33[((IOTA - 444) & 511)])) + (0.00407753885f * fVec33[((IOTA - 445) & 511)])) + (0.0022995295f * fVec33[((IOTA - 446) & 511)])) + (0.00177935092f * fVec33[((IOTA - 447) & 511)])) + (0.00242322916f * fVec33[((IOTA - 448) & 511)])) + (0.00359440455f * fVec33[((IOTA - 449) & 511)])) + (0.00453783898f * fVec33[((IOTA - 450) & 511)])) + (0.00473157503f * fVec33[((IOTA - 451) & 511)])) + (0.00431727199f * fVec33[((IOTA - 452) & 511)])) + (0.003328552f * fVec33[((IOTA - 453) & 511)])) + (0.00269691227f * fVec33[((IOTA - 454) & 511)])) + (0.00320471544f * fVec33[((IOTA - 455) & 511)])) + (0.00405998901f * fVec33[((IOTA - 456) & 511)])) + (0.00459684152f * fVec33[((IOTA - 457) & 511)])) + (0.00485626003f * fVec33[((IOTA - 458) & 511)])) + (0.00466257893f * fVec33[((IOTA - 459) & 511)])) + (0.00383287808f * fVec33[((IOTA - 460) & 511)])) + (0.00284793647f * fVec33[((IOTA - 461) & 511)])) + (0.00267342059f * fVec33[((IOTA - 462) & 511)])) + (0.00368335983f * fVec33[((IOTA - 463) & 511)])) + (0.00523625687f * fVec33[((IOTA - 464) & 511)])) + (0.0063943998f * fVec33[((IOTA - 465) & 511)])) + (0.00657800492f * fVec33[((IOTA - 466) & 511)])) + (0.00558912056f * fVec33[((IOTA - 467) & 511)])) + (0.00341476919f * fVec33[((IOTA - 468) & 511)])) + (0.0011459589f * fVec33[((IOTA - 469) & 511)])) + (5.76605089e-05f * fVec33[((IOTA - 470) & 511)])) + (5.37182204e-05f * fVec33[((IOTA - 471) & 511)])) + (0.000618935563f * fVec33[((IOTA - 472) & 511)])) + (0.00165923825f * fVec33[((IOTA - 473) & 511)])) + (0.00298182108f * fVec33[((IOTA - 474) & 511)])) + (0.00401423825f * fVec33[((IOTA - 475) & 511)])) + (0.00420849398f * fVec33[((IOTA - 476) & 511)])) + (0.00408282317f * fVec33[((IOTA - 477) & 511)])) + (0.00431174133f * fVec33[((IOTA - 478) & 511)])) + (0.00460349442f * fVec33[((IOTA - 479) & 511)])) + (0.00470791897f * fVec33[((IOTA - 480) & 511)])) + (0.00482792268f * fVec33[((IOTA - 481) & 511)])) + (0.00459426781f * fVec33[((IOTA - 482) & 511)])) + (0.00397804286f * fVec33[((IOTA - 483) & 511)])) + (0.00345898652f * fVec33[((IOTA - 484) & 511)])) + (0.00301692123f * fVec33[((IOTA - 485) & 511)])) + (0.00307209045f * fVec33[((IOTA - 486) & 511)])) + (0.00324411411f * fVec33[((IOTA - 488) & 511)])) + (0.00331045408f * fVec33[((IOTA - 489) & 511)])) + (0.00260686176f * fVec33[((IOTA - 490) & 511)])) + (0.00137892924f * fVec33[((IOTA - 491) & 511)])) + (0.000755612738f * fVec33[((IOTA - 492) & 511)])) + (0.000293642748f * fVec33[((IOTA - 493) & 511)])) + (1.66739337e-05f * fVec33[((IOTA - 494) & 511)])) + (0.000251149759f * fVec33[((IOTA - 495) & 511)])) + (0.000841693487f * fVec33[((IOTA - 496) & 511)])) + (0.00176568888f * fVec33[((IOTA - 497) & 511)])) + (0.00263922429f * fVec33[((IOTA - 498) & 511)])) + (0.00317717204f * fVec33[((IOTA - 499) & 511)])) + (0.00334823737f * fVec33[((IOTA - 500) & 511)])) + (0.00297095114f * fVec33[((IOTA - 501) & 511)])) + (0.00253406027f * fVec33[((IOTA - 502) & 511)])) + (0.00293264771f * fVec33[((IOTA - 503) & 511)])) + (0.00406872295f * fVec33[((IOTA - 504) & 511)])) + (0.00572089711f * fVec33[((IOTA - 505) & 511)])) + (0.00726092607f * fVec33[((IOTA - 506) & 511)])) + (0.00755749829f * fVec33[((IOTA - 507) & 511)])) + (0.00650906423f * fVec33[((IOTA - 508) & 511)])) + (0.00485708145f * fVec33[((IOTA - 509) & 511)])) + (0.0030773473f * fVec33[((IOTA - 510) & 511)])) + (0.00219220296f * fVec33[((IOTA - 511) & 511)]))))) : (iSlow93 ? (iSlow99 ? ((((((((((((((((((0.00151104992f * fVec32[((IOTA - 341) & 511)]) + ((0.00188579829f * fVec32[((IOTA - 338) & 511)]) + ((0.00480499165f * fVec32[((IOTA - 337) & 511)]) + ((0.00709493645f * fVec32[((IOTA - 336) & 511)]) + ((0.00765379937f * fVec32[((IOTA - 335) & 511)]) + ((0.00650593638f * fVec32[((IOTA - 334) & 511)]) + ((0.00386028411f * fVec32[((IOTA - 333) & 511)]) + ((0.00118969986f * fVec32[((IOTA - 332) & 511)]) + ((5.82481734e-05f * fVec32[((IOTA - 328) & 511)]) + ((0.00130526396f * fVec32[((IOTA - 327) & 511)]) + ((((((((((((((((((((((((((((((((((((((((0.00896994025f * fVec32[((IOTA - 284) & 511)]) + ((0.00903361291f * fVec32[((IOTA - 283) & 511)]) + ((0.00756601617f * fVec32[((IOTA - 282) & 511)]) + ((0.00531659275f * fVec32[((IOTA - 281) & 511)]) + ((0.00312629389f * fVec32[((IOTA - 280) & 511)]) + ((0.00145148672f * fVec32[((IOTA - 279) & 511)]) + ((0.00174527476f * fVec32[((IOTA - 278) & 511)]) + ((0.00405513821f * fVec32[((IOTA - 277) & 511)]) + ((0.00686813658f * fVec32[((IOTA - 276) & 511)]) + ((0.00945891067f * fVec32[((IOTA - 275) & 511)]) + ((0.0119342301f * fVec32[((IOTA - 274) & 511)]) + ((0.0132371383f * fVec32[((IOTA - 273) & 511)]) + ((0.0125504918f * fVec32[((IOTA - 272) & 511)]) + ((0.0103607401f * fVec32[((IOTA - 271) & 511)]) + ((0.00863798708f * fVec32[((IOTA - 270) & 511)]) + ((0.00906542223f * fVec32[((IOTA - 269) & 511)]) + ((0.0110056605f * fVec32[((IOTA - 268) & 511)]) + ((0.0137893707f * fVec32[((IOTA - 267) & 511)]) + ((0.0163264722f * fVec32[((IOTA - 266) & 511)]) + ((0.0161932912f * fVec32[((IOTA - 265) & 511)]) + ((0.0135042407f * fVec32[((IOTA - 264) & 511)]) + ((0.00907709356f * fVec32[((IOTA - 263) & 511)]) + ((0.00427563628f * fVec32[((IOTA - 262) & 511)]) + ((0.00224221777f * fVec32[((IOTA - 261) & 511)]) + ((0.00346419215f * fVec32[((IOTA - 260) & 511)]) + ((0.00740272505f * fVec32[((IOTA - 259) & 511)]) + ((0.0135047603f * fVec32[((IOTA - 258) & 511)]) + ((0.0184025224f * fVec32[((IOTA - 257) & 511)]) + ((0.0194218066f * fVec32[((IOTA - 256) & 511)]) + ((0.0163233206f * fVec32[((IOTA - 255) & 511)]) + ((0.0103395348f * fVec32[((IOTA - 254) & 511)]) + ((0.00473964727f * fVec32[((IOTA - 253) & 511)]) + ((0.00161546329f * fVec32[((IOTA - 252) & 511)]) + ((0.000520998612f * fVec32[((IOTA - 251) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00131942891f * fVec32[((IOTA - 153) & 511)]) + ((0.00212076306f * fVec32[((IOTA - 148) & 511)]) + ((0.00315177394f * fVec32[((IOTA - 147) & 511)]) + ((0.00143439043f * fVec32[((IOTA - 146) & 511)]) + ((0.00177464494f * fVec32[((IOTA - 139) & 511)]) + ((0.00368512934f * fVec32[((IOTA - 138) & 511)]) + ((0.00438605016f * fVec32[((IOTA - 137) & 511)]) + ((0.00162036764f * fVec32[((IOTA - 136) & 511)]) + (((((((((((((((((((((((((((((((((((((((0.110899031f * fVec32[((IOTA - 13) & 511)]) + ((0.0942586362f * fVec32[((IOTA - 12) & 511)]) + ((0.0323185809f * fVec32[((IOTA - 11) & 511)]) + ((0.051560685f * fVec32[((IOTA - 5) & 511)]) + ((0.162105486f * fVec32[((IOTA - 4) & 511)]) + ((0.208301604f * fVec32[((IOTA - 3) & 511)]) + ((0.222016126f * fVec32[((IOTA - 2) & 511)]) + ((0.194735825f * fVec32[((IOTA - 1) & 511)]) + ((fSlow103 * fTemp0) + ((0.0188274086f * fVec32[((IOTA - 21) & 511)]) + ((((0.0852342248f * fVec32[((IOTA - 14) & 511)]) + (0.0485688299f * fVec32[((IOTA - 15) & 511)])) + (0.00550141931f * fVec32[((IOTA - 16) & 511)])) + (0.0569803193f * fVec32[((IOTA - 22) & 511)])))))))))))) + (0.0829107761f * fVec32[((IOTA - 23) & 511)])) + (0.0737451315f * fVec32[((IOTA - 24) & 511)])) + (0.0376223773f * fVec32[((IOTA - 25) & 511)])) + (0.00555602321f * fVec32[((IOTA - 42) & 511)])) + (0.0138953999f * fVec32[((IOTA - 43) & 511)])) + (0.0130225308f * fVec32[((IOTA - 44) & 511)])) + (0.000278993044f * fVec32[((IOTA - 45) & 511)])) + (0.00441490021f * fVec32[((IOTA - 52) & 511)])) + (0.0318145156f * fVec32[((IOTA - 53) & 511)])) + (0.0527421087f * fVec32[((IOTA - 54) & 511)])) + (0.0531037636f * fVec32[((IOTA - 55) & 511)])) + (0.0346819237f * fVec32[((IOTA - 56) & 511)])) + (0.0221974067f * fVec32[((IOTA - 64) & 511)])) + (0.032108631f * fVec32[((IOTA - 65) & 511)])) + (0.0246553291f * fVec32[((IOTA - 66) & 511)])) + (0.00356367417f * fVec32[((IOTA - 73) & 511)])) + (0.0169758853f * fVec32[((IOTA - 74) & 511)])) + (0.0212968383f * fVec32[((IOTA - 75) & 511)])) + (0.0106254593f * fVec32[((IOTA - 76) & 511)])) + (0.000494806562f * fVec32[((IOTA - 84) & 511)])) + (0.0101234745f * fVec32[((IOTA - 85) & 511)])) + (0.0107618188f * fVec32[((IOTA - 86) & 511)])) + (0.00488776062f * fVec32[((IOTA - 87) & 511)])) + (0.00217747688f * fVec32[((IOTA - 100) & 511)])) + (0.00612839311f * fVec32[((IOTA - 101) & 511)])) + (0.00593096344f * fVec32[((IOTA - 102) & 511)])) + (0.00153568061f * fVec32[((IOTA - 114) & 511)])) + (0.00290675461f * fVec32[((IOTA - 115) & 511)])) + (0.000323350076f * fVec32[((IOTA - 116) & 511)])) + (0.00027885614f * fVec32[((IOTA - 125) & 511)])) + (0.00820740126f * fVec32[((IOTA - 126) & 511)])) + (0.0124630928f * fVec32[((IOTA - 127) & 511)])) + (0.0131909996f * fVec32[((IOTA - 128) & 511)])) + (0.0102450391f * fVec32[((IOTA - 129) & 511)])) + (0.00514582172f * fVec32[((IOTA - 130) & 511)])) + (0.00058552064f * fVec32[((IOTA - 131) & 511)])) + (0.00680906698f * fVec32[((IOTA - 154) & 511)])))))))))) + (0.00972376671f * fVec32[((IOTA - 155) & 511)])) + (0.00874598976f * fVec32[((IOTA - 156) & 511)])) + (0.00294612534f * fVec32[((IOTA - 157) & 511)])) + (0.00402212329f * fVec32[((IOTA - 164) & 511)])) + (0.00752653601f * fVec32[((IOTA - 165) & 511)])) + (0.00732031185f * fVec32[((IOTA - 166) & 511)])) + (0.00425933488f * fVec32[((IOTA - 167) & 511)])) + (0.00142173283f * fVec32[((IOTA - 168) & 511)])) + (0.000105509534f * fVec32[((IOTA - 169) & 511)])) + (0.00139989657f * fVec32[((IOTA - 170) & 511)])) + (0.00397836883f * fVec32[((IOTA - 171) & 511)])) + (0.0064576338f * fVec32[((IOTA - 172) & 511)])) + (0.00844285917f * fVec32[((IOTA - 173) & 511)])) + (0.00884330738f * fVec32[((IOTA - 174) & 511)])) + (0.00630719168f * fVec32[((IOTA - 175) & 511)])) + (0.0019734716f * fVec32[((IOTA - 176) & 511)])) + (0.00531511335f * fVec32[((IOTA - 181) & 511)])) + (0.0107810516f * fVec32[((IOTA - 182) & 511)])) + (0.0134252254f * fVec32[((IOTA - 183) & 511)])) + (0.0139805265f * fVec32[((IOTA - 184) & 511)])) + (0.0105688274f * fVec32[((IOTA - 185) & 511)])) + (0.00526593393f * fVec32[((IOTA - 186) & 511)])) + (0.0020428705f * fVec32[((IOTA - 187) & 511)])) + (0.00176174054f * fVec32[((IOTA - 188) & 511)])) + (0.00541127985f * fVec32[((IOTA - 189) & 511)])) + (0.0108169988f * fVec32[((IOTA - 190) & 511)])) + (0.0141299535f * fVec32[((IOTA - 191) & 511)])) + (0.0139832105f * fVec32[((IOTA - 192) & 511)])) + (0.0101580229f * fVec32[((IOTA - 193) & 511)])) + (0.0062459847f * fVec32[((IOTA - 194) & 511)])) + (0.00538267661f * fVec32[((IOTA - 195) & 511)])) + (0.00566895725f * fVec32[((IOTA - 196) & 511)])) + (0.00573915103f * fVec32[((IOTA - 197) & 511)])) + (0.00552722812f * fVec32[((IOTA - 198) & 511)])) + (0.00463416567f * fVec32[((IOTA - 199) & 511)])) + (0.00401130132f * fVec32[((IOTA - 200) & 511)])) + (0.00424826611f * fVec32[((IOTA - 201) & 511)])) + (0.00520667247f * fVec32[((IOTA - 202) & 511)])) + (0.00758549618f * fVec32[((IOTA - 203) & 511)])) + (0.010208874f * fVec32[((IOTA - 204) & 511)])) + (0.0114306286f * fVec32[((IOTA - 205) & 511)])) + (0.0108859036f * fVec32[((IOTA - 206) & 511)])) + (0.00740091642f * fVec32[((IOTA - 207) & 511)])) + (0.00312632136f * fVec32[((IOTA - 208) & 511)])) + (0.0018510581f * fVec32[((IOTA - 209) & 511)])) + (0.00293335784f * fVec32[((IOTA - 210) & 511)])) + (0.00649475772f * fVec32[((IOTA - 211) & 511)])) + (0.0116178393f * fVec32[((IOTA - 212) & 511)])) + (0.0157527328f * fVec32[((IOTA - 213) & 511)])) + (0.0183832888f * fVec32[((IOTA - 214) & 511)])) + (0.0185042229f * fVec32[((IOTA - 215) & 511)])) + (0.0143098487f * fVec32[((IOTA - 216) & 511)])) + (0.0074045877f * fVec32[((IOTA - 217) & 511)])) + (0.000264389906f * fVec32[((IOTA - 218) & 511)])) + (0.00349734398f * fVec32[((IOTA - 222) & 511)])) + (0.00885580108f * fVec32[((IOTA - 223) & 511)])) + (0.0132642621f * fVec32[((IOTA - 224) & 511)])) + (0.0146702677f * fVec32[((IOTA - 225) & 511)])) + (0.013825234f * fVec32[((IOTA - 226) & 511)])) + (0.0118942838f * fVec32[((IOTA - 227) & 511)])) + (0.00931808539f * fVec32[((IOTA - 228) & 511)])) + (0.0076980195f * fVec32[((IOTA - 229) & 511)])) + (0.00745787704f * fVec32[((IOTA - 230) & 511)])) + (0.00826395117f * fVec32[((IOTA - 231) & 511)])) + (0.00987390708f * fVec32[((IOTA - 232) & 511)])) + (0.010901521f * fVec32[((IOTA - 233) & 511)])) + (0.0118394606f * fVec32[((IOTA - 234) & 511)])) + (0.0132422335f * fVec32[((IOTA - 235) & 511)])) + (0.0133631956f * fVec32[((IOTA - 236) & 511)])) + (0.0117240604f * fVec32[((IOTA - 237) & 511)])) + (0.00938216969f * fVec32[((IOTA - 238) & 511)])) + (0.00720995292f * fVec32[((IOTA - 239) & 511)])) + (0.00679227198f * fVec32[((IOTA - 240) & 511)])) + (0.00764927873f * fVec32[((IOTA - 241) & 511)])) + (0.00858061574f * fVec32[((IOTA - 242) & 511)])) + (0.00924359076f * fVec32[((IOTA - 243) & 511)])) + (0.00907049049f * fVec32[((IOTA - 244) & 511)])) + (0.00854982063f * fVec32[((IOTA - 245) & 511)])) + (0.00872881152f * fVec32[((IOTA - 246) & 511)])) + (0.00778298033f * fVec32[((IOTA - 247) & 511)])) + (0.00544648618f * fVec32[((IOTA - 248) & 511)])) + (0.00340446504f * fVec32[((IOTA - 249) & 511)])) + (0.00144669227f * fVec32[((IOTA - 250) & 511)])) + (0.00840809196f * fVec32[((IOTA - 285) & 511)])))))))))))))))))))))))))))))))))))) + (0.00728831114f * fVec32[((IOTA - 286) & 511)])) + (0.0055590095f * fVec32[((IOTA - 287) & 511)])) + (0.00427284185f * fVec32[((IOTA - 288) & 511)])) + (0.00359597616f * fVec32[((IOTA - 289) & 511)])) + (0.00481389603f * fVec32[((IOTA - 290) & 511)])) + (0.0072964211f * fVec32[((IOTA - 291) & 511)])) + (0.00851836801f * fVec32[((IOTA - 292) & 511)])) + (0.00857398566f * fVec32[((IOTA - 293) & 511)])) + (0.00741042383f * fVec32[((IOTA - 294) & 511)])) + (0.00484208809f * fVec32[((IOTA - 295) & 511)])) + (0.00297579728f * fVec32[((IOTA - 296) & 511)])) + (0.00248312764f * fVec32[((IOTA - 297) & 511)])) + (0.00388713414f * fVec32[((IOTA - 298) & 511)])) + (0.00807076879f * fVec32[((IOTA - 299) & 511)])) + (0.0120697953f * fVec32[((IOTA - 300) & 511)])) + (0.0137063544f * fVec32[((IOTA - 301) & 511)])) + (0.0134921037f * fVec32[((IOTA - 302) & 511)])) + (0.0114516988f * fVec32[((IOTA - 303) & 511)])) + (0.00860730186f * fVec32[((IOTA - 304) & 511)])) + (0.00602630852f * fVec32[((IOTA - 305) & 511)])) + (0.00412955089f * fVec32[((IOTA - 306) & 511)])) + (0.00340780756f * fVec32[((IOTA - 307) & 511)])) + (0.0033237231f * fVec32[((IOTA - 308) & 511)])) + (0.00391461421f * fVec32[((IOTA - 309) & 511)])) + (0.0060277055f * fVec32[((IOTA - 310) & 511)])) + (0.00872467458f * fVec32[((IOTA - 311) & 511)])) + (0.0108869998f * fVec32[((IOTA - 312) & 511)])) + (0.0120682884f * fVec32[((IOTA - 313) & 511)])) + (0.0109749744f * fVec32[((IOTA - 314) & 511)])) + (0.00781522784f * fVec32[((IOTA - 315) & 511)])) + (0.0040645902f * fVec32[((IOTA - 316) & 511)])) + (0.00108816288f * fVec32[((IOTA - 321) & 511)])) + (0.00361457933f * fVec32[((IOTA - 322) & 511)])) + (0.00429265061f * fVec32[((IOTA - 323) & 511)])) + (0.00416793535f * fVec32[((IOTA - 324) & 511)])) + (0.00374307577f * fVec32[((IOTA - 325) & 511)])) + (0.00263937796f * fVec32[((IOTA - 326) & 511)])) + (0.00390135357f * fVec32[((IOTA - 342) & 511)])))))))))))) + (0.00505740847f * fVec32[((IOTA - 343) & 511)])) + (0.00494020013f * fVec32[((IOTA - 344) & 511)])) + (0.00371825323f * fVec32[((IOTA - 345) & 511)])) + (0.00305700442f * fVec32[((IOTA - 346) & 511)])) + (0.00356761971f * fVec32[((IOTA - 347) & 511)])) + (0.00456049247f * fVec32[((IOTA - 348) & 511)])) + (0.00553207751f * fVec32[((IOTA - 349) & 511)])) + (0.00544596557f * fVec32[((IOTA - 350) & 511)])) + (0.00372732198f * fVec32[((IOTA - 351) & 511)])) + (0.000916104298f * fVec32[((IOTA - 352) & 511)])) + (0.000642837491f * fVec32[((IOTA - 360) & 511)])) + (0.00147589808f * fVec32[((IOTA - 361) & 511)])) + (0.0014882274f * fVec32[((IOTA - 362) & 511)])) + (0.0011786581f * fVec32[((IOTA - 363) & 511)])) + (0.00085834926f * fVec32[((IOTA - 364) & 511)])) - ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.000277732499f * fVec32[((IOTA - 97) & 511)]) + ((0.00225487584f * fVec32[((IOTA - 96) & 511)]) + ((0.00797797181f * fVec32[((IOTA - 95) & 511)]) + ((0.0159599427f * fVec32[((IOTA - 94) & 511)]) + ((0.0303804241f * fVec32[((IOTA - 93) & 511)]) + ((0.0407946743f * fVec32[((IOTA - 92) & 511)]) + ((0.04086788f * fVec32[((IOTA - 91) & 511)]) + ((0.0383105874f * fVec32[((IOTA - 90) & 511)]) + ((0.0257269163f * fVec32[((IOTA - 89) & 511)]) + ((0.00698923552f * fVec32[((IOTA - 88) & 511)]) + ((0.0109709464f * fVec32[((IOTA - 83) & 511)]) + ((0.0187135972f * fVec32[((IOTA - 82) & 511)]) + ((0.0251093395f * fVec32[((IOTA - 81) & 511)]) + ((0.0268297102f * fVec32[((IOTA - 80) & 511)]) + ((0.0227325968f * fVec32[((IOTA - 79) & 511)]) + ((0.0201890301f * fVec32[((IOTA - 78) & 511)]) + ((0.0101100225f * fVec32[((IOTA - 77) & 511)]) + ((0.0196373463f * fVec32[((IOTA - 72) & 511)]) + ((0.0450188294f * fVec32[((IOTA - 71) & 511)]) + ((0.0550670698f * fVec32[((IOTA - 70) & 511)]) + ((0.0496337079f * fVec32[((IOTA - 69) & 511)]) + ((0.0337281488f * fVec32[((IOTA - 68) & 511)]) + ((0.00411689281f * fVec32[((IOTA - 67) & 511)]) + ((0.00831896625f * fVec32[((IOTA - 63) & 511)]) + ((0.0481427945f * fVec32[((IOTA - 62) & 511)]) + ((((((((((((((((((((((((((((((0.0372608639f * fVec32[((IOTA - 10) & 511)]) + ((0.112880699f * fVec32[((IOTA - 9) & 511)]) + ((0.170432806f * fVec32[((IOTA - 8) & 511)]) + ((0.164024904f * fVec32[((IOTA - 7) & 511)]) + ((0.0765449554f * fVec32[((IOTA - 6) & 511)]) + ((0.0395630561f * fVec32[((IOTA - 17) & 511)]) + (((0.0719473064f * fVec32[((IOTA - 18) & 511)]) + (0.0680814609f * fVec32[((IOTA - 19) & 511)])) + (0.0268336833f * fVec32[((IOTA - 20) & 511)])))))))) + (0.00280212192f * fVec32[((IOTA - 26) & 511)])) + (0.0369986668f * fVec32[((IOTA - 27) & 511)])) + (0.0559372529f * fVec32[((IOTA - 28) & 511)])) + (0.0555604249f * fVec32[((IOTA - 29) & 511)])) + (0.0454764552f * fVec32[((IOTA - 30) & 511)])) + (0.0230943877f * fVec32[((IOTA - 31) & 511)])) + (0.0155703723f * fVec32[((IOTA - 32) & 511)])) + (0.0143154655f * fVec32[((IOTA - 33) & 511)])) + (0.00534494966f * fVec32[((IOTA - 34) & 511)])) + (0.00514351996f * fVec32[((IOTA - 35) & 511)])) + (0.0121761262f * fVec32[((IOTA - 36) & 511)])) + (0.0120490547f * fVec32[((IOTA - 37) & 511)])) + (0.0177687537f * fVec32[((IOTA - 38) & 511)])) + (0.0226702392f * fVec32[((IOTA - 39) & 511)])) + (0.0160666294f * fVec32[((IOTA - 40) & 511)])) + (0.00302396249f * fVec32[((IOTA - 41) & 511)])) + (0.0230277833f * fVec32[((IOTA - 46) & 511)])) + (0.0475050509f * fVec32[((IOTA - 47) & 511)])) + (0.0602330267f * fVec32[((IOTA - 48) & 511)])) + (0.065165773f * fVec32[((IOTA - 49) & 511)])) + (0.0574463606f * fVec32[((IOTA - 50) & 511)])) + (0.0258869473f * fVec32[((IOTA - 51) & 511)])) + (0.00126057817f * fVec32[((IOTA - 57) & 511)])) + (0.0443664305f * fVec32[((IOTA - 58) & 511)])) + (0.0787931681f * fVec32[((IOTA - 59) & 511)])) + (0.0891333595f * fVec32[((IOTA - 60) & 511)])) + (0.0764265135f * fVec32[((IOTA - 61) & 511)])) + (0.00195621094f * fVec32[((IOTA - 98) & 511)]))))))))))))))))))))))))))) + (0.000952241942f * fVec32[((IOTA - 99) & 511)])) + (0.000569136813f * fVec32[((IOTA - 103) & 511)])) + (0.00834444538f * fVec32[((IOTA - 104) & 511)])) + (0.0155744813f * fVec32[((IOTA - 105) & 511)])) + (0.0209816527f * fVec32[((IOTA - 106) & 511)])) + (0.0226758849f * fVec32[((IOTA - 107) & 511)])) + (0.018697625f * fVec32[((IOTA - 108) & 511)])) + (0.0123965153f * fVec32[((IOTA - 109) & 511)])) + (0.00840335153f * fVec32[((IOTA - 110) & 511)])) + (0.0071459515f * fVec32[((IOTA - 111) & 511)])) + (0.00687180785f * fVec32[((IOTA - 112) & 511)])) + (0.00336986128f * fVec32[((IOTA - 113) & 511)])) + (0.00855110865f * fVec32[((IOTA - 117) & 511)])) + (0.0197886638f * fVec32[((IOTA - 118) & 511)])) + (0.0281545352f * fVec32[((IOTA - 119) & 511)])) + (0.0336917639f * fVec32[((IOTA - 120) & 511)])) + (0.0331823528f * fVec32[((IOTA - 121) & 511)])) + (0.02857567f * fVec32[((IOTA - 122) & 511)])) + (0.0209751856f * fVec32[((IOTA - 123) & 511)])) + (0.0103895357f * fVec32[((IOTA - 124) & 511)])) + (0.00496009132f * fVec32[((IOTA - 132) & 511)])) + (0.00802101381f * fVec32[((IOTA - 133) & 511)])) + (0.00553226937f * fVec32[((IOTA - 134) & 511)])) + (0.00196407409f * fVec32[((IOTA - 135) & 511)])) + (0.000428284053f * fVec32[((IOTA - 140) & 511)])) + (0.00506250467f * fVec32[((IOTA - 141) & 511)])) + (0.00978576764f * fVec32[((IOTA - 142) & 511)])) + (0.010608254f * fVec32[((IOTA - 143) & 511)])) + (0.0082656499f * fVec32[((IOTA - 144) & 511)])) + (0.00363553874f * fVec32[((IOTA - 145) & 511)])) + (0.000698126387f * fVec32[((IOTA - 149) & 511)])) + (0.00413777027f * fVec32[((IOTA - 150) & 511)])) + (0.00549363811f * fVec32[((IOTA - 151) & 511)])) + (0.00381340599f * fVec32[((IOTA - 152) & 511)])) + (0.00402108254f * fVec32[((IOTA - 158) & 511)])) + (0.00790199637f * fVec32[((IOTA - 159) & 511)])) + (0.00928572938f * fVec32[((IOTA - 160) & 511)])) + (0.00804756209f * fVec32[((IOTA - 161) & 511)])) + (0.00471107149f * fVec32[((IOTA - 162) & 511)])) + (0.000786512159f * fVec32[((IOTA - 163) & 511)])) + (0.00342627382f * fVec32[((IOTA - 177) & 511)])) + (0.00710778637f * fVec32[((IOTA - 178) & 511)])) + (0.00620658649f * fVec32[((IOTA - 179) & 511)])) + (0.00157154445f * fVec32[((IOTA - 180) & 511)])) + (0.00474800402f * fVec32[((IOTA - 219) & 511)])) + (0.00492913136f * fVec32[((IOTA - 220) & 511)])) + (0.00124375569f * fVec32[((IOTA - 221) & 511)])) + (7.59745017e-05f * fVec32[((IOTA - 317) & 511)])) + (0.00283245137f * fVec32[((IOTA - 318) & 511)])) + (0.00291259028f * fVec32[((IOTA - 319) & 511)])) + (0.00147014484f * fVec32[((IOTA - 320) & 511)])) + (0.0010134764f * fVec32[((IOTA - 329) & 511)])) + (0.00124794757f * fVec32[((IOTA - 330) & 511)])) + (0.000452723354f * fVec32[((IOTA - 331) & 511)])) + (0.000420886558f * fVec32[((IOTA - 339) & 511)])) + (0.000654070638f * fVec32[((IOTA - 340) & 511)])) + (0.00271379109f * fVec32[((IOTA - 353) & 511)])) + (0.00630050665f * fVec32[((IOTA - 354) & 511)])) + (0.00777303521f * fVec32[((IOTA - 355) & 511)])) + (0.00692408346f * fVec32[((IOTA - 356) & 511)])) + (0.00502036652f * fVec32[((IOTA - 357) & 511)])) + (0.00276321685f * fVec32[((IOTA - 358) & 511)])) + (0.000729688443f * fVec32[((IOTA - 359) & 511)])) + (0.000491491053f * fVec32[((IOTA - 365) & 511)])) + (0.00296768732f * fVec32[((IOTA - 366) & 511)])) + (0.00495518697f * fVec32[((IOTA - 367) & 511)])) + (0.00661859661f * fVec32[((IOTA - 368) & 511)])) + (0.00814186595f * fVec32[((IOTA - 369) & 511)])) + (0.00884643011f * fVec32[((IOTA - 370) & 511)])) + (0.0088663213f * fVec32[((IOTA - 371) & 511)])) + (0.00860384945f * fVec32[((IOTA - 372) & 511)])) + (0.00768401939f * fVec32[((IOTA - 373) & 511)])) + (0.00626867032f * fVec32[((IOTA - 374) & 511)])) + (0.0044292016f * fVec32[((IOTA - 375) & 511)])) + (0.00283861579f * fVec32[((IOTA - 376) & 511)])) + (0.00220008008f * fVec32[((IOTA - 377) & 511)])) + (0.00276434002f * fVec32[((IOTA - 378) & 511)])) + (0.00484258169f * fVec32[((IOTA - 379) & 511)])) + (0.00704690814f * fVec32[((IOTA - 380) & 511)])) + (0.00753689231f * fVec32[((IOTA - 381) & 511)])) + (0.00665755617f * fVec32[((IOTA - 382) & 511)])) + (0.00472951028f * fVec32[((IOTA - 383) & 511)])) + (0.00273042126f * fVec32[((IOTA - 384) & 511)])) + (0.00159001071f * fVec32[((IOTA - 385) & 511)])) + (0.000991366338f * fVec32[((IOTA - 386) & 511)])) + (0.00132162077f * fVec32[((IOTA - 387) & 511)])) + (0.00222120387f * fVec32[((IOTA - 388) & 511)])) + (0.00270554423f * fVec32[((IOTA - 389) & 511)])) + (0.00264189858f * fVec32[((IOTA - 390) & 511)])) + (0.00199555466f * fVec32[((IOTA - 391) & 511)])) + (0.00077368971f * fVec32[((IOTA - 392) & 511)])) + (0.000115537085f * fVec32[((IOTA - 393) & 511)])) + (0.000381625723f * fVec32[((IOTA - 394) & 511)])) + (0.00176930241f * fVec32[((IOTA - 395) & 511)])) + (0.00493781641f * fVec32[((IOTA - 396) & 511)])) + (0.00873187929f * fVec32[((IOTA - 397) & 511)])) + (0.0112853386f * fVec32[((IOTA - 398) & 511)])) + (0.0125228474f * fVec32[((IOTA - 399) & 511)])) + (0.0122883758f * fVec32[((IOTA - 400) & 511)])) + (0.0101911752f * fVec32[((IOTA - 401) & 511)])) + (0.00727274921f * fVec32[((IOTA - 402) & 511)])) + (0.00447183289f * fVec32[((IOTA - 403) & 511)])) + (0.0022248202f * fVec32[((IOTA - 404) & 511)])) + (0.00126079703f * fVec32[((IOTA - 405) & 511)])) + (0.00187209947f * fVec32[((IOTA - 406) & 511)])) + (0.00365115562f * fVec32[((IOTA - 407) & 511)])) + (0.00512614986f * fVec32[((IOTA - 408) & 511)])) + (0.00567671098f * fVec32[((IOTA - 409) & 511)])) + (0.00605913112f * fVec32[((IOTA - 410) & 511)])) + (0.00583224883f * fVec32[((IOTA - 411) & 511)])) + (0.0051424792f * fVec32[((IOTA - 412) & 511)])) + (0.00530760642f * fVec32[((IOTA - 413) & 511)])) + (0.00566155976f * fVec32[((IOTA - 414) & 511)])) + (0.00596170407f * fVec32[((IOTA - 415) & 511)])) + (0.00557095511f * fVec32[((IOTA - 416) & 511)])) + (0.00357989362f * fVec32[((IOTA - 417) & 511)])) + (0.00162464147f * fVec32[((IOTA - 418) & 511)])) + (0.00092659751f * fVec32[((IOTA - 419) & 511)])) + (0.000831279904f * fVec32[((IOTA - 420) & 511)])) + (0.00140288286f * fVec32[((IOTA - 421) & 511)])) + (0.00275420258f * fVec32[((IOTA - 422) & 511)])) + (0.00378409028f * fVec32[((IOTA - 423) & 511)])) + (0.00444928417f * fVec32[((IOTA - 424) & 511)])) + (0.00455906801f * fVec32[((IOTA - 425) & 511)])) + (0.00379611831f * fVec32[((IOTA - 426) & 511)])) + (0.00319185713f * fVec32[((IOTA - 427) & 511)])) + (0.0031687608f * fVec32[((IOTA - 428) & 511)])) + (0.00348498719f * fVec32[((IOTA - 429) & 511)])) + (0.00458657555f * fVec32[((IOTA - 430) & 511)])) + (0.00623299833f * fVec32[((IOTA - 431) & 511)])) + (0.0080683846f * fVec32[((IOTA - 432) & 511)])) + (0.00957028382f * fVec32[((IOTA - 433) & 511)])) + (0.00991026405f * fVec32[((IOTA - 434) & 511)])) + (0.00920854881f * fVec32[((IOTA - 435) & 511)])) + (0.00793145038f * fVec32[((IOTA - 436) & 511)])) + (0.0065645678f * fVec32[((IOTA - 437) & 511)])) + (0.00603154115f * fVec32[((IOTA - 438) & 511)])) + (0.0065953359f * fVec32[((IOTA - 439) & 511)])) + (0.0078592021f * fVec32[((IOTA - 440) & 511)])) + (0.00984355062f * fVec32[((IOTA - 441) & 511)])) + (0.0110546481f * fVec32[((IOTA - 442) & 511)])) + (0.0101399682f * fVec32[((IOTA - 443) & 511)])) + (0.00813117996f * fVec32[((IOTA - 444) & 511)])) + (0.0059748278f * fVec32[((IOTA - 445) & 511)])) + (0.00415245537f * fVec32[((IOTA - 446) & 511)])) + (0.00382420095f * fVec32[((IOTA - 447) & 511)])) + (0.0052580433f * fVec32[((IOTA - 448) & 511)])) + (0.00726707792f * fVec32[((IOTA - 449) & 511)])) + (0.00872856472f * fVec32[((IOTA - 450) & 511)])) + (0.00894333702f * fVec32[((IOTA - 451) & 511)])) + (0.0076740738f * fVec32[((IOTA - 452) & 511)])) + (0.00524319382f * fVec32[((IOTA - 453) & 511)])) + (0.00274968194f * fVec32[((IOTA - 454) & 511)])) + (0.00151943369f * fVec32[((IOTA - 455) & 511)])) + (0.00257688342f * fVec32[((IOTA - 456) & 511)])) + (0.00533527834f * fVec32[((IOTA - 457) & 511)])) + (0.00841729715f * fVec32[((IOTA - 458) & 511)])) + (0.0103391781f * fVec32[((IOTA - 459) & 511)])) + (0.00984826311f * fVec32[((IOTA - 460) & 511)])) + (0.00765747065f * fVec32[((IOTA - 461) & 511)])) + (0.00515258871f * fVec32[((IOTA - 462) & 511)])) + (0.00357835926f * fVec32[((IOTA - 463) & 511)])) + (0.00380546087f * fVec32[((IOTA - 464) & 511)])) + (0.00482660858f * fVec32[((IOTA - 465) & 511)])) + (0.00587057881f * fVec32[((IOTA - 466) & 511)])) + (0.00634806929f * fVec32[((IOTA - 467) & 511)])) + (0.00566358725f * fVec32[((IOTA - 468) & 511)])) + (0.00444131158f * fVec32[((IOTA - 469) & 511)])) + (0.00341487629f * fVec32[((IOTA - 470) & 511)])) + (0.00267069414f * fVec32[((IOTA - 471) & 511)])) + (0.0024281675f * fVec32[((IOTA - 472) & 511)])) + (0.002297014f * fVec32[((IOTA - 473) & 511)])) + (0.0019659102f * fVec32[((IOTA - 474) & 511)])) + (0.00238600234f * fVec32[((IOTA - 475) & 511)])) + (0.00383622851f * fVec32[((IOTA - 476) & 511)])) + (0.0057740286f * fVec32[((IOTA - 477) & 511)])) + (0.00748587772f * fVec32[((IOTA - 478) & 511)])) + (0.00804232899f * fVec32[((IOTA - 479) & 511)])) + (0.00779835088f * fVec32[((IOTA - 480) & 511)])) + (0.00731020188f * fVec32[((IOTA - 481) & 511)])) + (0.00658802036f * fVec32[((IOTA - 482) & 511)])) + (0.00603326736f * fVec32[((IOTA - 483) & 511)])) + (0.00568230031f * fVec32[((IOTA - 484) & 511)])) + (0.00509009417f * fVec32[((IOTA - 485) & 511)])) + (0.00445668167f * fVec32[((IOTA - 486) & 511)])) + (0.00351920724f * fVec32[((IOTA - 487) & 511)])) + (0.00252712891f * fVec32[((IOTA - 488) & 511)])) + (0.00219569635f * fVec32[((IOTA - 489) & 511)])) + (0.00193738891f * fVec32[((IOTA - 490) & 511)])) + (0.00160642201f * fVec32[((IOTA - 491) & 511)])) + (0.00150880311f * fVec32[((IOTA - 492) & 511)])) + (0.00180308428f * fVec32[((IOTA - 493) & 511)])) + (0.00241997559f * fVec32[((IOTA - 494) & 511)])) + (0.00302286679f * fVec32[((IOTA - 495) & 511)])) + (0.00345123326f * fVec32[((IOTA - 496) & 511)])) + (0.00345493201f * fVec32[((IOTA - 497) & 511)])) + (0.00262266537f * fVec32[((IOTA - 498) & 511)])) + (0.00119293248f * fVec32[((IOTA - 499) & 511)])) + (3.16719525e-05f * fVec32[((IOTA - 500) & 511)])) + (0.000144469086f * fVec32[((IOTA - 501) & 511)])) + (0.00217739446f * fVec32[((IOTA - 502) & 511)])) + (0.0057901931f * fVec32[((IOTA - 503) & 511)])) + (0.00914405473f * fVec32[((IOTA - 504) & 511)])) + (0.0110585382f * fVec32[((IOTA - 505) & 511)])) + (0.0115103023f * fVec32[((IOTA - 506) & 511)])) + (0.010168517f * fVec32[((IOTA - 507) & 511)])) + (0.00739938207f * fVec32[((IOTA - 508) & 511)])) + (0.00460846629f * fVec32[((IOTA - 509) & 511)])) + (0.00286431517f * fVec32[((IOTA - 510) & 511)])) + (0.00300733233f * fVec32[((IOTA - 511) & 511)]))) : ((((((((((((((((((((((((((((((((((0.00368481409f * fVec31[((IOTA - 298) & 511)]) + ((0.00411420548f * fVec31[((IOTA - 297) & 511)]) + ((0.000497857109f * fVec31[((IOTA - 315) & 511)]) + ((0.000517999753f * fVec31[((IOTA - 314) & 511)]) + ((0.000347407069f * fVec31[((IOTA - 313) & 511)]) + ((0.000999480486f * fVec31[((IOTA - 312) & 511)]) + ((0.00238712411f * fVec31[((IOTA - 311) & 511)]) + ((0.00366073707f * fVec31[((IOTA - 310) & 511)]) + ((0.00477058301f * fVec31[((IOTA - 309) & 511)]) + ((0.00499753607f * fVec31[((IOTA - 308) & 511)]) + ((0.00409903936f * fVec31[((IOTA - 307) & 511)]) + ((0.00313359033f * fVec31[((IOTA - 306) & 511)]) + ((0.00245545572f * fVec31[((IOTA - 305) & 511)]) + ((0.00225530379f * fVec31[((IOTA - 304) & 511)]) + ((0.00269700261f * fVec31[((IOTA - 303) & 511)]) + ((0.00300022308f * fVec31[((IOTA - 302) & 511)]) + ((0.00304636033f * fVec31[((IOTA - 301) & 511)]) + ((0.00332718436f * fVec31[((IOTA - 300) & 511)]) + ((0.00465984736f * fVec31[((IOTA - 295) & 511)]) + ((0.00473863678f * fVec31[((IOTA - 294) & 511)]) + ((0.00461058272f * fVec31[((IOTA - 293) & 511)]) + ((0.00399929984f * fVec31[((IOTA - 292) & 511)]) + ((0.00307057193f * fVec31[((IOTA - 291) & 511)]) + ((0.00238904078f * fVec31[((IOTA - 290) & 511)]) + ((0.00185126811f * fVec31[((IOTA - 289) & 511)]) + ((0.00131874112f * fVec31[((IOTA - 288) & 511)]) + ((0.00106387725f * fVec31[((IOTA - 287) & 511)]) + ((0.0010152515f * fVec31[((IOTA - 286) & 511)]) + ((0.00119489059f * fVec31[((IOTA - 285) & 511)]) + ((0.00199838867f * fVec31[((IOTA - 284) & 511)]) + ((0.00295502739f * fVec31[((IOTA - 283) & 511)]) + ((0.00353513751f * fVec31[((IOTA - 282) & 511)]) + ((0.00363992155f * fVec31[((IOTA - 281) & 511)]) + ((0.00286127394f * fVec31[((IOTA - 280) & 511)]) + ((0.00138582801f * fVec31[((IOTA - 279) & 511)]) + ((0.000257789157f * fVec31[((IOTA - 278) & 511)]) + ((0.000371013768f * fVec31[((IOTA - 276) & 511)]) + ((0.00200222246f * fVec31[((IOTA - 275) & 511)]) + ((0.00358023215f * fVec31[((IOTA - 299) & 511)]) + ((0.00367523031f * fVec31[((IOTA - 274) & 511)]) + ((0.00448848074f * fVec31[((IOTA - 273) & 511)]) + ((0.00332015613f * fVec31[((IOTA - 271) & 511)]) + ((0.0023700078f * fVec31[((IOTA - 270) & 511)]) + ((0.00228274427f * fVec31[((IOTA - 269) & 511)]) + ((0.00242623314f * fVec31[((IOTA - 268) & 511)]) + ((0.00282865483f * fVec31[((IOTA - 267) & 511)]) + ((0.00341609586f * fVec31[((IOTA - 266) & 511)]) + ((0.00347860949f * fVec31[((IOTA - 265) & 511)]) + ((0.00324372062f * fVec31[((IOTA - 264) & 511)]) + ((0.0032451665f * fVec31[((IOTA - 263) & 511)]) + ((0.00335412007f * fVec31[((IOTA - 262) & 511)]) + ((0.00355491089f * fVec31[((IOTA - 261) & 511)]) + ((0.00374013186f * fVec31[((IOTA - 260) & 511)]) + ((0.00419080909f * fVec31[((IOTA - 259) & 511)]) + ((0.00512017589f * fVec31[((IOTA - 258) & 511)]) + ((0.00568824727f * fVec31[((IOTA - 257) & 511)]) + ((0.00613724347f * fVec31[((IOTA - 256) & 511)]) + ((0.00660238042f * fVec31[((IOTA - 255) & 511)]) + ((0.006299261f * fVec31[((IOTA - 254) & 511)]) + ((0.00547827641f * fVec31[((IOTA - 253) & 511)]) + ((0.00428863196f * fVec31[((IOTA - 252) & 511)]) + (((0.00289187487f * fVec31[((IOTA - 251) & 511)]) + ((0.00208592135f * fVec31[((IOTA - 250) & 511)]) + ((0.00182352541f * fVec31[((IOTA - 249) & 511)]) + ((0.00190745993f * fVec31[((IOTA - 248) & 511)]) + ((0.00234034797f * fVec31[((IOTA - 247) & 511)]) + ((0.00258266879f * fVec31[((IOTA - 246) & 511)]) + ((0.0027314038f * fVec31[((IOTA - 245) & 511)]) + ((0.00332180411f * fVec31[((IOTA - 244) & 511)]) + ((0.00366880745f * fVec31[((IOTA - 243) & 511)]) + ((0.0033422159f * fVec31[((IOTA - 242) & 511)]) + ((0.00290539302f * fVec31[((IOTA - 241) & 511)]) + ((0.00218505599f * fVec31[((IOTA - 240) & 511)]) + ((0.0015871902f * fVec31[((IOTA - 239) & 511)]) + ((0.0013577491f * fVec31[((IOTA - 238) & 511)]) + ((0.00108196866f * fVec31[((IOTA - 237) & 511)]) + ((0.00150345732f * fVec31[((IOTA - 236) & 511)]) + ((0.00227420265f * fVec31[((IOTA - 235) & 511)]) + ((0.00298317382f * fVec31[((IOTA - 234) & 511)]) + ((0.00458361348f * fVec31[((IOTA - 233) & 511)]) + ((0.00637448626f * fVec31[((IOTA - 232) & 511)]) + ((0.0068630618f * fVec31[((IOTA - 231) & 511)]) + ((0.00579155143f * fVec31[((IOTA - 230) & 511)]) + ((0.00329100108f * fVec31[((IOTA - 229) & 511)]) + ((3.72258946e-05f * fVec31[((IOTA - 228) & 511)]) + ((0.00366356177f * fVec31[((IOTA - 224) & 511)]) + ((0.00676675234f * fVec31[((IOTA - 223) & 511)]) + ((((((((((((((((0.00127489073f * fVec31[((IOTA - 208) & 511)]) + ((0.00133306626f * fVec31[((IOTA - 205) & 511)]) + ((0.00476651406f * fVec31[((IOTA - 204) & 511)]) + ((0.00687106512f * fVec31[((IOTA - 203) & 511)]) + ((0.00693549588f * fVec31[((IOTA - 202) & 511)]) + ((0.00496518612f * fVec31[((IOTA - 201) & 511)]) + ((0.00195255456f * fVec31[((IOTA - 200) & 511)]) + ((0.00163221778f * fVec31[((IOTA - 196) & 511)]) + ((0.00325733982f * fVec31[((IOTA - 195) & 511)]) + ((0.00473194476f * fVec31[((IOTA - 194) & 511)]) + ((0.00551234093f * fVec31[((IOTA - 193) & 511)]) + ((0.00507380348f * fVec31[((IOTA - 192) & 511)]) + ((0.00451760227f * fVec31[((IOTA - 191) & 511)]) + ((0.00375718111f * fVec31[((IOTA - 190) & 511)]) + ((0.00186656835f * fVec31[((IOTA - 189) & 511)]) + ((0.00271543069f * fVec31[((IOTA - 185) & 511)]) + ((0.00616414519f * fVec31[((IOTA - 184) & 511)]) + ((0.00773983495f * fVec31[((IOTA - 183) & 511)]) + ((0.00631355308f * fVec31[((IOTA - 182) & 511)]) + ((0.00220886432f * fVec31[((IOTA - 181) & 511)]) + (((((((((((((((((0.00803928915f * fVec31[((IOTA - 149) & 511)]) + ((0.00377638219f * fVec31[((IOTA - 148) & 511)]) + ((0.000972410198f * fVec31[((IOTA - 138) & 511)]) + ((0.00275696069f * fVec31[((IOTA - 137) & 511)]) + ((0.00142389443f * fVec31[((IOTA - 136) & 511)]) + ((0.00148798898f * fVec31[((IOTA - 131) & 511)]) + ((0.00669431873f * fVec31[((IOTA - 130) & 511)]) + ((0.00842856243f * fVec31[((IOTA - 129) & 511)]) + ((0.00602005096f * fVec31[((IOTA - 128) & 511)]) + ((0.0014653909f * fVec31[((IOTA - 127) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((0.140191481f * fVec31[((IOTA - 10) & 511)]) + ((0.0272756349f * fVec31[((IOTA - 4) & 511)]) + ((0.0200792234f * fVec31[((IOTA - 9) & 511)]) + ((fSlow101 * fTemp0) + ((((0.206790552f * fVec31[((IOTA - 2) & 511)]) + ((0.217578292f * fVec31[((IOTA - 1) & 511)]) + (0.137094215f * fVec31[((IOTA - 3) & 511)]))) + (0.155915126f * fVec31[((IOTA - 11) & 511)])) + (0.114675179f * fVec31[((IOTA - 12) & 511)])))))) + (0.0372703038f * fVec31[((IOTA - 13) & 511)])) + (0.0118548814f * fVec31[((IOTA - 21) & 511)])) + (0.0692080408f * fVec31[((IOTA - 22) & 511)])) + (0.0954680219f * fVec31[((IOTA - 23) & 511)])) + (0.0683948249f * fVec31[((IOTA - 24) & 511)])) + (0.0102513814f * fVec31[((IOTA - 25) & 511)])) + (0.0010607834f * fVec31[((IOTA - 30) & 511)])) + (0.0215034205f * fVec31[((IOTA - 31) & 511)])) + (0.0107761743f * fVec31[((IOTA - 32) & 511)])) + (0.00101316674f * fVec31[((IOTA - 34) & 511)])) + (0.00579804135f * fVec31[((IOTA - 35) & 511)])) + (0.0148488833f * fVec31[((IOTA - 36) & 511)])) + (0.0218180064f * fVec31[((IOTA - 37) & 511)])) + (0.0097460933f * fVec31[((IOTA - 38) & 511)])) + (0.0031567933f * fVec31[((IOTA - 43) & 511)])) + (0.00434028404f * fVec31[((IOTA - 44) & 511)])) + (0.00301068136f * fVec31[((IOTA - 45) & 511)])) + (0.00100950152f * fVec31[((IOTA - 50) & 511)])) + (0.00426566415f * fVec31[((IOTA - 60) & 511)])) + (0.0127369668f * fVec31[((IOTA - 61) & 511)])) + (0.0137398103f * fVec31[((IOTA - 62) & 511)])) + (0.00916806795f * fVec31[((IOTA - 63) & 511)])) + (0.0095108673f * fVec31[((IOTA - 70) & 511)])) + (0.0100162569f * fVec31[((IOTA - 71) & 511)])) + (0.00452698441f * fVec31[((IOTA - 72) & 511)])) + (0.00775459735f * fVec31[((IOTA - 75) & 511)])) + (0.013363786f * fVec31[((IOTA - 76) & 511)])) + (0.00895735621f * fVec31[((IOTA - 77) & 511)])) + (0.00205703545f * fVec31[((IOTA - 83) & 511)])) + (0.00196371879f * fVec31[((IOTA - 84) & 511)])) + (0.00661603361f * fVec31[((IOTA - 94) & 511)])) + (0.0142793991f * fVec31[((IOTA - 95) & 511)])) + (0.0170835406f * fVec31[((IOTA - 96) & 511)])) + (0.014474473f * fVec31[((IOTA - 97) & 511)])) + (0.00430460507f * fVec31[((IOTA - 98) & 511)])) + (0.0043355762f * fVec31[((IOTA - 107) & 511)])) + (0.0100698937f * fVec31[((IOTA - 108) & 511)])) + (0.0136629716f * fVec31[((IOTA - 109) & 511)])) + (0.0111625213f * fVec31[((IOTA - 110) & 511)])) + (0.00329194264f * fVec31[((IOTA - 111) & 511)])) + (0.0015164041f * fVec31[((IOTA - 119) & 511)])) + (0.000418865588f * fVec31[((IOTA - 120) & 511)])) + (0.00966827851f * fVec31[((IOTA - 150) & 511)])))))))))))) + (0.00711022504f * fVec31[((IOTA - 151) & 511)])) + (0.00182618201f * fVec31[((IOTA - 152) & 511)])) + (0.0017212634f * fVec31[((IOTA - 162) & 511)])) + (0.00159253692f * fVec31[((IOTA - 163) & 511)])) + (0.00114179216f * fVec31[((IOTA - 168) & 511)])) + (0.00444617728f * fVec31[((IOTA - 169) & 511)])) + (0.00529103773f * fVec31[((IOTA - 170) & 511)])) + (0.00332288025f * fVec31[((IOTA - 171) & 511)])) + (0.00127391517f * fVec31[((IOTA - 172) & 511)])) + (0.000557915773f * fVec31[((IOTA - 173) & 511)])) + (0.000879093539f * fVec31[((IOTA - 174) & 511)])) + (0.00222729193f * fVec31[((IOTA - 175) & 511)])) + (0.00228042388f * fVec31[((IOTA - 176) & 511)])) + (0.000247364864f * fVec31[((IOTA - 177) & 511)])) + (0.00384891685f * fVec31[((IOTA - 209) & 511)])))))))))))))))))))))) + (0.00490596797f * fVec31[((IOTA - 210) & 511)])) + (0.00372580625f * fVec31[((IOTA - 211) & 511)])) + (0.00188600551f * fVec31[((IOTA - 212) & 511)])) + (0.000884003006f * fVec31[((IOTA - 213) & 511)])) + (0.000650458969f * fVec31[((IOTA - 214) & 511)])) + (0.00119209941f * fVec31[((IOTA - 215) & 511)])) + (0.00186999841f * fVec31[((IOTA - 216) & 511)])) + (0.00215738034f * fVec31[((IOTA - 217) & 511)])) + (0.00260432484f * fVec31[((IOTA - 218) & 511)])) + (0.00336767221f * fVec31[((IOTA - 219) & 511)])) + (0.00531242508f * fVec31[((IOTA - 220) & 511)])) + (0.00757798506f * fVec31[((IOTA - 221) & 511)])) + (0.00811353885f * fVec31[((IOTA - 222) & 511)])) + (0.00439573592f * fVec31[((IOTA - 272) & 511)])))))))))))))))))))))))))))) + (0.000332879834f * fVec31[((IOTA - 316) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (3.78983095e-05f * fVec31[((IOTA - 319) & 511)])) + (0.000537470449f * fVec31[((IOTA - 320) & 511)])) + (0.000979976263f * fVec31[((IOTA - 321) & 511)])) + (0.00119119138f * fVec31[((IOTA - 322) & 511)])) + (0.000477680471f * fVec31[((IOTA - 323) & 511)])) + (0.000267810188f * fVec31[((IOTA - 326) & 511)])) + (0.00136470981f * fVec31[((IOTA - 327) & 511)])) + (0.00226213038f * fVec31[((IOTA - 328) & 511)])) + (0.0021734545f * fVec31[((IOTA - 329) & 511)])) + (0.00152518088f * fVec31[((IOTA - 330) & 511)])) + (0.000466516241f * fVec31[((IOTA - 331) & 511)])) + (0.000770845916f * fVec31[((IOTA - 333) & 511)])) + (0.00203709444f * fVec31[((IOTA - 334) & 511)])) + (0.00311731454f * fVec31[((IOTA - 335) & 511)])) + (0.00373044703f * fVec31[((IOTA - 336) & 511)])) + (0.00324059324f * fVec31[((IOTA - 337) & 511)])) + (0.00232817512f * fVec31[((IOTA - 338) & 511)])) + (0.00158924144f * fVec31[((IOTA - 339) & 511)])) + (0.00101367105f * fVec31[((IOTA - 340) & 511)])) + (0.00110523915f * fVec31[((IOTA - 341) & 511)])) + (0.00125652971f * fVec31[((IOTA - 342) & 511)])) + (0.000950552057f * fVec31[((IOTA - 343) & 511)])) + (0.000477411319f * fVec31[((IOTA - 344) & 511)])) + (0.000234418083f * fVec31[((IOTA - 348) & 511)])) + (0.00131245237f * fVec31[((IOTA - 349) & 511)])) + (0.0023120339f * fVec31[((IOTA - 350) & 511)])) + (0.00233590929f * fVec31[((IOTA - 351) & 511)])) + (0.00182836782f * fVec31[((IOTA - 352) & 511)])) + (0.00109000597f * fVec31[((IOTA - 353) & 511)])) + (0.000387457665f * fVec31[((IOTA - 368) & 511)])) + (8.27237964e-05f * fVec31[((IOTA - 369) & 511)])) - (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.000821926631f * fVec31[((IOTA - 427) & 511)]) + ((0.000168373343f * fVec31[((IOTA - 426) & 511)]) + ((2.06474215e-05f * fVec31[((IOTA - 425) & 511)]) + ((0.000176982023f * fVec31[((IOTA - 424) & 511)]) + ((0.000480471645f * fVec31[((IOTA - 423) & 511)]) + ((0.000777941663f * fVec31[((IOTA - 422) & 511)]) + ((0.000852830242f * fVec31[((IOTA - 421) & 511)]) + ((0.00113893393f * fVec31[((IOTA - 420) & 511)]) + ((0.00150897261f * fVec31[((IOTA - 419) & 511)]) + ((0.00189568987f * fVec31[((IOTA - 418) & 511)]) + ((0.00250337506f * fVec31[((IOTA - 417) & 511)]) + ((0.00261804508f * fVec31[((IOTA - 416) & 511)]) + ((0.00219440414f * fVec31[((IOTA - 415) & 511)]) + ((0.00168450875f * fVec31[((IOTA - 414) & 511)]) + ((0.000891165808f * fVec31[((IOTA - 413) & 511)]) + ((0.000421185978f * fVec31[((IOTA - 412) & 511)]) + ((0.000557714142f * fVec31[((IOTA - 411) & 511)]) + ((0.000861842185f * fVec31[((IOTA - 410) & 511)]) + ((0.00171763171f * fVec31[((IOTA - 409) & 511)]) + ((0.00263838982f * fVec31[((IOTA - 408) & 511)]) + ((0.00304403994f * fVec31[((IOTA - 407) & 511)]) + ((0.00322754588f * fVec31[((IOTA - 406) & 511)]) + ((0.0029846197f * fVec31[((IOTA - 405) & 511)]) + ((0.00229232805f * fVec31[((IOTA - 404) & 511)]) + ((0.00152985519f * fVec31[((IOTA - 403) & 511)]) + ((0.000759076327f * fVec31[((IOTA - 402) & 511)]) + ((0.000211921521f * fVec31[((IOTA - 401) & 511)]) + ((0.000147860497f * fVec31[((IOTA - 400) & 511)]) + ((0.000527146738f * fVec31[((IOTA - 399) & 511)]) + ((0.00126910675f * fVec31[((IOTA - 398) & 511)]) + ((0.00210693898f * fVec31[((IOTA - 397) & 511)]) + ((0.00266424939f * fVec31[((IOTA - 396) & 511)]) + ((0.00305298483f * fVec31[((IOTA - 395) & 511)]) + ((0.00313264877f * fVec31[((IOTA - 394) & 511)]) + ((0.00265086582f * fVec31[((IOTA - 393) & 511)]) + ((0.00232225657f * fVec31[((IOTA - 392) & 511)]) + ((0.00214628316f * fVec31[((IOTA - 391) & 511)]) + ((0.00152242323f * fVec31[((IOTA - 390) & 511)]) + ((0.000932863913f * fVec31[((IOTA - 389) & 511)]) + ((0.000532257836f * fVec31[((IOTA - 388) & 511)]) + ((0.00016504433f * fVec31[((IOTA - 387) & 511)]) + ((0.000274199527f * fVec31[((IOTA - 386) & 511)]) + ((0.000537268352f * fVec31[((IOTA - 385) & 511)]) + ((0.000648575835f * fVec31[((IOTA - 384) & 511)]) + ((0.000909492839f * fVec31[((IOTA - 383) & 511)]) + ((0.000903473236f * fVec31[((IOTA - 382) & 511)]) + ((0.00061810948f * fVec31[((IOTA - 381) & 511)]) + ((0.000447684433f * fVec31[((IOTA - 380) & 511)]) + ((0.000324741937f * fVec31[((IOTA - 379) & 511)]) + ((0.000472131651f * fVec31[((IOTA - 378) & 511)]) + ((0.000819438137f * fVec31[((IOTA - 377) & 511)]) + ((0.000997092575f * fVec31[((IOTA - 376) & 511)]) + ((0.00157125061f * fVec31[((IOTA - 375) & 511)]) + ((0.00236748578f * fVec31[((IOTA - 374) & 511)]) + ((0.0028478899f * fVec31[((IOTA - 373) & 511)]) + ((0.00276721735f * fVec31[((IOTA - 372) & 511)]) + ((0.00177046098f * fVec31[((IOTA - 371) & 511)]) + ((0.000637512654f * fVec31[((IOTA - 370) & 511)]) + ((0.00035016425f * fVec31[((IOTA - 367) & 511)]) + ((0.0016423394f * fVec31[((IOTA - 366) & 511)]) + ((0.00236082729f * fVec31[((IOTA - 365) & 511)]) + ((0.00258461945f * fVec31[((IOTA - 364) & 511)]) + ((0.00218660291f * fVec31[((IOTA - 363) & 511)]) + ((0.00128931692f * fVec31[((IOTA - 362) & 511)]) + ((0.000854746904f * fVec31[((IOTA - 361) & 511)]) + ((0.00104807224f * fVec31[((IOTA - 360) & 511)]) + ((0.00171971694f * fVec31[((IOTA - 359) & 511)]) + ((0.00257123541f * fVec31[((IOTA - 358) & 511)]) + ((0.00266576279f * fVec31[((IOTA - 357) & 511)]) + ((0.00218031416f * fVec31[((IOTA - 356) & 511)]) + ((0.00161997741f * fVec31[((IOTA - 355) & 511)]) + ((0.000365599524f * fVec31[((IOTA - 354) & 511)]) + ((0.000704633072f * fVec31[((IOTA - 347) & 511)]) + ((0.00119270477f * fVec31[((IOTA - 346) & 511)]) + ((0.000493922736f * fVec31[((IOTA - 345) & 511)]) + ((5.56199811e-05f * fVec31[((IOTA - 332) & 511)]) + ((0.000150315464f * fVec31[((IOTA - 325) & 511)]) + ((0.000127986539f * fVec31[((IOTA - 324) & 511)]) + ((0.00035712542f * fVec31[((IOTA - 318) & 511)]) + ((4.95673157e-05f * fVec31[((IOTA - 317) & 511)]) + ((0.00452644657f * (fVec31[((IOTA - 91) & 511)] - fVec31[((IOTA - 296) & 511)])) + ((0.000118066557f * fVec31[((IOTA - 277) & 511)]) + (((0.00207001576f * fVec31[((IOTA - 227) & 511)]) + ((0.00208935142f * fVec31[((IOTA - 226) & 511)]) + ((1.56704336e-05f * fVec31[((IOTA - 225) & 511)]) + ((0.000832552556f * fVec31[((IOTA - 207) & 511)]) + ((0.000988181215f * fVec31[((IOTA - 206) & 511)]) + ((0.00050525507f * fVec31[((IOTA - 199) & 511)]) + ((0.00150238117f * fVec31[((IOTA - 198) & 511)]) + ((0.000448020641f * fVec31[((IOTA - 197) & 511)]) + ((0.00032470841f * fVec31[((IOTA - 188) & 511)]) + ((0.00137758907f * fVec31[((IOTA - 187) & 511)]) + ((0.000344952103f * fVec31[((IOTA - 186) & 511)]) + ((0.00183892669f * fVec31[((IOTA - 180) & 511)]) + ((0.00284287939f * fVec31[((IOTA - 179) & 511)]) + ((0.00170592964f * fVec31[((IOTA - 178) & 511)]) + ((0.00249907048f * fVec31[((IOTA - 167) & 511)]) + ((0.00437787967f * fVec31[((IOTA - 166) & 511)]) + ((0.00353517151f * fVec31[((IOTA - 165) & 511)]) + ((0.000733586494f * fVec31[((IOTA - 164) & 511)]) + ((0.000202404801f * fVec31[((IOTA - 161) & 511)]) + ((0.0024901256f * fVec31[((IOTA - 160) & 511)]) + ((0.00320995878f * fVec31[((IOTA - 159) & 511)]) + ((0.00224733399f * fVec31[((IOTA - 158) & 511)]) + ((0.00115426816f * fVec31[((IOTA - 157) & 511)]) + ((0.00113429362f * fVec31[((IOTA - 156) & 511)]) + ((0.00197276473f * fVec31[((IOTA - 155) & 511)]) + ((0.00274250098f * fVec31[((IOTA - 154) & 511)]) + ((0.00204287842f * fVec31[((IOTA - 153) & 511)]) + ((0.00164489541f * fVec31[((IOTA - 147) & 511)]) + ((0.00541650224f * fVec31[((IOTA - 146) & 511)]) + ((0.00566420332f * fVec31[((IOTA - 145) & 511)]) + ((0.00362139242f * fVec31[((IOTA - 144) & 511)]) + ((0.00226273574f * fVec31[((IOTA - 143) & 511)]) + ((0.00264440896f * fVec31[((IOTA - 142) & 511)]) + ((0.0034032166f * fVec31[((IOTA - 141) & 511)]) + ((0.00303058885f * fVec31[((IOTA - 140) & 511)]) + ((0.00145261269f * fVec31[((IOTA - 139) & 511)]) + ((0.00274959626f * fVec31[((IOTA - 135) & 511)]) + ((0.00615005521f * fVec31[((IOTA - 134) & 511)]) + ((0.00672895508f * fVec31[((IOTA - 133) & 511)]) + ((0.00388106517f * fVec31[((IOTA - 132) & 511)]) + ((0.00394408312f * fVec31[((IOTA - 126) & 511)]) + ((0.00758185238f * fVec31[((IOTA - 125) & 511)]) + ((0.00783604383f * fVec31[((IOTA - 124) & 511)]) + ((0.00675158622f * fVec31[((IOTA - 123) & 511)]) + ((0.00410347804f * fVec31[((IOTA - 122) & 511)]) + ((0.00121446187f * fVec31[((IOTA - 121) & 511)]) + ((0.000305574387f * fVec31[((IOTA - 118) & 511)]) + ((0.00509845233f * fVec31[((IOTA - 117) & 511)]) + ((0.0105248075f * fVec31[((IOTA - 116) & 511)]) + ((0.0159216039f * fVec31[((IOTA - 115) & 511)]) + ((0.0189265683f * fVec31[((IOTA - 114) & 511)]) + ((0.0156727266f * fVec31[((IOTA - 113) & 511)]) + ((0.0066680219f * fVec31[((IOTA - 112) & 511)]) + ((0.0020901924f * fVec31[((IOTA - 106) & 511)]) + ((0.00793080591f * fVec31[((IOTA - 105) & 511)]) + ((0.0115278186f * fVec31[((IOTA - 104) & 511)]) + ((0.0142871002f * fVec31[((IOTA - 103) & 511)]) + ((0.0176179502f * fVec31[((IOTA - 102) & 511)]) + ((0.0195523128f * fVec31[((IOTA - 101) & 511)]) + ((0.016338855f * fVec31[((IOTA - 100) & 511)]) + ((0.00782181881f * fVec31[((IOTA - 99) & 511)]) + ((0.00328494795f * fVec31[((IOTA - 93) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((0.164326534f * fVec31[((IOTA - 5) & 511)]) + (0.272497952f * fVec31[((IOTA - 6) & 511)])) + (0.242636904f * fVec31[((IOTA - 7) & 511)])) + (0.137113586f * fVec31[((IOTA - 8) & 511)])) + (0.0246115886f * fVec31[((IOTA - 14) & 511)])) + (0.0268697497f * fVec31[((IOTA - 15) & 511)])) + (0.0161303319f * fVec31[((IOTA - 16) & 511)])) + (0.0255891755f * fVec31[((IOTA - 17) & 511)])) + (0.0392079949f * fVec31[((IOTA - 18) & 511)])) + (0.0440744497f * fVec31[((IOTA - 19) & 511)])) + (0.0304354206f * fVec31[((IOTA - 20) & 511)])) + (0.0535289906f * fVec31[((IOTA - 26) & 511)])) + (0.0853884742f * fVec31[((IOTA - 27) & 511)])) + (0.0670243278f * fVec31[((IOTA - 28) & 511)])) + (0.0335203856f * fVec31[((IOTA - 29) & 511)])) + (0.00026269909f * fVec31[((IOTA - 33) & 511)])) + (0.0136934379f * fVec31[((IOTA - 39) & 511)])) + (0.0302407183f * fVec31[((IOTA - 40) & 511)])) + (0.031041896f * fVec31[((IOTA - 41) & 511)])) + (0.0128742354f * fVec31[((IOTA - 42) & 511)])) + (0.00136440713f * fVec31[((IOTA - 46) & 511)])) + (0.00980275497f * fVec31[((IOTA - 47) & 511)])) + (0.0115566039f * fVec31[((IOTA - 48) & 511)])) + (0.00229226053f * fVec31[((IOTA - 49) & 511)])) + (0.00659044273f * fVec31[((IOTA - 51) & 511)])) + (0.00609107269f * fVec31[((IOTA - 52) & 511)])) + (0.00752690481f * fVec31[((IOTA - 53) & 511)])) + (0.0140173398f * fVec31[((IOTA - 54) & 511)])) + (0.0111176968f * fVec31[((IOTA - 55) & 511)])) + (0.00758763636f * fVec31[((IOTA - 56) & 511)])) + (0.00405878713f * fVec31[((IOTA - 57) & 511)])) + (0.00235312665f * fVec31[((IOTA - 58) & 511)])) + (0.00323396875f * fVec31[((IOTA - 59) & 511)])) + (0.003791044f * fVec31[((IOTA - 64) & 511)])) + (0.0248629209f * fVec31[((IOTA - 65) & 511)])) + (0.0421564989f * fVec31[((IOTA - 66) & 511)])) + (0.0413328558f * fVec31[((IOTA - 67) & 511)])) + (0.0242304523f * fVec31[((IOTA - 68) & 511)])) + (0.00166325597f * fVec31[((IOTA - 69) & 511)])) + (0.00362260314f * fVec31[((IOTA - 73) & 511)])) + (0.00218088599f * fVec31[((IOTA - 74) & 511)])) + (0.00353930751f * fVec31[((IOTA - 78) & 511)])) + (0.0132668037f * fVec31[((IOTA - 79) & 511)])) + (0.0178444646f * fVec31[((IOTA - 80) & 511)])) + (0.0175697617f * fVec31[((IOTA - 81) & 511)])) + (0.00735348742f * fVec31[((IOTA - 82) & 511)])) + (0.0050748121f * fVec31[((IOTA - 85) & 511)])) + (0.0155323651f * fVec31[((IOTA - 86) & 511)])) + (0.0197305381f * fVec31[((IOTA - 87) & 511)])) + (0.0169797651f * fVec31[((IOTA - 88) & 511)])) + (0.0139289321f * fVec31[((IOTA - 89) & 511)])) + (0.00857796986f * fVec31[((IOTA - 90) & 511)])) + (0.00585013069f * fVec31[((IOTA - 92) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00152417226f * fVec31[((IOTA - 428) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00217217626f * fVec31[((IOTA - 429) & 511)])) + (0.00287015131f * fVec31[((IOTA - 430) & 511)])) + (0.00293945801f * fVec31[((IOTA - 431) & 511)])) + (0.0024600625f * fVec31[((IOTA - 432) & 511)])) + (0.00219467329f * fVec31[((IOTA - 433) & 511)])) + (0.00185405929f * fVec31[((IOTA - 434) & 511)])) + (0.00181767391f * fVec31[((IOTA - 435) & 511)])) + (0.00258246716f * fVec31[((IOTA - 436) & 511)])) + (0.00348883262f * fVec31[((IOTA - 437) & 511)])) + (0.00438558031f * fVec31[((IOTA - 438) & 511)])) + (0.00507790595f * fVec31[((IOTA - 439) & 511)])) + (0.00491888076f * fVec31[((IOTA - 440) & 511)])) + (0.00426317565f * fVec31[((IOTA - 441) & 511)])) + (0.00320649473f * fVec31[((IOTA - 442) & 511)])) + (0.00187043566f * fVec31[((IOTA - 443) & 511)])) + (0.0013060295f * fVec31[((IOTA - 444) & 511)])) + (0.00132738333f * fVec31[((IOTA - 445) & 511)])) + (0.00136484439f * fVec31[((IOTA - 446) & 511)])) + (0.00171023374f * fVec31[((IOTA - 447) & 511)])) + (0.00195618626f * fVec31[((IOTA - 448) & 511)])) + (0.00192134781f * fVec31[((IOTA - 449) & 511)])) + (0.00181474863f * fVec31[((IOTA - 450) & 511)])) + (0.00145009067f * fVec31[((IOTA - 451) & 511)])) + (0.00133373868f * fVec31[((IOTA - 452) & 511)])) + (0.00166244898f * fVec31[((IOTA - 453) & 511)])) + (0.00214836793f * fVec31[((IOTA - 454) & 511)])) + (0.00292361947f * fVec31[((IOTA - 455) & 511)])) + (0.00355262402f * fVec31[((IOTA - 456) & 511)])) + (0.00334463734f * fVec31[((IOTA - 457) & 511)])) + (0.00274179457f * fVec31[((IOTA - 458) & 511)])) + (0.0020248536f * fVec31[((IOTA - 459) & 511)])) + (0.00116223795f * fVec31[((IOTA - 460) & 511)])) + (0.000811468344f * fVec31[((IOTA - 461) & 511)])) + (0.00109209074f * fVec31[((IOTA - 462) & 511)])) + (0.00157686649f * fVec31[((IOTA - 463) & 511)])) + (0.00217631273f * fVec31[((IOTA - 464) & 511)])) + (0.00239687599f * fVec31[((IOTA - 465) & 511)])) + (0.00201459741f * fVec31[((IOTA - 466) & 511)])) + (0.00159411738f * fVec31[((IOTA - 467) & 511)])) + (0.00125821121f * fVec31[((IOTA - 468) & 511)])) + (0.000948635396f * fVec31[((IOTA - 469) & 511)])) + (0.000905693043f * fVec31[((IOTA - 470) & 511)])) + (0.000979169272f * fVec31[((IOTA - 471) & 511)])) + (0.00109797576f * fVec31[((IOTA - 472) & 511)])) + (0.00138687063f * fVec31[((IOTA - 473) & 511)])) + (0.00172412209f * fVec31[((IOTA - 474) & 511)])) + (0.00222638436f * fVec31[((IOTA - 475) & 511)])) + (0.00263654022f * fVec31[((IOTA - 476) & 511)])) + (0.00272218976f * fVec31[((IOTA - 477) & 511)])) + (0.0028267717f * fVec31[((IOTA - 478) & 511)])) + (0.00269226125f * fVec31[((IOTA - 479) & 511)])) + (0.00217859913f * fVec31[((IOTA - 480) & 511)])) + (0.00182867004f * fVec31[((IOTA - 481) & 511)])) + (0.00158258341f * fVec31[((IOTA - 482) & 511)])) + (0.00144524826f * fVec31[((IOTA - 483) & 511)])) + (0.00143569801f * fVec31[((IOTA - 484) & 511)])) + (0.00128121255f * fVec31[((IOTA - 485) & 511)])) + (0.00137156993f * fVec31[((IOTA - 486) & 511)])) + (0.00133656338f * fVec31[((IOTA - 487) & 511)])) + (0.000896714162f * fVec31[((IOTA - 488) & 511)])) + (0.000945003703f * fVec31[((IOTA - 489) & 511)])) + (0.00120447436f * fVec31[((IOTA - 490) & 511)])) + (0.00122333923f * fVec31[((IOTA - 491) & 511)])) + (0.00126779499f * fVec31[((IOTA - 492) & 511)])) + (0.00103522651f * fVec31[((IOTA - 493) & 511)])) + (0.000570358243f * fVec31[((IOTA - 494) & 511)])) + (0.000331534538f * fVec31[((IOTA - 495) & 511)])) + (0.000432350207f * fVec31[((IOTA - 496) & 511)])) + (0.00119626895f * fVec31[((IOTA - 497) & 511)])) + (0.00220563589f * fVec31[((IOTA - 498) & 511)])) + (0.00269629667f * fVec31[((IOTA - 499) & 511)])) + (0.00296864659f * fVec31[((IOTA - 500) & 511)])) + (0.00289432984f * fVec31[((IOTA - 501) & 511)])) + (0.00223519467f * fVec31[((IOTA - 502) & 511)])) + (0.00188543368f * fVec31[((IOTA - 503) & 511)])) + (0.00192255853f * fVec31[((IOTA - 504) & 511)])) + (0.00208336581f * fVec31[((IOTA - 505) & 511)])) + (0.00255344622f * fVec31[((IOTA - 506) & 511)])) + (0.00271569984f * fVec31[((IOTA - 507) & 511)])) + (0.0024449639f * fVec31[((IOTA - 508) & 511)])) + (0.00226707337f * fVec31[((IOTA - 509) & 511)])) + (0.00194707327f * fVec31[((IOTA - 510) & 511)])) + (0.00167499203f * fVec31[((IOTA - 511) & 511)])))) : (iSlow94 ? ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0620897897f * fVec30[((IOTA - 13) & 511)]) + ((0.134168059f * fVec30[((IOTA - 12) & 511)]) + ((0.144391805f * fVec30[((IOTA - 11) & 511)]) + ((0.0983900502f * fVec30[((IOTA - 10) & 511)]) + ((0.0675678179f * fVec30[((IOTA - 4) & 511)]) + ((0.172469631f * fVec30[((IOTA - 3) & 511)]) + ((0.208980173f * fVec30[((IOTA - 2) & 511)]) + ((0.218604922f * fVec30[((IOTA - 1) & 511)]) + ((fSlow98 * fTemp0) + (0.021602869f * fVec30[((IOTA - 21) & 511)])))))))))) + (0.0691225976f * fVec30[((IOTA - 22) & 511)])) + (0.087012127f * fVec30[((IOTA - 23) & 511)])) + (0.0597692095f * fVec30[((IOTA - 24) & 511)])) + (0.00273133814f * fVec30[((IOTA - 25) & 511)])) + (0.0156230703f * fVec30[((IOTA - 30) & 511)])) + (0.0346859396f * fVec30[((IOTA - 31) & 511)])) + (0.0186499991f * fVec30[((IOTA - 32) & 511)])) + (0.00505882502f * fVec30[((IOTA - 33) & 511)])) + (0.00250268634f * fVec30[((IOTA - 37) & 511)])) + (0.00616392726f * fVec30[((IOTA - 38) & 511)])) + (0.0101070013f * fVec30[((IOTA - 61) & 511)])) + (0.0189075172f * fVec30[((IOTA - 62) & 511)])) + (0.0236203782f * fVec30[((IOTA - 63) & 511)])) + (0.0111576561f * fVec30[((IOTA - 64) & 511)])) + (0.00490299147f * fVec30[((IOTA - 71) & 511)])) + (0.00810816512f * fVec30[((IOTA - 72) & 511)])) + (0.00946719758f * fVec30[((IOTA - 73) & 511)])) + (0.0119931716f * fVec30[((IOTA - 74) & 511)])) + (0.00889031775f * fVec30[((IOTA - 75) & 511)])) + (0.00229804544f * fVec30[((IOTA - 76) & 511)])) + (0.00424659671f * fVec30[((IOTA - 82) & 511)])) + (0.00729593681f * fVec30[((IOTA - 83) & 511)])) + (0.0023083617f * fVec30[((IOTA - 84) & 511)])) + (0.00567814661f * fVec30[((IOTA - 94) & 511)])) + (0.0111707775f * fVec30[((IOTA - 95) & 511)])) + (0.01366001f * fVec30[((IOTA - 96) & 511)])) + (0.0105014425f * fVec30[((IOTA - 97) & 511)])) + (0.00326616736f * fVec30[((IOTA - 98) & 511)])) + (0.00826125313f * fVec30[((IOTA - 108) & 511)])) + (0.0147087034f * fVec30[((IOTA - 109) & 511)])) + (0.0128436489f * fVec30[((IOTA - 110) & 511)])) + (0.0044116606f * fVec30[((IOTA - 111) & 511)])) + (0.000619351864f * fVec30[((IOTA - 128) & 511)])) + (0.00407188013f * fVec30[((IOTA - 129) & 511)])) + (0.00618015602f * fVec30[((IOTA - 130) & 511)])) + (0.00565120904f * fVec30[((IOTA - 131) & 511)])) + (0.00175127108f * fVec30[((IOTA - 132) & 511)])) + (0.000426415354f * fVec30[((IOTA - 145) & 511)])) + (0.000695911236f * fVec30[((IOTA - 146) & 511)])) + (0.00117062079f * fVec30[((IOTA - 147) & 511)])) + (0.00276542502f * fVec30[((IOTA - 148) & 511)])) + (0.00447105616f * fVec30[((IOTA - 149) & 511)])) + (0.0049409396f * fVec30[((IOTA - 150) & 511)])) + (0.00344963232f * fVec30[((IOTA - 151) & 511)])) + (0.000962149352f * fVec30[((IOTA - 152) & 511)])) + (0.000232724473f * fVec30[((IOTA - 157) & 511)])) + (0.00043078931f * fVec30[((IOTA - 167) & 511)])) + (0.00347726326f * fVec30[((IOTA - 168) & 511)])) + (0.00626187352f * fVec30[((IOTA - 169) & 511)])) + (0.00719186664f * fVec30[((IOTA - 170) & 511)])) + (0.0054439744f * fVec30[((IOTA - 171) & 511)])) + (0.00245508552f * fVec30[((IOTA - 172) & 511)])) + (0.00174339768f * fVec30[((IOTA - 179) & 511)])) + (0.00446475158f * fVec30[((IOTA - 180) & 511)])) + (0.00713916821f * fVec30[((IOTA - 181) & 511)])) + (0.00784476288f * fVec30[((IOTA - 182) & 511)])) + (0.00661963271f * fVec30[((IOTA - 183) & 511)])) + (0.0037379209f * fVec30[((IOTA - 184) & 511)])) + (0.00356278196f * fVec30[((IOTA - 189) & 511)])) + (0.00631749816f * fVec30[((IOTA - 190) & 511)])) + (0.00776762981f * fVec30[((IOTA - 191) & 511)])) + (0.00818662439f * fVec30[((IOTA - 192) & 511)])) + (0.00768223219f * fVec30[((IOTA - 193) & 511)])) + (0.00691449782f * fVec30[((IOTA - 194) & 511)])) + (0.00590423495f * fVec30[((IOTA - 195) & 511)])) + (0.00388211058f * fVec30[((IOTA - 196) & 511)])) + (0.00159160653f * fVec30[((IOTA - 197) & 511)])) + (0.000107900705f * fVec30[((IOTA - 198) & 511)])) + (0.000745442696f * fVec30[((IOTA - 200) & 511)])) + (0.00270726671f * fVec30[((IOTA - 201) & 511)])) + (0.00411507627f * fVec30[((IOTA - 202) & 511)])) + (0.00407622382f * fVec30[((IOTA - 203) & 511)])) + (0.0024318886f * fVec30[((IOTA - 204) & 511)])) + (0.000615702011f * fVec30[((IOTA - 205) & 511)])) + (0.000879768282f * fVec30[((IOTA - 206) & 511)])) + (0.00329898717f * fVec30[((IOTA - 207) & 511)])) + (0.00583775062f * fVec30[((IOTA - 208) & 511)])) + (0.00791402161f * fVec30[((IOTA - 209) & 511)])) + (0.00837838463f * fVec30[((IOTA - 210) & 511)])) + (0.00603693165f * fVec30[((IOTA - 211) & 511)])) + (0.00327959098f * fVec30[((IOTA - 212) & 511)])) + (0.00122208288f * fVec30[((IOTA - 213) & 511)])) + (0.000119484495f * fVec30[((IOTA - 214) & 511)])) + (0.000717660412f * fVec30[((IOTA - 215) & 511)])) + (0.0016446067f * fVec30[((IOTA - 216) & 511)])) + (0.00207753759f * fVec30[((IOTA - 217) & 511)])) + (0.00264572958f * fVec30[((IOTA - 218) & 511)])) + (0.00393761462f * fVec30[((IOTA - 219) & 511)])) + (0.00642787246f * fVec30[((IOTA - 220) & 511)])) + (0.00833751075f * fVec30[((IOTA - 221) & 511)])) + (0.00828628987f * fVec30[((IOTA - 222) & 511)])) + (0.00673601031f * fVec30[((IOTA - 223) & 511)])) + (0.00396295357f * fVec30[((IOTA - 224) & 511)])) + (0.000941486098f * fVec30[((IOTA - 225) & 511)])) + (0.000687283929f * fVec30[((IOTA - 227) & 511)])) + (0.00295531517f * fVec30[((IOTA - 228) & 511)])) + (0.00558792241f * fVec30[((IOTA - 229) & 511)])) + (0.00733177271f * fVec30[((IOTA - 230) & 511)])) + (0.0076191267f * fVec30[((IOTA - 231) & 511)])) + (0.0069429134f * fVec30[((IOTA - 232) & 511)])) + (0.00540122995f * fVec30[((IOTA - 233) & 511)])) + (0.00414542248f * fVec30[((IOTA - 234) & 511)])) + (0.0034114127f * fVec30[((IOTA - 235) & 511)])) + (0.00249653263f * fVec30[((IOTA - 236) & 511)])) + (0.00217038626f * fVec30[((IOTA - 237) & 511)])) + (0.00232591806f * fVec30[((IOTA - 238) & 511)])) + (0.00294171041f * fVec30[((IOTA - 239) & 511)])) + (0.00413513649f * fVec30[((IOTA - 240) & 511)])) + (0.00481753331f * fVec30[((IOTA - 241) & 511)])) + (0.00493029086f * fVec30[((IOTA - 242) & 511)])) + (0.00456625735f * fVec30[((IOTA - 243) & 511)])) + (0.00301449932f * fVec30[((IOTA - 244) & 511)])) + (0.00138762966f * fVec30[((IOTA - 245) & 511)])) + (0.00066475058f * fVec30[((IOTA - 246) & 511)])) + (0.00096398918f * fVec30[((IOTA - 247) & 511)])) + (0.0020927107f * fVec30[((IOTA - 248) & 511)])) + (0.00367970206f * fVec30[((IOTA - 249) & 511)])) + (0.00495927967f * fVec30[((IOTA - 250) & 511)])) + (0.00556303654f * fVec30[((IOTA - 251) & 511)])) + (0.00551151438f * fVec30[((IOTA - 252) & 511)])) + (0.00508503849f * fVec30[((IOTA - 253) & 511)])) + (0.00505541638f * fVec30[((IOTA - 254) & 511)])) + (0.00528780883f * fVec30[((IOTA - 255) & 511)])) + (0.00567576382f * fVec30[((IOTA - 256) & 511)])) + (0.00653302856f * fVec30[((IOTA - 257) & 511)])) + (0.00712520164f * fVec30[((IOTA - 258) & 511)])) + (0.00727635948f * fVec30[((IOTA - 259) & 511)])) + (0.00738145504f * fVec30[((IOTA - 260) & 511)])) + (0.00677462155f * fVec30[((IOTA - 261) & 511)])) + (0.00514962245f * fVec30[((IOTA - 262) & 511)])) + (0.00317902025f * fVec30[((IOTA - 263) & 511)])) + (0.00183736254f * fVec30[((IOTA - 264) & 511)])) + (0.00161260134f * fVec30[((IOTA - 265) & 511)])) + (0.00256202091f * fVec30[((IOTA - 266) & 511)])) + (0.00457349699f * fVec30[((IOTA - 267) & 511)])) + (0.00700125284f * fVec30[((IOTA - 268) & 511)])) + (0.00890051387f * fVec30[((IOTA - 269) & 511)])) + (0.00942934025f * fVec30[((IOTA - 270) & 511)])) + (0.00816740934f * fVec30[((IOTA - 271) & 511)])) + (0.00543024903f * fVec30[((IOTA - 272) & 511)])) + (0.00220311573f * fVec30[((IOTA - 273) & 511)])) + (0.000871744007f * fVec30[((IOTA - 277) & 511)])) + (0.00254503824f * fVec30[((IOTA - 278) & 511)])) + (0.00404023658f * fVec30[((IOTA - 279) & 511)])) + (0.00429268926f * fVec30[((IOTA - 280) & 511)])) + (0.0032446594f * fVec30[((IOTA - 281) & 511)])) + (0.00240766583f * fVec30[((IOTA - 282) & 511)])) + (0.00174083374f * fVec30[((IOTA - 283) & 511)])) + (0.00130636431f * fVec30[((IOTA - 284) & 511)])) + (0.00178774074f * fVec30[((IOTA - 285) & 511)])) + (0.00264950003f * fVec30[((IOTA - 286) & 511)])) + (0.00321096508f * fVec30[((IOTA - 287) & 511)])) + (0.00353352167f * fVec30[((IOTA - 288) & 511)])) + (0.00316073978f * fVec30[((IOTA - 289) & 511)])) + (0.00253794901f * fVec30[((IOTA - 290) & 511)])) + (0.00264648348f * fVec30[((IOTA - 291) & 511)])) + (0.00311120879f * fVec30[((IOTA - 292) & 511)])) + (0.00339946756f * fVec30[((IOTA - 293) & 511)])) + (0.00358899543f * fVec30[((IOTA - 294) & 511)])) + (0.00401471695f * fVec30[((IOTA - 295) & 511)])) + (0.00496178353f * fVec30[((IOTA - 296) & 511)])) + (0.00594673771f * fVec30[((IOTA - 297) & 511)])) + (0.00649598567f * fVec30[((IOTA - 298) & 511)])) + (0.0070690643f * fVec30[((IOTA - 299) & 511)])) + (0.00686967233f * fVec30[((IOTA - 300) & 511)])) + (0.00570339523f * fVec30[((IOTA - 301) & 511)])) + (0.00449404214f * fVec30[((IOTA - 302) & 511)])) + (0.0031271358f * fVec30[((IOTA - 303) & 511)])) + (0.00192647055f * fVec30[((IOTA - 304) & 511)])) + (0.00195277436f * fVec30[((IOTA - 305) & 511)])) + (0.0027762847f * fVec30[((IOTA - 306) & 511)])) + (0.00408041663f * fVec30[((IOTA - 307) & 511)])) + (0.00543039991f * fVec30[((IOTA - 308) & 511)])) + (0.00596522912f * fVec30[((IOTA - 309) & 511)])) + (0.00553449988f * fVec30[((IOTA - 310) & 511)])) + (0.00414750399f * fVec30[((IOTA - 311) & 511)])) + (0.00223880075f * fVec30[((IOTA - 312) & 511)])) + (0.00128108589f * fVec30[((IOTA - 313) & 511)])) + (0.00111357868f * fVec30[((IOTA - 314) & 511)])) + (0.00102407858f * fVec30[((IOTA - 315) & 511)])) + (0.00135287922f * fVec30[((IOTA - 316) & 511)])) + (0.00142799038f * fVec30[((IOTA - 317) & 511)])) + (0.00111671584f * fVec30[((IOTA - 318) & 511)])) + (0.000958710443f * fVec30[((IOTA - 319) & 511)])) + (0.000742969103f * fVec30[((IOTA - 320) & 511)])) + (0.000687857158f * fVec30[((IOTA - 321) & 511)])) + (0.000577935018f * fVec30[((IOTA - 322) & 511)])) + (9.16719437e-05f * fVec30[((IOTA - 323) & 511)])) + (0.000125849154f * fVec30[((IOTA - 324) & 511)])) + (0.000572324265f * fVec30[((IOTA - 325) & 511)])) + (0.00107858703f * fVec30[((IOTA - 326) & 511)])) + (0.00195974251f * fVec30[((IOTA - 327) & 511)])) + (0.00270750793f * fVec30[((IOTA - 328) & 511)])) + (0.0029024356f * fVec30[((IOTA - 329) & 511)])) + (0.00284472946f * fVec30[((IOTA - 330) & 511)])) + (0.00204224465f * fVec30[((IOTA - 331) & 511)])) + (0.00101472717f * fVec30[((IOTA - 332) & 511)])) + (0.00078269653f * fVec30[((IOTA - 333) & 511)])) + (0.000856933184f * fVec30[((IOTA - 334) & 511)])) + (0.00113520725f * fVec30[((IOTA - 335) & 511)])) + (0.00204818696f * fVec30[((IOTA - 336) & 511)])) + (0.00295290165f * fVec30[((IOTA - 337) & 511)])) + (0.00382455532f * fVec30[((IOTA - 338) & 511)])) + (0.00430339761f * fVec30[((IOTA - 339) & 511)])) + (0.0041986038f * fVec30[((IOTA - 340) & 511)])) + (0.00361792371f * fVec30[((IOTA - 341) & 511)])) + (0.00221735332f * fVec30[((IOTA - 342) & 511)])) + (0.000336070545f * fVec30[((IOTA - 343) & 511)])) + (0.00147715956f * fVec30[((IOTA - 347) & 511)])) + (0.00291809114f * fVec30[((IOTA - 348) & 511)])) + (0.00332218409f * fVec30[((IOTA - 349) & 511)])) + (0.00263870088f * fVec30[((IOTA - 350) & 511)])) + (0.00106459018f * fVec30[((IOTA - 351) & 511)])) + (5.50816767e-05f * fVec30[((IOTA - 359) & 511)])) + (8.18986446e-05f * fVec30[((IOTA - 360) & 511)])) + (0.000131188426f * fVec30[((IOTA - 410) & 511)])) + (0.000476006884f * fVec30[((IOTA - 411) & 511)])) - (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0100320112f * fVec30[((IOTA - 100) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((0.00853364542f * fVec30[((IOTA - 14) & 511)]) + ((0.0266109556f * fVec30[((IOTA - 9) & 511)]) + ((0.175597012f * fVec30[((IOTA - 8) & 511)]) + ((0.244440541f * fVec30[((IOTA - 7) & 511)]) + ((0.238544211f * fVec30[((IOTA - 6) & 511)]) + ((0.12882185f * fVec30[((IOTA - 5) & 511)]) + ((((0.0239208546f * fVec30[((IOTA - 15) & 511)]) + (((0.0278398264f * fVec30[((IOTA - 16) & 511)]) + (0.0397208147f * fVec30[((IOTA - 17) & 511)])) + (0.0415541939f * fVec30[((IOTA - 18) & 511)]))) + (0.0343343653f * fVec30[((IOTA - 19) & 511)])) + (0.0162270684f * fVec30[((IOTA - 20) & 511)])))))))) + (0.0657939538f * fVec30[((IOTA - 26) & 511)])) + (0.0885628611f * fVec30[((IOTA - 27) & 511)])) + (0.0636004955f * fVec30[((IOTA - 28) & 511)])) + (0.025732154f * fVec30[((IOTA - 29) & 511)])) + (0.00891831145f * fVec30[((IOTA - 34) & 511)])) + (0.0184502751f * fVec30[((IOTA - 35) & 511)])) + (0.00850670785f * fVec30[((IOTA - 36) & 511)])) + (0.00178783108f * fVec30[((IOTA - 39) & 511)])) + (0.0137092397f * fVec30[((IOTA - 40) & 511)])) + (0.0123242643f * fVec30[((IOTA - 41) & 511)])) + (0.00611931272f * fVec30[((IOTA - 42) & 511)])) + (0.00276916567f * fVec30[((IOTA - 43) & 511)])) + (0.00491002016f * fVec30[((IOTA - 44) & 511)])) + (0.00555416755f * fVec30[((IOTA - 45) & 511)])) + (0.00519978674f * fVec30[((IOTA - 46) & 511)])) + (0.0122810379f * fVec30[((IOTA - 47) & 511)])) + (0.0112797944f * fVec30[((IOTA - 48) & 511)])) + (0.000960279256f * fVec30[((IOTA - 49) & 511)])) + (0.00293453131f * fVec30[((IOTA - 50) & 511)])) + (0.0109861065f * fVec30[((IOTA - 51) & 511)])) + (0.00622009486f * fVec30[((IOTA - 52) & 511)])) + (0.00145007158f * fVec30[((IOTA - 53) & 511)])) + (0.00340206176f * fVec30[((IOTA - 54) & 511)])) + (0.00107798353f * fVec30[((IOTA - 55) & 511)])) + (0.00863620639f * fVec30[((IOTA - 56) & 511)])) + (0.0185404085f * fVec30[((IOTA - 57) & 511)])) + (0.0236059297f * fVec30[((IOTA - 58) & 511)])) + (0.0247348621f * fVec30[((IOTA - 59) & 511)])) + (0.00799172744f * fVec30[((IOTA - 60) & 511)])) + (0.0137665831f * fVec30[((IOTA - 65) & 511)])) + (0.0352461971f * fVec30[((IOTA - 66) & 511)])) + (0.0432652831f * fVec30[((IOTA - 67) & 511)])) + (0.0357032903f * fVec30[((IOTA - 68) & 511)])) + (0.0214575641f * fVec30[((IOTA - 69) & 511)])) + (0.00663818466f * fVec30[((IOTA - 70) & 511)])) + (0.00780038955f * fVec30[((IOTA - 77) & 511)])) + (0.0187743995f * fVec30[((IOTA - 78) & 511)])) + (0.0197862014f * fVec30[((IOTA - 79) & 511)])) + (0.0156671423f * fVec30[((IOTA - 80) & 511)])) + (0.00765276095f * fVec30[((IOTA - 81) & 511)])) + (0.00657197181f * fVec30[((IOTA - 85) & 511)])) + (0.0163252559f * fVec30[((IOTA - 86) & 511)])) + (0.020914983f * fVec30[((IOTA - 87) & 511)])) + (0.0228882693f * fVec30[((IOTA - 88) & 511)])) + (0.0217429865f * fVec30[((IOTA - 89) & 511)])) + (0.0157506391f * fVec30[((IOTA - 90) & 511)])) + (0.0111310799f * fVec30[((IOTA - 91) & 511)])) + (0.00948433205f * fVec30[((IOTA - 92) & 511)])) + (0.00328164222f * fVec30[((IOTA - 93) & 511)])) + (0.00417027902f * fVec30[((IOTA - 99) & 511)])) + (0.0119019216f * fVec30[((IOTA - 101) & 511)]))) + (0.0124887247f * fVec30[((IOTA - 102) & 511)])) + (0.0137603991f * fVec30[((IOTA - 103) & 511)])) + (0.0151199456f * fVec30[((IOTA - 104) & 511)])) + (0.0152745117f * fVec30[((IOTA - 105) & 511)])) + (0.0102163805f * fVec30[((IOTA - 106) & 511)])) + (0.00117891654f * fVec30[((IOTA - 107) & 511)])) + (0.00682167942f * fVec30[((IOTA - 112) & 511)])) + (0.0163826607f * fVec30[((IOTA - 113) & 511)])) + (0.02017322f * fVec30[((IOTA - 114) & 511)])) + (0.0181634631f * fVec30[((IOTA - 115) & 511)])) + (0.013085423f * fVec30[((IOTA - 116) & 511)])) + (0.00642455462f * fVec30[((IOTA - 117) & 511)])) + (0.00186671317f * fVec30[((IOTA - 118) & 511)])) + (0.000762365293f * fVec30[((IOTA - 119) & 511)])) + (0.000736453105f * fVec30[((IOTA - 120) & 511)])) + (0.00175320171f * fVec30[((IOTA - 121) & 511)])) + (0.00362552563f * fVec30[((IOTA - 122) & 511)])) + (0.00445256475f * fVec30[((IOTA - 123) & 511)])) + (0.00623351848f * fVec30[((IOTA - 124) & 511)])) + (0.00809567608f * fVec30[((IOTA - 125) & 511)])) + (0.0071617919f * fVec30[((IOTA - 126) & 511)])) + (0.00371807208f * fVec30[((IOTA - 127) & 511)])) + (0.00163827231f * fVec30[((IOTA - 133) & 511)])) + (0.00320263952f * fVec30[((IOTA - 134) & 511)])) + (0.00256346911f * fVec30[((IOTA - 135) & 511)])) + (0.000276464038f * fVec30[((IOTA - 136) & 511)])) + (0.000496821012f * fVec30[((IOTA - 137) & 511)])) + (0.00269960472f * fVec30[((IOTA - 138) & 511)])) + (0.0052205408f * fVec30[((IOTA - 139) & 511)])) + (0.00780250086f * fVec30[((IOTA - 140) & 511)])) + (0.00808931142f * fVec30[((IOTA - 141) & 511)])) + (0.00564140547f * fVec30[((IOTA - 142) & 511)])) + (0.00277595269f * fVec30[((IOTA - 143) & 511)])) + (0.00048840465f * fVec30[((IOTA - 144) & 511)])) + (0.000554315746f * fVec30[((IOTA - 153) & 511)])) + (0.00120160077f * fVec30[((IOTA - 154) & 511)])) + (0.00120078633f * fVec30[((IOTA - 155) & 511)])) + (9.80370678e-05f * fVec30[((IOTA - 156) & 511)])) + (0.000953431707f * fVec30[((IOTA - 158) & 511)])) + (0.00202091783f * fVec30[((IOTA - 159) & 511)])) + (0.00265520159f * fVec30[((IOTA - 160) & 511)])) + (0.0023142742f * fVec30[((IOTA - 161) & 511)])) + (0.00114832912f * fVec30[((IOTA - 162) & 511)])) + (0.000833163038f * fVec30[((IOTA - 163) & 511)])) + (0.0016092835f * fVec30[((IOTA - 164) & 511)])) + (0.00220091362f * fVec30[((IOTA - 165) & 511)])) + (0.00163383782f * fVec30[((IOTA - 166) & 511)])) + (0.00076882029f * fVec30[((IOTA - 173) & 511)])) + (0.00307145109f * fVec30[((IOTA - 174) & 511)])) + (0.00326345256f * fVec30[((IOTA - 175) & 511)])) + (0.00277740043f * fVec30[((IOTA - 176) & 511)])) + (0.0017366712f * fVec30[((IOTA - 177) & 511)])) + (0.000122953206f * fVec30[((IOTA - 178) & 511)])) + (2.02096999e-06f * fVec30[((IOTA - 185) & 511)])) + (0.00280955667f * fVec30[((IOTA - 186) & 511)])) + (0.00296333898f * fVec30[((IOTA - 187) & 511)])) + (0.000148653984f * fVec30[((IOTA - 188) & 511)])) + (0.00033537671f * fVec30[((IOTA - 199) & 511)])) + (0.000369523652f * fVec30[((IOTA - 226) & 511)])) + (0.000356703531f * fVec30[((IOTA - 274) & 511)])) + (0.00138931861f * fVec30[((IOTA - 275) & 511)])) + (0.000715367962f * fVec30[((IOTA - 276) & 511)])) + (0.00110199535f * fVec30[((IOTA - 344) & 511)])) + (0.00152925495f * fVec30[((IOTA - 345) & 511)])) + (0.000491451472f * fVec30[((IOTA - 346) & 511)])) + (0.000439537223f * fVec30[((IOTA - 352) & 511)])) + (0.0015635225f * fVec30[((IOTA - 353) & 511)])) + (0.00240081828f * fVec30[((IOTA - 354) & 511)])) + (0.00254232297f * fVec30[((IOTA - 355) & 511)])) + (0.00206972519f * fVec30[((IOTA - 356) & 511)])) + (0.0013714307f * fVec30[((IOTA - 357) & 511)])) + (0.000506685115f * fVec30[((IOTA - 358) & 511)])) + (0.000336040277f * fVec30[((IOTA - 361) & 511)])) + (0.00143468706f * fVec30[((IOTA - 362) & 511)])) + (0.00271290727f * fVec30[((IOTA - 363) & 511)])) + (0.00336161023f * fVec30[((IOTA - 364) & 511)])) + (0.00330354227f * fVec30[((IOTA - 365) & 511)])) + (0.00245903712f * fVec30[((IOTA - 366) & 511)])) + (0.00116745383f * fVec30[((IOTA - 367) & 511)])) + (0.000673015602f * fVec30[((IOTA - 368) & 511)])) + (0.000683151186f * fVec30[((IOTA - 369) & 511)])) + (0.000771836843f * fVec30[((IOTA - 370) & 511)])) + (0.00165742682f * fVec30[((IOTA - 371) & 511)])) + (0.00260880729f * fVec30[((IOTA - 372) & 511)])) + (0.00277896924f * fVec30[((IOTA - 373) & 511)])) + (0.00273317844f * fVec30[((IOTA - 374) & 511)])) + (0.00251040841f * fVec30[((IOTA - 375) & 511)])) + (0.00242449809f * fVec30[((IOTA - 376) & 511)])) + (0.00246102782f * fVec30[((IOTA - 377) & 511)])) + (0.00176104438f * fVec30[((IOTA - 378) & 511)])) + (0.000971470494f * fVec30[((IOTA - 379) & 511)])) + (0.000615943223f * fVec30[((IOTA - 380) & 511)])) + (0.00036014244f * fVec30[((IOTA - 381) & 511)])) + (0.000396159478f * fVec30[((IOTA - 382) & 511)])) + (0.000557875261f * fVec30[((IOTA - 383) & 511)])) + (0.000585627276f * fVec30[((IOTA - 384) & 511)])) + (0.000774913933f * fVec30[((IOTA - 385) & 511)])) + (0.000648883637f * fVec30[((IOTA - 386) & 511)])) + (0.000452357344f * fVec30[((IOTA - 387) & 511)])) + (0.000954125542f * fVec30[((IOTA - 388) & 511)])) + (0.00142352609f * fVec30[((IOTA - 389) & 511)])) + (0.00175169343f * fVec30[((IOTA - 390) & 511)])) + (0.00232519396f * fVec30[((IOTA - 391) & 511)])) + (0.00224748859f * fVec30[((IOTA - 392) & 511)])) + (0.00196942547f * fVec30[((IOTA - 393) & 511)])) + (0.00229177112f * fVec30[((IOTA - 394) & 511)])) + (0.00292674871f * fVec30[((IOTA - 395) & 511)])) + (0.00374760386f * fVec30[((IOTA - 396) & 511)])) + (0.00418783491f * fVec30[((IOTA - 397) & 511)])) + (0.00394781027f * fVec30[((IOTA - 398) & 511)])) + (0.00313389301f * fVec30[((IOTA - 399) & 511)])) + (0.00161088211f * fVec30[((IOTA - 400) & 511)])) + (0.000350429211f * fVec30[((IOTA - 401) & 511)])) + (0.000231276732f * fVec30[((IOTA - 402) & 511)])) + (0.000944110565f * fVec30[((IOTA - 403) & 511)])) + (0.00241940003f * fVec30[((IOTA - 404) & 511)])) + (0.00402931683f * fVec30[((IOTA - 405) & 511)])) + (0.00476278365f * fVec30[((IOTA - 406) & 511)])) + (0.00467708427f * fVec30[((IOTA - 407) & 511)])) + (0.00349297933f * fVec30[((IOTA - 408) & 511)])) + (0.00136639317f * fVec30[((IOTA - 409) & 511)])) + (7.75232911e-06f * fVec30[((IOTA - 412) & 511)])) + (0.00148264971f * fVec30[((IOTA - 413) & 511)])) + (0.00299980864f * fVec30[((IOTA - 414) & 511)])) + (0.00388078345f * fVec30[((IOTA - 415) & 511)])) + (0.00406111078f * fVec30[((IOTA - 416) & 511)])) + (0.00300101517f * fVec30[((IOTA - 417) & 511)])) + (0.0017086775f * fVec30[((IOTA - 418) & 511)])) + (0.00106624933f * fVec30[((IOTA - 419) & 511)])) + (0.000571329147f * fVec30[((IOTA - 420) & 511)])) + (0.000659501646f * fVec30[((IOTA - 421) & 511)])) + (0.00118304882f * fVec30[((IOTA - 422) & 511)])) + (0.00124835689f * fVec30[((IOTA - 423) & 511)])) + (0.00140440138f * fVec30[((IOTA - 424) & 511)])) + (0.00179899251f * fVec30[((IOTA - 425) & 511)])) + (0.00192079926f * fVec30[((IOTA - 426) & 511)])) + (0.00191274518f * fVec30[((IOTA - 427) & 511)])) + (0.00180034991f * fVec30[((IOTA - 428) & 511)])) + (0.00169854239f * fVec30[((IOTA - 429) & 511)])) + (0.00208332948f * fVec30[((IOTA - 430) & 511)])) + (0.00258983346f * fVec30[((IOTA - 431) & 511)])) + (0.00288207363f * fVec30[((IOTA - 432) & 511)])) + (0.00314541627f * fVec30[((IOTA - 433) & 511)])) + (0.00300433347f * fVec30[((IOTA - 434) & 511)])) + (0.00263444753f * fVec30[((IOTA - 435) & 511)])) + (0.00266461307f * fVec30[((IOTA - 436) & 511)])) + (0.00318481168f * fVec30[((IOTA - 437) & 511)])) + (0.00426593283f * fVec30[((IOTA - 438) & 511)])) + (0.00548698986f * fVec30[((IOTA - 439) & 511)])) + (0.00614272105f * fVec30[((IOTA - 440) & 511)])) + (0.00614606915f * fVec30[((IOTA - 441) & 511)])) + (0.00537664536f * fVec30[((IOTA - 442) & 511)])) + (0.00395646784f * fVec30[((IOTA - 443) & 511)])) + (0.00290883053f * fVec30[((IOTA - 444) & 511)])) + (0.00244012335f * fVec30[((IOTA - 445) & 511)])) + (0.00232857279f * fVec30[((IOTA - 446) & 511)])) + (0.00258012023f * fVec30[((IOTA - 447) & 511)])) + (0.00280367443f * fVec30[((IOTA - 448) & 511)])) + (0.00298246369f * fVec30[((IOTA - 449) & 511)])) + (0.00314635132f * fVec30[((IOTA - 450) & 511)])) + (0.00276077958f * fVec30[((IOTA - 451) & 511)])) + (0.0024280576f * fVec30[((IOTA - 452) & 511)])) + (0.00221753446f * fVec30[((IOTA - 453) & 511)])) + (0.00175148202f * fVec30[((IOTA - 454) & 511)])) + (0.00203859434f * fVec30[((IOTA - 455) & 511)])) + (0.00299519347f * fVec30[((IOTA - 456) & 511)])) + (0.00362268975f * fVec30[((IOTA - 457) & 511)])) + (0.00406623911f * fVec30[((IOTA - 458) & 511)])) + (0.0038667866f * fVec30[((IOTA - 459) & 511)])) + (0.00266796118f * fVec30[((IOTA - 460) & 511)])) + (0.00131957652f * fVec30[((IOTA - 461) & 511)])) + (0.000516850501f * fVec30[((IOTA - 462) & 511)])) + (0.000872769859f * fVec30[((IOTA - 463) & 511)])) + (0.00234709401f * fVec30[((IOTA - 464) & 511)])) + (0.00375671405f * fVec30[((IOTA - 465) & 511)])) + (0.00457198871f * fVec30[((IOTA - 466) & 511)])) + (0.00456800684f * fVec30[((IOTA - 467) & 511)])) + (0.00336185144f * fVec30[((IOTA - 468) & 511)])) + (0.00161585957f * fVec30[((IOTA - 469) & 511)])) + (0.000513532199f * fVec30[((IOTA - 470) & 511)])) + (0.000185214449f * fVec30[((IOTA - 471) & 511)])) + (0.000564873684f * fVec30[((IOTA - 472) & 511)])) + (0.00156243658f * fVec30[((IOTA - 473) & 511)])) + (0.00258844579f * fVec30[((IOTA - 474) & 511)])) + (0.00352441147f * fVec30[((IOTA - 475) & 511)])) + (0.00399079593f * fVec30[((IOTA - 476) & 511)])) + (0.00378549146f * fVec30[((IOTA - 477) & 511)])) + (0.00352471322f * fVec30[((IOTA - 478) & 511)])) + (0.00293944823f * fVec30[((IOTA - 479) & 511)])) + (0.00180158671f * fVec30[((IOTA - 480) & 511)])) + (0.000860793982f * fVec30[((IOTA - 481) & 511)])) + (0.000548523851f * fVec30[((IOTA - 482) & 511)])) + (0.00100338506f * fVec30[((IOTA - 483) & 511)])) + (0.00193576142f * fVec30[((IOTA - 484) & 511)])) + (0.00284249708f * fVec30[((IOTA - 485) & 511)])) + (0.00343436841f * fVec30[((IOTA - 486) & 511)])) + (0.00306273345f * fVec30[((IOTA - 487) & 511)])) + (0.00197645416f * fVec30[((IOTA - 488) & 511)])) + (0.00136458315f * fVec30[((IOTA - 489) & 511)])) + (0.0011820537f * fVec30[((IOTA - 490) & 511)])) + (0.0012865155f * fVec30[((IOTA - 491) & 511)])) + (0.00190191576f * fVec30[((IOTA - 492) & 511)])) + (0.00220308546f * fVec30[((IOTA - 493) & 511)])) + (0.00171676185f * fVec30[((IOTA - 494) & 511)])) + (0.000833585393f * fVec30[((IOTA - 495) & 511)])) + (7.16424547e-05f * fVec30[((IOTA - 496) & 511)])) + (0.000166964252f * fVec30[((IOTA - 497) & 511)])) + (0.00108296098f * fVec30[((IOTA - 498) & 511)])) + (0.00228878483f * fVec30[((IOTA - 499) & 511)])) + (0.00358100142f * fVec30[((IOTA - 500) & 511)])) + (0.00435169227f * fVec30[((IOTA - 501) & 511)])) + (0.0042848764f * fVec30[((IOTA - 502) & 511)])) + (0.00384371029f * fVec30[((IOTA - 503) & 511)])) + (0.00311497925f * fVec30[((IOTA - 504) & 511)])) + (0.00251963874f * fVec30[((IOTA - 505) & 511)])) + (0.00232552597f * fVec30[((IOTA - 506) & 511)])) + (0.0022555124f * fVec30[((IOTA - 507) & 511)])) + (0.00255239848f * fVec30[((IOTA - 508) & 511)])) + (0.00302158808f * fVec30[((IOTA - 509) & 511)])) + (0.00316743646f * fVec30[((IOTA - 510) & 511)])) + (0.0034478223f * fVec30[((IOTA - 511) & 511)]))) : ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((fSlow96 * fTemp0) + (0.189185485f * fVec29[((IOTA - 1) & 511)])) + (0.204877853f * fVec29[((IOTA - 2) & 511)])) + (0.20859839f * fVec29[((IOTA - 3) & 511)])) + (0.161518648f * fVec29[((IOTA - 4) & 511)])) + (0.0121166371f * fVec29[((IOTA - 5) & 511)])) + (0.0503392182f * fVec29[((IOTA - 11) & 511)])) + (0.12690711f * fVec29[((IOTA - 12) & 511)])) + (0.128523558f * fVec29[((IOTA - 13) & 511)])) + (0.0807697475f * fVec29[((IOTA - 14) & 511)])) + (0.0392562672f * fVec29[((IOTA - 15) & 511)])) + (0.0155144203f * fVec29[((IOTA - 21) & 511)])) + (0.0644648522f * fVec29[((IOTA - 22) & 511)])) + (0.0911155269f * fVec29[((IOTA - 23) & 511)])) + (0.0725243166f * fVec29[((IOTA - 24) & 511)])) + (0.0365138687f * fVec29[((IOTA - 25) & 511)])) + (0.0148678534f * fVec29[((IOTA - 31) & 511)])) + (0.0172894634f * fVec29[((IOTA - 32) & 511)])) + (0.0159493759f * fVec29[((IOTA - 33) & 511)])) + (0.00378531776f * fVec29[((IOTA - 34) & 511)])) + (0.00353013491f * fVec29[((IOTA - 43) & 511)])) + (0.00132726366f * fVec29[((IOTA - 44) & 511)])) + (0.00406248122f * fVec29[((IOTA - 52) & 511)])) + (0.00823978148f * fVec29[((IOTA - 53) & 511)])) + (0.00813117996f * fVec29[((IOTA - 54) & 511)])) + (0.0122829881f * fVec29[((IOTA - 55) & 511)])) + (0.00852004066f * fVec29[((IOTA - 56) & 511)])) + (0.00598316872f * fVec29[((IOTA - 57) & 511)])) + (0.010538796f * fVec29[((IOTA - 64) & 511)])) + (0.0211588014f * fVec29[((IOTA - 65) & 511)])) + (0.013482295f * fVec29[((IOTA - 66) & 511)])) + (0.0139481016f * fVec29[((IOTA - 73) & 511)])) + (0.0248703472f * fVec29[((IOTA - 74) & 511)])) + (0.0228895973f * fVec29[((IOTA - 75) & 511)])) + (0.00774434721f * fVec29[((IOTA - 76) & 511)])) + (0.00348661561f * fVec29[((IOTA - 85) & 511)])) + (0.0037032743f * fVec29[((IOTA - 86) & 511)])) + (0.000232265797f * fVec29[((IOTA - 95) & 511)])) + (0.006677547f * fVec29[((IOTA - 96) & 511)])) + (0.010562961f * fVec29[((IOTA - 97) & 511)])) + (0.0116336104f * fVec29[((IOTA - 98) & 511)])) + (0.00972262584f * fVec29[((IOTA - 99) & 511)])) + (0.00557435537f * fVec29[((IOTA - 100) & 511)])) + (0.000378924422f * fVec29[((IOTA - 101) & 511)])) + (0.00705470284f * fVec29[((IOTA - 109) & 511)])) + (0.0112139508f * fVec29[((IOTA - 110) & 511)])) + (0.00804598816f * fVec29[((IOTA - 111) & 511)])) + (0.00292695593f * fVec29[((IOTA - 130) & 511)])) + (0.00563917868f * fVec29[((IOTA - 131) & 511)])) + (0.0054381541f * fVec29[((IOTA - 132) & 511)])) + (0.00433168467f * fVec29[((IOTA - 133) & 511)])) + (0.00211190525f * fVec29[((IOTA - 134) & 511)])) + (0.000116796233f * fVec29[((IOTA - 135) & 511)])) + (0.00447478006f * fVec29[((IOTA - 146) & 511)])) + (0.00933673047f * fVec29[((IOTA - 147) & 511)])) + (0.0115281306f * fVec29[((IOTA - 148) & 511)])) + (0.0103163626f * fVec29[((IOTA - 149) & 511)])) + (0.00605030684f * fVec29[((IOTA - 150) & 511)])) + (9.75471921e-05f * fVec29[((IOTA - 151) & 511)])) + (0.0020056963f * fVec29[((IOTA - 157) & 511)])) + (0.00278471969f * fVec29[((IOTA - 158) & 511)])) + (0.0028954288f * fVec29[((IOTA - 159) & 511)])) + (0.00212043757f * fVec29[((IOTA - 160) & 511)])) + (0.00367169501f * fVec29[((IOTA - 168) & 511)])) + (0.008249823f * fVec29[((IOTA - 169) & 511)])) + (0.01039505f * fVec29[((IOTA - 170) & 511)])) + (0.0101847127f * fVec29[((IOTA - 171) & 511)])) + (0.00834234897f * fVec29[((IOTA - 172) & 511)])) + (0.00413804781f * fVec29[((IOTA - 173) & 511)])) + (8.24336894e-05f * fVec29[((IOTA - 180) & 511)])) + (0.00500226207f * fVec29[((IOTA - 181) & 511)])) + (0.00941172428f * fVec29[((IOTA - 182) & 511)])) + (0.0129310898f * fVec29[((IOTA - 183) & 511)])) + (0.0137811014f * fVec29[((IOTA - 184) & 511)])) + (0.0107530868f * fVec29[((IOTA - 185) & 511)])) + (0.00545095233f * fVec29[((IOTA - 186) & 511)])) + (0.000273235608f * fVec29[((IOTA - 187) & 511)])) + (0.00284181722f * fVec29[((IOTA - 190) & 511)])) + (0.00773232942f * fVec29[((IOTA - 191) & 511)])) + (0.0110399788f * fVec29[((IOTA - 192) & 511)])) + (0.0112626199f * fVec29[((IOTA - 193) & 511)])) + (0.0106071308f * fVec29[((IOTA - 194) & 511)])) + (0.00915045477f * fVec29[((IOTA - 195) & 511)])) + (0.00700340606f * fVec29[((IOTA - 196) & 511)])) + (0.00577293523f * fVec29[((IOTA - 197) & 511)])) + (0.00494984677f * fVec29[((IOTA - 198) & 511)])) + (0.00343622966f * fVec29[((IOTA - 199) & 511)])) + (0.00141159585f * fVec29[((IOTA - 200) & 511)])) + (8.3968509e-05f * fVec29[((IOTA - 201) & 511)])) + (7.16904178e-05f * fVec29[((IOTA - 202) & 511)])) + (0.00151650468f * fVec29[((IOTA - 203) & 511)])) + (0.00425955234f * fVec29[((IOTA - 204) & 511)])) + (0.00699653896f * fVec29[((IOTA - 205) & 511)])) + (0.00846785959f * fVec29[((IOTA - 206) & 511)])) + (0.00915753003f * fVec29[((IOTA - 207) & 511)])) + (0.00853463355f * fVec29[((IOTA - 208) & 511)])) + (0.00703649409f * fVec29[((IOTA - 209) & 511)])) + (0.00585849024f * fVec29[((IOTA - 210) & 511)])) + (0.00508943014f * fVec29[((IOTA - 211) & 511)])) + (0.0054119071f * fVec29[((IOTA - 212) & 511)])) + (0.00733662676f * fVec29[((IOTA - 213) & 511)])) + (0.00868696347f * fVec29[((IOTA - 214) & 511)])) + (0.00850539561f * fVec29[((IOTA - 215) & 511)])) + (0.00645058788f * fVec29[((IOTA - 216) & 511)])) + (0.00296550663f * fVec29[((IOTA - 217) & 511)])) + (0.000959576108f * fVec29[((IOTA - 220) & 511)])) + (0.00500686606f * fVec29[((IOTA - 221) & 511)])) + (0.00845620595f * fVec29[((IOTA - 222) & 511)])) + (0.0100359209f * fVec29[((IOTA - 223) & 511)])) + (0.00958595611f * fVec29[((IOTA - 224) & 511)])) + (0.00725845899f * fVec29[((IOTA - 225) & 511)])) + (0.00500964932f * fVec29[((IOTA - 226) & 511)])) + (0.00426116493f * fVec29[((IOTA - 227) & 511)])) + (0.00425736699f * fVec29[((IOTA - 228) & 511)])) + (0.00491290912f * fVec29[((IOTA - 229) & 511)])) + (0.00629263977f * fVec29[((IOTA - 230) & 511)])) + (0.00718094176f * fVec29[((IOTA - 231) & 511)])) + (0.00777272647f * fVec29[((IOTA - 232) & 511)])) + (0.0084758196f * fVec29[((IOTA - 233) & 511)])) + (0.00887872744f * fVec29[((IOTA - 234) & 511)])) + (0.00865460373f * fVec29[((IOTA - 235) & 511)])) + (0.00808139145f * fVec29[((IOTA - 236) & 511)])) + (0.00724709127f * fVec29[((IOTA - 237) & 511)])) + (0.00621236488f * fVec29[((IOTA - 238) & 511)])) + (0.00580909289f * fVec29[((IOTA - 239) & 511)])) + (0.00603847113f * fVec29[((IOTA - 240) & 511)])) + (0.00617214944f * fVec29[((IOTA - 241) & 511)])) + (0.00688073086f * fVec29[((IOTA - 242) & 511)])) + (0.00747714611f * fVec29[((IOTA - 243) & 511)])) + (0.00629838835f * fVec29[((IOTA - 244) & 511)])) + (0.00361035718f * fVec29[((IOTA - 245) & 511)])) + (0.000742423814f * fVec29[((IOTA - 246) & 511)])) + (0.000461540185f * fVec29[((IOTA - 249) & 511)])) + (0.00452391757f * fVec29[((IOTA - 250) & 511)])) + (0.00805808417f * fVec29[((IOTA - 251) & 511)])) + (0.00996053685f * fVec29[((IOTA - 252) & 511)])) + (0.0107605522f * fVec29[((IOTA - 253) & 511)])) + (0.0104040504f * fVec29[((IOTA - 254) & 511)])) + (0.00953621976f * fVec29[((IOTA - 255) & 511)])) + (0.00937205553f * fVec29[((IOTA - 256) & 511)])) + (0.0101486072f * fVec29[((IOTA - 257) & 511)])) + (0.0106023178f * fVec29[((IOTA - 258) & 511)])) + (0.0100673959f * fVec29[((IOTA - 259) & 511)])) + (0.00919454545f * fVec29[((IOTA - 260) & 511)])) + (0.00810852274f * fVec29[((IOTA - 261) & 511)])) + (0.00681091333f * fVec29[((IOTA - 262) & 511)])) + (0.00590250362f * fVec29[((IOTA - 263) & 511)])) + (0.00579678873f * fVec29[((IOTA - 264) & 511)])) + (0.00605426077f * fVec29[((IOTA - 265) & 511)])) + (0.00622123526f * fVec29[((IOTA - 266) & 511)])) + (0.0070339446f * fVec29[((IOTA - 267) & 511)])) + (0.00889056362f * fVec29[((IOTA - 268) & 511)])) + (0.0113091562f * fVec29[((IOTA - 269) & 511)])) + (0.0131545635f * fVec29[((IOTA - 270) & 511)])) + (0.0137029598f * fVec29[((IOTA - 271) & 511)])) + (0.0129222199f * fVec29[((IOTA - 272) & 511)])) + (0.0102423038f * fVec29[((IOTA - 273) & 511)])) + (0.00654069521f * fVec29[((IOTA - 274) & 511)])) + (0.0031041014f * fVec29[((IOTA - 275) & 511)])) + (0.000516713131f * fVec29[((IOTA - 276) & 511)])) + (0.000747860409f * fVec29[((IOTA - 278) & 511)])) + (0.00253328262f * fVec29[((IOTA - 279) & 511)])) + (0.00431420468f * fVec29[((IOTA - 280) & 511)])) + (0.00521369185f * fVec29[((IOTA - 281) & 511)])) + (0.00531051029f * fVec29[((IOTA - 282) & 511)])) + (0.00483398698f * fVec29[((IOTA - 283) & 511)])) + (0.00383029319f * fVec29[((IOTA - 284) & 511)])) + (0.0028969897f * fVec29[((IOTA - 285) & 511)])) + (0.00285635795f * fVec29[((IOTA - 286) & 511)])) + (0.00376180233f * fVec29[((IOTA - 287) & 511)])) + (0.00510100555f * fVec29[((IOTA - 288) & 511)])) + (0.00632117549f * fVec29[((IOTA - 289) & 511)])) + (0.00649447087f * fVec29[((IOTA - 290) & 511)])) + (0.00596839329f * fVec29[((IOTA - 291) & 511)])) + (0.0051154946f * fVec29[((IOTA - 292) & 511)])) + (0.00368405087f * fVec29[((IOTA - 293) & 511)])) + (0.00284881471f * fVec29[((IOTA - 294) & 511)])) + (0.00344499573f * fVec29[((IOTA - 295) & 511)])) + (0.00449923147f * fVec29[((IOTA - 296) & 511)])) + (0.0056217243f * fVec29[((IOTA - 297) & 511)])) + (0.00676242588f * fVec29[((IOTA - 298) & 511)])) + (0.00788621977f * fVec29[((IOTA - 299) & 511)])) + (0.00818385463f * fVec29[((IOTA - 300) & 511)])) + (0.00783822685f * fVec29[((IOTA - 301) & 511)])) + (0.00726371352f * fVec29[((IOTA - 302) & 511)])) + (0.00622378429f * fVec29[((IOTA - 303) & 511)])) + (0.00556017878f * fVec29[((IOTA - 304) & 511)])) + (0.00514374394f * fVec29[((IOTA - 305) & 511)])) + (0.00427456154f * fVec29[((IOTA - 306) & 511)])) + (0.00398350693f * fVec29[((IOTA - 307) & 511)])) + (0.0039009694f * fVec29[((IOTA - 308) & 511)])) + (0.00387113309f * fVec29[((IOTA - 309) & 511)])) + (0.0049575204f * fVec29[((IOTA - 310) & 511)])) + (0.00630161399f * fVec29[((IOTA - 311) & 511)])) + (0.00677215448f * fVec29[((IOTA - 312) & 511)])) + (0.00702681718f * fVec29[((IOTA - 313) & 511)])) + (0.00683125528f * fVec29[((IOTA - 314) & 511)])) + (0.00556426262f * fVec29[((IOTA - 315) & 511)])) + (0.00415128795f * fVec29[((IOTA - 316) & 511)])) + (0.00229121f * fVec29[((IOTA - 317) & 511)])) + (0.000195926521f * fVec29[((IOTA - 318) & 511)])) + (0.000371849164f * fVec29[((IOTA - 323) & 511)])) + (0.00107072806f * fVec29[((IOTA - 324) & 511)])) + (0.00170543371f * fVec29[((IOTA - 325) & 511)])) + (0.00145230582f * fVec29[((IOTA - 326) & 511)])) + (0.000898134895f * fVec29[((IOTA - 327) & 511)])) + (0.00092159817f * fVec29[((IOTA - 328) & 511)])) + (0.00121595571f * fVec29[((IOTA - 329) & 511)])) + (0.0015207706f * fVec29[((IOTA - 330) & 511)])) + (0.00179928681f * fVec29[((IOTA - 331) & 511)])) + (0.00264591677f * fVec29[((IOTA - 332) & 511)])) + (0.00400270429f * fVec29[((IOTA - 333) & 511)])) + (0.00482228119f * fVec29[((IOTA - 334) & 511)])) + (0.00467866613f * fVec29[((IOTA - 335) & 511)])) + (0.00370189548f * fVec29[((IOTA - 336) & 511)])) + (0.00237793569f * fVec29[((IOTA - 337) & 511)])) + (0.00189886289f * fVec29[((IOTA - 338) & 511)])) + (0.00249004969f * fVec29[((IOTA - 339) & 511)])) + (0.00390851311f * fVec29[((IOTA - 340) & 511)])) + (0.00545264315f * fVec29[((IOTA - 341) & 511)])) + (0.00570381992f * fVec29[((IOTA - 342) & 511)])) + (0.00417152559f * fVec29[((IOTA - 343) & 511)])) + (0.00181408785f * fVec29[((IOTA - 344) & 511)])) + (0.00220653927f * fVec29[((IOTA - 348) & 511)])) + (0.00505595189f * fVec29[((IOTA - 349) & 511)])) + (0.00655227061f * fVec29[((IOTA - 350) & 511)])) + (0.00559948385f * fVec29[((IOTA - 351) & 511)])) + (0.00251179608f * fVec29[((IOTA - 352) & 511)])) + (9.73907299e-05f * fVec29[((IOTA - 358) & 511)])) + (0.00281947246f * fVec29[((IOTA - 359) & 511)])) + (0.00355201121f * fVec29[((IOTA - 360) & 511)])) + (0.00248752628f * fVec29[((IOTA - 361) & 511)])) + (0.000397237483f * fVec29[((IOTA - 362) & 511)])) + (0.000100772362f * fVec29[((IOTA - 385) & 511)])) + (0.00158140576f * fVec29[((IOTA - 386) & 511)])) + (0.00175046129f * fVec29[((IOTA - 387) & 511)])) + (3.67555767e-05f * fVec29[((IOTA - 388) & 511)])) + (0.000207085628f * fVec29[((IOTA - 472) & 511)])) + (0.000101865269f * fVec29[((IOTA - 497) & 511)])) - ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00231246231f * fVec29[((IOTA - 428) & 511)]) + ((0.00418213895f * fVec29[((IOTA - 427) & 511)]) + ((0.00547399931f * fVec29[((IOTA - 426) & 511)]) + ((0.00574551802f * fVec29[((IOTA - 425) & 511)]) + ((0.00478659198f * fVec29[((IOTA - 424) & 511)]) + ((0.00304258196f * fVec29[((IOTA - 423) & 511)]) + ((0.00128267799f * fVec29[((IOTA - 422) & 511)]) + ((0.000104180072f * fVec29[((IOTA - 421) & 511)]) + ((0.000352339819f * fVec29[((IOTA - 420) & 511)]) + ((0.00169586111f * fVec29[((IOTA - 419) & 511)]) + ((0.00310098007f * fVec29[((IOTA - 418) & 511)]) + ((0.00457016798f * fVec29[((IOTA - 417) & 511)]) + ((0.00535093388f * fVec29[((IOTA - 416) & 511)]) + ((0.00467104418f * fVec29[((IOTA - 415) & 511)]) + ((0.0032989094f * fVec29[((IOTA - 414) & 511)]) + ((0.00192895951f * fVec29[((IOTA - 413) & 511)]) + ((0.00120440638f * fVec29[((IOTA - 412) & 511)]) + ((0.00146702863f * fVec29[((IOTA - 411) & 511)]) + ((0.00227848953f * fVec29[((IOTA - 410) & 511)]) + ((0.00345581677f * fVec29[((IOTA - 409) & 511)]) + ((0.00473298039f * fVec29[((IOTA - 408) & 511)]) + ((0.00501651689f * fVec29[((IOTA - 407) & 511)]) + ((0.00422690623f * fVec29[((IOTA - 406) & 511)]) + ((0.00352995284f * fVec29[((IOTA - 405) & 511)]) + ((0.0031139343f * fVec29[((IOTA - 404) & 511)]) + ((0.00312155578f * fVec29[((IOTA - 403) & 511)]) + ((0.00397185376f * fVec29[((IOTA - 402) & 511)]) + ((0.00544811692f * fVec29[((IOTA - 401) & 511)]) + ((0.00692547252f * fVec29[((IOTA - 400) & 511)]) + ((0.00744861038f * fVec29[((IOTA - 399) & 511)]) + ((0.0065476927f * fVec29[((IOTA - 398) & 511)]) + ((0.00478539569f * fVec29[((IOTA - 397) & 511)]) + ((0.002667611f * fVec29[((IOTA - 396) & 511)]) + ((0.00133311609f * fVec29[((IOTA - 395) & 511)]) + ((0.00142730772f * fVec29[((IOTA - 394) & 511)]) + ((0.00255640782f * fVec29[((IOTA - 393) & 511)]) + ((0.00422594417f * fVec29[((IOTA - 392) & 511)]) + ((0.00502954889f * fVec29[((IOTA - 391) & 511)]) + ((0.00392651372f * fVec29[((IOTA - 390) & 511)]) + ((0.0020852685f * fVec29[((IOTA - 389) & 511)]) + ((0.00146221649f * fVec29[((IOTA - 384) & 511)]) + ((0.00309234392f * fVec29[((IOTA - 383) & 511)]) + ((0.00392664364f * fVec29[((IOTA - 382) & 511)]) + ((0.00349821756f * fVec29[((IOTA - 381) & 511)]) + ((0.00246367278f * fVec29[((IOTA - 380) & 511)]) + ((0.00125008449f * fVec29[((IOTA - 379) & 511)]) + ((0.000141950324f * fVec29[((IOTA - 378) & 511)]) + ((2.22148374e-05f * fVec29[((IOTA - 377) & 511)]) + ((0.000992638059f * fVec29[((IOTA - 376) & 511)]) + ((0.00248632999f * fVec29[((IOTA - 375) & 511)]) + ((0.00421213126f * fVec29[((IOTA - 374) & 511)]) + ((0.00583890313f * fVec29[((IOTA - 373) & 511)]) + ((0.00674809283f * fVec29[((IOTA - 372) & 511)]) + ((0.00642408105f * fVec29[((IOTA - 371) & 511)]) + ((0.00538745569f * fVec29[((IOTA - 370) & 511)]) + ((0.00418520812f * fVec29[((IOTA - 369) & 511)]) + ((0.00273139402f * fVec29[((IOTA - 368) & 511)]) + ((0.00180794904f * fVec29[((IOTA - 367) & 511)]) + ((0.00185118197f * fVec29[((IOTA - 366) & 511)]) + ((0.0020846962f * fVec29[((IOTA - 365) & 511)]) + ((0.00218554679f * fVec29[((IOTA - 364) & 511)]) + ((0.00152225327f * fVec29[((IOTA - 363) & 511)]) + ((0.0037091272f * fVec29[((IOTA - 357) & 511)]) + ((0.00697565079f * fVec29[((IOTA - 356) & 511)]) + ((0.00804031827f * fVec29[((IOTA - 355) & 511)]) + ((0.00626959233f * fVec29[((IOTA - 354) & 511)]) + ((0.00202962803f * fVec29[((IOTA - 353) & 511)]) + ((0.000632312614f * fVec29[((IOTA - 347) & 511)]) + ((0.00188117428f * fVec29[((IOTA - 346) & 511)]) + ((0.000653876923f * fVec29[((IOTA - 345) & 511)]) + ((0.000425435137f * fVec29[((IOTA - 322) & 511)]) + ((0.00157914264f * fVec29[((IOTA - 321) & 511)]) + ((0.00156244263f * fVec29[((IOTA - 320) & 511)]) + ((0.00087997783f * fVec29[((IOTA - 319) & 511)]) + ((0.000293889549f * fVec29[((IOTA - 277) & 511)]) + ((0.00173909403f * fVec29[((IOTA - 248) & 511)]) + ((0.0013932311f * fVec29[((IOTA - 247) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0306612849f * fVec29[((IOTA - 47) & 511)]) + ((0.010456752f * fVec29[((IOTA - 46) & 511)]) + ((0.000588507392f * fVec29[((IOTA - 45) & 511)]) + ((0.00142962253f * fVec29[((IOTA - 42) & 511)]) + ((0.00636922056f * fVec29[((IOTA - 41) & 511)]) + ((0.00764328847f * fVec29[((IOTA - 40) & 511)]) + ((0.00553153874f * fVec29[((IOTA - 39) & 511)]) + ((0.00388609013f * fVec29[((IOTA - 38) & 511)]) + ((0.011535855f * fVec29[((IOTA - 37) & 511)]) + ((0.0182977356f * fVec29[((IOTA - 36) & 511)]) + ((0.0123924483f * fVec29[((IOTA - 35) & 511)]) + ((0.0254778452f * fVec29[((IOTA - 30) & 511)]) + ((0.0709409639f * fVec29[((IOTA - 29) & 511)]) + ((0.0812055096f * fVec29[((IOTA - 28) & 511)]) + ((0.0698200017f * fVec29[((IOTA - 27) & 511)]) + ((0.0215387922f * fVec29[((IOTA - 26) & 511)]) + ((0.0218625963f * fVec29[((IOTA - 20) & 511)]) + ((0.0579091758f * fVec29[((IOTA - 19) & 511)]) + ((0.076216355f * fVec29[((IOTA - 18) & 511)]) + ((0.0585145913f * fVec29[((IOTA - 17) & 511)]) + ((0.00947090238f * fVec29[((IOTA - 16) & 511)]) + ((0.043552056f * fVec29[((IOTA - 10) & 511)]) + ((0.143017858f * fVec29[((IOTA - 9) & 511)]) + ((0.210789829f * fVec29[((IOTA - 8) & 511)]) + ((0.200440839f * fVec29[((IOTA - 7) & 511)]) + ((0.121129721f * fVec29[((IOTA - 6) & 511)]) + ((0.0306605548f * fVec29[((IOTA - 49) & 511)]) + ((0.0391748734f * fVec29[((IOTA - 48) & 511)]) + (0.0273629203f * fVec29[((IOTA - 50) & 511)]))))))))))))))))))))))))))))) + (0.0169347823f * fVec29[((IOTA - 51) & 511)])) + (0.00789506361f * fVec29[((IOTA - 58) & 511)])) + (0.0299177412f * fVec29[((IOTA - 59) & 511)])) + (0.0383949913f * fVec29[((IOTA - 60) & 511)])) + (0.0437787548f * fVec29[((IOTA - 61) & 511)])) + (0.0381585881f * fVec29[((IOTA - 62) & 511)])) + (0.0131678563f * fVec29[((IOTA - 63) & 511)])) + (0.00983075984f * fVec29[((IOTA - 67) & 511)])) + (0.0338640511f * fVec29[((IOTA - 68) & 511)])) + (0.0478043482f * fVec29[((IOTA - 69) & 511)])) + (0.0456322245f * fVec29[((IOTA - 70) & 511)])) + (0.0273638312f * fVec29[((IOTA - 71) & 511)])) + (0.00491798157f * fVec29[((IOTA - 72) & 511)])) + (0.0113793127f * fVec29[((IOTA - 77) & 511)])) + (0.0205798931f * fVec29[((IOTA - 78) & 511)])) + (0.0226041097f * fVec29[((IOTA - 79) & 511)])) + (0.024251353f * fVec29[((IOTA - 80) & 511)])) + (0.0206159204f * fVec29[((IOTA - 81) & 511)])) + (0.012975337f * fVec29[((IOTA - 82) & 511)])) + (0.00670491206f * fVec29[((IOTA - 83) & 511)])) + (0.000746273436f * fVec29[((IOTA - 84) & 511)])) + (0.000737117138f * fVec29[((IOTA - 87) & 511)])) + (0.0122011006f * fVec29[((IOTA - 88) & 511)])) + (0.0262002647f * fVec29[((IOTA - 89) & 511)])) + (0.0335228182f * fVec29[((IOTA - 90) & 511)])) + (0.0342616513f * fVec29[((IOTA - 91) & 511)])) + (0.0309785064f * fVec29[((IOTA - 92) & 511)])) + (0.0211672038f * fVec29[((IOTA - 93) & 511)])) + (0.00882826373f * fVec29[((IOTA - 94) & 511)])) + (0.00653104438f * fVec29[((IOTA - 102) & 511)])) + (0.0142992716f * fVec29[((IOTA - 103) & 511)])) + (0.0210358929f * fVec29[((IOTA - 104) & 511)])) + (0.0248538554f * fVec29[((IOTA - 105) & 511)])) + (0.022550758f * fVec29[((IOTA - 106) & 511)])) + (0.0151379146f * fVec29[((IOTA - 107) & 511)])) + (0.00384886609f * fVec29[((IOTA - 108) & 511)])) + (0.00100166444f * fVec29[((IOTA - 112) & 511)])) + (0.00989147369f * fVec29[((IOTA - 113) & 511)])) + (0.0138032641f * fVec29[((IOTA - 114) & 511)])) + (0.0153440647f * fVec29[((IOTA - 115) & 511)])) + (0.0153415147f * fVec29[((IOTA - 116) & 511)])) + (0.013333166f * fVec29[((IOTA - 117) & 511)])) + (0.0124901515f * fVec29[((IOTA - 118) & 511)])) + (0.0132836122f * fVec29[((IOTA - 119) & 511)])) + (0.0119211534f * fVec29[((IOTA - 120) & 511)])) + (0.00871092081f * fVec29[((IOTA - 121) & 511)])) + (0.00615581358f * fVec29[((IOTA - 122) & 511)])) + (0.00421962282f * fVec29[((IOTA - 123) & 511)])) + (0.00373745477f * fVec29[((IOTA - 124) & 511)])) + (0.00501500815f * fVec29[((IOTA - 125) & 511)])) + (0.00636529271f * fVec29[((IOTA - 126) & 511)])) + (0.00566204404f * fVec29[((IOTA - 127) & 511)])) + (0.00387883279f * fVec29[((IOTA - 128) & 511)])) + (0.00135647552f * fVec29[((IOTA - 129) & 511)])) + (0.000819811132f * fVec29[((IOTA - 136) & 511)])) + (0.00176162086f * fVec29[((IOTA - 137) & 511)])) + (0.00313726766f * fVec29[((IOTA - 138) & 511)])) + (0.00545727322f * fVec29[((IOTA - 139) & 511)])) + (0.00903810654f * fVec29[((IOTA - 140) & 511)])) + (0.0124798771f * fVec29[((IOTA - 141) & 511)])) + (0.01382038f * fVec29[((IOTA - 142) & 511)])) + (0.0123343877f * fVec29[((IOTA - 143) & 511)])) + (0.00788320228f * fVec29[((IOTA - 144) & 511)])) + (0.00169359799f * fVec29[((IOTA - 145) & 511)])) + (0.00496334722f * fVec29[((IOTA - 152) & 511)])) + (0.0065548718f * fVec29[((IOTA - 153) & 511)])) + (0.0056624338f * fVec29[((IOTA - 154) & 511)])) + (0.00373932766f * fVec29[((IOTA - 155) & 511)])) + (0.00064412225f * fVec29[((IOTA - 156) & 511)])) + (0.000206227414f * fVec29[((IOTA - 161) & 511)])) + (0.00260804268f * fVec29[((IOTA - 162) & 511)])) + (0.00451421505f * fVec29[((IOTA - 163) & 511)])) + (0.00543687912f * fVec29[((IOTA - 164) & 511)])) + (0.00502650579f * fVec29[((IOTA - 165) & 511)])) + (0.00344166625f * fVec29[((IOTA - 166) & 511)])) + (0.000762192998f * fVec29[((IOTA - 167) & 511)])) + (3.21255066e-05f * fVec29[((IOTA - 174) & 511)])) + (0.00254394766f * fVec29[((IOTA - 175) & 511)])) + (0.00501425378f * fVec29[((IOTA - 176) & 511)])) + (0.00637200382f * fVec29[((IOTA - 177) & 511)])) + (0.00555063225f * fVec29[((IOTA - 178) & 511)])) + (0.00359977037f * fVec29[((IOTA - 179) & 511)])) + (0.00209876895f * fVec29[((IOTA - 188) & 511)])) + (0.00071851816f * fVec29[((IOTA - 189) & 511)])) + (0.000108186156f * fVec29[((IOTA - 218) & 511)])) + (0.00116286427f * fVec29[((IOTA - 219) & 511)])) + (0.0010569673f * fVec29[((IOTA - 429) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.0015500607f * fVec29[((IOTA - 430) & 511)])) + (0.00316895079f * fVec29[((IOTA - 431) & 511)])) + (0.004802668f * fVec29[((IOTA - 432) & 511)])) + (0.00575758796f * fVec29[((IOTA - 433) & 511)])) + (0.00543916831f * fVec29[((IOTA - 434) & 511)])) + (0.00436409656f * fVec29[((IOTA - 435) & 511)])) + (0.00326980138f * fVec29[((IOTA - 436) & 511)])) + (0.00301688164f * fVec29[((IOTA - 437) & 511)])) + (0.00419967109f * fVec29[((IOTA - 438) & 511)])) + (0.00604013586f * fVec29[((IOTA - 439) & 511)])) + (0.00758161256f * fVec29[((IOTA - 440) & 511)])) + (0.00873089768f * fVec29[((IOTA - 441) & 511)])) + (0.00914660469f * fVec29[((IOTA - 442) & 511)])) + (0.00873212144f * fVec29[((IOTA - 443) & 511)])) + (0.00778058264f * fVec29[((IOTA - 444) & 511)])) + (0.00631927652f * fVec29[((IOTA - 445) & 511)])) + (0.00469060568f * fVec29[((IOTA - 446) & 511)])) + (0.00366279855f * fVec29[((IOTA - 447) & 511)])) + (0.00349496584f * fVec29[((IOTA - 448) & 511)])) + (0.00411172304f * fVec29[((IOTA - 449) & 511)])) + (0.00485849055f * fVec29[((IOTA - 450) & 511)])) + (0.00509119872f * fVec29[((IOTA - 451) & 511)])) + (0.00503183808f * fVec29[((IOTA - 452) & 511)])) + (0.00425817352f * fVec29[((IOTA - 453) & 511)])) + (0.00303483009f * fVec29[((IOTA - 454) & 511)])) + (0.00278747687f * fVec29[((IOTA - 455) & 511)])) + (0.00361332297f * fVec29[((IOTA - 456) & 511)])) + (0.00461948756f * fVec29[((IOTA - 457) & 511)])) + (0.00529313413f * fVec29[((IOTA - 458) & 511)])) + (0.00505465129f * fVec29[((IOTA - 459) & 511)])) + (0.00399019243f * fVec29[((IOTA - 460) & 511)])) + (0.00243417453f * fVec29[((IOTA - 461) & 511)])) + (0.00123486714f * fVec29[((IOTA - 462) & 511)])) + (0.00160101941f * fVec29[((IOTA - 463) & 511)])) + (0.00328681339f * fVec29[((IOTA - 464) & 511)])) + (0.00532874512f * fVec29[((IOTA - 465) & 511)])) + (0.00750854332f * fVec29[((IOTA - 466) & 511)])) + (0.00868111011f * fVec29[((IOTA - 467) & 511)])) + (0.00753726112f * fVec29[((IOTA - 468) & 511)])) + (0.00482043438f * fVec29[((IOTA - 469) & 511)])) + (0.001940405f * fVec29[((IOTA - 470) & 511)])) + (3.60272825e-05f * fVec29[((IOTA - 471) & 511)])) + (0.00085664494f * fVec29[((IOTA - 473) & 511)])) + (0.00267523294f * fVec29[((IOTA - 474) & 511)])) + (0.00474809343f * fVec29[((IOTA - 475) & 511)])) + (0.00578336651f * fVec29[((IOTA - 476) & 511)])) + (0.00556236366f * fVec29[((IOTA - 477) & 511)])) + (0.00495491922f * fVec29[((IOTA - 478) & 511)])) + (0.00420383317f * fVec29[((IOTA - 479) & 511)])) + (0.00345402211f * fVec29[((IOTA - 480) & 511)])) + (0.00321894698f * fVec29[((IOTA - 481) & 511)])) + (0.00327326078f * fVec29[((IOTA - 482) & 511)])) + (0.00329058524f * fVec29[((IOTA - 483) & 511)])) + (0.00323619321f * fVec29[((IOTA - 484) & 511)])) + (0.00296405004f * fVec29[((IOTA - 485) & 511)])) + (0.00287636183f * fVec29[((IOTA - 486) & 511)])) + (0.00264211884f * fVec29[((IOTA - 487) & 511)])) + (0.00207697041f * fVec29[((IOTA - 488) & 511)])) + (0.00234653847f * fVec29[((IOTA - 489) & 511)])) + (0.00302179763f * fVec29[((IOTA - 490) & 511)])) + (0.00344429351f * fVec29[((IOTA - 491) & 511)])) + (0.00390117755f * fVec29[((IOTA - 492) & 511)])) + (0.00374302128f * fVec29[((IOTA - 493) & 511)])) + (0.00275189197f * fVec29[((IOTA - 494) & 511)])) + (0.0013981997f * fVec29[((IOTA - 495) & 511)])) + (5.52767888e-05f * fVec29[((IOTA - 496) & 511)])) + (0.000854355749f * fVec29[((IOTA - 498) & 511)])) + (0.00207715249f * fVec29[((IOTA - 499) & 511)])) + (0.00358858472f * fVec29[((IOTA - 500) & 511)])) + (0.00466253841f * fVec29[((IOTA - 501) & 511)])) + (0.0049338229f * fVec29[((IOTA - 502) & 511)])) + (0.00508888392f * fVec29[((IOTA - 503) & 511)])) + (0.00476656249f * fVec29[((IOTA - 504) & 511)])) + (0.00427679857f * fVec29[((IOTA - 505) & 511)])) + (0.00440467615f * fVec29[((IOTA - 506) & 511)])) + (0.00473620556f * fVec29[((IOTA - 507) & 511)])) + (0.00511715934f * fVec29[((IOTA - 508) & 511)])) + (0.00552768912f * fVec29[((IOTA - 509) & 511)])) + (0.00566435885f * fVec29[((IOTA - 510) & 511)])) + (0.00561831659f * fVec29[((IOTA - 511) & 511)])))))))) : (iSlow2 ? (iSlow46 ? (iSlow70 ? (iSlow82 ? ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0529586487f * fVec28[((IOTA - 22) & 511)]) + ((0.0193263665f * fVec28[((IOTA - 21) & 511)]) + ((0.0110981483f * fVec28[((IOTA - 16) & 511)]) + ((0.056281656f * fVec28[((IOTA - 15) & 511)]) + ((0.0854275376f * fVec28[((IOTA - 14) & 511)]) + ((0.111660682f * fVec28[((IOTA - 13) & 511)]) + ((0.100570284f * fVec28[((IOTA - 12) & 511)]) + ((0.0373942479f * fVec28[((IOTA - 11) & 511)]) + ((0.0543358438f * fVec28[((IOTA - 5) & 511)]) + ((0.167363748f * fVec28[((IOTA - 4) & 511)]) + ((0.214415148f * fVec28[((IOTA - 3) & 511)]) + ((0.221238792f * fVec28[((IOTA - 2) & 511)]) + ((0.198823512f * fVec28[((IOTA - 1) & 511)]) + ((fSlow89 * fTemp0) + (((0.0663444847f * fVec28[((IOTA - 23) & 511)]) + (0.0496698245f * fVec28[((IOTA - 24) & 511)])) + (0.0221351422f * fVec28[((IOTA - 25) & 511)])))))))))))))))) + (0.00128185563f * fVec28[((IOTA - 34) & 511)])) + (0.00343401683f * fVec28[((IOTA - 35) & 511)])) + (0.00613213563f * fVec28[((IOTA - 42) & 511)])) + (0.0230787806f * fVec28[((IOTA - 43) & 511)])) + (0.0242426097f * fVec28[((IOTA - 44) & 511)])) + (0.0158468112f * fVec28[((IOTA - 45) & 511)])) + (0.0149961626f * fVec28[((IOTA - 53) & 511)])) + (0.0444046073f * fVec28[((IOTA - 54) & 511)])) + (0.0594306663f * fVec28[((IOTA - 55) & 511)])) + (0.0531921089f * fVec28[((IOTA - 56) & 511)])) + (0.0237090178f * fVec28[((IOTA - 57) & 511)])) + (0.00834078435f * fVec28[((IOTA - 65) & 511)])) + (0.0150002036f * fVec28[((IOTA - 66) & 511)])) + (0.00676491391f * fVec28[((IOTA - 73) & 511)])) + (0.0260625873f * fVec28[((IOTA - 74) & 511)])) + (0.0269699134f * fVec28[((IOTA - 75) & 511)])) + (0.0108586829f * fVec28[((IOTA - 76) & 511)])) + (0.00693394057f * fVec28[((IOTA - 86) & 511)])) + (0.00997592788f * fVec28[((IOTA - 87) & 511)])) + (0.0021517789f * fVec28[((IOTA - 88) & 511)])) + (0.00524853403f * fVec28[((IOTA - 100) & 511)])) + (0.00879304204f * fVec28[((IOTA - 101) & 511)])) + (0.00541698746f * fVec28[((IOTA - 102) & 511)])) + (0.00327364495f * fVec28[((IOTA - 126) & 511)])) + (0.0132689849f * fVec28[((IOTA - 127) & 511)])) + (0.0165374689f * fVec28[((IOTA - 128) & 511)])) + (0.0145740742f * fVec28[((IOTA - 129) & 511)])) + (0.0086176265f * fVec28[((IOTA - 130) & 511)])) + (0.00178167317f * fVec28[((IOTA - 131) & 511)])) + (0.00467775855f * fVec28[((IOTA - 137) & 511)])) + (0.00562388171f * fVec28[((IOTA - 138) & 511)])) + (0.0025578686f * fVec28[((IOTA - 139) & 511)])) + (0.00344032329f * fVec28[((IOTA - 146) & 511)])) + (0.00703787897f * fVec28[((IOTA - 147) & 511)])) + (0.00696279854f * fVec28[((IOTA - 148) & 511)])) + (0.00394177902f * fVec28[((IOTA - 149) & 511)])) + (7.07120635e-05f * fVec28[((IOTA - 150) & 511)])) + (0.000490289181f * fVec28[((IOTA - 154) & 511)])) + (0.0033087004f * fVec28[((IOTA - 155) & 511)])) + (0.00411361782f * fVec28[((IOTA - 156) & 511)])) + (0.00195981842f * fVec28[((IOTA - 157) & 511)])) + (0.00229186518f * fVec28[((IOTA - 167) & 511)])) + (0.0101073328f * fVec28[((IOTA - 168) & 511)])) + (0.0161516108f * fVec28[((IOTA - 169) & 511)])) + (0.0172190629f * fVec28[((IOTA - 170) & 511)])) + (0.0128125492f * fVec28[((IOTA - 171) & 511)])) + (0.0053058411f * fVec28[((IOTA - 172) & 511)])) + (0.000413270202f * fVec28[((IOTA - 176) & 511)])) + (0.00262432173f * fVec28[((IOTA - 177) & 511)])) + (0.00345845195f * fVec28[((IOTA - 178) & 511)])) + (0.00252139335f * fVec28[((IOTA - 179) & 511)])) + (2.65650451e-05f * fVec28[((IOTA - 180) & 511)])) + (0.0012824838f * fVec28[((IOTA - 182) & 511)])) + (0.00506839575f * fVec28[((IOTA - 183) & 511)])) + (0.00983141828f * fVec28[((IOTA - 184) & 511)])) + (0.012016424f * fVec28[((IOTA - 185) & 511)])) + (0.0108033149f * fVec28[((IOTA - 186) & 511)])) + (0.00798902567f * fVec28[((IOTA - 187) & 511)])) + (0.00544112222f * fVec28[((IOTA - 188) & 511)])) + (0.00618149759f * fVec28[((IOTA - 189) & 511)])) + (0.0100336447f * fVec28[((IOTA - 190) & 511)])) + (0.0123945288f * fVec28[((IOTA - 191) & 511)])) + (0.0122267306f * fVec28[((IOTA - 192) & 511)])) + (0.0103098042f * fVec28[((IOTA - 193) & 511)])) + (0.00693424093f * fVec28[((IOTA - 194) & 511)])) + (0.0050691599f * fVec28[((IOTA - 195) & 511)])) + (0.0061270576f * fVec28[((IOTA - 196) & 511)])) + (0.0077385027f * fVec28[((IOTA - 197) & 511)])) + (0.0088488739f * fVec28[((IOTA - 198) & 511)])) + (0.00833753496f * fVec28[((IOTA - 199) & 511)])) + (0.00563657749f * fVec28[((IOTA - 200) & 511)])) + (0.00314816507f * fVec28[((IOTA - 201) & 511)])) + (0.00298072165f * fVec28[((IOTA - 202) & 511)])) + (0.00508985482f * fVec28[((IOTA - 203) & 511)])) + (0.00819985196f * fVec28[((IOTA - 204) & 511)])) + (0.0114352461f * fVec28[((IOTA - 205) & 511)])) + (0.0120084248f * fVec28[((IOTA - 206) & 511)])) + (0.00923639908f * fVec28[((IOTA - 207) & 511)])) + (0.00647100806f * fVec28[((IOTA - 208) & 511)])) + (0.0054918495f * fVec28[((IOTA - 209) & 511)])) + (0.00567040453f * fVec28[((IOTA - 210) & 511)])) + (0.00718159694f * fVec28[((IOTA - 211) & 511)])) + (0.00967230275f * fVec28[((IOTA - 212) & 511)])) + (0.0112432037f * fVec28[((IOTA - 213) & 511)])) + (0.0119693279f * fVec28[((IOTA - 214) & 511)])) + (0.0131432042f * fVec28[((IOTA - 215) & 511)])) + (0.0135754216f * fVec28[((IOTA - 216) & 511)])) + (0.0117606595f * fVec28[((IOTA - 217) & 511)])) + (0.00825410057f * fVec28[((IOTA - 218) & 511)])) + (0.00491979113f * fVec28[((IOTA - 219) & 511)])) + (0.00339874253f * fVec28[((IOTA - 220) & 511)])) + (0.0023303614f * fVec28[((IOTA - 221) & 511)])) + (0.00223914534f * fVec28[((IOTA - 222) & 511)])) + (0.00418722397f * fVec28[((IOTA - 223) & 511)])) + (0.00589034939f * fVec28[((IOTA - 224) & 511)])) + (0.00700088497f * fVec28[((IOTA - 225) & 511)])) + (0.00757439062f * fVec28[((IOTA - 226) & 511)])) + (0.00747845136f * fVec28[((IOTA - 227) & 511)])) + (0.00816618837f * fVec28[((IOTA - 228) & 511)])) + (0.0102989376f * fVec28[((IOTA - 229) & 511)])) + (0.0129556116f * fVec28[((IOTA - 230) & 511)])) + (0.0148185641f * fVec28[((IOTA - 231) & 511)])) + (0.0148139494f * fVec28[((IOTA - 232) & 511)])) + (0.013012182f * fVec28[((IOTA - 233) & 511)])) + (0.0111525338f * fVec28[((IOTA - 234) & 511)])) + (0.00985762849f * fVec28[((IOTA - 235) & 511)])) + (0.00960486662f * fVec28[((IOTA - 236) & 511)])) + (0.0109204669f * fVec28[((IOTA - 237) & 511)])) + (0.011741383f * fVec28[((IOTA - 238) & 511)])) + (0.0120494319f * fVec28[((IOTA - 239) & 511)])) + (0.0120008346f * fVec28[((IOTA - 240) & 511)])) + (0.00994218327f * fVec28[((IOTA - 241) & 511)])) + (0.00784405228f * fVec28[((IOTA - 242) & 511)])) + (0.00675571291f * fVec28[((IOTA - 243) & 511)])) + (0.00571149401f * fVec28[((IOTA - 244) & 511)])) + (0.00540612126f * fVec28[((IOTA - 245) & 511)])) + (0.00627003796f * fVec28[((IOTA - 246) & 511)])) + (0.00699007325f * fVec28[((IOTA - 247) & 511)])) + (0.00648588734f * fVec28[((IOTA - 248) & 511)])) + (0.00516242348f * fVec28[((IOTA - 249) & 511)])) + (0.00357241044f * fVec28[((IOTA - 250) & 511)])) + (0.00292726466f * fVec28[((IOTA - 251) & 511)])) + (0.00348250521f * fVec28[((IOTA - 252) & 511)])) + (0.00449213246f * fVec28[((IOTA - 253) & 511)])) + (0.00621404173f * fVec28[((IOTA - 254) & 511)])) + (0.00853948854f * fVec28[((IOTA - 255) & 511)])) + (0.0107214637f * fVec28[((IOTA - 256) & 511)])) + (0.0122144185f * fVec28[((IOTA - 257) & 511)])) + (0.0131359147f * fVec28[((IOTA - 258) & 511)])) + (0.0137385242f * fVec28[((IOTA - 259) & 511)])) + (0.0141983982f * fVec28[((IOTA - 260) & 511)])) + (0.0134771615f * fVec28[((IOTA - 261) & 511)])) + (0.010956943f * fVec28[((IOTA - 262) & 511)])) + (0.00879609957f * fVec28[((IOTA - 263) & 511)])) + (0.00936059561f * fVec28[((IOTA - 264) & 511)])) + (0.0117917825f * fVec28[((IOTA - 265) & 511)])) + (0.0138699012f * fVec28[((IOTA - 266) & 511)])) + (0.0144612081f * fVec28[((IOTA - 267) & 511)])) + (0.0132019036f * fVec28[((IOTA - 268) & 511)])) + (0.0104802772f * fVec28[((IOTA - 269) & 511)])) + (0.00846847612f * fVec28[((IOTA - 270) & 511)])) + (0.00837220903f * fVec28[((IOTA - 271) & 511)])) + (0.0103517119f * fVec28[((IOTA - 272) & 511)])) + (0.0134480856f * fVec28[((IOTA - 273) & 511)])) + (0.0150144547f * fVec28[((IOTA - 274) & 511)])) + (0.0135686789f * fVec28[((IOTA - 275) & 511)])) + (0.0107037164f * fVec28[((IOTA - 276) & 511)])) + (0.00749838166f * fVec28[((IOTA - 277) & 511)])) + (0.0043121851f * fVec28[((IOTA - 278) & 511)])) + (0.00319676241f * fVec28[((IOTA - 279) & 511)])) + (0.00401789695f * fVec28[((IOTA - 280) & 511)])) + (0.00440269103f * fVec28[((IOTA - 281) & 511)])) + (0.00419836305f * fVec28[((IOTA - 282) & 511)])) + (0.00400790432f * fVec28[((IOTA - 283) & 511)])) + (0.00399294309f * fVec28[((IOTA - 284) & 511)])) + (0.0052623488f * fVec28[((IOTA - 285) & 511)])) + (0.00737500424f * fVec28[((IOTA - 286) & 511)])) + (0.00845400617f * fVec28[((IOTA - 287) & 511)])) + (0.00821363926f * fVec28[((IOTA - 288) & 511)])) + (0.00706299674f * fVec28[((IOTA - 289) & 511)])) + (0.00587448664f * fVec28[((IOTA - 290) & 511)])) + (0.00632322207f * fVec28[((IOTA - 291) & 511)])) + (0.00790537242f * fVec28[((IOTA - 292) & 511)])) + (0.00901386049f * fVec28[((IOTA - 293) & 511)])) + (0.00937208999f * fVec28[((IOTA - 294) & 511)])) + (0.00891491771f * fVec28[((IOTA - 295) & 511)])) + (0.00720387511f * fVec28[((IOTA - 296) & 511)])) + (0.00491536781f * fVec28[((IOTA - 297) & 511)])) + (0.00386099238f * fVec28[((IOTA - 298) & 511)])) + (0.00473446492f * fVec28[((IOTA - 299) & 511)])) + (0.00669592153f * fVec28[((IOTA - 300) & 511)])) + (0.00867343135f * fVec28[((IOTA - 301) & 511)])) + (0.00981563795f * fVec28[((IOTA - 302) & 511)])) + (0.0103323832f * fVec28[((IOTA - 303) & 511)])) + (0.0111041553f * fVec28[((IOTA - 304) & 511)])) + (0.0114633404f * fVec28[((IOTA - 305) & 511)])) + (0.0106073134f * fVec28[((IOTA - 306) & 511)])) + (0.00880115107f * fVec28[((IOTA - 307) & 511)])) + (0.00580871617f * fVec28[((IOTA - 308) & 511)])) + (0.00256207306f * fVec28[((IOTA - 309) & 511)])) + (0.00163497962f * fVec28[((IOTA - 310) & 511)])) + (0.00346855354f * fVec28[((IOTA - 311) & 511)])) + (0.00716027385f * fVec28[((IOTA - 312) & 511)])) + (0.0114274928f * fVec28[((IOTA - 313) & 511)])) + (0.0139138307f * fVec28[((IOTA - 314) & 511)])) + (0.0137396436f * fVec28[((IOTA - 315) & 511)])) + (0.0112887435f * fVec28[((IOTA - 316) & 511)])) + (0.00674798666f * fVec28[((IOTA - 317) & 511)])) + (0.00199776841f * fVec28[((IOTA - 318) & 511)])) + (0.00115738576f * fVec28[((IOTA - 324) & 511)])) + (0.00375926541f * fVec28[((IOTA - 325) & 511)])) + (0.00550197857f * fVec28[((IOTA - 326) & 511)])) + (0.00521107577f * fVec28[((IOTA - 327) & 511)])) + (0.00343811186f * fVec28[((IOTA - 328) & 511)])) + (0.000906999223f * fVec28[((IOTA - 329) & 511)])) + (0.00240475917f * fVec28[((IOTA - 333) & 511)])) + (0.00620926358f * fVec28[((IOTA - 334) & 511)])) + (0.00887945294f * fVec28[((IOTA - 335) & 511)])) + (0.00914985128f * fVec28[((IOTA - 336) & 511)])) + (0.00688324077f * fVec28[((IOTA - 337) & 511)])) + (0.00384979881f * fVec28[((IOTA - 338) & 511)])) + (0.00139261968f * fVec28[((IOTA - 339) & 511)])) + (0.000910248142f * fVec28[((IOTA - 340) & 511)])) + (0.00283468328f * fVec28[((IOTA - 341) & 511)])) + (0.00520304916f * fVec28[((IOTA - 342) & 511)])) + (0.00666313199f * fVec28[((IOTA - 343) & 511)])) + (0.00662149629f * fVec28[((IOTA - 344) & 511)])) + (0.0048734867f * fVec28[((IOTA - 345) & 511)])) + (0.00296707079f * fVec28[((IOTA - 346) & 511)])) + (0.00182183413f * fVec28[((IOTA - 347) & 511)])) + (0.00206119101f * fVec28[((IOTA - 348) & 511)])) + (0.00344149768f * fVec28[((IOTA - 349) & 511)])) + (0.00423486577f * fVec28[((IOTA - 350) & 511)])) + (0.00371768419f * fVec28[((IOTA - 351) & 511)])) + (0.00218770839f * fVec28[((IOTA - 352) & 511)])) + (0.000138011761f * fVec28[((IOTA - 364) & 511)])) + (0.000176862348f * fVec28[((IOTA - 365) & 511)])) + (0.000539050438f * fVec28[((IOTA - 385) & 511)])) + (0.0021860702f * fVec28[((IOTA - 386) & 511)])) + (0.00186789269f * fVec28[((IOTA - 387) & 511)])) + (0.000791211613f * fVec28[((IOTA - 419) & 511)])) + (0.00135292253f * fVec28[((IOTA - 420) & 511)])) + (9.86419618e-05f * fVec28[((IOTA - 421) & 511)])) - ((((((0.0101195369f * fVec28[((IOTA - 506) & 511)]) + ((0.00848665927f * fVec28[((IOTA - 505) & 511)]) + ((0.00618914235f * fVec28[((IOTA - 504) & 511)]) + ((0.00377373537f * fVec28[((IOTA - 503) & 511)]) + ((0.0017432319f * fVec28[((IOTA - 502) & 511)]) + ((0.00164576387f * fVec28[((IOTA - 501) & 511)]) + ((0.00279651536f * fVec28[((IOTA - 500) & 511)]) + ((0.00398286851f * fVec28[((IOTA - 499) & 511)]) + ((0.00488757435f * fVec28[((IOTA - 498) & 511)]) + ((0.00447662501f * fVec28[((IOTA - 497) & 511)]) + ((0.00324776256f * fVec28[((IOTA - 496) & 511)]) + ((0.00213463325f * fVec28[((IOTA - 495) & 511)]) + ((0.00121848751f * fVec28[((IOTA - 494) & 511)]) + ((0.00104615744f * fVec28[((IOTA - 493) & 511)]) + ((0.00155692315f * fVec28[((IOTA - 492) & 511)]) + ((0.00259701954f * fVec28[((IOTA - 491) & 511)]) + ((0.00396405766f * fVec28[((IOTA - 490) & 511)]) + ((0.00469960039f * fVec28[((IOTA - 489) & 511)]) + ((0.00495664869f * fVec28[((IOTA - 488) & 511)]) + ((0.00529846968f * fVec28[((IOTA - 487) & 511)]) + ((0.00507096201f * fVec28[((IOTA - 486) & 511)]) + ((0.00431005564f * fVec28[((IOTA - 485) & 511)]) + ((0.00391237484f * fVec28[((IOTA - 484) & 511)]) + ((0.00416890439f * fVec28[((IOTA - 483) & 511)]) + ((0.00523968833f * fVec28[((IOTA - 482) & 511)]) + ((0.00688919239f * fVec28[((IOTA - 481) & 511)]) + ((0.0079318285f * fVec28[((IOTA - 480) & 511)]) + ((0.00785513688f * fVec28[((IOTA - 479) & 511)]) + ((0.0067138318f * fVec28[((IOTA - 478) & 511)]) + ((0.0044871089f * fVec28[((IOTA - 477) & 511)]) + ((0.0027559991f * fVec28[((IOTA - 476) & 511)]) + ((0.0025188541f * fVec28[((IOTA - 475) & 511)]) + ((0.00298099499f * fVec28[((IOTA - 474) & 511)]) + ((0.0034513534f * fVec28[((IOTA - 473) & 511)]) + ((0.00366043206f * fVec28[((IOTA - 472) & 511)]) + ((0.00410034927f * fVec28[((IOTA - 471) & 511)]) + ((0.0054998761f * fVec28[((IOTA - 470) & 511)]) + ((0.00740121398f * fVec28[((IOTA - 469) & 511)]) + ((0.00865751505f * fVec28[((IOTA - 468) & 511)]) + ((0.00858311728f * fVec28[((IOTA - 467) & 511)]) + ((0.00710520567f * fVec28[((IOTA - 466) & 511)]) + ((0.00500721205f * fVec28[((IOTA - 465) & 511)]) + ((0.00331380591f * fVec28[((IOTA - 464) & 511)]) + ((0.00284194574f * fVec28[((IOTA - 463) & 511)]) + ((0.00394950574f * fVec28[((IOTA - 462) & 511)]) + ((0.00571261346f * fVec28[((IOTA - 461) & 511)]) + ((0.00727920141f * fVec28[((IOTA - 460) & 511)]) + ((0.00776632363f * fVec28[((IOTA - 459) & 511)]) + ((0.00672215875f * fVec28[((IOTA - 458) & 511)]) + ((0.0048928163f * fVec28[((IOTA - 456) & 511)]) + ((0.0051757195f * fVec28[((IOTA - 455) & 511)]) + ((0.00612593815f * fVec28[((IOTA - 454) & 511)]) + ((0.00722650858f * fVec28[((IOTA - 453) & 511)]) + ((0.00771234743f * fVec28[((IOTA - 452) & 511)]) + ((0.0078192614f * fVec28[((IOTA - 451) & 511)]) + ((0.00756786531f * fVec28[((IOTA - 450) & 511)]) + ((0.00653716084f * fVec28[((IOTA - 449) & 511)]) + ((0.00530540431f * fVec28[((IOTA - 448) & 511)]) + ((0.00489983335f * fVec28[((IOTA - 447) & 511)]) + ((0.0059845685f * fVec28[((IOTA - 446) & 511)]) + ((0.00819911435f * fVec28[((IOTA - 445) & 511)]) + ((0.0104782572f * fVec28[((IOTA - 444) & 511)]) + ((0.0120523255f * fVec28[((IOTA - 443) & 511)]) + ((0.0123062897f * fVec28[((IOTA - 442) & 511)]) + ((0.0107553992f * fVec28[((IOTA - 441) & 511)]) + ((0.00809214544f * fVec28[((IOTA - 440) & 511)]) + ((0.00606095931f * fVec28[((IOTA - 439) & 511)]) + ((0.00512062432f * fVec28[((IOTA - 438) & 511)]) + ((0.00535809714f * fVec28[((IOTA - 437) & 511)]) + ((0.00668330817f * fVec28[((IOTA - 436) & 511)]) + ((0.0081836069f * fVec28[((IOTA - 435) & 511)]) + ((0.00873270445f * fVec28[((IOTA - 434) & 511)]) + ((0.00758645777f * fVec28[((IOTA - 433) & 511)]) + ((0.00571102975f * fVec28[((IOTA - 432) & 511)]) + ((0.00461168773f * fVec28[((IOTA - 431) & 511)]) + ((0.00412229961f * fVec28[((IOTA - 430) & 511)]) + ((0.00415301463f * fVec28[((IOTA - 429) & 511)]) + ((0.00521569001f * fVec28[((IOTA - 428) & 511)]) + ((0.00635500159f * fVec28[((IOTA - 427) & 511)]) + ((0.00697743241f * fVec28[((IOTA - 426) & 511)]) + ((0.00737426709f * fVec28[((IOTA - 425) & 511)]) + ((0.00666687218f * fVec28[((IOTA - 424) & 511)]) + ((0.00456827786f * fVec28[((IOTA - 423) & 511)]) + ((0.00217697863f * fVec28[((IOTA - 422) & 511)]) + ((0.000944102649f * fVec28[((IOTA - 418) & 511)]) + ((0.00353959342f * fVec28[((IOTA - 417) & 511)]) + ((0.00625515822f * fVec28[((IOTA - 416) & 511)]) + ((0.00740563683f * fVec28[((IOTA - 415) & 511)]) + ((0.00699392287f * fVec28[((IOTA - 414) & 511)]) + ((0.00577609055f * fVec28[((IOTA - 413) & 511)]) + ((0.00432507182f * fVec28[((IOTA - 412) & 511)]) + ((0.00337419799f * fVec28[((IOTA - 411) & 511)]) + ((0.00536085432f * fVec28[((IOTA - 457) & 511)]) + ((0.00303199515f * fVec28[((IOTA - 410) & 511)]) + ((0.00340321986f * fVec28[((IOTA - 408) & 511)]) + ((0.00390254613f * fVec28[((IOTA - 407) & 511)]) + ((0.00434819655f * fVec28[((IOTA - 406) & 511)]) + ((0.00584459119f * fVec28[((IOTA - 405) & 511)]) + ((0.00805867277f * fVec28[((IOTA - 404) & 511)]) + ((0.00950480439f * fVec28[((IOTA - 403) & 511)]) + ((0.00985552557f * fVec28[((IOTA - 402) & 511)]) + ((0.00956672616f * fVec28[((IOTA - 401) & 511)]) + ((0.00875673071f * fVec28[((IOTA - 400) & 511)]) + ((0.00758613041f * fVec28[((IOTA - 399) & 511)]) + ((0.00616659084f * fVec28[((IOTA - 398) & 511)]) + ((0.00458965544f * fVec28[((IOTA - 397) & 511)]) + ((0.00357612362f * fVec28[((IOTA - 396) & 511)]) + ((0.00343145011f * fVec28[((IOTA - 395) & 511)]) + ((0.00387016591f * fVec28[((IOTA - 394) & 511)]) + ((0.00424775248f * fVec28[((IOTA - 393) & 511)]) + ((0.00431417814f * fVec28[((IOTA - 392) & 511)]) + ((0.00415074872f * fVec28[((IOTA - 391) & 511)]) + ((0.00335470447f * fVec28[((IOTA - 390) & 511)]) + ((0.00192173244f * fVec28[((IOTA - 389) & 511)]) + ((1.72820874e-05f * fVec28[((IOTA - 388) & 511)]) + ((0.00262284745f * fVec28[((IOTA - 384) & 511)]) + ((0.00641047955f * fVec28[((IOTA - 383) & 511)]) + ((0.00873136707f * fVec28[((IOTA - 382) & 511)]) + ((0.00856818259f * fVec28[((IOTA - 381) & 511)]) + ((0.00619132631f * fVec28[((IOTA - 380) & 511)]) + ((0.00261127111f * fVec28[((IOTA - 379) & 511)]) + ((8.824002e-05f * fVec28[((IOTA - 378) & 511)]) + ((0.000129657332f * fVec28[((IOTA - 377) & 511)]) + ((0.0026632268f * fVec28[((IOTA - 376) & 511)]) + ((0.00620557787f * fVec28[((IOTA - 375) & 511)]) + ((0.00895857438f * fVec28[((IOTA - 374) & 511)]) + ((0.0101844054f * fVec28[((IOTA - 373) & 511)]) + ((0.00978768058f * fVec28[((IOTA - 372) & 511)]) + ((0.0083368253f * fVec28[((IOTA - 371) & 511)]) + ((0.00683346903f * fVec28[((IOTA - 370) & 511)]) + ((0.00523717655f * fVec28[((IOTA - 369) & 511)]) + ((0.00351119926f * fVec28[((IOTA - 368) & 511)]) + ((0.0021058023f * fVec28[((IOTA - 367) & 511)]) + ((0.000918165781f * fVec28[((IOTA - 366) & 511)]) + ((0.000379279256f * fVec28[((IOTA - 363) & 511)]) + ((0.000264938455f * fVec28[((IOTA - 362) & 511)]) + ((0.000202990137f * fVec28[((IOTA - 361) & 511)]) + ((0.000499271322f * fVec28[((IOTA - 360) & 511)]) + ((0.00105688721f * fVec28[((IOTA - 359) & 511)]) + (((0.0034778635f * fVec28[((IOTA - 357) & 511)]) + ((0.00511838542f * fVec28[((IOTA - 356) & 511)]) + ((0.00589368027f * fVec28[((IOTA - 355) & 511)]) + ((0.00440258207f * fVec28[((IOTA - 354) & 511)]) + ((0.000900610816f * fVec28[((IOTA - 353) & 511)]) + ((0.000789218582f * fVec28[((IOTA - 332) & 511)]) + ((0.00211822474f * fVec28[((IOTA - 331) & 511)]) + ((0.00140627101f * fVec28[((IOTA - 330) & 511)]) + ((0.000665021595f * fVec28[((IOTA - 323) & 511)]) + ((0.0019663712f * fVec28[((IOTA - 322) & 511)]) + ((0.00325234933f * fVec28[((IOTA - 321) & 511)]) + ((0.00315526361f * fVec28[((IOTA - 320) & 511)]) + ((0.00130850216f * fVec28[((IOTA - 319) & 511)]) + ((0.00203418918f * fVec28[((IOTA - 358) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0224089809f * fVec28[((IOTA - 20) & 511)]) + ((0.0583418906f * fVec28[((IOTA - 19) & 511)]) + ((0.0654357672f * fVec28[((IOTA - 18) & 511)]) + ((0.043731533f * fVec28[((IOTA - 17) & 511)]) + ((0.0412451401f * fVec28[((IOTA - 10) & 511)]) + ((0.11709547f * fVec28[((IOTA - 9) & 511)]) + ((0.17583397f * fVec28[((IOTA - 8) & 511)]) + ((0.170300677f * fVec28[((IOTA - 7) & 511)]) + ((0.0750930533f * fVec28[((IOTA - 6) & 511)]) + (((0.0120436167f * fVec28[((IOTA - 26) & 511)]) + (0.0369676836f * fVec28[((IOTA - 27) & 511)])) + (0.039481461f * fVec28[((IOTA - 28) & 511)]))))))))))) + (0.041391369f * fVec28[((IOTA - 29) & 511)])) + (0.0370720848f * fVec28[((IOTA - 30) & 511)])) + (0.0223141331f * fVec28[((IOTA - 31) & 511)])) + (0.0167766623f * fVec28[((IOTA - 32) & 511)])) + (0.0105630029f * fVec28[((IOTA - 33) & 511)])) + (0.00251560519f * fVec28[((IOTA - 36) & 511)])) + (0.0117950048f * fVec28[((IOTA - 37) & 511)])) + (0.0301720276f * fVec28[((IOTA - 38) & 511)])) + (0.0354995467f * fVec28[((IOTA - 39) & 511)])) + (0.0291634649f * fVec28[((IOTA - 40) & 511)])) + (0.0153314313f * fVec28[((IOTA - 41) & 511)])) + (0.00676586945f * fVec28[((IOTA - 46) & 511)])) + (0.0359820276f * fVec28[((IOTA - 47) & 511)])) + (0.0532961562f * fVec28[((IOTA - 48) & 511)])) + (0.0674429014f * fVec28[((IOTA - 49) & 511)])) + (0.0744483471f * fVec28[((IOTA - 50) & 511)])) + (0.0531465672f * fVec28[((IOTA - 51) & 511)])) + (0.0182702988f * fVec28[((IOTA - 52) & 511)])) + (0.0189922731f * fVec28[((IOTA - 58) & 511)])) + (0.051200483f * fVec28[((IOTA - 59) & 511)])) + (0.0704382285f * fVec28[((IOTA - 60) & 511)])) + (0.0770040303f * fVec28[((IOTA - 61) & 511)])) + (0.0605946854f * fVec28[((IOTA - 62) & 511)])) + (0.0308895502f * fVec28[((IOTA - 63) & 511)])) + (0.00774483662f * fVec28[((IOTA - 64) & 511)])) + (0.00197016587f * fVec28[((IOTA - 67) & 511)])) + (0.0270471778f * fVec28[((IOTA - 68) & 511)])) + (0.0418097712f * fVec28[((IOTA - 69) & 511)])) + (0.0472030081f * fVec28[((IOTA - 70) & 511)])) + (0.0418130495f * fVec28[((IOTA - 71) & 511)])) + (0.0196762159f * fVec28[((IOTA - 72) & 511)])) + (0.0105637126f * fVec28[((IOTA - 77) & 511)])) + (0.0228665881f * fVec28[((IOTA - 78) & 511)])) + (0.0267155953f * fVec28[((IOTA - 79) & 511)])) + (0.028095657f * fVec28[((IOTA - 80) & 511)])) + (0.0267330687f * fVec28[((IOTA - 81) & 511)])) + (0.0248498321f * fVec28[((IOTA - 82) & 511)])) + (0.0234511234f * fVec28[((IOTA - 83) & 511)])) + (0.015334107f * fVec28[((IOTA - 84) & 511)])) + (0.00321098696f * fVec28[((IOTA - 85) & 511)])) + (0.0142120225f * fVec28[((IOTA - 89) & 511)])) + (0.0305787995f * fVec28[((IOTA - 90) & 511)])) + (0.0384048037f * fVec28[((IOTA - 91) & 511)])) + (0.0392978527f * fVec28[((IOTA - 92) & 511)])) + (0.0329713002f * fVec28[((IOTA - 93) & 511)])) + (0.0205994584f * fVec28[((IOTA - 94) & 511)])) + (0.0124851717f * fVec28[((IOTA - 95) & 511)])) + (0.00957052037f * fVec28[((IOTA - 96) & 511)])) + (0.0072824778f * fVec28[((IOTA - 97) & 511)])) + (0.0054563568f * fVec28[((IOTA - 98) & 511)])) + (0.000674495474f * fVec28[((IOTA - 99) & 511)])) + (0.00458130101f * fVec28[((IOTA - 103) & 511)])) + (0.0139775798f * fVec28[((IOTA - 104) & 511)])) + (0.0183639452f * fVec28[((IOTA - 105) & 511)])) + (0.018894095f * fVec28[((IOTA - 106) & 511)])) + (0.0166546497f * fVec28[((IOTA - 107) & 511)])) + (0.0112933312f * fVec28[((IOTA - 108) & 511)])) + (0.00571032008f * fVec28[((IOTA - 109) & 511)])) + (0.00408981042f * fVec28[((IOTA - 110) & 511)])) + (0.00399075868f * fVec28[((IOTA - 111) & 511)])) + (0.0073424601f * fVec28[((IOTA - 112) & 511)])) + (0.0105635207f * fVec28[((IOTA - 113) & 511)])) + (0.0104391333f * fVec28[((IOTA - 114) & 511)])) + (0.0106348619f * fVec28[((IOTA - 115) & 511)])) + (0.0103025138f * fVec28[((IOTA - 116) & 511)])) + (0.0105945366f * fVec28[((IOTA - 117) & 511)])) + (0.0129659325f * fVec28[((IOTA - 118) & 511)])) + (0.0155921923f * fVec28[((IOTA - 119) & 511)])) + (0.0187329575f * fVec28[((IOTA - 120) & 511)])) + (0.023217611f * fVec28[((IOTA - 121) & 511)])) + (0.027824657f * fVec28[((IOTA - 122) & 511)])) + (0.0280671529f * fVec28[((IOTA - 123) & 511)])) + (0.0210951529f * fVec28[((IOTA - 124) & 511)])) + (0.0101047931f * fVec28[((IOTA - 125) & 511)])) + (0.00571946613f * fVec28[((IOTA - 132) & 511)])) + (0.0108177029f * fVec28[((IOTA - 133) & 511)])) + (0.00940758176f * fVec28[((IOTA - 134) & 511)])) + (0.00516373431f * fVec28[((IOTA - 135) & 511)])) + (0.000129575375f * fVec28[((IOTA - 136) & 511)])) + (0.00359766465f * fVec28[((IOTA - 140) & 511)])) + (0.0111548277f * fVec28[((IOTA - 141) & 511)])) + (0.0164748654f * fVec28[((IOTA - 142) & 511)])) + (0.0168210007f * fVec28[((IOTA - 143) & 511)])) + (0.0119641684f * fVec28[((IOTA - 144) & 511)])) + (0.00379129034f * fVec28[((IOTA - 145) & 511)])) + (0.00288710324f * fVec28[((IOTA - 151) & 511)])) + (0.00424584141f * fVec28[((IOTA - 152) & 511)])) + (0.00283457432f * fVec28[((IOTA - 153) & 511)])) + (0.000963377766f * fVec28[((IOTA - 158) & 511)])) + (0.00234950008f * fVec28[((IOTA - 159) & 511)])) + (0.00256371126f * fVec28[((IOTA - 160) & 511)])) + (0.00178104499f * fVec28[((IOTA - 161) & 511)])) + (0.00228479411f * fVec28[((IOTA - 162) & 511)])) + (0.00489328057f * fVec28[((IOTA - 163) & 511)])) + (0.00655548042f * fVec28[((IOTA - 164) & 511)])) + (0.00629035058f * fVec28[((IOTA - 165) & 511)])) + (0.00368115446f * fVec28[((IOTA - 166) & 511)])) + (0.00195973646f * fVec28[((IOTA - 173) & 511)])) + (0.005805986f * fVec28[((IOTA - 174) & 511)])) + (0.00406638533f * fVec28[((IOTA - 175) & 511)])) + (0.000535528641f * fVec28[((IOTA - 181) & 511)])) + (0.00301716989f * fVec28[((IOTA - 409) & 511)])))))))))))))))) + (0.010417019f * fVec28[((IOTA - 507) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00958340708f * fVec28[((IOTA - 508) & 511)])) + (0.0079161562f * fVec28[((IOTA - 509) & 511)])) + (0.00576585205f * fVec28[((IOTA - 510) & 511)])) + (0.00424450357f * fVec28[((IOTA - 511) & 511)]))) : (iSlow83 ? (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((fSlow87 * fTemp0) + (0.221686557f * fVec27[((IOTA - 1) & 511)])) + (0.21192576f * fVec27[((IOTA - 2) & 511)])) + (0.139397442f * fVec27[((IOTA - 3) & 511)])) + (0.0297111552f * fVec27[((IOTA - 4) & 511)])) + (0.0291223638f * fVec27[((IOTA - 9) & 511)])) + (0.152806044f * fVec27[((IOTA - 10) & 511)])) + (0.158686429f * fVec27[((IOTA - 11) & 511)])) + (0.110475667f * fVec27[((IOTA - 12) & 511)])) + (0.0271622147f * fVec27[((IOTA - 13) & 511)])) + (0.0053730146f * fVec27[((IOTA - 21) & 511)])) + (0.0554790534f * fVec27[((IOTA - 22) & 511)])) + (0.0772565529f * fVec27[((IOTA - 23) & 511)])) + (0.0541146472f * fVec27[((IOTA - 24) & 511)])) + (0.00366432685f * fVec27[((IOTA - 25) & 511)])) + (0.00735564809f * fVec27[((IOTA - 30) & 511)])) + (0.0253374111f * fVec27[((IOTA - 31) & 511)])) + (0.00975310151f * fVec27[((IOTA - 32) & 511)])) + (0.0123341233f * fVec27[((IOTA - 36) & 511)])) + (0.025297394f * fVec27[((IOTA - 37) & 511)])) + (0.012234454f * fVec27[((IOTA - 38) & 511)])) + (0.00930860825f * fVec27[((IOTA - 43) & 511)])) + (0.017874632f * fVec27[((IOTA - 44) & 511)])) + (0.015151618f * fVec27[((IOTA - 45) & 511)])) + (0.00327202585f * fVec27[((IOTA - 46) & 511)])) + (0.00171180768f * fVec27[((IOTA - 50) & 511)])) + (0.002395113f * fVec27[((IOTA - 51) & 511)])) + (0.00105352979f * fVec27[((IOTA - 52) & 511)])) + (0.00643681968f * fVec27[((IOTA - 61) & 511)])) + (0.0161615014f * fVec27[((IOTA - 62) & 511)])) + (0.0226362702f * fVec27[((IOTA - 63) & 511)])) + (0.0162803996f * fVec27[((IOTA - 64) & 511)])) + (0.00903361104f * fVec27[((IOTA - 70) & 511)])) + (0.0186205059f * fVec27[((IOTA - 71) & 511)])) + (0.0159954317f * fVec27[((IOTA - 72) & 511)])) + (0.00260428619f * fVec27[((IOTA - 73) & 511)])) + (0.00534958113f * fVec27[((IOTA - 77) & 511)])) + (0.00454863254f * fVec27[((IOTA - 78) & 511)])) + (9.72272828e-05f * fVec27[((IOTA - 92) & 511)])) + (0.00262134429f * fVec27[((IOTA - 93) & 511)])) + (0.00637343712f * fVec27[((IOTA - 94) & 511)])) + (0.00773028098f * fVec27[((IOTA - 95) & 511)])) + (0.00933689158f * fVec27[((IOTA - 96) & 511)])) + (0.0070024142f * fVec27[((IOTA - 97) & 511)])) + (0.00219007721f * fVec27[((IOTA - 98) & 511)])) + (0.00268655829f * fVec27[((IOTA - 106) & 511)])) + (0.00563916098f * fVec27[((IOTA - 107) & 511)])) + (0.00810135342f * fVec27[((IOTA - 108) & 511)])) + (0.00874389522f * fVec27[((IOTA - 109) & 511)])) + (0.00688985828f * fVec27[((IOTA - 110) & 511)])) + (0.00144389784f * fVec27[((IOTA - 111) & 511)])) + (0.00142860319f * fVec27[((IOTA - 119) & 511)])) + (0.00108181266f * fVec27[((IOTA - 120) & 511)])) + (0.00145817501f * fVec27[((IOTA - 128) & 511)])) + (0.00389167713f * fVec27[((IOTA - 129) & 511)])) + (0.0043800869f * fVec27[((IOTA - 130) & 511)])) + (0.00303195836f * fVec27[((IOTA - 131) & 511)])) + (0.000716133043f * fVec27[((IOTA - 148) & 511)])) + (0.00406178273f * fVec27[((IOTA - 149) & 511)])) + (0.00626939302f * fVec27[((IOTA - 150) & 511)])) + (0.00608497625f * fVec27[((IOTA - 151) & 511)])) + (0.00339136412f * fVec27[((IOTA - 152) & 511)])) + (0.000889697578f * fVec27[((IOTA - 153) & 511)])) + (0.00122088846f * fVec27[((IOTA - 162) & 511)])) + (0.00251519773f * fVec27[((IOTA - 163) & 511)])) + (0.0017327657f * fVec27[((IOTA - 164) & 511)])) + (0.00052981684f * fVec27[((IOTA - 165) & 511)])) + (0.000423433259f * fVec27[((IOTA - 168) & 511)])) + (0.00121040922f * fVec27[((IOTA - 169) & 511)])) + (0.00131313084f * fVec27[((IOTA - 170) & 511)])) + (0.000400813296f * fVec27[((IOTA - 171) & 511)])) + (0.000490953214f * fVec27[((IOTA - 174) & 511)])) + (0.00185617339f * fVec27[((IOTA - 175) & 511)])) + (0.00257858029f * fVec27[((IOTA - 176) & 511)])) + (0.00140442373f * fVec27[((IOTA - 177) & 511)])) + (0.00287897838f * fVec27[((IOTA - 181) & 511)])) + (0.00726191374f * fVec27[((IOTA - 182) & 511)])) + (0.00898406468f * fVec27[((IOTA - 183) & 511)])) + (0.00749316392f * fVec27[((IOTA - 184) & 511)])) + (0.00346759986f * fVec27[((IOTA - 185) & 511)])) + (0.00218237936f * fVec27[((IOTA - 190) & 511)])) + (0.0048371274f * fVec27[((IOTA - 191) & 511)])) + (0.00669547124f * fVec27[((IOTA - 192) & 511)])) + (0.00749913277f * fVec27[((IOTA - 193) & 511)])) + (0.00677269045f * fVec27[((IOTA - 194) & 511)])) + (0.0051603145f * fVec27[((IOTA - 195) & 511)])) + (0.00283143297f * fVec27[((IOTA - 196) & 511)])) + (0.000637591351f * fVec27[((IOTA - 197) & 511)])) + (0.000523712486f * fVec27[((IOTA - 200) & 511)])) + (0.00283363741f * fVec27[((IOTA - 201) & 511)])) + (0.00452645356f * fVec27[((IOTA - 202) & 511)])) + (0.00473416829f * fVec27[((IOTA - 203) & 511)])) + (0.00403024396f * fVec27[((IOTA - 204) & 511)])) + (0.00234292168f * fVec27[((IOTA - 205) & 511)])) + (0.000954742078f * fVec27[((IOTA - 206) & 511)])) + (0.00171608059f * fVec27[((IOTA - 207) & 511)])) + (0.00381513638f * fVec27[((IOTA - 208) & 511)])) + (0.00594111905f * fVec27[((IOTA - 209) & 511)])) + (0.00643369975f * fVec27[((IOTA - 210) & 511)])) + (0.0041147205f * fVec27[((IOTA - 211) & 511)])) + (0.000385857653f * fVec27[((IOTA - 212) & 511)])) + (8.81729648e-06f * fVec27[((IOTA - 216) & 511)])) + (0.00359467044f * fVec27[((IOTA - 217) & 511)])) + (0.00595217431f * fVec27[((IOTA - 218) & 511)])) + (0.00663863355f * fVec27[((IOTA - 219) & 511)])) + (0.00595892314f * fVec27[((IOTA - 220) & 511)])) + (0.00481087901f * fVec27[((IOTA - 221) & 511)])) + (0.00403482234f * fVec27[((IOTA - 222) & 511)])) + (0.00376097811f * fVec27[((IOTA - 223) & 511)])) + (0.00362573424f * fVec27[((IOTA - 224) & 511)])) + (0.0029432429f * fVec27[((IOTA - 225) & 511)])) + (0.00211903034f * fVec27[((IOTA - 226) & 511)])) + (0.00171326566f * fVec27[((IOTA - 227) & 511)])) + (0.00171360513f * fVec27[((IOTA - 228) & 511)])) + (0.00216240482f * fVec27[((IOTA - 229) & 511)])) + (0.00289854594f * fVec27[((IOTA - 230) & 511)])) + (0.00370176649f * fVec27[((IOTA - 231) & 511)])) + (0.00424653897f * fVec27[((IOTA - 232) & 511)])) + (0.00385447498f * fVec27[((IOTA - 233) & 511)])) + (0.00318524335f * fVec27[((IOTA - 234) & 511)])) + (0.00280772801f * fVec27[((IOTA - 235) & 511)])) + (0.00244520186f * fVec27[((IOTA - 236) & 511)])) + (0.0025780038f * fVec27[((IOTA - 237) & 511)])) + (0.00331651885f * fVec27[((IOTA - 238) & 511)])) + (0.00379760377f * fVec27[((IOTA - 239) & 511)])) + (0.00377806975f * fVec27[((IOTA - 240) & 511)])) + (0.00323221227f * fVec27[((IOTA - 241) & 511)])) + (0.00253642676f * fVec27[((IOTA - 242) & 511)])) + (0.00223138276f * fVec27[((IOTA - 243) & 511)])) + (0.00184996752f * fVec27[((IOTA - 244) & 511)])) + (0.00136349117f * fVec27[((IOTA - 245) & 511)])) + (0.0014936137f * fVec27[((IOTA - 246) & 511)])) + (0.00215335004f * fVec27[((IOTA - 247) & 511)])) + (0.00337589998f * fVec27[((IOTA - 248) & 511)])) + (0.00481033605f * fVec27[((IOTA - 249) & 511)])) + (0.00579034351f * fVec27[((IOTA - 250) & 511)])) + (0.00610980019f * fVec27[((IOTA - 251) & 511)])) + (0.00563404011f * fVec27[((IOTA - 252) & 511)])) + (0.00464470685f * fVec27[((IOTA - 253) & 511)])) + (0.00383202499f * fVec27[((IOTA - 254) & 511)])) + (0.00330197066f * fVec27[((IOTA - 255) & 511)])) + (0.00339916395f * fVec27[((IOTA - 256) & 511)])) + (0.00471371925f * fVec27[((IOTA - 257) & 511)])) + (0.00608524727f * fVec27[((IOTA - 258) & 511)])) + (0.00626288168f * fVec27[((IOTA - 259) & 511)])) + (0.00568050053f * fVec27[((IOTA - 260) & 511)])) + (0.00472569047f * fVec27[((IOTA - 261) & 511)])) + (0.0036747721f * fVec27[((IOTA - 262) & 511)])) + (0.00337993586f * fVec27[((IOTA - 263) & 511)])) + (0.00397018483f * fVec27[((IOTA - 264) & 511)])) + (0.00495683867f * fVec27[((IOTA - 265) & 511)])) + (0.00550639303f * fVec27[((IOTA - 266) & 511)])) + (0.00536986068f * fVec27[((IOTA - 267) & 511)])) + (0.00497545674f * fVec27[((IOTA - 268) & 511)])) + (0.00413801847f * fVec27[((IOTA - 269) & 511)])) + (0.00316272536f * fVec27[((IOTA - 270) & 511)])) + (0.0029427004f * fVec27[((IOTA - 271) & 511)])) + (0.00308604864f * fVec27[((IOTA - 272) & 511)])) + (0.00301618874f * fVec27[((IOTA - 273) & 511)])) + (0.00238761818f * fVec27[((IOTA - 274) & 511)])) + (0.00117473351f * fVec27[((IOTA - 275) & 511)])) + (0.000126324594f * fVec27[((IOTA - 276) & 511)])) + (0.000618600287f * fVec27[((IOTA - 278) & 511)])) + (0.00226336252f * fVec27[((IOTA - 279) & 511)])) + (0.0040369588f * fVec27[((IOTA - 280) & 511)])) + (0.00473433826f * fVec27[((IOTA - 281) & 511)])) + (0.00406381767f * fVec27[((IOTA - 282) & 511)])) + (0.00261968235f * fVec27[((IOTA - 283) & 511)])) + (0.00100730686f * fVec27[((IOTA - 284) & 511)])) + (1.02417544e-05f * fVec27[((IOTA - 285) & 511)])) + (0.000339906197f * fVec27[((IOTA - 287) & 511)])) + (0.00129895518f * fVec27[((IOTA - 288) & 511)])) + (0.00205201888f * fVec27[((IOTA - 289) & 511)])) + (0.00252594799f * fVec27[((IOTA - 290) & 511)])) + (0.00324367452f * fVec27[((IOTA - 291) & 511)])) + (0.00407853583f * fVec27[((IOTA - 292) & 511)])) + (0.00491268467f * fVec27[((IOTA - 293) & 511)])) + (0.0052904035f * fVec27[((IOTA - 294) & 511)])) + (0.00475566927f * fVec27[((IOTA - 295) & 511)])) + (0.00398205454f * fVec27[((IOTA - 296) & 511)])) + (0.00318097044f * fVec27[((IOTA - 297) & 511)])) + (0.00244676182f * fVec27[((IOTA - 298) & 511)])) + (0.00265369657f * fVec27[((IOTA - 299) & 511)])) + (0.00331760431f * fVec27[((IOTA - 300) & 511)])) + (0.00339529803f * fVec27[((IOTA - 301) & 511)])) + (0.00331621384f * fVec27[((IOTA - 302) & 511)])) + (0.00316686276f * fVec27[((IOTA - 303) & 511)])) + (0.00268106442f * fVec27[((IOTA - 304) & 511)])) + (0.00261513796f * fVec27[((IOTA - 305) & 511)])) + (0.00305308588f * fVec27[((IOTA - 306) & 511)])) + (0.00377749326f * fVec27[((IOTA - 307) & 511)])) + (0.00462551229f * fVec27[((IOTA - 308) & 511)])) + (0.00457152352f * fVec27[((IOTA - 309) & 511)])) + (0.00384854013f * fVec27[((IOTA - 310) & 511)])) + (0.0032959003f * fVec27[((IOTA - 311) & 511)])) + (0.00239792792f * fVec27[((IOTA - 312) & 511)])) + (0.00175097678f * fVec27[((IOTA - 313) & 511)])) + (0.00152928988f * fVec27[((IOTA - 314) & 511)])) + (0.000637387857f * fVec27[((IOTA - 315) & 511)])) + (0.000933106057f * fVec27[((IOTA - 320) & 511)])) + (0.0019121971f * fVec27[((IOTA - 321) & 511)])) + (0.00244425237f * fVec27[((IOTA - 322) & 511)])) + (0.00160742458f * fVec27[((IOTA - 323) & 511)])) + (0.000407392159f * fVec27[((IOTA - 324) & 511)])) + (0.000488748774f * fVec27[((IOTA - 327) & 511)])) + (0.00171197718f * fVec27[((IOTA - 328) & 511)])) + (0.00215755496f * fVec27[((IOTA - 329) & 511)])) + (0.00190409226f * fVec27[((IOTA - 330) & 511)])) + (0.00101303775f * fVec27[((IOTA - 331) & 511)])) + (0.000752215739f * fVec27[((IOTA - 334) & 511)])) + (0.00199416419f * fVec27[((IOTA - 335) & 511)])) + (0.00342514133f * fVec27[((IOTA - 336) & 511)])) + (0.00411743345f * fVec27[((IOTA - 337) & 511)])) + (0.00404716656f * fVec27[((IOTA - 338) & 511)])) + (0.00339773996f * fVec27[((IOTA - 339) & 511)])) + (0.00228181109f * fVec27[((IOTA - 340) & 511)])) + (0.00144396583f * fVec27[((IOTA - 341) & 511)])) + (0.000793826766f * fVec27[((IOTA - 342) & 511)])) + (0.000311690848f * fVec27[((IOTA - 343) & 511)])) + (0.000604526605f * fVec27[((IOTA - 344) & 511)])) + (0.000846391078f * fVec27[((IOTA - 345) & 511)])) + (0.000690427143f * fVec27[((IOTA - 346) & 511)])) + (0.00100313546f * fVec27[((IOTA - 347) & 511)])) + (0.00126605993f * fVec27[((IOTA - 348) & 511)])) + (0.0011971835f * fVec27[((IOTA - 349) & 511)])) + (0.0011884002f * fVec27[((IOTA - 350) & 511)])) + (0.000944500323f * fVec27[((IOTA - 351) & 511)])) + (0.000876776874f * fVec27[((IOTA - 352) & 511)])) + (0.000982719939f * fVec27[((IOTA - 353) & 511)])) + (0.000558846164f * fVec27[((IOTA - 354) & 511)])) + (8.71531665e-06f * fVec27[((IOTA - 355) & 511)])) + (0.000590859447f * fVec27[((IOTA - 368) & 511)])) + (0.000636505894f * fVec27[((IOTA - 369) & 511)])) + (0.000255124643f * fVec27[((IOTA - 370) & 511)])) + (0.000115133356f * fVec27[((IOTA - 380) & 511)])) + (0.000374564901f * fVec27[((IOTA - 381) & 511)])) + (0.00012998702f * fVec27[((IOTA - 489) & 511)])) + (0.000137854833f * fVec27[((IOTA - 490) & 511)])) - (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00143514853f * fVec27[((IOTA - 425) & 511)]) + ((0.00127291027f * fVec27[((IOTA - 424) & 511)]) + ((0.00113135902f * fVec27[((IOTA - 423) & 511)]) + ((0.000870571006f * fVec27[((IOTA - 422) & 511)]) + ((0.000556913204f * fVec27[((IOTA - 421) & 511)]) + ((0.000814784784f * fVec27[((IOTA - 420) & 511)]) + ((0.00125347823f * fVec27[((IOTA - 419) & 511)]) + ((0.00165076461f * fVec27[((IOTA - 418) & 511)]) + ((0.00216867821f * fVec27[((IOTA - 417) & 511)]) + ((0.00221035723f * fVec27[((IOTA - 416) & 511)]) + ((0.00200579595f * fVec27[((IOTA - 415) & 511)]) + ((0.00188476173f * fVec27[((IOTA - 414) & 511)]) + ((0.0013014311f * fVec27[((IOTA - 413) & 511)]) + ((0.000686866231f * fVec27[((IOTA - 412) & 511)]) + ((0.00037337793f * fVec27[((IOTA - 411) & 511)]) + ((0.000322577078f * fVec27[((IOTA - 410) & 511)]) + ((0.00103101181f * fVec27[((IOTA - 409) & 511)]) + ((0.00225878414f * fVec27[((IOTA - 408) & 511)]) + ((0.00334066479f * fVec27[((IOTA - 407) & 511)]) + ((0.00394932879f * fVec27[((IOTA - 406) & 511)]) + ((0.00387258455f * fVec27[((IOTA - 405) & 511)]) + ((0.00321942708f * fVec27[((IOTA - 404) & 511)]) + ((0.00217162864f * fVec27[((IOTA - 403) & 511)]) + ((0.000918489415f * fVec27[((IOTA - 402) & 511)]) + ((0.00018618023f * fVec27[((IOTA - 401) & 511)]) + ((0.000116862822f * fVec27[((IOTA - 400) & 511)]) + ((0.000266960356f * fVec27[((IOTA - 399) & 511)]) + ((0.000997370109f * fVec27[((IOTA - 398) & 511)]) + ((0.00218258239f * fVec27[((IOTA - 397) & 511)]) + ((0.00303012691f * fVec27[((IOTA - 396) & 511)]) + ((0.00357194897f * fVec27[((IOTA - 395) & 511)]) + ((0.00357924029f * fVec27[((IOTA - 394) & 511)]) + ((0.00296423491f * fVec27[((IOTA - 393) & 511)]) + ((0.00234753359f * fVec27[((IOTA - 392) & 511)]) + ((0.00157636032f * fVec27[((IOTA - 391) & 511)]) + ((0.000661601312f * fVec27[((IOTA - 390) & 511)]) + ((0.000229825731f * fVec27[((IOTA - 389) & 511)]) + ((0.000110385474f * fVec27[((IOTA - 388) & 511)]) + ((0.000255260151f * fVec27[((IOTA - 387) & 511)]) + ((0.000807968434f * fVec27[((IOTA - 386) & 511)]) + ((0.000953962095f * fVec27[((IOTA - 385) & 511)]) + ((0.000691885594f * fVec27[((IOTA - 384) & 511)]) + ((0.000495497137f * fVec27[((IOTA - 383) & 511)]) + ((2.42134556e-05f * fVec27[((IOTA - 382) & 511)]) + ((0.000577328727f * fVec27[((IOTA - 379) & 511)]) + ((0.00147306267f * fVec27[((IOTA - 378) & 511)]) + ((0.00202610996f * fVec27[((IOTA - 377) & 511)]) + ((0.00203374028f * fVec27[((IOTA - 376) & 511)]) + ((((0.0017724433f * fVec27[((IOTA - 373) & 511)]) + ((0.00147580961f * fVec27[((IOTA - 372) & 511)]) + ((0.000603916124f * fVec27[((IOTA - 371) & 511)]) + ((0.000135650393f * fVec27[((IOTA - 367) & 511)]) + ((0.00126195652f * fVec27[((IOTA - 366) & 511)]) + ((0.00199324824f * fVec27[((IOTA - 365) & 511)]) + ((0.00221527461f * fVec27[((IOTA - 364) & 511)]) + ((0.0019732737f * fVec27[((IOTA - 363) & 511)]) + ((0.00147418166f * fVec27[((IOTA - 362) & 511)]) + ((0.00138929859f * fVec27[((IOTA - 361) & 511)]) + ((0.00177535973f * fVec27[((IOTA - 360) & 511)]) + ((0.00230975496f * fVec27[((IOTA - 359) & 511)]) + ((0.00249410421f * fVec27[((IOTA - 358) & 511)]) + ((0.00180561002f * fVec27[((IOTA - 357) & 511)]) + ((0.000691648107f * fVec27[((IOTA - 356) & 511)]) + (((((((((0.000513844192f * fVec27[((IOTA - 316) & 511)]) + ((0.000136294868f * fVec27[((IOTA - 286) & 511)]) + ((0.000118456781f * fVec27[((IOTA - 277) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00977243111f * fVec27[((IOTA - 49) & 511)]) + ((0.0208768155f * fVec27[((IOTA - 48) & 511)]) + ((0.0139826164f * fVec27[((IOTA - 47) & 511)]) + ((0.0112495637f * fVec27[((IOTA - 42) & 511)]) + ((0.0331387743f * fVec27[((IOTA - 41) & 511)]) + ((0.0380983576f * fVec27[((IOTA - 40) & 511)]) + ((0.01761025f * fVec27[((IOTA - 39) & 511)]) + ((0.00480416417f * fVec27[((IOTA - 35) & 511)]) + ((0.0107042827f * fVec27[((IOTA - 34) & 511)]) + ((0.00893336535f * fVec27[((IOTA - 33) & 511)]) + ((0.0216976032f * fVec27[((IOTA - 29) & 511)]) + ((0.0499450229f * fVec27[((IOTA - 28) & 511)]) + ((0.0691497773f * fVec27[((IOTA - 27) & 511)]) + ((0.0494397245f * fVec27[((IOTA - 26) & 511)]) + ((0.0259427503f * fVec27[((IOTA - 20) & 511)]) + ((0.0278262924f * fVec27[((IOTA - 19) & 511)]) + ((0.0237451121f * fVec27[((IOTA - 18) & 511)]) + ((0.0188869573f * fVec27[((IOTA - 17) & 511)]) + ((0.0185178537f * fVec27[((IOTA - 16) & 511)]) + ((0.0413153768f * fVec27[((IOTA - 15) & 511)]) + ((0.0435899645f * fVec27[((IOTA - 14) & 511)]) + ((0.136131376f * fVec27[((IOTA - 8) & 511)]) + ((0.242034882f * fVec27[((IOTA - 7) & 511)]) + ((0.274807423f * fVec27[((IOTA - 6) & 511)]) + ((0.163784891f * fVec27[((IOTA - 5) & 511)]) + ((0.00433532195f * fVec27[((IOTA - 53) & 511)]) + (0.0181979891f * fVec27[((IOTA - 54) & 511)]))))))))))))))))))))))))))) + (0.0196488723f * fVec27[((IOTA - 55) & 511)])) + (0.0143990628f * fVec27[((IOTA - 56) & 511)])) + (0.00879405253f * fVec27[((IOTA - 57) & 511)])) + (0.00266878773f * fVec27[((IOTA - 58) & 511)])) + (0.00512877572f * fVec27[((IOTA - 59) & 511)])) + (0.00455063349f * fVec27[((IOTA - 60) & 511)])) + (0.0110192634f * fVec27[((IOTA - 65) & 511)])) + (0.0396033004f * fVec27[((IOTA - 66) & 511)])) + (0.0510529801f * fVec27[((IOTA - 67) & 511)])) + (0.0396486074f * fVec27[((IOTA - 68) & 511)])) + (0.0128743174f * fVec27[((IOTA - 69) & 511)])) + (0.0078883823f * fVec27[((IOTA - 74) & 511)])) + (0.00896283612f * fVec27[((IOTA - 75) & 511)])) + (0.00293439161f * fVec27[((IOTA - 76) & 511)])) + (0.00250461698f * fVec27[((IOTA - 79) & 511)])) + (0.00864066556f * fVec27[((IOTA - 80) & 511)])) + (0.0122923767f * fVec27[((IOTA - 81) & 511)])) + (0.0091818776f * fVec27[((IOTA - 82) & 511)])) + (0.0027048029f * fVec27[((IOTA - 83) & 511)])) + (0.00176359201f * fVec27[((IOTA - 84) & 511)])) + (0.00847100094f * fVec27[((IOTA - 85) & 511)])) + (0.0161459371f * fVec27[((IOTA - 86) & 511)])) + (0.0209227335f * fVec27[((IOTA - 87) & 511)])) + (0.0213333126f * fVec27[((IOTA - 88) & 511)])) + (0.0167839676f * fVec27[((IOTA - 89) & 511)])) + (0.00719564874f * fVec27[((IOTA - 90) & 511)])) + (0.000304942485f * fVec27[((IOTA - 91) & 511)])) + (0.00295931753f * fVec27[((IOTA - 99) & 511)])) + (0.0126187522f * fVec27[((IOTA - 100) & 511)])) + (0.0203304496f * fVec27[((IOTA - 101) & 511)])) + (0.020553086f * fVec27[((IOTA - 102) & 511)])) + (0.0164960846f * fVec27[((IOTA - 103) & 511)])) + (0.00921229646f * fVec27[((IOTA - 104) & 511)])) + (0.00162885711f * fVec27[((IOTA - 105) & 511)])) + (0.00566235697f * fVec27[((IOTA - 112) & 511)])) + (0.0125427879f * fVec27[((IOTA - 113) & 511)])) + (0.0171591099f * fVec27[((IOTA - 114) & 511)])) + (0.0169717763f * fVec27[((IOTA - 115) & 511)])) + (0.0132313157f * fVec27[((IOTA - 116) & 511)])) + (0.00705918437f * fVec27[((IOTA - 117) & 511)])) + (0.00100669637f * fVec27[((IOTA - 118) & 511)])) + (0.000415632967f * fVec27[((IOTA - 121) & 511)])) + (0.00292228488f * fVec27[((IOTA - 122) & 511)])) + (0.00460441876f * fVec27[((IOTA - 123) & 511)])) + (0.00538135692f * fVec27[((IOTA - 124) & 511)])) + (0.00530956406f * fVec27[((IOTA - 125) & 511)])) + (0.00346719287f * fVec27[((IOTA - 126) & 511)])) + (0.00105546275f * fVec27[((IOTA - 127) & 511)])) + (0.000669469126f * fVec27[((IOTA - 132) & 511)])) + (0.00460777618f * fVec27[((IOTA - 133) & 511)])) + (0.00546356104f * fVec27[((IOTA - 134) & 511)])) + (0.0041763396f * fVec27[((IOTA - 135) & 511)])) + (0.00208328664f * fVec27[((IOTA - 136) & 511)])) + (0.00107862474f * fVec27[((IOTA - 137) & 511)])) + (0.00182480458f * fVec27[((IOTA - 138) & 511)])) + (0.0021340875f * fVec27[((IOTA - 139) & 511)])) + (0.00186068378f * fVec27[((IOTA - 140) & 511)])) + (0.00165208755f * fVec27[((IOTA - 141) & 511)])) + (0.0012196335f * fVec27[((IOTA - 142) & 511)])) + (0.00136959506f * fVec27[((IOTA - 143) & 511)])) + (0.00263267104f * fVec27[((IOTA - 144) & 511)])) + (0.00405991776f * fVec27[((IOTA - 145) & 511)])) + (0.00450512255f * fVec27[((IOTA - 146) & 511)])) + (0.00271975854f * fVec27[((IOTA - 147) & 511)])) + (0.00024247542f * fVec27[((IOTA - 154) & 511)])) + (0.000877929851f * fVec27[((IOTA - 155) & 511)])) + (0.00151938712f * fVec27[((IOTA - 156) & 511)])) + (0.00239986088f * fVec27[((IOTA - 157) & 511)])) + (0.00374378404f * fVec27[((IOTA - 158) & 511)])) + (0.00445666164f * fVec27[((IOTA - 159) & 511)])) + (0.00358164776f * fVec27[((IOTA - 160) & 511)])) + (0.00144206639f * fVec27[((IOTA - 161) & 511)])) + (0.000265603885f * fVec27[((IOTA - 166) & 511)])) + (0.000357676297f * fVec27[((IOTA - 167) & 511)])) + (0.000342348125f * fVec27[((IOTA - 172) & 511)])) + (0.000151352026f * fVec27[((IOTA - 173) & 511)])) + (0.00025095325f * fVec27[((IOTA - 178) & 511)])) + (0.00143813249f * fVec27[((IOTA - 179) & 511)])) + (0.000820143148f * fVec27[((IOTA - 180) & 511)])) + (0.000856259838f * fVec27[((IOTA - 186) & 511)])) + (0.00340520078f * fVec27[((IOTA - 187) & 511)])) + (0.00354749803f * fVec27[((IOTA - 188) & 511)])) + (0.00122719631f * fVec27[((IOTA - 189) & 511)])) + (0.000390877016f * fVec27[((IOTA - 198) & 511)])) + (0.000515573658f * fVec27[((IOTA - 199) & 511)])) + (0.00250573596f * fVec27[((IOTA - 213) & 511)])) + (0.00364696374f * fVec27[((IOTA - 214) & 511)])) + (0.00286751613f * fVec27[((IOTA - 215) & 511)])) + (0.0012536142f * fVec27[((IOTA - 317) & 511)]))))) + (0.00126589043f * fVec27[((IOTA - 318) & 511)])) + (0.000239321496f * fVec27[((IOTA - 319) & 511)])) + (0.000108588021f * fVec27[((IOTA - 325) & 511)])) + (0.000220262446f * fVec27[((IOTA - 326) & 511)])) + (5.69731928e-05f * fVec27[((IOTA - 332) & 511)])) + (9.44468193e-05f * fVec27[((IOTA - 333) & 511)])) + (0.00193549506f * fVec27[((IOTA - 374) & 511)]))))))))))))))))) + (0.00200315099f * fVec27[((IOTA - 375) & 511)])) + (0.00141734444f * fVec27[((IOTA - 426) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00143416505f * fVec27[((IOTA - 427) & 511)])) + (0.00143586053f * fVec27[((IOTA - 428) & 511)])) + (0.00144196488f * fVec27[((IOTA - 429) & 511)])) + (0.00186173525f * fVec27[((IOTA - 430) & 511)])) + (0.00223562215f * fVec27[((IOTA - 431) & 511)])) + (0.00218454935f * fVec27[((IOTA - 432) & 511)])) + (0.00222290494f * fVec27[((IOTA - 433) & 511)])) + (0.00229242584f * fVec27[((IOTA - 434) & 511)])) + (0.00233444339f * fVec27[((IOTA - 435) & 511)])) + (0.0027996907f * fVec27[((IOTA - 436) & 511)])) + (0.00339662051f * fVec27[((IOTA - 437) & 511)])) + (0.00399232982f * fVec27[((IOTA - 438) & 511)])) + (0.00444160448f * fVec27[((IOTA - 439) & 511)])) + (0.00436760671f * fVec27[((IOTA - 440) & 511)])) + (0.00417216867f * fVec27[((IOTA - 441) & 511)])) + (0.00369820558f * fVec27[((IOTA - 442) & 511)])) + (0.00265074661f * fVec27[((IOTA - 443) & 511)])) + (0.0019644564f * fVec27[((IOTA - 444) & 511)])) + (0.00166633073f * fVec27[((IOTA - 445) & 511)])) + (0.00135274092f * fVec27[((IOTA - 446) & 511)])) + (0.00145793753f * fVec27[((IOTA - 447) & 511)])) + (0.00166660221f * fVec27[((IOTA - 448) & 511)])) + (0.00188618619f * fVec27[((IOTA - 449) & 511)])) + (0.0023899246f * fVec27[((IOTA - 450) & 511)])) + (0.00251601171f * fVec27[((IOTA - 451) & 511)])) + (0.00235960633f * fVec27[((IOTA - 452) & 511)])) + (0.00238168379f * fVec27[((IOTA - 453) & 511)])) + (0.0021644053f * fVec27[((IOTA - 454) & 511)])) + (0.00224416796f * fVec27[((IOTA - 455) & 511)])) + (0.00286714267f * fVec27[((IOTA - 456) & 511)])) + (0.00308357319f * fVec27[((IOTA - 457) & 511)])) + (0.00285473093f * fVec27[((IOTA - 458) & 511)])) + (0.00229707174f * fVec27[((IOTA - 459) & 511)])) + (0.00130346557f * fVec27[((IOTA - 460) & 511)])) + (0.000666620675f * fVec27[((IOTA - 461) & 511)])) + (0.00080647599f * fVec27[((IOTA - 462) & 511)])) + (0.00157164689f * fVec27[((IOTA - 463) & 511)])) + (0.00263568899f * fVec27[((IOTA - 464) & 511)])) + (0.00311460346f * fVec27[((IOTA - 465) & 511)])) + (0.00273254374f * fVec27[((IOTA - 466) & 511)])) + (0.00203926768f * fVec27[((IOTA - 467) & 511)])) + (0.00130848493f * fVec27[((IOTA - 468) & 511)])) + (0.000806306489f * fVec27[((IOTA - 469) & 511)])) + (0.00102311f * fVec27[((IOTA - 470) & 511)])) + (0.00159240142f * fVec27[((IOTA - 471) & 511)])) + (0.00198490592f * fVec27[((IOTA - 472) & 511)])) + (0.00223168824f * fVec27[((IOTA - 473) & 511)])) + (0.00228401506f * fVec27[((IOTA - 474) & 511)])) + (0.00233766483f * fVec27[((IOTA - 475) & 511)])) + (0.00239470601f * fVec27[((IOTA - 476) & 511)])) + (0.00228482904f * fVec27[((IOTA - 477) & 511)])) + (0.00228971243f * fVec27[((IOTA - 478) & 511)])) + (0.00216847518f * fVec27[((IOTA - 479) & 511)])) + (0.00169783551f * fVec27[((IOTA - 480) & 511)])) + (0.0015155552f * fVec27[((IOTA - 481) & 511)])) + (0.00178041263f * fVec27[((IOTA - 482) & 511)])) + (0.00226407452f * fVec27[((IOTA - 483) & 511)])) + (0.00262287026f * fVec27[((IOTA - 484) & 511)])) + (0.00252354005f * fVec27[((IOTA - 485) & 511)])) + (0.00226275204f * fVec27[((IOTA - 486) & 511)])) + (0.00152318552f * fVec27[((IOTA - 487) & 511)])) + (0.000381890219f * fVec27[((IOTA - 488) & 511)])) + (0.000246849842f * fVec27[((IOTA - 491) & 511)])) + (0.00117846392f * fVec27[((IOTA - 492) & 511)])) + (0.00172106549f * fVec27[((IOTA - 493) & 511)])) + (0.001741549f * fVec27[((IOTA - 494) & 511)])) + (0.00167914992f * fVec27[((IOTA - 495) & 511)])) + (0.00129681872f * fVec27[((IOTA - 496) & 511)])) + (0.00132052368f * fVec27[((IOTA - 497) & 511)])) + (0.00193671603f * fVec27[((IOTA - 498) & 511)])) + (0.00226105656f * fVec27[((IOTA - 499) & 511)])) + (0.00258414214f * fVec27[((IOTA - 500) & 511)])) + (0.00296528591f * fVec27[((IOTA - 501) & 511)])) + (0.00277791871f * fVec27[((IOTA - 502) & 511)])) + (0.00259750336f * fVec27[((IOTA - 503) & 511)])) + (0.00258203922f * fVec27[((IOTA - 504) & 511)])) + (0.00240728771f * fVec27[((IOTA - 505) & 511)])) + (0.00225271378f * fVec27[((IOTA - 506) & 511)])) + (0.00200006505f * fVec27[((IOTA - 507) & 511)])) + (0.00173154473f * fVec27[((IOTA - 508) & 511)])) + (0.00190938264f * fVec27[((IOTA - 509) & 511)])) + (0.00208189618f * fVec27[((IOTA - 510) & 511)])) + (0.00231870776f * fVec27[((IOTA - 511) & 511)]))) : (((((((((((((((((((((((((((((((((((((((5.56604937e-05f * fVec26[((IOTA - 394) & 511)]) + ((0.00100968825f * fVec26[((IOTA - 393) & 511)]) + ((0.00146831153f * fVec26[((IOTA - 392) & 511)]) + ((0.00109077198f * fVec26[((IOTA - 391) & 511)]) + ((0.00128581887f * fVec26[((IOTA - 390) & 511)]) + ((0.00156317605f * fVec26[((IOTA - 389) & 511)]) + ((0.00166899059f * fVec26[((IOTA - 388) & 511)]) + ((0.00259029586f * fVec26[((IOTA - 387) & 511)]) + ((0.00303472858f * fVec26[((IOTA - 386) & 511)]) + ((0.00237709377f * fVec26[((IOTA - 385) & 511)]) + ((0.0022271038f * fVec26[((IOTA - 384) & 511)]) + ((0.0019345805f * fVec26[((IOTA - 383) & 511)]) + ((0.00168849854f * fVec26[((IOTA - 382) & 511)]) + ((0.00244600046f * fVec26[((IOTA - 381) & 511)]) + ((0.00333628198f * fVec26[((IOTA - 380) & 511)]) + ((0.00420290232f * fVec26[((IOTA - 379) & 511)]) + ((0.00507395901f * fVec26[((IOTA - 378) & 511)]) + ((0.00471863337f * fVec26[((IOTA - 377) & 511)]) + ((0.00374978548f * fVec26[((IOTA - 376) & 511)]) + ((0.00245764246f * fVec26[((IOTA - 375) & 511)]) + ((0.000586588401f * fVec26[((IOTA - 374) & 511)]) + ((0.00104798051f * fVec26[((IOTA - 369) & 511)]) + ((0.0022778241f * fVec26[((IOTA - 368) & 511)]) + ((0.00306616118f * fVec26[((IOTA - 367) & 511)]) + ((0.00218450138f * fVec26[((IOTA - 366) & 511)]) + ((0.000888834242f * fVec26[((IOTA - 365) & 511)]) + ((0.000258888118f * fVec26[((IOTA - 364) & 511)]) + ((0.000376281328f * fVec26[((IOTA - 363) & 511)]) + ((0.00167839834f * fVec26[((IOTA - 362) & 511)]) + ((0.00323433802f * fVec26[((IOTA - 361) & 511)]) + ((0.00381139247f * fVec26[((IOTA - 360) & 511)]) + ((0.00372250611f * fVec26[((IOTA - 359) & 511)]) + ((0.0031751222f * fVec26[((IOTA - 358) & 511)]) + ((0.0017333664f * fVec26[((IOTA - 357) & 511)]) + ((0.000369925518f * fVec26[((IOTA - 356) & 511)]) + ((0.000114466995f * fVec26[((IOTA - 355) & 511)]) + ((0.000754072797f * fVec26[((IOTA - 354) & 511)]) + ((0.00204552338f * fVec26[((IOTA - 353) & 511)]) + ((0.00313148135f * fVec26[((IOTA - 352) & 511)]) + ((0.00392453792f * fVec26[((IOTA - 351) & 511)]) + ((0.00486352621f * fVec26[((IOTA - 350) & 511)]) + ((0.00504224328f * fVec26[((IOTA - 349) & 511)]) + ((0.00476309238f * fVec26[((IOTA - 348) & 511)]) + ((0.00291887717f * fVec26[((IOTA - 346) & 511)]) + ((0.00225699507f * fVec26[((IOTA - 345) & 511)]) + ((0.0025155684f * fVec26[((IOTA - 344) & 511)]) + ((0.00282580592f * fVec26[((IOTA - 343) & 511)]) + ((0.00379949901f * fVec26[((IOTA - 342) & 511)]) + ((0.0048621418f * fVec26[((IOTA - 341) & 511)]) + ((0.00542506902f * fVec26[((IOTA - 340) & 511)]) + ((0.00633986108f * fVec26[((IOTA - 339) & 511)]) + ((0.0071064881f * fVec26[((IOTA - 338) & 511)]) + ((0.00716010295f * fVec26[((IOTA - 337) & 511)]) + ((0.00734508131f * fVec26[((IOTA - 336) & 511)]) + ((0.00665437803f * fVec26[((IOTA - 335) & 511)]) + ((0.00550911017f * fVec26[((IOTA - 334) & 511)]) + ((0.00436406257f * fVec26[((IOTA - 333) & 511)]) + ((0.00292098522f * fVec26[((IOTA - 332) & 511)]) + ((0.00196248945f * fVec26[((IOTA - 331) & 511)]) + ((0.0015528244f * fVec26[((IOTA - 330) & 511)]) + ((0.000935558695f * fVec26[((IOTA - 329) & 511)]) + ((0.0013091336f * fVec26[((IOTA - 328) & 511)]) + ((0.00228814455f * fVec26[((IOTA - 327) & 511)]) + ((0.00245037442f * fVec26[((IOTA - 326) & 511)]) + ((0.00282731606f * fVec26[((IOTA - 325) & 511)]) + ((0.00262553571f * fVec26[((IOTA - 324) & 511)]) + ((0.00151553936f * fVec26[((IOTA - 323) & 511)]) + ((0.00124787306f * fVec26[((IOTA - 322) & 511)]) + ((0.000908751041f * fVec26[((IOTA - 321) & 511)]) + ((0.000779621769f * fVec26[((IOTA - 320) & 511)]) + ((0.00165259792f * fVec26[((IOTA - 319) & 511)]) + ((0.00202865852f * fVec26[((IOTA - 318) & 511)]) + ((0.00224066479f * fVec26[((IOTA - 317) & 511)]) + ((0.00243656151f * fVec26[((IOTA - 316) & 511)]) + ((0.00229934556f * fVec26[((IOTA - 315) & 511)]) + ((0.00347189326f * fVec26[((IOTA - 314) & 511)]) + ((0.00524216704f * fVec26[((IOTA - 313) & 511)]) + ((0.00673225196f * fVec26[((IOTA - 312) & 511)]) + ((0.00854846369f * fVec26[((IOTA - 311) & 511)]) + ((0.00916963164f * fVec26[((IOTA - 310) & 511)]) + ((0.00826987997f * fVec26[((IOTA - 309) & 511)]) + ((0.00716211693f * fVec26[((IOTA - 308) & 511)]) + ((0.00534713222f * fVec26[((IOTA - 307) & 511)]) + ((0.00442522904f * fVec26[((IOTA - 306) & 511)]) + ((0.00528461253f * fVec26[((IOTA - 305) & 511)]) + ((0.00626900373f * fVec26[((IOTA - 304) & 511)]) + ((0.00750016887f * fVec26[((IOTA - 303) & 511)]) + ((0.00905041397f * fVec26[((IOTA - 302) & 511)]) + ((0.00986659713f * fVec26[((IOTA - 301) & 511)]) + ((0.00978198927f * fVec26[((IOTA - 300) & 511)]) + ((0.00879980065f * fVec26[((IOTA - 299) & 511)]) + ((0.00710469438f * fVec26[((IOTA - 298) & 511)]) + ((0.0059026964f * fVec26[((IOTA - 297) & 511)]) + ((0.00468927715f * fVec26[((IOTA - 296) & 511)]) + ((0.00360791339f * fVec26[((IOTA - 295) & 511)]) + ((0.00352251902f * fVec26[((IOTA - 294) & 511)]) + ((0.00377866952f * fVec26[((IOTA - 293) & 511)]) + ((0.00420781085f * fVec26[((IOTA - 292) & 511)]) + ((0.00481060334f * fVec26[((IOTA - 291) & 511)]) + ((0.00495033618f * fVec26[((IOTA - 290) & 511)]) + ((0.0057139108f * fVec26[((IOTA - 289) & 511)]) + ((0.00700054783f * fVec26[((IOTA - 288) & 511)]) + ((0.00723162154f * fVec26[((IOTA - 287) & 511)]) + ((0.00676818425f * fVec26[((IOTA - 286) & 511)]) + ((0.00564714381f * fVec26[((IOTA - 285) & 511)]) + ((0.00384634919f * fVec26[((IOTA - 284) & 511)]) + ((0.00236652186f * fVec26[((IOTA - 283) & 511)]) + ((0.00184087968f * fVec26[((IOTA - 282) & 511)]) + ((0.00266247476f * fVec26[((IOTA - 281) & 511)]) + ((0.00449070614f * fVec26[((IOTA - 280) & 511)]) + ((0.00590845477f * fVec26[((IOTA - 279) & 511)]) + ((0.00663323374f * fVec26[((IOTA - 278) & 511)]) + ((0.00625239033f * fVec26[((IOTA - 277) & 511)]) + ((0.00430047326f * fVec26[((IOTA - 276) & 511)]) + ((0.00258268137f * fVec26[((IOTA - 275) & 511)]) + ((0.00220740726f * fVec26[((IOTA - 274) & 511)]) + ((0.00308664469f * fVec26[((IOTA - 273) & 511)]) + ((0.00524119195f * fVec26[((IOTA - 272) & 511)]) + ((0.00731789647f * fVec26[((IOTA - 271) & 511)]) + ((0.00425868854f * fVec26[((IOTA - 347) & 511)]) + ((0.0085111782f * fVec26[((IOTA - 270) & 511)]) + ((0.00888994522f * fVec26[((IOTA - 269) & 511)]) + ((0.00840048678f * fVec26[((IOTA - 268) & 511)]) + ((0.00788862631f * fVec26[((IOTA - 267) & 511)]) + ((0.00792084634f * fVec26[((IOTA - 266) & 511)]) + ((0.00802448951f * fVec26[((IOTA - 265) & 511)]) + ((0.00808559358f * fVec26[((IOTA - 264) & 511)]) + ((0.00797357969f * fVec26[((IOTA - 263) & 511)]) + ((0.00742462324f * fVec26[((IOTA - 262) & 511)]) + ((0.0072284434f * fVec26[((IOTA - 261) & 511)]) + ((0.00719817495f * fVec26[((IOTA - 260) & 511)]) + ((0.00685880147f * fVec26[((IOTA - 259) & 511)]) + ((0.00732009904f * fVec26[((IOTA - 258) & 511)]) + ((0.00810390525f * fVec26[((IOTA - 257) & 511)]) + ((0.00782296062f * fVec26[((IOTA - 256) & 511)]) + ((0.00743126217f * fVec26[((IOTA - 255) & 511)]) + ((0.00710286945f * fVec26[((IOTA - 254) & 511)]) + ((0.00653506536f * fVec26[((IOTA - 253) & 511)]) + ((0.00587598328f * fVec26[((IOTA - 252) & 511)]) + ((0.00433986634f * fVec26[((IOTA - 251) & 511)]) + ((0.00233873911f * fVec26[((IOTA - 250) & 511)]) + ((0.00111990748f * fVec26[((IOTA - 249) & 511)]) + ((0.000550876372f * fVec26[((IOTA - 248) & 511)]) + ((0.000666444656f * fVec26[((IOTA - 247) & 511)]) + ((0.001532719f * fVec26[((IOTA - 246) & 511)]) + ((0.00234260922f * fVec26[((IOTA - 245) & 511)]) + ((0.00278354948f * fVec26[((IOTA - 244) & 511)]) + ((0.00314913271f * fVec26[((IOTA - 243) & 511)]) + ((0.00303063821f * fVec26[((IOTA - 242) & 511)]) + ((0.00350187859f * fVec26[((IOTA - 241) & 511)]) + ((0.00392664596f * fVec26[((IOTA - 240) & 511)]) + ((0.00340270298f * fVec26[((IOTA - 239) & 511)]) + ((0.00318050245f * fVec26[((IOTA - 238) & 511)]) + ((0.0022653956f * fVec26[((IOTA - 237) & 511)]) + ((0.00194858201f * fVec26[((IOTA - 236) & 511)]) + ((0.00361483544f * fVec26[((IOTA - 235) & 511)]) + ((0.00523049384f * fVec26[((IOTA - 234) & 511)]) + ((0.00639407383f * fVec26[((IOTA - 233) & 511)]) + ((0.00761595741f * fVec26[((IOTA - 232) & 511)]) + ((0.00685408153f * fVec26[((IOTA - 231) & 511)]) + ((0.00430157455f * fVec26[((IOTA - 230) & 511)]) + ((0.000725030899f * fVec26[((IOTA - 229) & 511)]) + ((0.00493233837f * fVec26[((IOTA - 223) & 511)]) + ((0.00804953463f * fVec26[((IOTA - 222) & 511)]) + ((0.00914691389f * fVec26[((IOTA - 221) & 511)]) + ((0.00770056481f * fVec26[((IOTA - 220) & 511)]) + ((0.00370350154f * fVec26[((IOTA - 219) & 511)]) + ((0.000768735074f * fVec26[((IOTA - 211) & 511)]) + ((0.00342749711f * fVec26[((IOTA - 210) & 511)]) + ((0.00498214643f * fVec26[((IOTA - 209) & 511)]) + ((0.00517014554f * fVec26[((IOTA - 208) & 511)]) + ((0.00465365965f * fVec26[((IOTA - 207) & 511)]) + ((0.00297252368f * fVec26[((IOTA - 206) & 511)]) + ((0.000887827016f * fVec26[((IOTA - 205) & 511)]) + ((0.00192111358f * fVec26[((IOTA - 197) & 511)]) + ((0.00352157513f * fVec26[((IOTA - 196) & 511)]) + ((0.00418062555f * fVec26[((IOTA - 195) & 511)]) + ((0.00383842038f * fVec26[((IOTA - 194) & 511)]) + ((0.00354932668f * fVec26[((IOTA - 193) & 511)]) + ((0.0037012361f * fVec26[((IOTA - 192) & 511)]) + ((0.00344738225f * fVec26[((IOTA - 191) & 511)]) + ((0.00290934369f * fVec26[((IOTA - 190) & 511)]) + ((0.00173034612f * fVec26[((IOTA - 189) & 511)]) + ((0.000115348026f * fVec26[((IOTA - 188) & 511)]) + ((2.31890008e-05f * fVec26[((IOTA - 185) & 511)]) + ((0.000621985644f * fVec26[((IOTA - 184) & 511)]) + ((0.00126228342f * fVec26[((IOTA - 183) & 511)]) + ((0.000446887221f * fVec26[((IOTA - 182) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((0.000664494f * fVec26[((IOTA - 19) & 511)]) + ((0.0229591615f * fVec26[((IOTA - 18) & 511)]) + ((0.0325090699f * fVec26[((IOTA - 17) & 511)]) + ((0.0098824231f * fVec26[((IOTA - 16) & 511)]) + ((0.0123794898f * fVec26[((IOTA - 13) & 511)]) + ((0.0823037252f * fVec26[((IOTA - 12) & 511)]) + ((0.117220253f * fVec26[((IOTA - 11) & 511)]) + ((0.0875141472f * fVec26[((IOTA - 10) & 511)]) + ((0.06181366f * fVec26[((IOTA - 4) & 511)]) + ((0.224619254f * fVec26[((IOTA - 3) & 511)]) + ((0.230688453f * fVec26[((IOTA - 2) & 511)]) + ((0.254967421f * fVec26[((IOTA - 1) & 511)]) + ((fSlow85 * fTemp0) + (((0.0412507877f * fVec26[((IOTA - 25) & 511)]) + (((0.0216402113f * fVec26[((IOTA - 23) & 511)]) + (0.040264383f * fVec26[((IOTA - 24) & 511)])) + (0.0108402893f * fVec26[((IOTA - 26) & 511)]))) + (0.00228698039f * fVec26[((IOTA - 27) & 511)]))))))))))))))) + (0.00694170967f * fVec26[((IOTA - 35) & 511)])) + (0.0260739028f * fVec26[((IOTA - 36) & 511)])) + (0.0256772656f * fVec26[((IOTA - 37) & 511)])) + (0.011862658f * fVec26[((IOTA - 38) & 511)])) + (0.0095907487f * fVec26[((IOTA - 42) & 511)])) + (0.00432809861f * fVec26[((IOTA - 43) & 511)])) + (0.035559278f * fVec26[((IOTA - 49) & 511)])) + (0.0395306684f * fVec26[((IOTA - 50) & 511)])) + (0.0208970867f * fVec26[((IOTA - 51) & 511)])) + (0.0122970222f * fVec26[((IOTA - 58) & 511)])) + (0.010844348f * fVec26[((IOTA - 59) & 511)])) + (0.010898184f * fVec26[((IOTA - 60) & 511)])) + (0.000991407782f * fVec26[((IOTA - 61) & 511)])) + (0.000626862515f * fVec26[((IOTA - 62) & 511)])) + (0.00552754803f * fVec26[((IOTA - 63) & 511)])) + (0.00600656029f * fVec26[((IOTA - 72) & 511)])) + (0.0130889155f * fVec26[((IOTA - 73) & 511)])) + (0.0145529788f * fVec26[((IOTA - 74) & 511)])) + (0.00506231748f * fVec26[((IOTA - 75) & 511)])) + (0.00688183308f * fVec26[((IOTA - 96) & 511)])) + (0.0146748405f * fVec26[((IOTA - 97) & 511)])) + (0.0147471447f * fVec26[((IOTA - 98) & 511)])) + (0.00727302814f * fVec26[((IOTA - 99) & 511)])) + (0.00500234636f * fVec26[((IOTA - 108) & 511)])) + (0.0119445287f * fVec26[((IOTA - 109) & 511)])) + (0.0134213036f * fVec26[((IOTA - 110) & 511)])) + (0.00679659657f * fVec26[((IOTA - 111) & 511)])) + (0.00161836483f * fVec26[((IOTA - 130) & 511)])) + (0.00464038178f * fVec26[((IOTA - 131) & 511)])) + (0.00368946837f * fVec26[((IOTA - 132) & 511)])) + (0.00122210383f * fVec26[((IOTA - 133) & 511)])) + (0.00210058596f * fVec26[((IOTA - 147) & 511)])) + (0.00609481754f * fVec26[((IOTA - 148) & 511)])) + (0.00833887979f * fVec26[((IOTA - 149) & 511)])) + (0.00776572712f * fVec26[((IOTA - 150) & 511)])) + (0.00365331629f * fVec26[((IOTA - 151) & 511)])) + (0.00192410266f * fVec26[((IOTA - 172) & 511)])) + (0.00329185463f * fVec26[((IOTA - 173) & 511)])) + (0.00293089636f * fVec26[((IOTA - 174) & 511)])) + (0.00125473225f * fVec26[((IOTA - 175) & 511)])) + (0.000830027275f * fVec26[((IOTA - 399) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00281284237f * fVec26[((IOTA - 400) & 511)])) + (0.00381107815f * fVec26[((IOTA - 401) & 511)])) + (0.00316904951f * fVec26[((IOTA - 402) & 511)])) + (0.00181680964f * fVec26[((IOTA - 403) & 511)])) + (0.0017698966f * fVec26[((IOTA - 409) & 511)])) + (0.00263742916f * fVec26[((IOTA - 410) & 511)])) + (0.00288105709f * fVec26[((IOTA - 411) & 511)])) + (0.00231026392f * fVec26[((IOTA - 412) & 511)])) + (0.00117934356f * fVec26[((IOTA - 413) & 511)])) + (0.000684158877f * fVec26[((IOTA - 414) & 511)])) + (0.000646653585f * fVec26[((IOTA - 417) & 511)])) + (0.000829838682f * fVec26[((IOTA - 418) & 511)])) + (0.000494051725f * fVec26[((IOTA - 419) & 511)])) + (5.95618039e-05f * fVec26[((IOTA - 420) & 511)])) + (0.000922406558f * fVec26[((IOTA - 423) & 511)])) + (0.00186438393f * fVec26[((IOTA - 424) & 511)])) + (0.00281740492f * fVec26[((IOTA - 425) & 511)])) + (0.00286466442f * fVec26[((IOTA - 426) & 511)])) + (0.0020201318f * fVec26[((IOTA - 427) & 511)])) + (0.000891005155f * fVec26[((IOTA - 428) & 511)])) + (0.000366401393f * fVec26[((IOTA - 448) & 511)])) + (0.000537818763f * fVec26[((IOTA - 449) & 511)])) + (0.000182775781f * fVec26[((IOTA - 450) & 511)])) + (0.000571013428f * fVec26[((IOTA - 461) & 511)])) + (0.000915264245f * fVec26[((IOTA - 462) & 511)])) + (0.000175161753f * fVec26[((IOTA - 469) & 511)])) + (0.00143524259f * fVec26[((IOTA - 470) & 511)])) + (0.00198747171f * fVec26[((IOTA - 471) & 511)])) + (0.00166637916f * fVec26[((IOTA - 472) & 511)])) + (0.000816749409f * fVec26[((IOTA - 473) & 511)])) + (0.000365929212f * fVec26[((IOTA - 488) & 511)])) + (4.26657498e-05f * fVec26[((IOTA - 489) & 511)])) + (0.00168100977f * fVec26[((IOTA - 495) & 511)])) + (0.00319510186f * fVec26[((IOTA - 496) & 511)])) + (0.00266046124f * fVec26[((IOTA - 497) & 511)])) + (0.000922217499f * fVec26[((IOTA - 498) & 511)])) - (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00239760848f * fVec26[((IOTA - 158) & 511)]) + ((0.00369324442f * fVec26[((IOTA - 157) & 511)]) + ((0.00595218968f * fVec26[((IOTA - 156) & 511)]) + ((0.00917573553f * fVec26[((IOTA - 155) & 511)]) + ((0.00932248496f * fVec26[((IOTA - 154) & 511)]) + ((0.00594816264f * fVec26[((IOTA - 153) & 511)]) + ((0.00171719398f * fVec26[((IOTA - 152) & 511)]) + ((0.00200792355f * fVec26[((IOTA - 146) & 511)]) + ((0.00601278991f * fVec26[((IOTA - 145) & 511)]) + ((0.0104372948f * fVec26[((IOTA - 144) & 511)]) + ((0.0140479151f * fVec26[((IOTA - 143) & 511)]) + ((0.0149643421f * fVec26[((IOTA - 142) & 511)]) + ((0.0142052677f * fVec26[((IOTA - 141) & 511)]) + ((0.0108990017f * fVec26[((IOTA - 140) & 511)]) + ((0.00520352926f * fVec26[((IOTA - 139) & 511)]) + ((0.00318817981f * fVec26[((IOTA - 138) & 511)]) + ((0.00323490426f * fVec26[((IOTA - 137) & 511)]) + ((0.00262770662f * fVec26[((IOTA - 136) & 511)]) + ((0.0041453545f * fVec26[((IOTA - 135) & 511)]) + ((0.0032985881f * fVec26[((IOTA - 134) & 511)]) + ((0.00434232084f * fVec26[((IOTA - 129) & 511)]) + ((0.00941933133f * fVec26[((IOTA - 128) & 511)]) + ((0.0119053237f * fVec26[((IOTA - 127) & 511)]) + ((0.01193232f * fVec26[((IOTA - 126) & 511)]) + ((0.0109141357f * fVec26[((IOTA - 125) & 511)]) + ((0.0080942139f * fVec26[((IOTA - 124) & 511)]) + ((0.00593573414f * fVec26[((IOTA - 123) & 511)]) + ((0.00516032847f * fVec26[((IOTA - 122) & 511)]) + ((0.00387501344f * fVec26[((IOTA - 121) & 511)]) + ((0.00344980508f * fVec26[((IOTA - 120) & 511)]) + ((0.00434880238f * fVec26[((IOTA - 119) & 511)]) + ((0.00953826681f * fVec26[((IOTA - 118) & 511)]) + ((0.0174444187f * fVec26[((IOTA - 117) & 511)]) + ((0.0249284152f * fVec26[((IOTA - 116) & 511)]) + ((0.0285700578f * fVec26[((IOTA - 115) & 511)]) + ((0.0250988882f * fVec26[((IOTA - 114) & 511)]) + ((0.0151173845f * fVec26[((IOTA - 113) & 511)]) + ((0.00341160782f * fVec26[((IOTA - 112) & 511)]) + ((0.00128182257f * fVec26[((IOTA - 107) & 511)]) + ((0.011929079f * fVec26[((IOTA - 106) & 511)]) + ((0.0209161229f * fVec26[((IOTA - 105) & 511)]) + ((0.0244460683f * fVec26[((IOTA - 104) & 511)]) + ((0.0301262178f * fVec26[((IOTA - 103) & 511)]) + ((0.0263951849f * fVec26[((IOTA - 102) & 511)]) + ((0.0154495537f * fVec26[((IOTA - 101) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((0.0198072605f * fVec26[((IOTA - 21) & 511)]) + ((0.0129326321f * fVec26[((IOTA - 20) & 511)]) + ((0.00833752751f * fVec26[((IOTA - 15) & 511)]) + ((0.01890238f * fVec26[((IOTA - 14) & 511)]) + ((0.00556118321f * fVec26[((IOTA - 9) & 511)]) + ((0.148464561f * fVec26[((IOTA - 8) & 511)]) + ((0.232306689f * fVec26[((IOTA - 7) & 511)]) + ((0.199573472f * fVec26[((IOTA - 6) & 511)]) + ((0.127753422f * fVec26[((IOTA - 5) & 511)]) + ((0.0011839373f * fVec26[((IOTA - 22) & 511)]) + (0.00460246718f * fVec26[((IOTA - 28) & 511)]))))))))))) + (0.0229650456f * fVec26[((IOTA - 29) & 511)])) + (0.0289930329f * fVec26[((IOTA - 30) & 511)])) + (0.0407163352f * fVec26[((IOTA - 31) & 511)])) + (0.0438397005f * fVec26[((IOTA - 32) & 511)])) + (0.0248467978f * fVec26[((IOTA - 33) & 511)])) + (0.012516045f * fVec26[((IOTA - 34) & 511)])) + (0.00939972978f * fVec26[((IOTA - 39) & 511)])) + (0.0186572727f * fVec26[((IOTA - 40) & 511)])) + (0.00661051692f * fVec26[((IOTA - 41) & 511)])) + (0.0153539963f * fVec26[((IOTA - 44) & 511)])) + (0.0318251923f * fVec26[((IOTA - 45) & 511)])) + (0.0454050153f * fVec26[((IOTA - 46) & 511)])) + (0.0414703749f * fVec26[((IOTA - 47) & 511)])) + (0.00253085978f * fVec26[((IOTA - 48) & 511)])) + (0.00182288233f * fVec26[((IOTA - 52) & 511)])) + (0.038441278f * fVec26[((IOTA - 53) & 511)])) + (0.0592756905f * fVec26[((IOTA - 54) & 511)])) + (0.0447208546f * fVec26[((IOTA - 55) & 511)])) + (0.031499099f * fVec26[((IOTA - 56) & 511)])) + (0.00323128607f * fVec26[((IOTA - 57) & 511)])) + (0.00221285038f * fVec26[((IOTA - 64) & 511)])) + (0.0107893804f * fVec26[((IOTA - 65) & 511)])) + (0.0259394255f * fVec26[((IOTA - 66) & 511)])) + (0.0399207287f * fVec26[((IOTA - 67) & 511)])) + (0.0397939608f * fVec26[((IOTA - 68) & 511)])) + (0.0321557261f * fVec26[((IOTA - 69) & 511)])) + (0.0167744197f * fVec26[((IOTA - 70) & 511)])) + (0.0022910391f * fVec26[((IOTA - 71) & 511)])) + (0.00158941746f * fVec26[((IOTA - 76) & 511)])) + (0.00914279185f * fVec26[((IOTA - 77) & 511)])) + (0.0156605523f * fVec26[((IOTA - 78) & 511)])) + (0.0120513812f * fVec26[((IOTA - 79) & 511)])) + (0.010626113f * fVec26[((IOTA - 80) & 511)])) + (0.0101410914f * fVec26[((IOTA - 81) & 511)])) + (0.00484911539f * fVec26[((IOTA - 82) & 511)])) + (0.00389253907f * fVec26[((IOTA - 83) & 511)])) + (0.00460589677f * fVec26[((IOTA - 84) & 511)])) + (0.00928856619f * fVec26[((IOTA - 85) & 511)])) + (0.0171898101f * fVec26[((IOTA - 86) & 511)])) + (0.0216624867f * fVec26[((IOTA - 87) & 511)])) + (0.0254450906f * fVec26[((IOTA - 88) & 511)])) + (0.024378892f * fVec26[((IOTA - 89) & 511)])) + (0.0164985396f * fVec26[((IOTA - 90) & 511)])) + (0.0120993322f * fVec26[((IOTA - 91) & 511)])) + (0.0143494681f * fVec26[((IOTA - 92) & 511)])) + (0.0113201831f * fVec26[((IOTA - 93) & 511)])) + (0.00793233048f * fVec26[((IOTA - 94) & 511)])) + (0.00402409118f * fVec26[((IOTA - 95) & 511)])) + (0.00479713641f * fVec26[((IOTA - 100) & 511)])) + (0.0021675732f * fVec26[((IOTA - 159) & 511)]))))))))))))))))))))))))))))))))))))))))))))))) + (0.00234046951f * fVec26[((IOTA - 160) & 511)])) + (0.00146356039f * fVec26[((IOTA - 161) & 511)])) + (0.000872693025f * fVec26[((IOTA - 162) & 511)])) + (0.000348750036f * fVec26[((IOTA - 163) & 511)])) + (0.000499432441f * fVec26[((IOTA - 164) & 511)])) + (0.00295748375f * fVec26[((IOTA - 165) & 511)])) + (0.00612197118f * fVec26[((IOTA - 166) & 511)])) + (0.00914949365f * fVec26[((IOTA - 167) & 511)])) + (0.0106139667f * fVec26[((IOTA - 168) & 511)])) + (0.00901983026f * fVec26[((IOTA - 169) & 511)])) + (0.00580468541f * fVec26[((IOTA - 170) & 511)])) + (0.00207151286f * fVec26[((IOTA - 171) & 511)])) + (0.00192476343f * fVec26[((IOTA - 176) & 511)])) + (0.00374333514f * fVec26[((IOTA - 177) & 511)])) + (0.00483143283f * fVec26[((IOTA - 178) & 511)])) + (0.00538473204f * fVec26[((IOTA - 179) & 511)])) + (0.00352865458f * fVec26[((IOTA - 180) & 511)])) + (0.00130148791f * fVec26[((IOTA - 181) & 511)])) + (0.000625730027f * fVec26[((IOTA - 186) & 511)])) + (0.000893553719f * fVec26[((IOTA - 187) & 511)])) + (0.000460605603f * fVec26[((IOTA - 198) & 511)])) + (0.00331356516f * fVec26[((IOTA - 199) & 511)])) + (0.00482403859f * fVec26[((IOTA - 200) & 511)])) + (0.0053036483f * fVec26[((IOTA - 201) & 511)])) + (0.00510844402f * fVec26[((IOTA - 202) & 511)])) + (0.00307726813f * fVec26[((IOTA - 203) & 511)])) + (0.000868633855f * fVec26[((IOTA - 204) & 511)])) + (0.00172811188f * fVec26[((IOTA - 212) & 511)])) + (0.00395820476f * fVec26[((IOTA - 213) & 511)])) + (0.00506426813f * fVec26[((IOTA - 214) & 511)])) + (0.00504277833f * fVec26[((IOTA - 215) & 511)])) + (0.00477457652f * fVec26[((IOTA - 216) & 511)])) + (0.00332306698f * fVec26[((IOTA - 217) & 511)])) + (0.000254640356f * fVec26[((IOTA - 218) & 511)])) + (0.00015559094f * fVec26[((IOTA - 224) & 511)])) + (0.00413497118f * fVec26[((IOTA - 225) & 511)])) + (0.00622891821f * fVec26[((IOTA - 226) & 511)])) + (0.00605951436f * fVec26[((IOTA - 227) & 511)])) + (0.00330337044f * fVec26[((IOTA - 228) & 511)])) + (0.000276256353f * fVec26[((IOTA - 370) & 511)])) + (0.0015277788f * fVec26[((IOTA - 371) & 511)])) + (0.00165722286f * fVec26[((IOTA - 372) & 511)])) + (0.000840032939f * fVec26[((IOTA - 373) & 511)])) + (0.000859037507f * fVec26[((IOTA - 395) & 511)])) + (0.0020341333f * fVec26[((IOTA - 396) & 511)])) + (0.00198479742f * fVec26[((IOTA - 397) & 511)])) + (0.000769647304f * fVec26[((IOTA - 398) & 511)])) + (0.000121924095f * fVec26[((IOTA - 404) & 511)])) + (0.00167726586f * fVec26[((IOTA - 405) & 511)])) + (0.00207953621f * fVec26[((IOTA - 406) & 511)])) + (0.00177618954f * fVec26[((IOTA - 407) & 511)])) + (0.000140110496f * fVec26[((IOTA - 408) & 511)])) + (0.000190799125f * fVec26[((IOTA - 415) & 511)])) + (0.000478351489f * fVec26[((IOTA - 416) & 511)])) + (0.000629663002f * fVec26[((IOTA - 421) & 511)])) + (0.000156031456f * fVec26[((IOTA - 422) & 511)])) + (0.000562801491f * fVec26[((IOTA - 429) & 511)])) + (0.00193873374f * fVec26[((IOTA - 430) & 511)])) + (0.00226048753f * fVec26[((IOTA - 431) & 511)])) + (0.0021940032f * fVec26[((IOTA - 432) & 511)])) + (0.00203866418f * fVec26[((IOTA - 433) & 511)])) + (0.00094946567f * fVec26[((IOTA - 434) & 511)])) + (0.000303189736f * fVec26[((IOTA - 435) & 511)])) + (0.000563115813f * fVec26[((IOTA - 436) & 511)])) + (0.00149373477f * fVec26[((IOTA - 437) & 511)])) + (0.00357427774f * fVec26[((IOTA - 438) & 511)])) + (0.00553041138f * fVec26[((IOTA - 439) & 511)])) + (0.00673863944f * fVec26[((IOTA - 440) & 511)])) + (0.00724993367f * fVec26[((IOTA - 441) & 511)])) + (0.0062133749f * fVec26[((IOTA - 442) & 511)])) + (0.00458462676f * fVec26[((IOTA - 443) & 511)])) + (0.00346874679f * fVec26[((IOTA - 444) & 511)])) + (0.0021890006f * fVec26[((IOTA - 445) & 511)])) + (0.00131526915f * fVec26[((IOTA - 446) & 511)])) + (0.000623149797f * fVec26[((IOTA - 447) & 511)])) + (0.000163991936f * fVec26[((IOTA - 451) & 511)])) + (0.00114762783f * fVec26[((IOTA - 452) & 511)])) + (0.00191032141f * fVec26[((IOTA - 453) & 511)])) + (0.00260225218f * fVec26[((IOTA - 454) & 511)])) + (0.00376910437f * fVec26[((IOTA - 455) & 511)])) + (0.00423203828f * fVec26[((IOTA - 456) & 511)])) + (0.00387872616f * fVec26[((IOTA - 457) & 511)])) + (0.00340339541f * fVec26[((IOTA - 458) & 511)])) + (0.00226986362f * fVec26[((IOTA - 459) & 511)])) + (0.000625100452f * fVec26[((IOTA - 460) & 511)])) + (0.000363097526f * fVec26[((IOTA - 463) & 511)])) + (0.00260926876f * fVec26[((IOTA - 464) & 511)])) + (0.00421680976f * fVec26[((IOTA - 465) & 511)])) + (0.00481444178f * fVec26[((IOTA - 466) & 511)])) + (0.0041063386f * fVec26[((IOTA - 467) & 511)])) + (0.00202387618f * fVec26[((IOTA - 468) & 511)])) + (0.00020067906f * fVec26[((IOTA - 474) & 511)])) + (0.00158664864f * fVec26[((IOTA - 475) & 511)])) + (0.0023846454f * fVec26[((IOTA - 476) & 511)])) + (0.00280799717f * fVec26[((IOTA - 477) & 511)])) + (0.00319337146f * fVec26[((IOTA - 478) & 511)])) + (0.00274610706f * fVec26[((IOTA - 479) & 511)])) + (0.00237460807f * fVec26[((IOTA - 480) & 511)])) + (0.00214951299f * fVec26[((IOTA - 481) & 511)])) + (0.00190361962f * fVec26[((IOTA - 482) & 511)])) + (0.00223276718f * fVec26[((IOTA - 483) & 511)])) + (0.00223163469f * fVec26[((IOTA - 484) & 511)])) + (0.00198882492f * fVec26[((IOTA - 485) & 511)])) + (0.00184600847f * fVec26[((IOTA - 486) & 511)])) + (0.0005584592f * fVec26[((IOTA - 487) & 511)])) + (0.000505127478f * fVec26[((IOTA - 490) & 511)])) + (0.00184339704f * fVec26[((IOTA - 491) & 511)])) + (0.00279154116f * fVec26[((IOTA - 492) & 511)])) + (0.00207981933f * fVec26[((IOTA - 493) & 511)])) + (0.000493328087f * fVec26[((IOTA - 494) & 511)])) + (0.00163183128f * fVec26[((IOTA - 499) & 511)])) + (0.00429046759f * fVec26[((IOTA - 500) & 511)])) + (0.00557647506f * fVec26[((IOTA - 501) & 511)])) + (0.00558106881f * fVec26[((IOTA - 502) & 511)])) + (0.00514041167f * fVec26[((IOTA - 503) & 511)])) + (0.00423099985f * fVec26[((IOTA - 504) & 511)])) + (0.00391802518f * fVec26[((IOTA - 505) & 511)])) + (0.00400927151f * fVec26[((IOTA - 506) & 511)])) + (0.00399904558f * fVec26[((IOTA - 507) & 511)])) + (0.00450980477f * fVec26[((IOTA - 508) & 511)])) + (0.00485320576f * fVec26[((IOTA - 509) & 511)])) + (0.00464242697f * fVec26[((IOTA - 510) & 511)])) + (0.00481293164f * fVec26[((IOTA - 511) & 511)]))))) : (iSlow71 ? (iSlow77 ? ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.010002207f * fVec25[((IOTA - 312) & 511)]) + ((0.00963451061f * fVec25[((IOTA - 311) & 511)]) + ((0.00991004333f * fVec25[((IOTA - 310) & 511)]) + ((0.01089615f * fVec25[((IOTA - 309) & 511)]) + ((0.013016101f * fVec25[((IOTA - 308) & 511)]) + ((0.0143044069f * fVec25[((IOTA - 307) & 511)]) + ((0.0151654538f * fVec25[((IOTA - 306) & 511)]) + ((0.0154119134f * fVec25[((IOTA - 305) & 511)]) + ((0.0133416709f * fVec25[((IOTA - 304) & 511)]) + ((0.0115069449f * fVec25[((IOTA - 303) & 511)]) + ((0.0104616713f * fVec25[((IOTA - 302) & 511)]) + ((0.00967528485f * fVec25[((IOTA - 301) & 511)]) + ((0.00978999399f * fVec25[((IOTA - 300) & 511)]) + ((0.0100059649f * fVec25[((IOTA - 299) & 511)]) + ((0.00996238831f * fVec25[((IOTA - 298) & 511)]) + ((0.00967531838f * fVec25[((IOTA - 297) & 511)]) + ((0.0076534641f * fVec25[((IOTA - 296) & 511)]) + ((0.00483210478f * fVec25[((IOTA - 295) & 511)]) + ((0.00359119847f * fVec25[((IOTA - 294) & 511)]) + ((0.00346070016f * fVec25[((IOTA - 293) & 511)]) + ((0.00422275998f * fVec25[((IOTA - 292) & 511)]) + ((0.00676426757f * fVec25[((IOTA - 291) & 511)]) + ((0.00996070728f * fVec25[((IOTA - 290) & 511)]) + ((0.0123852305f * fVec25[((IOTA - 289) & 511)]) + ((0.0127551695f * fVec25[((IOTA - 288) & 511)]) + ((0.0115649924f * fVec25[((IOTA - 287) & 511)]) + ((0.0100730769f * fVec25[((IOTA - 286) & 511)]) + ((0.00851147808f * fVec25[((IOTA - 285) & 511)]) + ((0.00766394613f * fVec25[((IOTA - 284) & 511)]) + ((0.0068348404f * fVec25[((IOTA - 283) & 511)]) + ((0.00536088925f * fVec25[((IOTA - 282) & 511)]) + ((0.00448570214f * fVec25[((IOTA - 281) & 511)]) + ((0.00451615918f * fVec25[((IOTA - 280) & 511)]) + ((0.00449268986f * fVec25[((IOTA - 279) & 511)]) + ((0.00430154055f * fVec25[((IOTA - 278) & 511)]) + ((0.00409700815f * fVec25[((IOTA - 277) & 511)]) + ((0.00470971502f * fVec25[((IOTA - 276) & 511)]) + ((0.00709494762f * fVec25[((IOTA - 275) & 511)]) + ((0.00958015583f * fVec25[((IOTA - 274) & 511)]) + ((0.0117835999f * fVec25[((IOTA - 273) & 511)]) + ((0.0147379301f * fVec25[((IOTA - 272) & 511)]) + ((0.0168541223f * fVec25[((IOTA - 271) & 511)]) + ((0.0162749048f * fVec25[((IOTA - 270) & 511)]) + ((0.0135236569f * fVec25[((IOTA - 269) & 511)]) + ((0.00952504203f * fVec25[((IOTA - 268) & 511)]) + ((0.00630213367f * fVec25[((IOTA - 267) & 511)]) + ((0.00576402061f * fVec25[((IOTA - 266) & 511)]) + ((0.00757837575f * fVec25[((IOTA - 265) & 511)]) + ((0.0111616962f * fVec25[((IOTA - 264) & 511)]) + ((0.014640064f * fVec25[((IOTA - 263) & 511)]) + ((0.0155443568f * fVec25[((IOTA - 262) & 511)]) + ((0.0142759271f * fVec25[((IOTA - 261) & 511)]) + ((0.0124081401f * fVec25[((IOTA - 260) & 511)]) + ((0.0110312635f * fVec25[((IOTA - 259) & 511)]) + ((0.0110482387f * fVec25[((IOTA - 258) & 511)]) + ((0.0112492777f * fVec25[((IOTA - 257) & 511)]) + ((0.0110011362f * fVec25[((IOTA - 256) & 511)]) + ((0.0115776174f * fVec25[((IOTA - 255) & 511)]) + ((0.0110572381f * fVec25[((IOTA - 254) & 511)]) + ((0.0087513458f * fVec25[((IOTA - 253) & 511)]) + ((0.00649779895f * fVec25[((IOTA - 252) & 511)]) + ((0.00499579683f * fVec25[((IOTA - 251) & 511)]) + ((0.00380759733f * fVec25[((IOTA - 250) & 511)]) + ((0.00251995027f * fVec25[((IOTA - 249) & 511)]) + ((0.000722603872f * fVec25[((IOTA - 248) & 511)]) + ((0.000990193337f * fVec25[((IOTA - 246) & 511)]) + ((0.00269102538f * fVec25[((IOTA - 245) & 511)]) + ((0.00517006917f * fVec25[((IOTA - 244) & 511)]) + ((0.00814519823f * fVec25[((IOTA - 243) & 511)]) + ((0.00921641476f * fVec25[((IOTA - 242) & 511)]) + ((0.0086482726f * fVec25[((IOTA - 241) & 511)]) + ((0.00760135055f * fVec25[((IOTA - 240) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((fSlow81 * fTemp0) + (0.213664278f * fVec25[((IOTA - 1) & 511)])) + (0.236962214f * fVec25[((IOTA - 2) & 511)])) + (0.267108172f * fVec25[((IOTA - 3) & 511)])) + (0.200446084f * fVec25[((IOTA - 4) & 511)])) + (0.0609033294f * fVec25[((IOTA - 5) & 511)])) + (0.0361984298f * fVec25[((IOTA - 11) & 511)])) + (0.100266322f * fVec25[((IOTA - 12) & 511)])) + (0.0915521234f * fVec25[((IOTA - 13) & 511)])) + (0.041319713f * fVec25[((IOTA - 14) & 511)])) + (0.0246090125f * fVec25[((IOTA - 15) & 511)])) + (0.00103123207f * fVec25[((IOTA - 18) & 511)])) + (0.0099603124f * fVec25[((IOTA - 19) & 511)])) + (0.0244282447f * fVec25[((IOTA - 20) & 511)])) + (0.0116631547f * fVec25[((IOTA - 21) & 511)])) + (0.0190723017f * fVec25[((IOTA - 22) & 511)])) + (0.02090073f * fVec25[((IOTA - 23) & 511)])) + (0.0133315185f * fVec25[((IOTA - 24) & 511)])) + (0.0355431661f * fVec25[((IOTA - 25) & 511)])) + (0.0337876827f * fVec25[((IOTA - 26) & 511)])) + (0.0201402195f * fVec25[((IOTA - 27) & 511)])) + (0.00777802942f * fVec25[((IOTA - 28) & 511)])) + (0.0182003118f * fVec25[((IOTA - 37) & 511)])) + (0.0182863437f * fVec25[((IOTA - 38) & 511)])) + (0.015268065f * fVec25[((IOTA - 39) & 511)])) + (0.0150152761f * fVec25[((IOTA - 40) & 511)])) + (0.00662641879f * fVec25[((IOTA - 41) & 511)])) + (0.00595444487f * fVec25[((IOTA - 42) & 511)])) + (0.00438114488f * fVec25[((IOTA - 43) & 511)])) + (0.0134622473f * fVec25[((IOTA - 52) & 511)])) + (0.0116357626f * fVec25[((IOTA - 53) & 511)])) + (0.00572215812f * fVec25[((IOTA - 54) & 511)])) + (0.000777882058f * fVec25[((IOTA - 55) & 511)])) + (0.00638922025f * fVec25[((IOTA - 65) & 511)])) + (0.00813784823f * fVec25[((IOTA - 66) & 511)])) + (0.00106854551f * fVec25[((IOTA - 73) & 511)])) + (0.00990101229f * fVec25[((IOTA - 74) & 511)])) + (0.0047609387f * fVec25[((IOTA - 75) & 511)])) + (0.00138983084f * fVec25[((IOTA - 81) & 511)])) + (0.00326203508f * fVec25[((IOTA - 97) & 511)])) + (0.00790882483f * fVec25[((IOTA - 98) & 511)])) + (0.00946752261f * fVec25[((IOTA - 99) & 511)])) + (0.00927568041f * fVec25[((IOTA - 100) & 511)])) + (0.00715863099f * fVec25[((IOTA - 101) & 511)])) + (0.00151663739f * fVec25[((IOTA - 102) & 511)])) + (0.00583630754f * fVec25[((IOTA - 111) & 511)])) + (0.00441526109f * fVec25[((IOTA - 112) & 511)])) + (0.00541768363f * fVec25[((IOTA - 133) & 511)])) + (0.00850735791f * fVec25[((IOTA - 134) & 511)])) + (0.00671235193f * fVec25[((IOTA - 135) & 511)])) + (0.00338623766f * fVec25[((IOTA - 136) & 511)])) + (6.73425384e-05f * fVec25[((IOTA - 137) & 511)])) + (0.00831531826f * fVec25[((IOTA - 147) & 511)])) + (0.0124675389f * fVec25[((IOTA - 148) & 511)])) + (0.0116033936f * fVec25[((IOTA - 149) & 511)])) + (0.00687933993f * fVec25[((IOTA - 150) & 511)])) + (0.00121819507f * fVec25[((IOTA - 151) & 511)])) + (0.00537773315f * fVec25[((IOTA - 171) & 511)])) + (0.0111720795f * fVec25[((IOTA - 172) & 511)])) + (0.0119929109f * fVec25[((IOTA - 173) & 511)])) + (0.00821409002f * fVec25[((IOTA - 174) & 511)])) + (0.00071673654f * fVec25[((IOTA - 175) & 511)])) + (0.0016830652f * fVec25[((IOTA - 182) & 511)])) + (0.00365613448f * fVec25[((IOTA - 183) & 511)])) + (0.00472441642f * fVec25[((IOTA - 184) & 511)])) + (0.00637481594f * fVec25[((IOTA - 185) & 511)])) + (0.00831795484f * fVec25[((IOTA - 186) & 511)])) + (0.00880326144f * fVec25[((IOTA - 187) & 511)])) + (0.00693679368f * fVec25[((IOTA - 188) & 511)])) + (0.00396074122f * fVec25[((IOTA - 189) & 511)])) + (0.00194587512f * fVec25[((IOTA - 190) & 511)])) + (0.00152863609f * fVec25[((IOTA - 191) & 511)])) + (0.00250966614f * fVec25[((IOTA - 192) & 511)])) + (0.00327993371f * fVec25[((IOTA - 193) & 511)])) + (0.00258142548f * fVec25[((IOTA - 194) & 511)])) + (0.000466485508f * fVec25[((IOTA - 195) & 511)])) + (0.00150839705f * fVec25[((IOTA - 205) & 511)])) + (0.0030700285f * fVec25[((IOTA - 206) & 511)])) + (0.00380964112f * fVec25[((IOTA - 207) & 511)])) + (0.00328711933f * fVec25[((IOTA - 208) & 511)])) + (0.00113321794f * fVec25[((IOTA - 209) & 511)])) + (0.00237270677f * fVec25[((IOTA - 213) & 511)])) + (0.00520349341f * fVec25[((IOTA - 214) & 511)])) + (0.00467019295f * fVec25[((IOTA - 215) & 511)])) + (0.00120098889f * fVec25[((IOTA - 216) & 511)])) + (0.0028825379f * fVec25[((IOTA - 223) & 511)])) + (0.00355358841f * fVec25[((IOTA - 224) & 511)])) + (0.00153236091f * fVec25[((IOTA - 225) & 511)])) + (0.00028944388f * fVec25[((IOTA - 226) & 511)])) + (0.00102846278f * fVec25[((IOTA - 227) & 511)])) + (0.00230388111f * fVec25[((IOTA - 228) & 511)])) + (0.00498353457f * fVec25[((IOTA - 229) & 511)])) + (0.00905351341f * fVec25[((IOTA - 230) & 511)])) + (0.0122230556f * fVec25[((IOTA - 231) & 511)])) + (0.0135133732f * fVec25[((IOTA - 232) & 511)])) + (0.0123285353f * fVec25[((IOTA - 233) & 511)])) + (0.00843424723f * fVec25[((IOTA - 234) & 511)])) + (0.00397211313f * fVec25[((IOTA - 235) & 511)])) + (0.00147269852f * fVec25[((IOTA - 236) & 511)])) + (0.00110826502f * fVec25[((IOTA - 237) & 511)])) + (0.00229817862f * fVec25[((IOTA - 238) & 511)])) + (0.0049688993f * fVec25[((IOTA - 239) & 511)])) + (0.0118440855f * fVec25[((IOTA - 313) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.0129716005f * fVec25[((IOTA - 314) & 511)])) + (0.0115857255f * fVec25[((IOTA - 315) & 511)])) + (0.00831472501f * fVec25[((IOTA - 316) & 511)])) + (0.00436690496f * fVec25[((IOTA - 317) & 511)])) + (0.0010702922f * fVec25[((IOTA - 318) & 511)])) + (0.00136418594f * fVec25[((IOTA - 321) & 511)])) + (0.00413062982f * fVec25[((IOTA - 322) & 511)])) + (0.00595263205f * fVec25[((IOTA - 323) & 511)])) + (0.0060702092f * fVec25[((IOTA - 324) & 511)])) + (0.00458983053f * fVec25[((IOTA - 325) & 511)])) + (0.00299599487f * fVec25[((IOTA - 326) & 511)])) + (0.00231386861f * fVec25[((IOTA - 327) & 511)])) + (0.00215314329f * fVec25[((IOTA - 328) & 511)])) + (0.00251932396f * fVec25[((IOTA - 329) & 511)])) + (0.00312524056f * fVec25[((IOTA - 330) & 511)])) + (0.00343584642f * fVec25[((IOTA - 331) & 511)])) + (0.00487492327f * fVec25[((IOTA - 332) & 511)])) + (0.007002356f * fVec25[((IOTA - 333) & 511)])) + (0.00763184065f * fVec25[((IOTA - 334) & 511)])) + (0.00764433341f * fVec25[((IOTA - 335) & 511)])) + (0.00691302773f * fVec25[((IOTA - 336) & 511)])) + (0.00581003632f * fVec25[((IOTA - 337) & 511)])) + (0.00685211271f * fVec25[((IOTA - 338) & 511)])) + (0.00910078175f * fVec25[((IOTA - 339) & 511)])) + (0.0115988776f * fVec25[((IOTA - 340) & 511)])) + (0.0132672414f * fVec25[((IOTA - 341) & 511)])) + (0.0124549139f * fVec25[((IOTA - 342) & 511)])) + (0.00904418528f * fVec25[((IOTA - 343) & 511)])) + (0.00442369934f * fVec25[((IOTA - 344) & 511)])) + (0.000244021416f * fVec25[((IOTA - 345) & 511)])) + (0.000634429045f * fVec25[((IOTA - 347) & 511)])) + (0.00531994971f * fVec25[((IOTA - 348) & 511)])) + (0.0105903577f * fVec25[((IOTA - 349) & 511)])) + (0.0139270853f * fVec25[((IOTA - 350) & 511)])) + (0.0137027754f * fVec25[((IOTA - 351) & 511)])) + (0.0107791331f * fVec25[((IOTA - 352) & 511)])) + (0.00578307314f * fVec25[((IOTA - 353) & 511)])) + (0.00152652618f * fVec25[((IOTA - 358) & 511)])) + (0.00481601898f * fVec25[((IOTA - 359) & 511)])) + (0.00681967754f * fVec25[((IOTA - 360) & 511)])) + (0.00790819898f * fVec25[((IOTA - 361) & 511)])) + (0.0079198014f * fVec25[((IOTA - 362) & 511)])) + (0.00756472908f * fVec25[((IOTA - 363) & 511)])) + (0.00785011798f * fVec25[((IOTA - 364) & 511)])) + (0.00789428875f * fVec25[((IOTA - 365) & 511)])) + (0.0073978072f * fVec25[((IOTA - 366) & 511)])) + (0.00661399169f * fVec25[((IOTA - 367) & 511)])) + (0.00373992557f * fVec25[((IOTA - 368) & 511)])) + (0.0045968513f * fVec25[((IOTA - 375) & 511)])) + (0.00865199789f * fVec25[((IOTA - 376) & 511)])) + (0.0102687087f * fVec25[((IOTA - 377) & 511)])) + (0.00922488607f * fVec25[((IOTA - 378) & 511)])) + (0.00604990451f * fVec25[((IOTA - 379) & 511)])) + (0.00257595349f * fVec25[((IOTA - 380) & 511)])) + (4.06755134e-05f * fVec25[((IOTA - 381) & 511)])) + (0.000122291036f * fVec25[((IOTA - 383) & 511)])) + (0.0021657683f * fVec25[((IOTA - 384) & 511)])) + (0.00428713579f * fVec25[((IOTA - 385) & 511)])) + (0.00585681014f * fVec25[((IOTA - 386) & 511)])) + (0.00560049387f * fVec25[((IOTA - 387) & 511)])) + (0.0041703498f * fVec25[((IOTA - 388) & 511)])) + (0.0028756815f * fVec25[((IOTA - 389) & 511)])) + (0.0018161349f * fVec25[((IOTA - 390) & 511)])) + (0.00132690556f * fVec25[((IOTA - 391) & 511)])) + (0.00203213841f * fVec25[((IOTA - 392) & 511)])) + (0.00272072479f * fVec25[((IOTA - 393) & 511)])) + (0.00245521171f * fVec25[((IOTA - 394) & 511)])) + (0.00119248452f * fVec25[((IOTA - 395) & 511)])) + (0.000378047116f * fVec25[((IOTA - 400) & 511)])) + (0.00133181689f * fVec25[((IOTA - 401) & 511)])) + (0.00121555803f * fVec25[((IOTA - 402) & 511)])) + (0.000195335597f * fVec25[((IOTA - 403) & 511)])) + (6.5267086e-06f * fVec25[((IOTA - 407) & 511)])) + (0.00293198135f * fVec25[((IOTA - 408) & 511)])) + (0.00580344396f * fVec25[((IOTA - 409) & 511)])) + (0.00638971478f * fVec25[((IOTA - 410) & 511)])) + (0.00557910092f * fVec25[((IOTA - 411) & 511)])) + (0.0037308936f * fVec25[((IOTA - 412) & 511)])) + (0.00140835578f * fVec25[((IOTA - 413) & 511)])) + (0.000150275882f * fVec25[((IOTA - 418) & 511)])) + (0.00196845457f * fVec25[((IOTA - 419) & 511)])) + (0.00347612659f * fVec25[((IOTA - 420) & 511)])) + (0.0038890806f * fVec25[((IOTA - 421) & 511)])) + (0.00332993781f * fVec25[((IOTA - 422) & 511)])) + (0.00233358005f * fVec25[((IOTA - 423) & 511)])) + (0.000999225304f * fVec25[((IOTA - 424) & 511)])) + (0.000302628614f * fVec25[((IOTA - 428) & 511)])) + (0.00137133896f * fVec25[((IOTA - 429) & 511)])) + (0.00114244735f * fVec25[((IOTA - 430) & 511)])) + (3.59620899e-05f * fVec25[((IOTA - 437) & 511)])) + (0.0025548907f * fVec25[((IOTA - 471) & 511)])) + (0.00278786942f * fVec25[((IOTA - 472) & 511)])) + (0.00103268214f * fVec25[((IOTA - 473) & 511)])) + (0.000697948039f * fVec25[((IOTA - 488) & 511)])) + (0.00184329599f * fVec25[((IOTA - 496) & 511)])) + (0.00175667042f * fVec25[((IOTA - 497) & 511)])) + (0.000480329618f * fVec25[((IOTA - 498) & 511)])) - ((((((((((((((((((((((((((((0.00141956285f * fVec25[((IOTA - 480) & 511)]) + ((0.00137305306f * fVec25[((IOTA - 479) & 511)]) + ((0.00265928265f * fVec25[((IOTA - 478) & 511)]) + ((0.00381741999f * fVec25[((IOTA - 477) & 511)]) + ((0.00474920403f * fVec25[((IOTA - 476) & 511)]) + ((0.00428367453f * fVec25[((IOTA - 475) & 511)]) + ((0.00173656363f * fVec25[((IOTA - 474) & 511)]) + ((8.09230842e-05f * fVec25[((IOTA - 470) & 511)]) + ((0.00387925794f * fVec25[((IOTA - 469) & 511)]) + ((0.00702727539f * fVec25[((IOTA - 468) & 511)]) + ((0.00798177067f * fVec25[((IOTA - 467) & 511)]) + ((0.00640342711f * fVec25[((IOTA - 466) & 511)]) + ((0.0040265345f * fVec25[((IOTA - 465) & 511)]) + ((0.00207782397f * fVec25[((IOTA - 464) & 511)]) + ((0.00057997508f * fVec25[((IOTA - 463) & 511)]) + ((0.000525817741f * fVec25[((IOTA - 462) & 511)]) + ((0.00218234817f * fVec25[((IOTA - 461) & 511)]) + ((0.00358938565f * fVec25[((IOTA - 460) & 511)]) + ((0.00434445776f * fVec25[((IOTA - 459) & 511)]) + ((0.00446928665f * fVec25[((IOTA - 458) & 511)]) + ((0.00352125196f * fVec25[((IOTA - 457) & 511)]) + ((0.00259774178f * fVec25[((IOTA - 456) & 511)]) + ((0.00161061389f * fVec25[((IOTA - 455) & 511)]) + ((0.00123909349f * fVec25[((IOTA - 454) & 511)]) + ((0.00291259959f * fVec25[((IOTA - 453) & 511)]) + ((0.00468014786f * fVec25[((IOTA - 452) & 511)]) + ((0.00517873839f * fVec25[((IOTA - 451) & 511)]) + ((0.00542266108f * fVec25[((IOTA - 450) & 511)]) + ((0.00467589544f * fVec25[((IOTA - 449) & 511)]) + ((0.00296847103f * fVec25[((IOTA - 448) & 511)]) + ((0.00153911812f * fVec25[((IOTA - 447) & 511)]) + ((0.000959274825f * fVec25[((IOTA - 446) & 511)]) + ((0.00230358448f * fVec25[((IOTA - 445) & 511)]) + ((0.005250399f * fVec25[((IOTA - 444) & 511)]) + ((0.00793951284f * fVec25[((IOTA - 443) & 511)]) + ((0.00992108695f * fVec25[((IOTA - 442) & 511)]) + ((0.00986267626f * fVec25[((IOTA - 441) & 511)]) + ((0.00755925756f * fVec25[((IOTA - 440) & 511)]) + ((0.00462101307f * fVec25[((IOTA - 439) & 511)]) + ((0.00160909723f * fVec25[((IOTA - 438) & 511)]) + ((0.000381804537f * fVec25[((IOTA - 436) & 511)]) + ((0.00146155711f * fVec25[((IOTA - 435) & 511)]) + ((0.00250920467f * fVec25[((IOTA - 434) & 511)]) + ((0.0028827684f * fVec25[((IOTA - 433) & 511)]) + (((8.06264579e-05f * fVec25[((IOTA - 431) & 511)]) + ((0.000672896393f * fVec25[((IOTA - 427) & 511)]) + ((0.000713110901f * fVec25[((IOTA - 426) & 511)]) + ((8.80430453e-05f * fVec25[((IOTA - 425) & 511)]) + ((0.00167881325f * fVec25[((IOTA - 417) & 511)]) + ((0.00295251701f * fVec25[((IOTA - 416) & 511)]) + ((0.00220720191f * fVec25[((IOTA - 415) & 511)]) + ((0.000419348944f * fVec25[((IOTA - 414) & 511)]) + ((0.00157109182f * fVec25[((IOTA - 406) & 511)]) + ((0.00223060558f * fVec25[((IOTA - 405) & 511)]) + ((0.00145582203f * fVec25[((IOTA - 404) & 511)]) + ((0.00130515033f * fVec25[((IOTA - 399) & 511)]) + ((0.0023886608f * fVec25[((IOTA - 398) & 511)]) + ((0.00221257471f * fVec25[((IOTA - 397) & 511)]) + ((0.000827886164f * fVec25[((IOTA - 396) & 511)]) + ((0.000870473683f * fVec25[((IOTA - 382) & 511)]) + ((0.000759719871f * fVec25[((IOTA - 374) & 511)]) + ((0.00560444919f * fVec25[((IOTA - 373) & 511)]) + ((0.00870018825f * fVec25[((IOTA - 372) & 511)]) + ((0.00845550746f * fVec25[((IOTA - 371) & 511)]) + ((0.00500271888f * fVec25[((IOTA - 370) & 511)]) + ((0.000586798415f * fVec25[((IOTA - 369) & 511)]) + ((0.0023251418f * fVec25[((IOTA - 357) & 511)]) + ((0.00447073672f * fVec25[((IOTA - 356) & 511)]) + ((0.00367433019f * fVec25[((IOTA - 355) & 511)]) + ((1.2525823e-05f * fVec25[((IOTA - 354) & 511)]) + ((0.00148364203f * fVec25[((IOTA - 346) & 511)]) + ((0.000514116138f * fVec25[((IOTA - 320) & 511)]) + ((0.000594709534f * fVec25[((IOTA - 319) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0222806409f * fVec25[((IOTA - 50) & 511)]) + ((0.0330871306f * fVec25[((IOTA - 49) & 511)]) + ((0.0521587394f * fVec25[((IOTA - 48) & 511)]) + ((0.0607159697f * fVec25[((IOTA - 47) & 511)]) + ((0.0401101895f * fVec25[((IOTA - 46) & 511)]) + ((0.0222397f * fVec25[((IOTA - 45) & 511)]) + ((0.0127981193f * fVec25[((IOTA - 44) & 511)]) + ((0.00257707434f * fVec25[((IOTA - 36) & 511)]) + ((0.0195915587f * fVec25[((IOTA - 35) & 511)]) + ((0.0335743167f * fVec25[((IOTA - 34) & 511)]) + ((0.052660726f * fVec25[((IOTA - 33) & 511)]) + ((0.0623143874f * fVec25[((IOTA - 32) & 511)]) + ((0.0432816409f * fVec25[((IOTA - 31) & 511)]) + ((0.0259747803f * fVec25[((IOTA - 30) & 511)]) + ((0.0125489561f * fVec25[((IOTA - 29) & 511)]) + ((0.00981781445f * fVec25[((IOTA - 17) & 511)]) + ((0.00411144551f * fVec25[((IOTA - 16) & 511)]) + ((0.0331511796f * fVec25[((IOTA - 10) & 511)]) + ((0.118776053f * fVec25[((IOTA - 9) & 511)]) + ((0.176075026f * fVec25[((IOTA - 8) & 511)]) + ((0.164582163f * fVec25[((IOTA - 7) & 511)]) + ((0.0686390698f * fVec25[((IOTA - 6) & 511)]) + (0.00308238948f * fVec25[((IOTA - 51) & 511)]))))))))))))))))))))))) + (0.00919917412f * fVec25[((IOTA - 56) & 511)])) + (0.0101162903f * fVec25[((IOTA - 57) & 511)])) + (0.0179837141f * fVec25[((IOTA - 58) & 511)])) + (0.0315069407f * fVec25[((IOTA - 59) & 511)])) + (0.0312714912f * fVec25[((IOTA - 60) & 511)])) + (0.0379232243f * fVec25[((IOTA - 61) & 511)])) + (0.0360629857f * fVec25[((IOTA - 62) & 511)])) + (0.0155246779f * fVec25[((IOTA - 63) & 511)])) + (0.00531012705f * fVec25[((IOTA - 64) & 511)])) + (0.0137998834f * fVec25[((IOTA - 67) & 511)])) + (0.0292765349f * fVec25[((IOTA - 68) & 511)])) + (0.0399137661f * fVec25[((IOTA - 69) & 511)])) + (0.0436233319f * fVec25[((IOTA - 70) & 511)])) + (0.0317992531f * fVec25[((IOTA - 71) & 511)])) + (0.0175621901f * fVec25[((IOTA - 72) & 511)])) + (0.00693507958f * fVec25[((IOTA - 76) & 511)])) + (0.0186064411f * fVec25[((IOTA - 77) & 511)])) + (0.0160137098f * fVec25[((IOTA - 78) & 511)])) + (0.0088968426f * fVec25[((IOTA - 79) & 511)])) + (0.00381949684f * fVec25[((IOTA - 80) & 511)])) + (0.00550404564f * fVec25[((IOTA - 82) & 511)])) + (0.0151347984f * fVec25[((IOTA - 83) & 511)])) + (0.022139363f * fVec25[((IOTA - 84) & 511)])) + (0.0246170554f * fVec25[((IOTA - 85) & 511)])) + (0.0213642828f * fVec25[((IOTA - 86) & 511)])) + (0.012786055f * fVec25[((IOTA - 87) & 511)])) + (0.00799601059f * fVec25[((IOTA - 88) & 511)])) + (0.0150352847f * fVec25[((IOTA - 89) & 511)])) + (0.0226772111f * fVec25[((IOTA - 90) & 511)])) + (0.0304957516f * fVec25[((IOTA - 91) & 511)])) + (0.0395586267f * fVec25[((IOTA - 92) & 511)])) + (0.0381401181f * fVec25[((IOTA - 93) & 511)])) + (0.0293385051f * fVec25[((IOTA - 94) & 511)])) + (0.0188660882f * fVec25[((IOTA - 95) & 511)])) + (0.00593918329f * fVec25[((IOTA - 96) & 511)])) + (0.00846648403f * fVec25[((IOTA - 103) & 511)])) + (0.0209801048f * fVec25[((IOTA - 104) & 511)])) + (0.0320163108f * fVec25[((IOTA - 105) & 511)])) + (0.0391880609f * fVec25[((IOTA - 106) & 511)])) + (0.0392304845f * fVec25[((IOTA - 107) & 511)])) + (0.0270939227f * fVec25[((IOTA - 108) & 511)])) + (0.0122908261f * fVec25[((IOTA - 109) & 511)])) + (0.00140736671f * fVec25[((IOTA - 110) & 511)])) + (0.000279324129f * fVec25[((IOTA - 113) & 511)])) + (0.00528032891f * fVec25[((IOTA - 114) & 511)])) + (0.0127705298f * fVec25[((IOTA - 115) & 511)])) + (0.0177432857f * fVec25[((IOTA - 116) & 511)])) + (0.0220880397f * fVec25[((IOTA - 117) & 511)])) + (0.0256740972f * fVec25[((IOTA - 118) & 511)])) + (0.0278332382f * fVec25[((IOTA - 119) & 511)])) + (0.0276871156f * fVec25[((IOTA - 120) & 511)])) + (0.0247570798f * fVec25[((IOTA - 121) & 511)])) + (0.0201714355f * fVec25[((IOTA - 122) & 511)])) + (0.0132552106f * fVec25[((IOTA - 123) & 511)])) + (0.0062689404f * fVec25[((IOTA - 124) & 511)])) + (0.00353331631f * fVec25[((IOTA - 125) & 511)])) + (0.0045834356f * fVec25[((IOTA - 126) & 511)])) + (0.00933076069f * fVec25[((IOTA - 127) & 511)])) + (0.0155749796f * fVec25[((IOTA - 128) & 511)])) + (0.0194766186f * fVec25[((IOTA - 129) & 511)])) + (0.0155553669f * fVec25[((IOTA - 130) & 511)])) + (0.00810781866f * fVec25[((IOTA - 131) & 511)])) + (0.00148983905f * fVec25[((IOTA - 132) & 511)])) + (0.00399558246f * fVec25[((IOTA - 138) & 511)])) + (0.00873766653f * fVec25[((IOTA - 139) & 511)])) + (0.0149646457f * fVec25[((IOTA - 140) & 511)])) + (0.0230445787f * fVec25[((IOTA - 141) & 511)])) + (0.0292766672f * fVec25[((IOTA - 142) & 511)])) + (0.0297981333f * fVec25[((IOTA - 143) & 511)])) + (0.0239757039f * fVec25[((IOTA - 144) & 511)])) + (0.0129869618f * fVec25[((IOTA - 145) & 511)])) + (0.000881351531f * fVec25[((IOTA - 146) & 511)])) + (0.00356634473f * fVec25[((IOTA - 152) & 511)])) + (0.00622051815f * fVec25[((IOTA - 153) & 511)])) + (0.00809806213f * fVec25[((IOTA - 154) & 511)])) + (0.00993740279f * fVec25[((IOTA - 155) & 511)])) + (0.011099793f * fVec25[((IOTA - 156) & 511)])) + (0.0110960342f * fVec25[((IOTA - 157) & 511)])) + (0.0100862617f * fVec25[((IOTA - 158) & 511)])) + (0.00838012248f * fVec25[((IOTA - 159) & 511)])) + (0.00589306885f * fVec25[((IOTA - 160) & 511)])) + (0.00239192368f * fVec25[((IOTA - 161) & 511)])) + (0.00073895324f * fVec25[((IOTA - 162) & 511)])) + (0.00204832293f * fVec25[((IOTA - 163) & 511)])) + (0.00443243468f * fVec25[((IOTA - 164) & 511)])) + (0.00850257836f * fVec25[((IOTA - 165) & 511)])) + (0.0124534313f * fVec25[((IOTA - 166) & 511)])) + (0.0143543445f * fVec25[((IOTA - 167) & 511)])) + (0.0129422639f * fVec25[((IOTA - 168) & 511)])) + (0.00848385505f * fVec25[((IOTA - 169) & 511)])) + (0.00223350618f * fVec25[((IOTA - 170) & 511)])) + (0.00820301473f * fVec25[((IOTA - 176) & 511)])) + (0.0130278021f * fVec25[((IOTA - 177) & 511)])) + (0.0125227831f * fVec25[((IOTA - 178) & 511)])) + (0.00957224425f * fVec25[((IOTA - 179) & 511)])) + (0.00538267754f * fVec25[((IOTA - 180) & 511)])) + (0.0014894763f * fVec25[((IOTA - 181) & 511)])) + (0.00233064638f * fVec25[((IOTA - 196) & 511)])) + (0.00377618428f * fVec25[((IOTA - 197) & 511)])) + (0.00356914662f * fVec25[((IOTA - 198) & 511)])) + (0.00357606867f * fVec25[((IOTA - 199) & 511)])) + (0.00357521186f * fVec25[((IOTA - 200) & 511)])) + (0.00299365446f * fVec25[((IOTA - 201) & 511)])) + (0.00261142105f * fVec25[((IOTA - 202) & 511)])) + (0.0025487924f * fVec25[((IOTA - 203) & 511)])) + (0.000873868819f * fVec25[((IOTA - 204) & 511)])) + (0.00195991714f * fVec25[((IOTA - 210) & 511)])) + (0.00312688854f * fVec25[((IOTA - 211) & 511)])) + (0.00119050685f * fVec25[((IOTA - 212) & 511)])) + (0.00300908089f * fVec25[((IOTA - 217) & 511)])) + (0.00715869712f * fVec25[((IOTA - 218) & 511)])) + (0.00967004336f * fVec25[((IOTA - 219) & 511)])) + (0.00847597793f * fVec25[((IOTA - 220) & 511)])) + (0.00515569793f * fVec25[((IOTA - 221) & 511)])) + (0.000863123219f * fVec25[((IOTA - 222) & 511)])) + (5.1422976e-06f * fVec25[((IOTA - 247) & 511)])) + (0.0016635186f * fVec25[((IOTA - 432) & 511)]))))))))))))))))))))))))))))))) + (0.00274831429f * fVec25[((IOTA - 481) & 511)])))))))))))))))))))))))))))))))))))))))))))))) + (0.00417529419f * fVec25[((IOTA - 482) & 511)])) + (0.00540449889f * fVec25[((IOTA - 483) & 511)])) + (0.00522508379f * fVec25[((IOTA - 484) & 511)])) + (0.00342503469f * fVec25[((IOTA - 485) & 511)])) + (0.00196222449f * fVec25[((IOTA - 486) & 511)])) + (0.000248141587f * fVec25[((IOTA - 487) & 511)])) + (0.000528158154f * fVec25[((IOTA - 489) & 511)])) + (0.00228166441f * fVec25[((IOTA - 490) & 511)])) + (0.00415258296f * fVec25[((IOTA - 491) & 511)])) + (0.0053080502f * fVec25[((IOTA - 492) & 511)])) + (0.00460492726f * fVec25[((IOTA - 493) & 511)])) + (0.00270905625f * fVec25[((IOTA - 494) & 511)])) + (0.000165373087f * fVec25[((IOTA - 495) & 511)])) + (0.00109455269f * fVec25[((IOTA - 499) & 511)])) + (0.0024943715f * fVec25[((IOTA - 500) & 511)])) + (0.00327142933f * fVec25[((IOTA - 501) & 511)])) + (0.00358289201f * fVec25[((IOTA - 502) & 511)])) + (0.003885224f * fVec25[((IOTA - 503) & 511)])) + (0.00412568543f * fVec25[((IOTA - 504) & 511)])) + (0.00504253758f * fVec25[((IOTA - 505) & 511)])) + (0.0065780296f * fVec25[((IOTA - 506) & 511)])) + (0.00792675652f * fVec25[((IOTA - 507) & 511)])) + (0.00900861807f * fVec25[((IOTA - 508) & 511)])) + (0.00914178696f * fVec25[((IOTA - 509) & 511)])) + (0.00819134619f * fVec25[((IOTA - 510) & 511)])) + (0.0072538266f * fVec25[((IOTA - 511) & 511)]))) : (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00590199325f * fVec24[((IOTA - 319) & 511)]) + ((0.00657166075f * fVec24[((IOTA - 318) & 511)]) + ((0.00924602896f * fVec24[((IOTA - 317) & 511)]) + ((0.0124171078f * fVec24[((IOTA - 316) & 511)]) + ((0.0139596397f * fVec24[((IOTA - 315) & 511)]) + ((0.0132515263f * fVec24[((IOTA - 314) & 511)]) + ((0.0114795864f * fVec24[((IOTA - 313) & 511)]) + ((0.00992417894f * fVec24[((IOTA - 312) & 511)]) + ((0.00905813742f * fVec24[((IOTA - 311) & 511)]) + ((0.00993886776f * fVec24[((IOTA - 310) & 511)]) + ((0.013939634f * fVec24[((IOTA - 309) & 511)]) + ((0.0192846209f * fVec24[((IOTA - 308) & 511)]) + ((0.0227221716f * fVec24[((IOTA - 307) & 511)]) + ((0.0226876289f * fVec24[((IOTA - 306) & 511)]) + ((0.0197043493f * fVec24[((IOTA - 305) & 511)]) + ((0.0151763558f * fVec24[((IOTA - 304) & 511)]) + ((0.010949254f * fVec24[((IOTA - 303) & 511)]) + ((0.00755906012f * fVec24[((IOTA - 302) & 511)]) + ((0.0059647467f * fVec24[((IOTA - 301) & 511)]) + ((0.00665614149f * fVec24[((IOTA - 300) & 511)]) + ((0.00834046677f * fVec24[((IOTA - 299) & 511)]) + ((0.0102831824f * fVec24[((IOTA - 298) & 511)]) + ((0.0124440603f * fVec24[((IOTA - 297) & 511)]) + ((0.0133161545f * fVec24[((IOTA - 296) & 511)]) + ((0.0115531571f * fVec24[((IOTA - 295) & 511)]) + ((0.00992934126f * fVec24[((IOTA - 294) & 511)]) + ((0.00983803812f * fVec24[((IOTA - 293) & 511)]) + ((0.0106046014f * fVec24[((IOTA - 292) & 511)]) + ((0.0118384361f * fVec24[((IOTA - 291) & 511)]) + ((0.0123349018f * fVec24[((IOTA - 290) & 511)]) + ((0.0128475018f * fVec24[((IOTA - 289) & 511)]) + ((0.0132078882f * fVec24[((IOTA - 288) & 511)]) + ((0.0116847493f * fVec24[((IOTA - 287) & 511)]) + ((0.00908681005f * fVec24[((IOTA - 286) & 511)]) + ((0.00731287105f * fVec24[((IOTA - 285) & 511)]) + ((0.00662285928f * fVec24[((IOTA - 284) & 511)]) + ((0.00692934357f * fVec24[((IOTA - 283) & 511)]) + ((0.0088909585f * fVec24[((IOTA - 282) & 511)]) + ((0.0109948292f * fVec24[((IOTA - 281) & 511)]) + ((0.0109109636f * fVec24[((IOTA - 280) & 511)]) + ((0.00969679654f * fVec24[((IOTA - 279) & 511)]) + ((0.00906680338f * fVec24[((IOTA - 278) & 511)]) + ((0.00963355228f * fVec24[((IOTA - 277) & 511)]) + ((0.0112339193f * fVec24[((IOTA - 276) & 511)]) + ((0.0128230397f * fVec24[((IOTA - 275) & 511)]) + ((0.015845716f * fVec24[((IOTA - 274) & 511)]) + ((0.0184577927f * fVec24[((IOTA - 273) & 511)]) + ((0.0184230041f * fVec24[((IOTA - 272) & 511)]) + (((((((((((((0.0108634215f * fVec24[((IOTA - 260) & 511)]) + ((0.0123139434f * fVec24[((IOTA - 259) & 511)]) + ((0.0136015266f * fVec24[((IOTA - 258) & 511)]) + ((0.0142875127f * fVec24[((IOTA - 257) & 511)]) + ((0.0126769422f * fVec24[((IOTA - 256) & 511)]) + ((0.00892439485f * fVec24[((IOTA - 255) & 511)]) + ((0.00505669555f * fVec24[((IOTA - 254) & 511)]) + ((0.00313358707f * fVec24[((IOTA - 253) & 511)]) + ((0.00413933303f * fVec24[((IOTA - 252) & 511)]) + ((0.00687943585f * fVec24[((IOTA - 251) & 511)]) + ((0.0103937853f * fVec24[((IOTA - 250) & 511)]) + ((0.0136954412f * fVec24[((IOTA - 249) & 511)]) + ((0.0138432598f * fVec24[((IOTA - 248) & 511)]) + ((0.00959144905f * fVec24[((IOTA - 247) & 511)]) + ((0.00254812371f * fVec24[((IOTA - 246) & 511)]) + ((0.00164689496f * fVec24[((IOTA - 242) & 511)]) + ((0.00855865981f * fVec24[((IOTA - 241) & 511)]) + ((0.0148987602f * fVec24[((IOTA - 240) & 511)]) + ((0.0159085318f * fVec24[((IOTA - 239) & 511)]) + ((0.0129772499f * fVec24[((IOTA - 238) & 511)]) + ((0.0102214739f * fVec24[((IOTA - 237) & 511)]) + ((0.00848134048f * fVec24[((IOTA - 236) & 511)]) + ((0.00842565484f * fVec24[((IOTA - 235) & 511)]) + ((0.0108743012f * fVec24[((IOTA - 234) & 511)]) + ((0.0144593008f * fVec24[((IOTA - 233) & 511)]) + ((0.0177603737f * fVec24[((IOTA - 232) & 511)]) + ((0.0185439326f * fVec24[((IOTA - 231) & 511)]) + ((0.0157534927f * fVec24[((IOTA - 230) & 511)]) + ((0.010724362f * fVec24[((IOTA - 229) & 511)]) + ((0.00518247951f * fVec24[((IOTA - 228) & 511)]) + ((0.000258881133f * fVec24[((IOTA - 227) & 511)]) + ((0.00383140473f * fVec24[((IOTA - 219) & 511)]) + ((0.00966136344f * fVec24[((IOTA - 218) & 511)]) + ((0.0140536167f * fVec24[((IOTA - 217) & 511)]) + ((0.0163240507f * fVec24[((IOTA - 216) & 511)]) + ((0.0144286919f * fVec24[((IOTA - 215) & 511)]) + ((0.00616434729f * fVec24[((IOTA - 214) & 511)]) + ((0.00561686745f * fVec24[((IOTA - 207) & 511)]) + ((0.0071723056f * fVec24[((IOTA - 206) & 511)]) + ((0.00435774121f * fVec24[((IOTA - 205) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((0.0653625205f * fVec24[((IOTA - 5) & 511)]) + ((0.0533584729f * fVec24[((IOTA - 14) & 511)]) + ((0.045722831f * fVec24[((IOTA - 15) & 511)]) + ((0.0100420946f * fVec24[((IOTA - 10) & 511)]) + ((0.0223713424f * fVec24[((IOTA - 16) & 511)]) + ((0.175777957f * fVec24[((IOTA - 4) & 511)]) + ((0.0554466695f * fVec24[((IOTA - 11) & 511)]) + ((((fSlow79 * fTemp0) + ((0.244819701f * fVec24[((IOTA - 1) & 511)]) + ((0.249028578f * fVec24[((IOTA - 3) & 511)]) + ((0.0148368366f * fVec24[((IOTA - 17) & 511)]) + (((0.0768061504f * fVec24[((IOTA - 12) & 511)]) + ((0.248890013f * fVec24[((IOTA - 2) & 511)]) + (0.0698548034f * fVec24[((IOTA - 13) & 511)]))) + (0.0257615671f * fVec24[((IOTA - 18) & 511)])))))) + (0.00928361341f * fVec24[((IOTA - 19) & 511)])) + (0.0207454674f * fVec24[((IOTA - 20) & 511)]))))))))) + (0.0106402198f * fVec24[((IOTA - 21) & 511)])) + (0.00521702133f * fVec24[((IOTA - 24) & 511)])) + (0.0262563415f * fVec24[((IOTA - 25) & 511)])) + (0.0391688421f * fVec24[((IOTA - 26) & 511)])) + (0.0377498791f * fVec24[((IOTA - 27) & 511)])) + (0.021535879f * fVec24[((IOTA - 28) & 511)])) + (0.00309766224f * fVec24[((IOTA - 34) & 511)])) + (0.0169991273f * fVec24[((IOTA - 35) & 511)])) + (0.0234733392f * fVec24[((IOTA - 36) & 511)])) + (0.00958462711f * fVec24[((IOTA - 37) & 511)])) + (0.0156796761f * fVec24[((IOTA - 43) & 511)])) + (0.0156136639f * fVec24[((IOTA - 44) & 511)])) + (0.0125812143f * fVec24[((IOTA - 45) & 511)])) + (0.0186480191f * fVec24[((IOTA - 53) & 511)])) + (0.0289756097f * fVec24[((IOTA - 54) & 511)])) + (0.0263821259f * fVec24[((IOTA - 55) & 511)])) + (0.0179577917f * fVec24[((IOTA - 56) & 511)])) + (0.000286047813f * fVec24[((IOTA - 66) & 511)])) + (0.000821695663f * fVec24[((IOTA - 74) & 511)])) + (0.00247900886f * fVec24[((IOTA - 80) & 511)])) + (0.00485645002f * fVec24[((IOTA - 81) & 511)])) + (0.00184627995f * fVec24[((IOTA - 101) & 511)])) + (0.00698856264f * fVec24[((IOTA - 126) & 511)])) + (0.0169460233f * fVec24[((IOTA - 127) & 511)])) + (0.0153443962f * fVec24[((IOTA - 128) & 511)])) + (0.00542743923f * fVec24[((IOTA - 129) & 511)])) + (0.00160015235f * fVec24[((IOTA - 136) & 511)])) + (0.000204917043f * fVec24[((IOTA - 137) & 511)])) + (0.000399047043f * fVec24[((IOTA - 154) & 511)])) + (0.00188432541f * fVec24[((IOTA - 155) & 511)])) + (0.00473755039f * fVec24[((IOTA - 170) & 511)])) + (0.00948431995f * fVec24[((IOTA - 171) & 511)])) + (0.0110472571f * fVec24[((IOTA - 172) & 511)])) + (0.0104364092f * fVec24[((IOTA - 173) & 511)])) + (0.00722633163f * fVec24[((IOTA - 174) & 511)])) + (0.00379043957f * fVec24[((IOTA - 175) & 511)])) + (0.00166244479f * fVec24[((IOTA - 182) & 511)])) + (0.00497365976f * fVec24[((IOTA - 183) & 511)])) + (0.00729606114f * fVec24[((IOTA - 184) & 511)])) + (0.00749071361f * fVec24[((IOTA - 185) & 511)])) + (0.00505405292f * fVec24[((IOTA - 186) & 511)])) + (0.000136846676f * fVec24[((IOTA - 187) & 511)])) + (0.0026895185f * fVec24[((IOTA - 192) & 511)])) + (0.00566059817f * fVec24[((IOTA - 193) & 511)])) + (0.00748447515f * fVec24[((IOTA - 194) & 511)])) + (0.00785023998f * fVec24[((IOTA - 195) & 511)])) + (0.00557501148f * fVec24[((IOTA - 196) & 511)])) + (0.00201431941f * fVec24[((IOTA - 197) & 511)])) + (0.00970782898f * fVec24[((IOTA - 261) & 511)])))))))))))))))))))))))))))))))))))))))))) + (0.0103959357f * fVec24[((IOTA - 262) & 511)])) + (0.0129575199f * fVec24[((IOTA - 263) & 511)])) + (0.0163298286f * fVec24[((IOTA - 264) & 511)])) + (0.0186628625f * fVec24[((IOTA - 265) & 511)])) + (0.0179791506f * fVec24[((IOTA - 266) & 511)])) + (0.0150455944f * fVec24[((IOTA - 267) & 511)])) + (0.0126246987f * fVec24[((IOTA - 268) & 511)])) + (0.0116209202f * fVec24[((IOTA - 269) & 511)])) + (0.0132188592f * fVec24[((IOTA - 270) & 511)])) + (0.0163696874f * fVec24[((IOTA - 271) & 511)])) + (0.00652971258f * fVec24[((IOTA - 320) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00840764586f * fVec24[((IOTA - 321) & 511)])) + (0.00934612099f * fVec24[((IOTA - 322) & 511)])) + (0.00786357746f * fVec24[((IOTA - 323) & 511)])) + (0.0053399778f * fVec24[((IOTA - 324) & 511)])) + (0.00307406066f * fVec24[((IOTA - 325) & 511)])) + (0.0015022424f * fVec24[((IOTA - 326) & 511)])) + (0.00160331791f * fVec24[((IOTA - 327) & 511)])) + (0.00340134976f * fVec24[((IOTA - 328) & 511)])) + (0.00546963327f * fVec24[((IOTA - 329) & 511)])) + (0.00664295768f * fVec24[((IOTA - 330) & 511)])) + (0.00683115656f * fVec24[((IOTA - 331) & 511)])) + (0.00642378163f * fVec24[((IOTA - 332) & 511)])) + (0.0065219989f * fVec24[((IOTA - 333) & 511)])) + (0.00711450027f * fVec24[((IOTA - 334) & 511)])) + (0.00768794771f * fVec24[((IOTA - 335) & 511)])) + (0.00796259381f * fVec24[((IOTA - 336) & 511)])) + (0.0066806036f * fVec24[((IOTA - 337) & 511)])) + (0.00545746367f * fVec24[((IOTA - 338) & 511)])) + (0.00544258999f * fVec24[((IOTA - 339) & 511)])) + (0.00694547733f * fVec24[((IOTA - 340) & 511)])) + (0.0102838278f * fVec24[((IOTA - 341) & 511)])) + (0.0142022334f * fVec24[((IOTA - 342) & 511)])) + (0.0160365291f * fVec24[((IOTA - 343) & 511)])) + (0.0152595462f * fVec24[((IOTA - 344) & 511)])) + (0.0121593028f * fVec24[((IOTA - 345) & 511)])) + (0.00826326944f * fVec24[((IOTA - 346) & 511)])) + (0.00552488863f * fVec24[((IOTA - 347) & 511)])) + (0.00437476626f * fVec24[((IOTA - 348) & 511)])) + (0.0050652083f * fVec24[((IOTA - 349) & 511)])) + (0.0069233817f * fVec24[((IOTA - 350) & 511)])) + (0.00830531027f * fVec24[((IOTA - 351) & 511)])) + (0.00892141275f * fVec24[((IOTA - 352) & 511)])) + (0.00757550169f * fVec24[((IOTA - 353) & 511)])) + (0.00452983705f * fVec24[((IOTA - 354) & 511)])) + (0.00244468171f * fVec24[((IOTA - 355) & 511)])) + (0.00163702993f * fVec24[((IOTA - 356) & 511)])) + (0.00133011583f * fVec24[((IOTA - 357) & 511)])) + (0.00200559152f * fVec24[((IOTA - 358) & 511)])) + (0.00337759452f * fVec24[((IOTA - 359) & 511)])) + (0.00577178458f * fVec24[((IOTA - 360) & 511)])) + (0.00849559903f * fVec24[((IOTA - 361) & 511)])) + (0.00996594224f * fVec24[((IOTA - 362) & 511)])) + (0.0108817071f * fVec24[((IOTA - 363) & 511)])) + (0.0117983017f * fVec24[((IOTA - 364) & 511)])) + (0.0113986395f * fVec24[((IOTA - 365) & 511)])) + (0.00995752215f * fVec24[((IOTA - 366) & 511)])) + (0.00800540298f * fVec24[((IOTA - 367) & 511)])) + (0.00508920942f * fVec24[((IOTA - 368) & 511)])) + (0.00211444218f * fVec24[((IOTA - 369) & 511)])) + (0.00244071754f * fVec24[((IOTA - 376) & 511)])) + (0.00469222153f * fVec24[((IOTA - 377) & 511)])) + (0.00445171772f * fVec24[((IOTA - 378) & 511)])) + (0.00202421471f * fVec24[((IOTA - 379) & 511)])) + (0.00123607786f * fVec24[((IOTA - 383) & 511)])) + (0.00461674528f * fVec24[((IOTA - 384) & 511)])) + (0.0074217217f * fVec24[((IOTA - 385) & 511)])) + (0.00936090294f * fVec24[((IOTA - 386) & 511)])) + (0.00938806869f * fVec24[((IOTA - 387) & 511)])) + (0.00752654625f * fVec24[((IOTA - 388) & 511)])) + (0.00499984249f * fVec24[((IOTA - 389) & 511)])) + (0.00287891598f * fVec24[((IOTA - 390) & 511)])) + (0.0017440985f * fVec24[((IOTA - 391) & 511)])) + (0.00140473153f * fVec24[((IOTA - 392) & 511)])) + (0.00187175628f * fVec24[((IOTA - 393) & 511)])) + (0.00296481047f * fVec24[((IOTA - 394) & 511)])) + (0.00352412136f * fVec24[((IOTA - 395) & 511)])) + (0.00255725067f * fVec24[((IOTA - 396) & 511)])) + (0.000742009375f * fVec24[((IOTA - 397) & 511)])) + (7.52918422e-05f * fVec24[((IOTA - 402) & 511)])) + (0.00049877027f * fVec24[((IOTA - 407) & 511)])) + (0.00297350716f * fVec24[((IOTA - 408) & 511)])) + (0.00511425547f * fVec24[((IOTA - 409) & 511)])) + (0.00612799171f * fVec24[((IOTA - 410) & 511)])) + (0.00609636912f * fVec24[((IOTA - 411) & 511)])) + (0.00409652432f * fVec24[((IOTA - 412) & 511)])) + (0.000906698871f * fVec24[((IOTA - 413) & 511)])) + (0.00129612675f * fVec24[((IOTA - 418) & 511)])) + (0.00335811079f * fVec24[((IOTA - 419) & 511)])) + (0.00527018681f * fVec24[((IOTA - 420) & 511)])) + (0.00572113926f * fVec24[((IOTA - 421) & 511)])) + (0.00513641303f * fVec24[((IOTA - 422) & 511)])) + (0.00371023081f * fVec24[((IOTA - 423) & 511)])) + (0.0011748299f * fVec24[((IOTA - 424) & 511)])) + (3.18069942e-05f * fVec24[((IOTA - 429) & 511)])) + (0.000843453687f * fVec24[((IOTA - 501) & 511)])) + (0.000957221258f * fVec24[((IOTA - 502) & 511)])) - (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0112575823f * fVec24[((IOTA - 143) & 511)]) + ((0.0117641585f * fVec24[((IOTA - 142) & 511)]) + ((0.00995297357f * fVec24[((IOTA - 141) & 511)]) + ((0.0107734706f * fVec24[((IOTA - 140) & 511)]) + ((0.00999295525f * fVec24[((IOTA - 139) & 511)]) + ((0.00539166806f * fVec24[((IOTA - 138) & 511)]) + ((0.00413764315f * fVec24[((IOTA - 135) & 511)]) + ((0.0126049388f * fVec24[((IOTA - 134) & 511)]) + ((0.0215313919f * fVec24[((IOTA - 133) & 511)]) + ((0.0248911008f * fVec24[((IOTA - 132) & 511)]) + ((0.0179669205f * fVec24[((IOTA - 131) & 511)]) + ((0.00658210972f * fVec24[((IOTA - 130) & 511)]) + ((0.00968542695f * fVec24[((IOTA - 125) & 511)]) + ((0.027121339f * fVec24[((IOTA - 124) & 511)]) + ((0.041477412f * fVec24[((IOTA - 123) & 511)]) + ((0.047335431f * fVec24[((IOTA - 122) & 511)]) + ((0.0452272557f * fVec24[((IOTA - 121) & 511)]) + ((0.0387084857f * fVec24[((IOTA - 120) & 511)]) + ((0.029028222f * fVec24[((IOTA - 119) & 511)]) + ((0.0195204224f * fVec24[((IOTA - 118) & 511)]) + ((0.0122350249f * fVec24[((IOTA - 117) & 511)]) + ((0.00732571678f * fVec24[((IOTA - 116) & 511)]) + ((0.00677098474f * fVec24[((IOTA - 115) & 511)]) + ((0.0123885591f * fVec24[((IOTA - 114) & 511)]) + ((0.018253766f * fVec24[((IOTA - 113) & 511)]) + ((0.020434374f * fVec24[((IOTA - 112) & 511)]) + ((0.0174399391f * fVec24[((IOTA - 111) & 511)]) + ((0.0161334537f * fVec24[((IOTA - 110) & 511)]) + ((0.0170096066f * fVec24[((IOTA - 109) & 511)]) + ((0.0195880011f * fVec24[((IOTA - 108) & 511)]) + ((0.0212854799f * fVec24[((IOTA - 107) & 511)]) + ((0.0194857884f * fVec24[((IOTA - 106) & 511)]) + ((0.0168571472f * fVec24[((IOTA - 105) & 511)]) + ((0.0145892333f * fVec24[((IOTA - 104) & 511)]) + ((0.00726692751f * fVec24[((IOTA - 103) & 511)]) + ((2.7352944e-06f * fVec24[((IOTA - 102) & 511)]) + ((0.00415512919f * fVec24[((IOTA - 100) & 511)]) + ((0.0111554312f * fVec24[((IOTA - 99) & 511)]) + ((0.0192891061f * fVec24[((IOTA - 98) & 511)]) + ((0.0254923906f * fVec24[((IOTA - 97) & 511)]) + ((0.0267366134f * fVec24[((IOTA - 96) & 511)]) + ((0.0256723538f * fVec24[((IOTA - 95) & 511)]) + ((0.0251989067f * fVec24[((IOTA - 94) & 511)]) + ((0.0245600939f * fVec24[((IOTA - 93) & 511)]) + ((0.0238730926f * fVec24[((IOTA - 92) & 511)]) + ((0.024105791f * fVec24[((IOTA - 91) & 511)]) + ((((0.0168284755f * fVec24[((IOTA - 88) & 511)]) + ((0.0227786563f * fVec24[((IOTA - 87) & 511)]) + ((0.027938731f * fVec24[((IOTA - 86) & 511)]) + ((0.0295561552f * fVec24[((IOTA - 85) & 511)]) + ((0.0257628579f * fVec24[((IOTA - 84) & 511)]) + ((0.0172522627f * fVec24[((IOTA - 83) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((0.108475491f * fVec24[((IOTA - 8) & 511)]) + (((0.0574696884f * fVec24[((IOTA - 6) & 511)]) + (0.13820903f * fVec24[((IOTA - 7) & 511)])) + (0.0553351492f * fVec24[((IOTA - 9) & 511)]))) + (0.00141284475f * fVec24[((IOTA - 22) & 511)])) + (0.0020742761f * fVec24[((IOTA - 23) & 511)])) + (0.0138633586f * fVec24[((IOTA - 29) & 511)])) + (0.0507223979f * fVec24[((IOTA - 30) & 511)])) + (0.0660558492f * fVec24[((IOTA - 31) & 511)])) + (0.0613729432f * fVec24[((IOTA - 32) & 511)])) + (0.0314208753f * fVec24[((IOTA - 33) & 511)])) + (0.0286465995f * fVec24[((IOTA - 38) & 511)])) + (0.0378689021f * fVec24[((IOTA - 39) & 511)])) + (0.0381036922f * fVec24[((IOTA - 40) & 511)])) + (0.0295051411f * fVec24[((IOTA - 41) & 511)])) + (0.0013299929f * fVec24[((IOTA - 42) & 511)])) + (0.0144196264f * fVec24[((IOTA - 46) & 511)])) + (0.0472281165f * fVec24[((IOTA - 47) & 511)])) + (0.0616046265f * fVec24[((IOTA - 48) & 511)])) + (0.0647147372f * fVec24[((IOTA - 49) & 511)])) + (0.0632742345f * fVec24[((IOTA - 50) & 511)])) + (0.0344472714f * fVec24[((IOTA - 51) & 511)])) + (0.00468149642f * fVec24[((IOTA - 52) & 511)])) + (0.00391096808f * fVec24[((IOTA - 57) & 511)])) + (0.0297400523f * fVec24[((IOTA - 58) & 511)])) + (0.0373835303f * fVec24[((IOTA - 59) & 511)])) + (0.0442288555f * fVec24[((IOTA - 60) & 511)])) + (0.053393323f * fVec24[((IOTA - 61) & 511)])) + (0.0521461517f * fVec24[((IOTA - 62) & 511)])) + (0.0440364145f * fVec24[((IOTA - 63) & 511)])) + (0.0360138044f * fVec24[((IOTA - 64) & 511)])) + (0.0152752809f * fVec24[((IOTA - 65) & 511)])) + (0.00983619504f * fVec24[((IOTA - 67) & 511)])) + (0.0188454688f * fVec24[((IOTA - 68) & 511)])) + (0.0258647949f * fVec24[((IOTA - 69) & 511)])) + (0.0371274166f * fVec24[((IOTA - 70) & 511)])) + (0.0353031717f * fVec24[((IOTA - 71) & 511)])) + (0.0171798579f * fVec24[((IOTA - 72) & 511)])) + (0.00589354197f * fVec24[((IOTA - 73) & 511)])) + (0.00486250408f * fVec24[((IOTA - 75) & 511)])) + (0.0215470959f * fVec24[((IOTA - 76) & 511)])) + (0.0353289545f * fVec24[((IOTA - 77) & 511)])) + (0.0242847092f * fVec24[((IOTA - 78) & 511)])) + (0.00522568775f * fVec24[((IOTA - 79) & 511)])) + (0.00266468758f * fVec24[((IOTA - 82) & 511)])) + (0.0180938412f * fVec24[((IOTA - 89) & 511)])))))))) + (0.0226643346f * fVec24[((IOTA - 90) & 511)])) + (0.010101622f * fVec24[((IOTA - 144) & 511)])))))))))))))))))))))))))))))))))))))))))))))))) + (0.0116179381f * fVec24[((IOTA - 145) & 511)])) + (0.0110955667f * fVec24[((IOTA - 146) & 511)])) + (0.0101119466f * fVec24[((IOTA - 147) & 511)])) + (0.0101720886f * fVec24[((IOTA - 148) & 511)])) + (0.00888306089f * fVec24[((IOTA - 149) & 511)])) + (0.00789258815f * fVec24[((IOTA - 150) & 511)])) + (0.00855328143f * fVec24[((IOTA - 151) & 511)])) + (0.00751674315f * fVec24[((IOTA - 152) & 511)])) + (0.00332396803f * fVec24[((IOTA - 153) & 511)])) + (0.000223109964f * fVec24[((IOTA - 156) & 511)])) + (0.00606674422f * fVec24[((IOTA - 157) & 511)])) + (0.0111608403f * fVec24[((IOTA - 158) & 511)])) + (0.0111421244f * fVec24[((IOTA - 159) & 511)])) + (0.00855091587f * fVec24[((IOTA - 160) & 511)])) + (0.00599492481f * fVec24[((IOTA - 161) & 511)])) + (0.00470586633f * fVec24[((IOTA - 162) & 511)])) + (0.00820269808f * fVec24[((IOTA - 163) & 511)])) + (0.0140079185f * fVec24[((IOTA - 164) & 511)])) + (0.0171953775f * fVec24[((IOTA - 165) & 511)])) + (0.0181953162f * fVec24[((IOTA - 166) & 511)])) + (0.0160513408f * fVec24[((IOTA - 167) & 511)])) + (0.0092597967f * fVec24[((IOTA - 168) & 511)])) + (0.00193785969f * fVec24[((IOTA - 169) & 511)])) + (0.00155549962f * fVec24[((IOTA - 176) & 511)])) + (0.00857820548f * fVec24[((IOTA - 177) & 511)])) + (0.0115731014f * fVec24[((IOTA - 178) & 511)])) + (0.0108310003f * fVec24[((IOTA - 179) & 511)])) + (0.00712021627f * fVec24[((IOTA - 180) & 511)])) + (0.00223973393f * fVec24[((IOTA - 181) & 511)])) + (0.00357488962f * fVec24[((IOTA - 188) & 511)])) + (0.004906327f * fVec24[((IOTA - 189) & 511)])) + (0.0046544834f * fVec24[((IOTA - 190) & 511)])) + (0.00192753412f * fVec24[((IOTA - 191) & 511)])) + (0.00135755911f * fVec24[((IOTA - 198) & 511)])) + (0.00432869978f * fVec24[((IOTA - 199) & 511)])) + (0.00726867933f * fVec24[((IOTA - 200) & 511)])) + (0.00826532952f * fVec24[((IOTA - 201) & 511)])) + (0.00739280367f * fVec24[((IOTA - 202) & 511)])) + (0.00512737781f * fVec24[((IOTA - 203) & 511)])) + (0.000863121822f * fVec24[((IOTA - 204) & 511)])) + (0.00032400107f * fVec24[((IOTA - 208) & 511)])) + (0.00758843962f * fVec24[((IOTA - 209) & 511)])) + (0.0132890809f * fVec24[((IOTA - 210) & 511)])) + (0.0139824729f * fVec24[((IOTA - 211) & 511)])) + (0.0101739317f * fVec24[((IOTA - 212) & 511)])) + (0.00374123873f * fVec24[((IOTA - 213) & 511)])) + (0.00165488524f * fVec24[((IOTA - 220) & 511)])) + (0.00611465424f * fVec24[((IOTA - 221) & 511)])) + (0.0104973186f * fVec24[((IOTA - 222) & 511)])) + (0.0121320132f * fVec24[((IOTA - 223) & 511)])) + (0.0107074901f * fVec24[((IOTA - 224) & 511)])) + (0.00764283398f * fVec24[((IOTA - 225) & 511)])) + (0.00365946256f * fVec24[((IOTA - 226) & 511)])) + (0.0041560512f * fVec24[((IOTA - 243) & 511)])) + (0.00671831099f * fVec24[((IOTA - 244) & 511)])) + (0.00378370937f * fVec24[((IOTA - 245) & 511)])) + (0.000537491869f * fVec24[((IOTA - 370) & 511)])) + (0.00287679583f * fVec24[((IOTA - 371) & 511)])) + (0.00491010724f * fVec24[((IOTA - 372) & 511)])) + (0.00557799218f * fVec24[((IOTA - 373) & 511)])) + (0.00388838071f * fVec24[((IOTA - 374) & 511)])) + (0.000739028212f * fVec24[((IOTA - 375) & 511)])) + (0.000416594557f * fVec24[((IOTA - 380) & 511)])) + (0.00177375413f * fVec24[((IOTA - 381) & 511)])) + (0.00134824729f * fVec24[((IOTA - 382) & 511)])) + (0.00110460911f * fVec24[((IOTA - 398) & 511)])) + (0.00177194085f * fVec24[((IOTA - 399) & 511)])) + (0.00112864096f * fVec24[((IOTA - 400) & 511)])) + (0.000407897867f * fVec24[((IOTA - 401) & 511)])) + (0.000432267785f * fVec24[((IOTA - 403) & 511)])) + (0.00145387091f * fVec24[((IOTA - 404) & 511)])) + (0.00136020174f * fVec24[((IOTA - 405) & 511)])) + (0.0007250458f * fVec24[((IOTA - 406) & 511)])) + (0.00110510038f * fVec24[((IOTA - 414) & 511)])) + (0.00239978312f * fVec24[((IOTA - 415) & 511)])) + (0.00255838782f * fVec24[((IOTA - 416) & 511)])) + (0.00073340442f * fVec24[((IOTA - 417) & 511)])) + (0.000739120413f * fVec24[((IOTA - 425) & 511)])) + (0.00169784762f * fVec24[((IOTA - 426) & 511)])) + (0.00219646422f * fVec24[((IOTA - 427) & 511)])) + (0.00117642805f * fVec24[((IOTA - 428) & 511)])) + (5.23356721e-05f * fVec24[((IOTA - 430) & 511)])) + (0.00063171424f * fVec24[((IOTA - 431) & 511)])) + (0.00178862829f * fVec24[((IOTA - 432) & 511)])) + (0.00313945673f * fVec24[((IOTA - 433) & 511)])) + (0.0031263344f * fVec24[((IOTA - 434) & 511)])) + (0.00217615068f * fVec24[((IOTA - 435) & 511)])) + (0.00130531564f * fVec24[((IOTA - 436) & 511)])) + (0.00119603472f * fVec24[((IOTA - 437) & 511)])) + (0.00213561626f * fVec24[((IOTA - 438) & 511)])) + (0.00419471134f * fVec24[((IOTA - 439) & 511)])) + (0.00647584023f * fVec24[((IOTA - 440) & 511)])) + (0.00834996253f * fVec24[((IOTA - 441) & 511)])) + (0.00891738757f * fVec24[((IOTA - 442) & 511)])) + (0.00842439476f * fVec24[((IOTA - 443) & 511)])) + (0.00790478848f * fVec24[((IOTA - 444) & 511)])) + (0.00667722337f * fVec24[((IOTA - 445) & 511)])) + (0.00477909902f * fVec24[((IOTA - 446) & 511)])) + (0.00345675834f * fVec24[((IOTA - 447) & 511)])) + (0.00326207513f * fVec24[((IOTA - 448) & 511)])) + (0.00439102342f * fVec24[((IOTA - 449) & 511)])) + (0.00634507835f * fVec24[((IOTA - 450) & 511)])) + (0.00822848268f * fVec24[((IOTA - 451) & 511)])) + (0.00971074961f * fVec24[((IOTA - 452) & 511)])) + (0.0093045719f * fVec24[((IOTA - 453) & 511)])) + (0.00675773947f * fVec24[((IOTA - 454) & 511)])) + (0.00351296598f * fVec24[((IOTA - 455) & 511)])) + (0.000875783153f * fVec24[((IOTA - 456) & 511)])) + (0.00020838948f * fVec24[((IOTA - 457) & 511)])) + (0.00173030002f * fVec24[((IOTA - 458) & 511)])) + (0.00354907569f * fVec24[((IOTA - 459) & 511)])) + (0.00456757518f * fVec24[((IOTA - 460) & 511)])) + (0.00432876125f * fVec24[((IOTA - 461) & 511)])) + (0.00266256742f * fVec24[((IOTA - 462) & 511)])) + (0.00184898451f * fVec24[((IOTA - 463) & 511)])) + (0.00292485952f * fVec24[((IOTA - 464) & 511)])) + (0.00414778432f * fVec24[((IOTA - 465) & 511)])) + (0.00523060467f * fVec24[((IOTA - 466) & 511)])) + (0.00577479601f * fVec24[((IOTA - 467) & 511)])) + (0.00464274408f * fVec24[((IOTA - 468) & 511)])) + (0.00290171895f * fVec24[((IOTA - 469) & 511)])) + (0.00143798301f * fVec24[((IOTA - 470) & 511)])) + (0.00122864079f * fVec24[((IOTA - 471) & 511)])) + (0.00282482896f * fVec24[((IOTA - 472) & 511)])) + (0.0043075569f * fVec24[((IOTA - 473) & 511)])) + (0.00431013806f * fVec24[((IOTA - 474) & 511)])) + (0.00330008985f * fVec24[((IOTA - 475) & 511)])) + (0.00190254953f * fVec24[((IOTA - 476) & 511)])) + (0.00175009109f * fVec24[((IOTA - 477) & 511)])) + (0.00214222353f * fVec24[((IOTA - 478) & 511)])) + (0.00225958647f * fVec24[((IOTA - 479) & 511)])) + (0.00307335379f * fVec24[((IOTA - 480) & 511)])) + (0.00326127606f * fVec24[((IOTA - 481) & 511)])) + (0.00350537524f * fVec24[((IOTA - 482) & 511)])) + (0.00448035914f * fVec24[((IOTA - 483) & 511)])) + (0.00465515954f * fVec24[((IOTA - 484) & 511)])) + (0.00494695408f * fVec24[((IOTA - 485) & 511)])) + (0.00558404624f * fVec24[((IOTA - 486) & 511)])) + (0.00486148987f * fVec24[((IOTA - 487) & 511)])) + (0.00404886017f * fVec24[((IOTA - 488) & 511)])) + (0.00412123231f * fVec24[((IOTA - 489) & 511)])) + (0.0035053445f * fVec24[((IOTA - 490) & 511)])) + (0.00279249949f * fVec24[((IOTA - 491) & 511)])) + (0.00215340964f * fVec24[((IOTA - 492) & 511)])) + (0.00108036166f * fVec24[((IOTA - 493) & 511)])) + (0.00101170782f * fVec24[((IOTA - 494) & 511)])) + (0.00153558608f * fVec24[((IOTA - 495) & 511)])) + (0.00185156614f * fVec24[((IOTA - 496) & 511)])) + (0.00295030512f * fVec24[((IOTA - 497) & 511)])) + (0.00315632857f * fVec24[((IOTA - 498) & 511)])) + (0.00209053326f * fVec24[((IOTA - 499) & 511)])) + (0.000647110865f * fVec24[((IOTA - 500) & 511)])) + (0.00155519228f * fVec24[((IOTA - 503) & 511)])) + (0.00514547853f * fVec24[((IOTA - 504) & 511)])) + (0.00865912065f * fVec24[((IOTA - 505) & 511)])) + (0.0113547854f * fVec24[((IOTA - 506) & 511)])) + (0.0121769737f * fVec24[((IOTA - 507) & 511)])) + (0.0112813376f * fVec24[((IOTA - 508) & 511)])) + (0.00916351564f * fVec24[((IOTA - 509) & 511)])) + (0.00699467817f * fVec24[((IOTA - 510) & 511)])) + (0.00602882169f * fVec24[((IOTA - 511) & 511)])))) : (iSlow72 ? (((((((((((((((((((((((((((((((0.0024114605f * fVec23[((IOTA - 414) & 511)]) + ((0.00233826041f * fVec23[((IOTA - 413) & 511)]) + ((0.00204227166f * fVec23[((IOTA - 412) & 511)]) + ((0.000967312139f * fVec23[((IOTA - 411) & 511)]) + ((0.000714875758f * fVec23[((IOTA - 404) & 511)]) + ((0.00304906024f * fVec23[((IOTA - 403) & 511)]) + ((0.00487117283f * fVec23[((IOTA - 402) & 511)]) + ((0.00579674123f * fVec23[((IOTA - 401) & 511)]) + ((0.00479826843f * fVec23[((IOTA - 400) & 511)]) + ((0.00286581321f * fVec23[((IOTA - 399) & 511)]) + ((0.000787385274f * fVec23[((IOTA - 398) & 511)]) + ((0.000994166359f * fVec23[((IOTA - 392) & 511)]) + ((0.0012973207f * fVec23[((IOTA - 391) & 511)]) + ((0.00177658862f * fVec23[((IOTA - 390) & 511)]) + ((0.00207060529f * fVec23[((IOTA - 389) & 511)]) + ((0.00183762703f * fVec23[((IOTA - 388) & 511)]) + ((0.00176702393f * fVec23[((IOTA - 387) & 511)]) + ((0.00164705049f * fVec23[((IOTA - 386) & 511)]) + ((0.00163360685f * fVec23[((IOTA - 385) & 511)]) + ((0.00211517606f * fVec23[((IOTA - 384) & 511)]) + ((0.00251937052f * fVec23[((IOTA - 383) & 511)]) + ((0.00317757903f * fVec23[((IOTA - 382) & 511)]) + ((0.00406547915f * fVec23[((IOTA - 381) & 511)]) + ((0.0043038805f * fVec23[((IOTA - 380) & 511)]) + ((0.00403349707f * fVec23[((IOTA - 379) & 511)]) + ((0.00316840876f * fVec23[((IOTA - 378) & 511)]) + ((0.00183345284f * fVec23[((IOTA - 377) & 511)]) + ((0.000805923715f * fVec23[((IOTA - 376) & 511)]) + ((0.00128190499f * fVec23[((IOTA - 371) & 511)]) + ((0.00364314066f * fVec23[((IOTA - 370) & 511)]) + ((0.00505688461f * fVec23[((IOTA - 369) & 511)]) + ((0.00537035987f * fVec23[((IOTA - 368) & 511)]) + ((0.0042455704f * fVec23[((IOTA - 367) & 511)]) + ((0.00149660744f * fVec23[((IOTA - 366) & 511)]) + ((0.000586816575f * fVec23[((IOTA - 360) & 511)]) + ((0.00156878866f * fVec23[((IOTA - 359) & 511)]) + ((0.00228350004f * fVec23[((IOTA - 358) & 511)]) + ((0.002805728f * fVec23[((IOTA - 357) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00349969883f * fVec23[((IOTA - 294) & 511)]) + ((0.00328433886f * fVec23[((IOTA - 293) & 511)]) + ((0.00316946069f * fVec23[((IOTA - 292) & 511)]) + ((0.00359173305f * fVec23[((IOTA - 291) & 511)]) + ((0.00398590229f * fVec23[((IOTA - 290) & 511)]) + ((0.00459668087f * fVec23[((IOTA - 289) & 511)]) + ((0.004705281f * fVec23[((IOTA - 288) & 511)]) + ((0.00389860151f * fVec23[((IOTA - 287) & 511)]) + ((0.00300872931f * fVec23[((IOTA - 286) & 511)]) + ((0.00176370377f * fVec23[((IOTA - 285) & 511)]) + ((0.000378030352f * fVec23[((IOTA - 284) & 511)]) + ((0.000267523807f * fVec23[((IOTA - 283) & 511)]) + ((0.00124693196f * fVec23[((IOTA - 282) & 511)]) + ((0.00285368459f * fVec23[((IOTA - 281) & 511)]) + ((0.00462212181f * fVec23[((IOTA - 280) & 511)]) + ((0.00536510069f * fVec23[((IOTA - 279) & 511)]) + ((0.0052279369f * fVec23[((IOTA - 278) & 511)]) + ((0.00489806011f * fVec23[((IOTA - 277) & 511)]) + ((0.00408868492f * fVec23[((IOTA - 276) & 511)]) + ((0.00343994237f * fVec23[((IOTA - 275) & 511)]) + ((0.00291817449f * fVec23[((IOTA - 274) & 511)]) + ((0.00201722514f * fVec23[((IOTA - 273) & 511)]) + ((0.00112327747f * fVec23[((IOTA - 272) & 511)]) + ((0.000612520613f * fVec23[((IOTA - 271) & 511)]) + ((0.00105638802f * fVec23[((IOTA - 270) & 511)]) + ((0.00308643235f * fVec23[((IOTA - 269) & 511)]) + ((0.0059016929f * fVec23[((IOTA - 268) & 511)]) + ((0.00843450706f * fVec23[((IOTA - 267) & 511)]) + ((0.0105414651f * fVec23[((IOTA - 266) & 511)]) + ((0.0107726678f * fVec23[((IOTA - 265) & 511)]) + ((0.00871833414f * fVec23[((IOTA - 264) & 511)]) + ((0.00596230384f * fVec23[((IOTA - 263) & 511)]) + ((0.00305270869f * fVec23[((IOTA - 262) & 511)]) + ((0.000943909399f * fVec23[((IOTA - 261) & 511)]) + ((0.00114290044f * fVec23[((IOTA - 260) & 511)]) + ((0.00260407478f * fVec23[((IOTA - 259) & 511)]) + ((0.00468253577f * fVec23[((IOTA - 258) & 511)]) + ((0.00715467287f * fVec23[((IOTA - 257) & 511)]) + ((0.00856427476f * fVec23[((IOTA - 256) & 511)]) + ((0.00936608948f * fVec23[((IOTA - 255) & 511)]) + ((0.00916959718f * fVec23[((IOTA - 254) & 511)]) + ((0.00696590403f * fVec23[((IOTA - 253) & 511)]) + ((0.00430374919f * fVec23[((IOTA - 252) & 511)]) + ((0.00145410746f * fVec23[((IOTA - 251) & 511)]) + ((0.00132427365f * fVec23[((IOTA - 246) & 511)]) + ((0.00275418907f * fVec23[((IOTA - 245) & 511)]) + ((0.00423340872f * fVec23[((IOTA - 244) & 511)]) + ((0.00548849208f * fVec23[((IOTA - 243) & 511)]) + ((0.0058713872f * fVec23[((IOTA - 242) & 511)]) + ((0.00588962995f * fVec23[((IOTA - 241) & 511)]) + ((0.00458589988f * fVec23[((IOTA - 240) & 511)]) + ((0.00152996974f * fVec23[((IOTA - 239) & 511)]) + ((0.0019686115f * fVec23[((IOTA - 234) & 511)]) + ((0.00549273239f * fVec23[((IOTA - 233) & 511)]) + ((0.00861929823f * fVec23[((IOTA - 232) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0146538485f * fVec23[((IOTA - 34) & 511)]) + ((0.0102907382f * fVec23[((IOTA - 27) & 511)]) + ((0.0290133543f * fVec23[((IOTA - 26) & 511)]) + ((0.0536210947f * fVec23[((IOTA - 25) & 511)]) + ((0.0465906039f * fVec23[((IOTA - 24) & 511)]) + ((0.0259268545f * fVec23[((IOTA - 23) & 511)]) + ((0.0224276818f * fVec23[((IOTA - 18) & 511)]) + ((0.0458155423f * fVec23[((IOTA - 17) & 511)]) + ((0.0341931023f * fVec23[((IOTA - 16) & 511)]) + ((0.0524204113f * fVec23[((IOTA - 12) & 511)]) + ((0.116055451f * fVec23[((IOTA - 11) & 511)]) + ((0.128443941f * fVec23[((IOTA - 10) & 511)]) + ((0.0537013933f * fVec23[((IOTA - 9) & 511)]) + ((0.0124539696f * fVec23[((IOTA - 4) & 511)]) + ((0.165357217f * fVec23[((IOTA - 3) & 511)]) + ((0.214131787f * fVec23[((IOTA - 2) & 511)]) + ((0.266353369f * fVec23[((IOTA - 1) & 511)]) + ((fSlow76 * fTemp0) + ((((0.0326218158f * fVec23[((IOTA - 35) & 511)]) + (0.0367526747f * fVec23[((IOTA - 36) & 511)])) + (0.0346683301f * fVec23[((IOTA - 37) & 511)])) + (0.0141693223f * fVec23[((IOTA - 38) & 511)])))))))))))))))))))) + (0.00839072466f * fVec23[((IOTA - 46) & 511)])) + (0.0189971402f * fVec23[((IOTA - 47) & 511)])) + (0.0279802047f * fVec23[((IOTA - 48) & 511)])) + (0.0328968354f * fVec23[((IOTA - 49) & 511)])) + (0.0156728327f * fVec23[((IOTA - 50) & 511)])) + (0.00227709021f * fVec23[((IOTA - 57) & 511)])) + (0.0258204229f * fVec23[((IOTA - 58) & 511)])) + (0.0302411225f * fVec23[((IOTA - 59) & 511)])) + (0.0299378373f * fVec23[((IOTA - 60) & 511)])) + (0.0197091885f * fVec23[((IOTA - 61) & 511)])) + (0.00458609685f * fVec23[((IOTA - 62) & 511)])) + (0.00727096433f * fVec23[((IOTA - 71) & 511)])) + (0.022253342f * fVec23[((IOTA - 72) & 511)])) + (0.0253008902f * fVec23[((IOTA - 73) & 511)])) + (0.0169778448f * fVec23[((IOTA - 74) & 511)])) + (0.00217499817f * fVec23[((IOTA - 75) & 511)])) + (0.00127092656f * fVec23[((IOTA - 82) & 511)])) + (0.00498743169f * fVec23[((IOTA - 93) & 511)])) + (0.0145964595f * fVec23[((IOTA - 94) & 511)])) + (0.0135926288f * fVec23[((IOTA - 95) & 511)])) + (0.00890483428f * fVec23[((IOTA - 96) & 511)])) + (0.00601298874f * fVec23[((IOTA - 97) & 511)])) + (0.00689516915f * fVec23[((IOTA - 106) & 511)])) + (0.0159812458f * fVec23[((IOTA - 107) & 511)])) + (0.0174177345f * fVec23[((IOTA - 108) & 511)])) + (0.0111978995f * fVec23[((IOTA - 109) & 511)])) + (0.00069689611f * fVec23[((IOTA - 110) & 511)])) + (0.0014150585f * fVec23[((IOTA - 118) & 511)])) + (0.000388745684f * fVec23[((IOTA - 119) & 511)])) + (0.00261262059f * fVec23[((IOTA - 128) & 511)])) + (0.00652022846f * fVec23[((IOTA - 129) & 511)])) + (0.00498046353f * fVec23[((IOTA - 130) & 511)])) + (0.000299538486f * fVec23[((IOTA - 131) & 511)])) + (0.000293096062f * fVec23[((IOTA - 148) & 511)])) + (0.00504498603f * fVec23[((IOTA - 149) & 511)])) + (0.0083009256f * fVec23[((IOTA - 150) & 511)])) + (0.00751551241f * fVec23[((IOTA - 151) & 511)])) + (0.00327605568f * fVec23[((IOTA - 152) & 511)])) + (0.00259927567f * fVec23[((IOTA - 162) & 511)])) + (0.00348204793f * fVec23[((IOTA - 163) & 511)])) + (0.0020389189f * fVec23[((IOTA - 164) & 511)])) + (0.00216168584f * fVec23[((IOTA - 172) & 511)])) + (0.00578339584f * fVec23[((IOTA - 173) & 511)])) + (0.00614926498f * fVec23[((IOTA - 174) & 511)])) + (0.00485404767f * fVec23[((IOTA - 175) & 511)])) + (0.000770227518f * fVec23[((IOTA - 176) & 511)])) + (0.00190402335f * fVec23[((IOTA - 182) & 511)])) + (0.00642671529f * fVec23[((IOTA - 183) & 511)])) + (0.00837113522f * fVec23[((IOTA - 184) & 511)])) + (0.00669584936f * fVec23[((IOTA - 185) & 511)])) + (0.0041369372f * fVec23[((IOTA - 186) & 511)])) + (0.0008139438f * fVec23[((IOTA - 187) & 511)])) + (0.000486499164f * fVec23[((IOTA - 192) & 511)])) + (0.00149387959f * fVec23[((IOTA - 193) & 511)])) + (0.001761436f * fVec23[((IOTA - 194) & 511)])) + (0.00190027617f * fVec23[((IOTA - 195) & 511)])) + (0.000725788064f * fVec23[((IOTA - 196) & 511)])) + (0.000408138614f * fVec23[((IOTA - 197) & 511)])) + (0.00102190813f * fVec23[((IOTA - 198) & 511)])) + (0.000358407386f * fVec23[((IOTA - 199) & 511)])) + (0.00198274525f * fVec23[((IOTA - 206) & 511)])) + (0.00495709339f * fVec23[((IOTA - 207) & 511)])) + (0.00723286904f * fVec23[((IOTA - 208) & 511)])) + (0.0072230408f * fVec23[((IOTA - 209) & 511)])) + (0.00413851487f * fVec23[((IOTA - 210) & 511)])) + (0.00337752374f * fVec23[((IOTA - 217) & 511)])) + (0.00810177065f * fVec23[((IOTA - 218) & 511)])) + (0.010187462f * fVec23[((IOTA - 219) & 511)])) + (0.01002328f * fVec23[((IOTA - 220) & 511)])) + (0.00744648697f * fVec23[((IOTA - 221) & 511)])) + (0.00356027717f * fVec23[((IOTA - 222) & 511)])) + (0.00133130746f * fVec23[((IOTA - 228) & 511)])) + (0.004950881f * fVec23[((IOTA - 229) & 511)])) + (0.00743810507f * fVec23[((IOTA - 230) & 511)])) + (0.00896741822f * fVec23[((IOTA - 231) & 511)])) + (0.00370871508f * fVec23[((IOTA - 295) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00465637166f * fVec23[((IOTA - 296) & 511)])) + (0.00561431609f * fVec23[((IOTA - 297) & 511)])) + (0.00648338208f * fVec23[((IOTA - 298) & 511)])) + (0.00760140037f * fVec23[((IOTA - 299) & 511)])) + (0.00784532353f * fVec23[((IOTA - 300) & 511)])) + (0.00726195844f * fVec23[((IOTA - 301) & 511)])) + (0.00632873178f * fVec23[((IOTA - 302) & 511)])) + (0.00483577233f * fVec23[((IOTA - 303) & 511)])) + (0.00327720633f * fVec23[((IOTA - 304) & 511)])) + (0.00236656098f * fVec23[((IOTA - 305) & 511)])) + (0.00246612215f * fVec23[((IOTA - 306) & 511)])) + (0.00418249425f * fVec23[((IOTA - 307) & 511)])) + (0.00670064846f * fVec23[((IOTA - 308) & 511)])) + (0.00839088857f * fVec23[((IOTA - 309) & 511)])) + (0.00919227675f * fVec23[((IOTA - 310) & 511)])) + (0.00833017938f * fVec23[((IOTA - 311) & 511)])) + (0.00609256513f * fVec23[((IOTA - 312) & 511)])) + (0.00376863591f * fVec23[((IOTA - 313) & 511)])) + (0.000933029689f * fVec23[((IOTA - 314) & 511)])) + (0.000709156506f * fVec23[((IOTA - 319) & 511)])) + (0.00246467581f * fVec23[((IOTA - 320) & 511)])) + (0.00409854576f * fVec23[((IOTA - 321) & 511)])) + (0.00437813252f * fVec23[((IOTA - 322) & 511)])) + (0.00290436903f * fVec23[((IOTA - 323) & 511)])) + (0.00146567728f * fVec23[((IOTA - 324) & 511)])) + (0.000169375911f * fVec23[((IOTA - 328) & 511)])) + (0.000845235307f * fVec23[((IOTA - 329) & 511)])) + (0.00159294764f * fVec23[((IOTA - 330) & 511)])) + (0.00147573557f * fVec23[((IOTA - 331) & 511)])) + (0.00209058961f * fVec23[((IOTA - 332) & 511)])) + (0.0038123522f * fVec23[((IOTA - 333) & 511)])) + (0.0051432983f * fVec23[((IOTA - 334) & 511)])) + (0.00606636843f * fVec23[((IOTA - 335) & 511)])) + (0.00609023171f * fVec23[((IOTA - 336) & 511)])) + (0.0046193609f * fVec23[((IOTA - 337) & 511)])) + (0.00292977737f * fVec23[((IOTA - 338) & 511)])) + (0.00136072561f * fVec23[((IOTA - 339) & 511)])) + (0.000568376854f * fVec23[((IOTA - 340) & 511)])) + (0.0014660717f * fVec23[((IOTA - 341) & 511)])) + (0.00277147815f * fVec23[((IOTA - 342) & 511)])) + (0.00424261205f * fVec23[((IOTA - 343) & 511)])) + (0.00583286444f * fVec23[((IOTA - 344) & 511)])) + (0.00603083661f * fVec23[((IOTA - 345) & 511)])) + (0.00500202551f * fVec23[((IOTA - 346) & 511)])) + (0.00385110546f * fVec23[((IOTA - 347) & 511)])) + (0.00234259898f * fVec23[((IOTA - 348) & 511)])) + (0.00100948382f * fVec23[((IOTA - 349) & 511)])) + (0.000748271123f * fVec23[((IOTA - 350) & 511)])) + (0.00108432723f * fVec23[((IOTA - 351) & 511)])) + (0.00233339565f * fVec23[((IOTA - 352) & 511)])) + (0.00339793554f * fVec23[((IOTA - 353) & 511)])) + (0.00378950825f * fVec23[((IOTA - 354) & 511)])) + (0.00430519553f * fVec23[((IOTA - 355) & 511)])) + (0.00388400769f * fVec23[((IOTA - 356) & 511)])) + (0.00186487567f * fVec23[((IOTA - 415) & 511)])))))))))))))))))))))))))))))))))))))))) + (0.000535770319f * fVec23[((IOTA - 416) & 511)])) + (0.0011253152f * fVec23[((IOTA - 423) & 511)])) + (0.00199540006f * fVec23[((IOTA - 424) & 511)])) + (0.00256344816f * fVec23[((IOTA - 425) & 511)])) + (0.00237944536f * fVec23[((IOTA - 426) & 511)])) + (0.00131036993f * fVec23[((IOTA - 427) & 511)])) + (0.000329909846f * fVec23[((IOTA - 428) & 511)])) + (0.00058336556f * fVec23[((IOTA - 445) & 511)])) + (0.00117813656f * fVec23[((IOTA - 446) & 511)])) + (0.00102683855f * fVec23[((IOTA - 447) & 511)])) + (0.000837083906f * fVec23[((IOTA - 448) & 511)])) + (0.000573307276f * fVec23[((IOTA - 468) & 511)])) + (0.00175325153f * fVec23[((IOTA - 469) & 511)])) + (0.00208319398f * fVec23[((IOTA - 470) & 511)])) + (0.00159087684f * fVec23[((IOTA - 471) & 511)])) + (0.000325275119f * fVec23[((IOTA - 472) & 511)])) + (0.000351143535f * fVec23[((IOTA - 479) & 511)])) + (0.00129883271f * fVec23[((IOTA - 480) & 511)])) + (0.000930531416f * fVec23[((IOTA - 481) & 511)])) + (7.14906491e-05f * fVec23[((IOTA - 488) & 511)])) + (2.02148221e-05f * fVec23[((IOTA - 489) & 511)])) + (0.000258944929f * fVec23[((IOTA - 490) & 511)])) + (0.00031028688f * fVec23[((IOTA - 491) & 511)])) + (0.000122964382f * fVec23[((IOTA - 492) & 511)])) + (0.000585140195f * fVec23[((IOTA - 493) & 511)])) + (0.0007581315f * fVec23[((IOTA - 494) & 511)])) + (0.000860454049f * fVec23[((IOTA - 495) & 511)])) + (0.000777163077f * fVec23[((IOTA - 496) & 511)])) - (((((((((((((((((((((((((((((((0.00403918372f * fVec23[((IOTA - 464) & 511)]) + ((0.00281019835f * fVec23[((IOTA - 463) & 511)]) + ((0.00164603163f * fVec23[((IOTA - 462) & 511)]) + ((0.000922380015f * fVec23[((IOTA - 461) & 511)]) + ((0.000478052069f * fVec23[((IOTA - 460) & 511)]) + ((0.00059493538f * fVec23[((IOTA - 459) & 511)]) + ((0.000762996264f * fVec23[((IOTA - 458) & 511)]) + ((0.000763883814f * fVec23[((IOTA - 457) & 511)]) + ((0.00102654286f * fVec23[((IOTA - 456) & 511)]) + ((0.00139924837f * fVec23[((IOTA - 455) & 511)]) + ((0.00222325046f * fVec23[((IOTA - 454) & 511)]) + ((0.00359393517f * fVec23[((IOTA - 453) & 511)]) + ((0.00418666843f * fVec23[((IOTA - 452) & 511)]) + ((0.00372735225f * fVec23[((IOTA - 451) & 511)]) + ((0.00271415431f * fVec23[((IOTA - 450) & 511)]) + ((0.000647690613f * fVec23[((IOTA - 449) & 511)]) + ((0.000659490936f * fVec23[((IOTA - 444) & 511)]) + ((0.00189172989f * fVec23[((IOTA - 443) & 511)]) + ((0.00359071419f * fVec23[((IOTA - 442) & 511)]) + ((0.00478163688f * fVec23[((IOTA - 441) & 511)]) + ((0.00505271042f * fVec23[((IOTA - 440) & 511)]) + ((0.00488668727f * fVec23[((IOTA - 439) & 511)]) + ((0.003882627f * fVec23[((IOTA - 438) & 511)]) + ((0.00273384294f * fVec23[((IOTA - 437) & 511)]) + ((0.00201498996f * fVec23[((IOTA - 436) & 511)]) + ((0.001265503f * fVec23[((IOTA - 435) & 511)]) + ((0.00135244243f * fVec23[((IOTA - 434) & 511)]) + ((0.00198136456f * fVec23[((IOTA - 433) & 511)]) + ((0.00223192805f * fVec23[((IOTA - 432) & 511)]) + ((0.00240544509f * fVec23[((IOTA - 431) & 511)]) + ((0.00183473481f * fVec23[((IOTA - 430) & 511)]) + ((0.000624353532f * fVec23[((IOTA - 429) & 511)]) + ((0.00025887927f * fVec23[((IOTA - 422) & 511)]) + ((0.00103052007f * fVec23[((IOTA - 421) & 511)]) + ((0.00147570251f * fVec23[((IOTA - 420) & 511)]) + ((0.00213989383f * fVec23[((IOTA - 419) & 511)]) + ((0.00153033156f * fVec23[((IOTA - 418) & 511)]) + ((0.000420563389f * fVec23[((IOTA - 417) & 511)]) + ((8.44411552e-05f * fVec23[((IOTA - 410) & 511)]) + ((0.00107380887f * fVec23[((IOTA - 409) & 511)]) + ((0.00231222762f * fVec23[((IOTA - 408) & 511)]) + ((0.00297839101f * fVec23[((IOTA - 407) & 511)]) + ((0.00281687081f * fVec23[((IOTA - 406) & 511)]) + ((0.00166095421f * fVec23[((IOTA - 405) & 511)]) + ((0.00171236182f * fVec23[((IOTA - 397) & 511)]) + ((0.00293529918f * fVec23[((IOTA - 396) & 511)]) + ((0.00249534287f * fVec23[((IOTA - 395) & 511)]) + ((0.0014894749f * fVec23[((IOTA - 394) & 511)]) + ((8.59205611e-05f * fVec23[((IOTA - 393) & 511)]) + ((0.000379049219f * fVec23[((IOTA - 375) & 511)]) + ((0.00138409575f * fVec23[((IOTA - 374) & 511)]) + ((0.001342976f * fVec23[((IOTA - 373) & 511)]) + ((0.000547011849f * fVec23[((IOTA - 372) & 511)]) + ((0.000870216172f * fVec23[((IOTA - 365) & 511)]) + ((0.00232054386f * fVec23[((IOTA - 364) & 511)]) + ((0.00287560839f * fVec23[((IOTA - 363) & 511)]) + ((0.00187759614f * fVec23[((IOTA - 362) & 511)]) + ((0.000413529575f * fVec23[((IOTA - 361) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0244373474f * fVec23[((IOTA - 112) & 511)]) + ((0.0134878745f * fVec23[((IOTA - 111) & 511)]) + ((0.002527982f * fVec23[((IOTA - 105) & 511)]) + ((0.0126622617f * fVec23[((IOTA - 104) & 511)]) + ((0.0209221672f * fVec23[((IOTA - 103) & 511)]) + ((0.0241568722f * fVec23[((IOTA - 102) & 511)]) + ((0.0251847636f * fVec23[((IOTA - 101) & 511)]) + ((0.0200441275f * fVec23[((IOTA - 100) & 511)]) + ((0.0107464381f * fVec23[((IOTA - 99) & 511)]) + ((0.00135858916f * fVec23[((IOTA - 98) & 511)]) + (((((((((((((((((((((((((((((((((((((((0.0209244024f * fVec23[((IOTA - 33) & 511)]) + ((0.0494937897f * fVec23[((IOTA - 32) & 511)]) + ((0.0488373227f * fVec23[((IOTA - 31) & 511)]) + ((0.0473239832f * fVec23[((IOTA - 30) & 511)]) + ((0.0399535224f * fVec23[((IOTA - 29) & 511)]) + ((0.0108075431f * fVec23[((IOTA - 28) & 511)]) + ((0.00342590734f * fVec23[((IOTA - 22) & 511)]) + ((0.0396087915f * fVec23[((IOTA - 21) & 511)]) + ((0.0434642993f * fVec23[((IOTA - 20) & 511)]) + ((0.0149071738f * fVec23[((IOTA - 19) & 511)]) + ((0.00491206208f * fVec23[((IOTA - 15) & 511)]) + ((0.0431802422f * fVec23[((IOTA - 14) & 511)]) + ((0.0223910324f * fVec23[((IOTA - 13) & 511)]) + ((0.0969579294f * fVec23[((IOTA - 8) & 511)]) + ((0.213284716f * fVec23[((IOTA - 7) & 511)]) + ((0.235670298f * fVec23[((IOTA - 6) & 511)]) + ((0.182096139f * fVec23[((IOTA - 5) & 511)]) + (0.0111987535f * fVec23[((IOTA - 39) & 511)])))))))))))))))))) + (0.0229734778f * fVec23[((IOTA - 40) & 511)])) + (0.0273476653f * fVec23[((IOTA - 41) & 511)])) + (0.0237218793f * fVec23[((IOTA - 42) & 511)])) + (0.0246687811f * fVec23[((IOTA - 43) & 511)])) + (0.0295228288f * fVec23[((IOTA - 44) & 511)])) + (0.0131230904f * fVec23[((IOTA - 45) & 511)])) + (0.0108955335f * fVec23[((IOTA - 51) & 511)])) + (0.0268320777f * fVec23[((IOTA - 52) & 511)])) + (0.0436677299f * fVec23[((IOTA - 53) & 511)])) + (0.0542853177f * fVec23[((IOTA - 54) & 511)])) + (0.0432262942f * fVec23[((IOTA - 55) & 511)])) + (0.0250699185f * fVec23[((IOTA - 56) & 511)])) + (0.0089729391f * fVec23[((IOTA - 63) & 511)])) + (0.0189291984f * fVec23[((IOTA - 64) & 511)])) + (0.0222384855f * fVec23[((IOTA - 65) & 511)])) + (0.0319605507f * fVec23[((IOTA - 66) & 511)])) + (0.0378058068f * fVec23[((IOTA - 67) & 511)])) + (0.0327017233f * fVec23[((IOTA - 68) & 511)])) + (0.0263970178f * fVec23[((IOTA - 69) & 511)])) + (0.0124057494f * fVec23[((IOTA - 70) & 511)])) + (0.0102959648f * fVec23[((IOTA - 76) & 511)])) + (0.0174585246f * fVec23[((IOTA - 77) & 511)])) + (0.0211817361f * fVec23[((IOTA - 78) & 511)])) + (0.0113166561f * fVec23[((IOTA - 79) & 511)])) + (0.00141315209f * fVec23[((IOTA - 80) & 511)])) + (0.000891088042f * fVec23[((IOTA - 81) & 511)])) + (0.00131523423f * fVec23[((IOTA - 83) & 511)])) + (0.00558568677f * fVec23[((IOTA - 84) & 511)])) + (0.00929621048f * fVec23[((IOTA - 85) & 511)])) + (0.0174057707f * fVec23[((IOTA - 86) & 511)])) + (0.0228058435f * fVec23[((IOTA - 87) & 511)])) + (0.0266560279f * fVec23[((IOTA - 88) & 511)])) + (0.027754128f * fVec23[((IOTA - 89) & 511)])) + (0.021447124f * fVec23[((IOTA - 90) & 511)])) + (0.00994288176f * fVec23[((IOTA - 91) & 511)])) + (0.00201436551f * fVec23[((IOTA - 92) & 511)])) + (0.0262451284f * fVec23[((IOTA - 113) & 511)])))))))))))) + (0.0223541204f * fVec23[((IOTA - 114) & 511)])) + (0.0150669515f * fVec23[((IOTA - 115) & 511)])) + (0.00556557067f * fVec23[((IOTA - 116) & 511)])) + (0.00011714641f * fVec23[((IOTA - 117) & 511)])) + (0.00369329937f * fVec23[((IOTA - 120) & 511)])) + (0.00665528839f * fVec23[((IOTA - 121) & 511)])) + (0.00973912515f * fVec23[((IOTA - 122) & 511)])) + (0.0118620582f * fVec23[((IOTA - 123) & 511)])) + (0.0124635668f * fVec23[((IOTA - 124) & 511)])) + (0.0127439089f * fVec23[((IOTA - 125) & 511)])) + (0.00741575425f * fVec23[((IOTA - 126) & 511)])) + (0.00151803857f * fVec23[((IOTA - 127) & 511)])) + (0.00423830608f * fVec23[((IOTA - 132) & 511)])) + (0.00754381297f * fVec23[((IOTA - 133) & 511)])) + (0.00823502243f * fVec23[((IOTA - 134) & 511)])) + (0.00616655406f * fVec23[((IOTA - 135) & 511)])) + (0.00267395517f * fVec23[((IOTA - 136) & 511)])) + (0.00291971909f * fVec23[((IOTA - 137) & 511)])) + (0.00419639796f * fVec23[((IOTA - 138) & 511)])) + (0.00375065627f * fVec23[((IOTA - 139) & 511)])) + (0.00345463492f * fVec23[((IOTA - 140) & 511)])) + (0.0032205726f * fVec23[((IOTA - 141) & 511)])) + (0.00341321947f * fVec23[((IOTA - 142) & 511)])) + (0.00525564561f * fVec23[((IOTA - 143) & 511)])) + (0.00855257362f * fVec23[((IOTA - 144) & 511)])) + (0.011284017f * fVec23[((IOTA - 145) & 511)])) + (0.0101070646f * fVec23[((IOTA - 146) & 511)])) + (0.00545286201f * fVec23[((IOTA - 147) & 511)])) + (8.1253238e-05f * fVec23[((IOTA - 153) & 511)])) + (0.00291965343f * fVec23[((IOTA - 154) & 511)])) + (0.00548070204f * fVec23[((IOTA - 155) & 511)])) + (0.00720045995f * fVec23[((IOTA - 156) & 511)])) + (0.0089036189f * fVec23[((IOTA - 157) & 511)])) + (0.00902474206f * fVec23[((IOTA - 158) & 511)])) + (0.00773583585f * fVec23[((IOTA - 159) & 511)])) + (0.0053486987f * fVec23[((IOTA - 160) & 511)])) + (0.0010553035f * fVec23[((IOTA - 161) & 511)])) + (0.00105484342f * fVec23[((IOTA - 165) & 511)])) + (0.00462143123f * fVec23[((IOTA - 166) & 511)])) + (0.00835095346f * fVec23[((IOTA - 167) & 511)])) + (0.0101698767f * fVec23[((IOTA - 168) & 511)])) + (0.00893517304f * fVec23[((IOTA - 169) & 511)])) + (0.00593916373f * fVec23[((IOTA - 170) & 511)])) + (0.00238901051f * fVec23[((IOTA - 171) & 511)])) + (0.00440998282f * fVec23[((IOTA - 177) & 511)])) + (0.00792654417f * fVec23[((IOTA - 178) & 511)])) + (0.0107295439f * fVec23[((IOTA - 179) & 511)])) + (0.00902756862f * fVec23[((IOTA - 180) & 511)])) + (0.0031611775f * fVec23[((IOTA - 181) & 511)])) + (0.00203369278f * fVec23[((IOTA - 188) & 511)])) + (0.00309681939f * fVec23[((IOTA - 189) & 511)])) + (0.00297092972f * fVec23[((IOTA - 190) & 511)])) + (0.00164945005f * fVec23[((IOTA - 191) & 511)])) + (0.000237678178f * fVec23[((IOTA - 200) & 511)])) + (0.00121169584f * fVec23[((IOTA - 201) & 511)])) + (0.00261847163f * fVec23[((IOTA - 202) & 511)])) + (0.00288556796f * fVec23[((IOTA - 203) & 511)])) + (0.00217509689f * fVec23[((IOTA - 204) & 511)])) + (0.000579322223f * fVec23[((IOTA - 205) & 511)])) + (0.000832383521f * fVec23[((IOTA - 211) & 511)])) + (0.00532197626f * fVec23[((IOTA - 212) & 511)])) + (0.00841209013f * fVec23[((IOTA - 213) & 511)])) + (0.00897892192f * fVec23[((IOTA - 214) & 511)])) + (0.00655056676f * fVec23[((IOTA - 215) & 511)])) + (0.00228037732f * fVec23[((IOTA - 216) & 511)])) + (0.000159547664f * fVec23[((IOTA - 223) & 511)])) + (0.0033737109f * fVec23[((IOTA - 224) & 511)])) + (0.00469262665f * fVec23[((IOTA - 225) & 511)])) + (0.00410636887f * fVec23[((IOTA - 226) & 511)])) + (0.00213180762f * fVec23[((IOTA - 227) & 511)])) + (0.000961724669f * fVec23[((IOTA - 235) & 511)])) + (0.00317110401f * fVec23[((IOTA - 236) & 511)])) + (0.00293572666f * fVec23[((IOTA - 237) & 511)])) + (0.00114359055f * fVec23[((IOTA - 238) & 511)])) + (0.000181734562f * fVec23[((IOTA - 247) & 511)])) + (0.00107108103f * fVec23[((IOTA - 248) & 511)])) + (0.00128486333f * fVec23[((IOTA - 249) & 511)])) + (0.000719115604f * fVec23[((IOTA - 250) & 511)])) + (0.00167811196f * fVec23[((IOTA - 315) & 511)])) + (0.0027667121f * fVec23[((IOTA - 316) & 511)])) + (0.00297300052f * fVec23[((IOTA - 317) & 511)])) + (0.0015975493f * fVec23[((IOTA - 318) & 511)])) + (4.92711551e-05f * fVec23[((IOTA - 325) & 511)])) + (0.00104113668f * fVec23[((IOTA - 326) & 511)])) + (0.000522589777f * fVec23[((IOTA - 327) & 511)])) + (0.0041183331f * fVec23[((IOTA - 465) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00297066662f * fVec23[((IOTA - 466) & 511)])) + (0.00121094007f * fVec23[((IOTA - 467) & 511)])) + (0.0014747493f * fVec23[((IOTA - 473) & 511)])) + (0.00314227771f * fVec23[((IOTA - 474) & 511)])) + (0.00446231104f * fVec23[((IOTA - 475) & 511)])) + (0.00449077599f * fVec23[((IOTA - 476) & 511)])) + (0.00331921317f * fVec23[((IOTA - 477) & 511)])) + (0.00165530061f * fVec23[((IOTA - 478) & 511)])) + (7.88862817e-05f * fVec23[((IOTA - 482) & 511)])) + (0.00169073371f * fVec23[((IOTA - 483) & 511)])) + (0.00247973017f * fVec23[((IOTA - 484) & 511)])) + (0.00228655664f * fVec23[((IOTA - 485) & 511)])) + (0.00194783788f * fVec23[((IOTA - 486) & 511)])) + (0.000821963884f * fVec23[((IOTA - 487) & 511)])) + (0.000513386447f * fVec23[((IOTA - 497) & 511)])) + (0.00183322281f * fVec23[((IOTA - 498) & 511)])) + (0.00287761353f * fVec23[((IOTA - 499) & 511)])) + (0.00399086578f * fVec23[((IOTA - 500) & 511)])) + (0.00396118453f * fVec23[((IOTA - 501) & 511)])) + (0.00309468294f * fVec23[((IOTA - 502) & 511)])) + (0.00233227806f * fVec23[((IOTA - 503) & 511)])) + (0.00130557083f * fVec23[((IOTA - 504) & 511)])) + (0.000954920426f * fVec23[((IOTA - 505) & 511)])) + (0.00154969143f * fVec23[((IOTA - 506) & 511)])) + (0.0024133008f * fVec23[((IOTA - 507) & 511)])) + (0.00371844461f * fVec23[((IOTA - 508) & 511)])) + (0.00460775802f * fVec23[((IOTA - 509) & 511)])) + (0.00440597301f * fVec23[((IOTA - 510) & 511)])) + (0.00406370405f * fVec23[((IOTA - 511) & 511)]))) : (((((((((0.00862149522f * fVec22[((IOTA - 490) & 511)]) + ((0.00946544856f * fVec22[((IOTA - 489) & 511)]) + ((0.00916372053f * fVec22[((IOTA - 488) & 511)]) + ((0.00718613993f * fVec22[((IOTA - 487) & 511)]) + ((0.00294451509f * fVec22[((IOTA - 486) & 511)]) + ((0.000436417293f * fVec22[((IOTA - 480) & 511)]) + ((0.00315483147f * fVec22[((IOTA - 479) & 511)]) + ((0.00461594434f * fVec22[((IOTA - 478) & 511)]) + ((0.00397619279f * fVec22[((IOTA - 477) & 511)]) + ((0.00302439183f * fVec22[((IOTA - 476) & 511)]) + ((0.00278892461f * fVec22[((IOTA - 475) & 511)]) + ((0.00287209684f * fVec22[((IOTA - 474) & 511)]) + ((0.00340040307f * fVec22[((IOTA - 473) & 511)]) + ((0.00368682342f * fVec22[((IOTA - 472) & 511)]) + ((0.00340638729f * fVec22[((IOTA - 471) & 511)]) + ((0.00298258895f * fVec22[((IOTA - 470) & 511)]) + ((0.00219817413f * fVec22[((IOTA - 469) & 511)]) + ((0.00101892836f * fVec22[((IOTA - 468) & 511)]) + ((1.07977539e-05f * fVec22[((IOTA - 467) & 511)]) + ((0.000280956738f * fVec22[((IOTA - 465) & 511)]) + ((0.00174965849f * fVec22[((IOTA - 464) & 511)]) + ((0.00389518822f * fVec22[((IOTA - 463) & 511)]) + ((0.00521831634f * fVec22[((IOTA - 462) & 511)]) + ((0.00542433979f * fVec22[((IOTA - 461) & 511)]) + ((0.005401487f * fVec22[((IOTA - 460) & 511)]) + ((0.00478176912f * fVec22[((IOTA - 459) & 511)]) + ((0.00349771231f * fVec22[((IOTA - 458) & 511)]) + ((0.00204921793f * fVec22[((IOTA - 457) & 511)]) + ((0.000575833023f * fVec22[((IOTA - 456) & 511)]) + ((0.000690704677f * fVec22[((IOTA - 436) & 511)]) + ((0.00324711064f * fVec22[((IOTA - 435) & 511)]) + ((0.00505886646f * fVec22[((IOTA - 434) & 511)]) + ((0.00606253045f * fVec22[((IOTA - 433) & 511)]) + ((0.0064656008f * fVec22[((IOTA - 432) & 511)]) + ((0.00650475873f * fVec22[((IOTA - 431) & 511)]) + ((0.0061624418f * fVec22[((IOTA - 430) & 511)]) + ((0.00560724968f * fVec22[((IOTA - 429) & 511)]) + ((0.00469868351f * fVec22[((IOTA - 428) & 511)]) + ((0.00329823699f * fVec22[((IOTA - 427) & 511)]) + ((0.00244162092f * fVec22[((IOTA - 426) & 511)]) + ((0.00277491799f * fVec22[((IOTA - 425) & 511)]) + ((0.00422414904f * fVec22[((IOTA - 424) & 511)]) + ((0.00662713218f * fVec22[((IOTA - 423) & 511)]) + ((0.0081889797f * fVec22[((IOTA - 422) & 511)]) + ((0.00729394332f * fVec22[((IOTA - 421) & 511)]) + ((0.00500873756f * fVec22[((IOTA - 420) & 511)]) + ((0.00239357306f * fVec22[((IOTA - 419) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.324823618f * fVec22[((IOTA - 4) & 511)]) + ((0.0796504319f * fVec22[((IOTA - 6) & 511)]) + ((0.0167897474f * fVec22[((IOTA - 7) & 511)]) + ((0.12224187f * fVec22[((IOTA - 12) & 511)]) + ((0.188474864f * fVec22[((IOTA - 5) & 511)]) + ((0.0378040336f * fVec22[((IOTA - 9) & 511)]) + ((fSlow74 * fTemp0) + (((0.351397157f * fVec22[((IOTA - 3) & 511)]) + (((0.288776398f * fVec22[((IOTA - 2) & 511)]) + ((0.237692907f * fVec22[((IOTA - 1) & 511)]) + (0.0989802778f * fVec22[((IOTA - 10) & 511)]))) + (0.144942239f * fVec22[((IOTA - 11) & 511)]))) + (0.0604240969f * fVec22[((IOTA - 13) & 511)]))))))))) + (0.0207439978f * fVec22[((IOTA - 14) & 511)])) + (0.0020025149f * fVec22[((IOTA - 21) & 511)])) + (0.0180635266f * fVec22[((IOTA - 22) & 511)])) + (0.00505470345f * fVec22[((IOTA - 23) & 511)])) + (0.00141180772f * fVec22[((IOTA - 61) & 511)])) + (0.00388443377f * fVec22[((IOTA - 62) & 511)])) + (0.00280722417f * fVec22[((IOTA - 63) & 511)])) + (0.00298341271f * fVec22[((IOTA - 69) & 511)])) + (0.0193569064f * fVec22[((IOTA - 70) & 511)])) + (0.0337733738f * fVec22[((IOTA - 71) & 511)])) + (0.0305752233f * fVec22[((IOTA - 72) & 511)])) + (0.0188564397f * fVec22[((IOTA - 73) & 511)])) + (0.00310283806f * fVec22[((IOTA - 74) & 511)])) + (0.000297261402f * fVec22[((IOTA - 82) & 511)])) + (0.00425619539f * fVec22[((IOTA - 112) & 511)])) + (0.00435198657f * fVec22[((IOTA - 113) & 511)])) + (0.00130886119f * fVec22[((IOTA - 129) & 511)])) + (0.00560152577f * fVec22[((IOTA - 130) & 511)])) + (0.00804379676f * fVec22[((IOTA - 131) & 511)])) + (0.00585043617f * fVec22[((IOTA - 132) & 511)])) + (0.00193621125f * fVec22[((IOTA - 133) & 511)])) + (0.00266464287f * fVec22[((IOTA - 138) & 511)])) + (0.00362060638f * fVec22[((IOTA - 139) & 511)])) + (0.00176574662f * fVec22[((IOTA - 140) & 511)])) + (0.000130959786f * fVec22[((IOTA - 141) & 511)])) + (0.00156531716f * fVec22[((IOTA - 153) & 511)])) + (0.00546310749f * fVec22[((IOTA - 154) & 511)])) + (0.00780091435f * fVec22[((IOTA - 155) & 511)])) + (0.00763639063f * fVec22[((IOTA - 156) & 511)])) + (0.004383686f * fVec22[((IOTA - 157) & 511)])) + (0.000724442303f * fVec22[((IOTA - 164) & 511)])) + (0.0109959878f * fVec22[((IOTA - 165) & 511)])) + (0.0207068343f * fVec22[((IOTA - 166) & 511)])) + (0.0284659453f * fVec22[((IOTA - 167) & 511)])) + (0.0327724852f * fVec22[((IOTA - 168) & 511)])) + (0.0312566906f * fVec22[((IOTA - 169) & 511)])) + (0.0235355236f * fVec22[((IOTA - 170) & 511)])) + (0.012239933f * fVec22[((IOTA - 171) & 511)])) + (0.00139931915f * fVec22[((IOTA - 172) & 511)])) + (0.00272357464f * fVec22[((IOTA - 182) & 511)])) + (0.00930209551f * fVec22[((IOTA - 183) & 511)])) + (0.0177294929f * fVec22[((IOTA - 184) & 511)])) + (0.0242749266f * fVec22[((IOTA - 185) & 511)])) + (0.0281527694f * fVec22[((IOTA - 186) & 511)])) + (0.0280387215f * fVec22[((IOTA - 187) & 511)])) + (0.022789225f * fVec22[((IOTA - 188) & 511)])) + (0.0180567615f * fVec22[((IOTA - 189) & 511)])) + (0.0160800926f * fVec22[((IOTA - 190) & 511)])) + (0.0171119422f * fVec22[((IOTA - 191) & 511)])) + (0.0207733549f * fVec22[((IOTA - 192) & 511)])) + (0.0232752077f * fVec22[((IOTA - 193) & 511)])) + (0.0218198188f * fVec22[((IOTA - 194) & 511)])) + (0.016320806f * fVec22[((IOTA - 195) & 511)])) + (0.00805385783f * fVec22[((IOTA - 196) & 511)])) + (0.000384597108f * fVec22[((IOTA - 197) & 511)])) + (0.00278307032f * fVec22[((IOTA - 200) & 511)])) + (0.00676455349f * fVec22[((IOTA - 201) & 511)])) + (0.00949237775f * fVec22[((IOTA - 202) & 511)])) + (0.0107092205f * fVec22[((IOTA - 203) & 511)])) + (0.0142993415f * fVec22[((IOTA - 204) & 511)])) + (0.0206732713f * fVec22[((IOTA - 205) & 511)])) + (0.0302490816f * fVec22[((IOTA - 206) & 511)])) + (0.0429832339f * fVec22[((IOTA - 207) & 511)])) + (0.0532239042f * fVec22[((IOTA - 208) & 511)])) + (0.0565782115f * fVec22[((IOTA - 209) & 511)])) + (0.0528534465f * fVec22[((IOTA - 210) & 511)])) + (0.0430127233f * fVec22[((IOTA - 211) & 511)])) + (0.0308697522f * fVec22[((IOTA - 212) & 511)])) + (0.0212579928f * fVec22[((IOTA - 213) & 511)])) + (0.0157362577f * fVec22[((IOTA - 214) & 511)])) + (0.0135111101f * fVec22[((IOTA - 215) & 511)])) + (0.0135002267f * fVec22[((IOTA - 216) & 511)])) + (0.014808394f * fVec22[((IOTA - 217) & 511)])) + (0.0148898317f * fVec22[((IOTA - 218) & 511)])) + (0.0130524039f * fVec22[((IOTA - 219) & 511)])) + (0.0110896546f * fVec22[((IOTA - 220) & 511)])) + (0.0103462618f * fVec22[((IOTA - 221) & 511)])) + (0.00966765545f * fVec22[((IOTA - 222) & 511)])) + (0.00928553008f * fVec22[((IOTA - 223) & 511)])) + (0.00898722839f * fVec22[((IOTA - 224) & 511)])) + (0.00794635713f * fVec22[((IOTA - 225) & 511)])) + (0.00599297415f * fVec22[((IOTA - 226) & 511)])) + (0.00434578583f * fVec22[((IOTA - 227) & 511)])) + (0.00333036995f * fVec22[((IOTA - 228) & 511)])) + (0.00265306467f * fVec22[((IOTA - 229) & 511)])) + (0.00241044164f * fVec22[((IOTA - 230) & 511)])) + (0.00232952414f * fVec22[((IOTA - 231) & 511)])) + (0.00135513069f * fVec22[((IOTA - 232) & 511)])) + (0.00149064418f * fVec22[((IOTA - 239) & 511)])) + (0.0101416698f * fVec22[((IOTA - 240) & 511)])) + (0.0201378521f * fVec22[((IOTA - 241) & 511)])) + (0.0295782797f * fVec22[((IOTA - 242) & 511)])) + (0.03697877f * fVec22[((IOTA - 243) & 511)])) + (0.0399624854f * fVec22[((IOTA - 244) & 511)])) + (0.0377728119f * fVec22[((IOTA - 245) & 511)])) + (0.0293963663f * fVec22[((IOTA - 246) & 511)])) + (0.0156427212f * fVec22[((IOTA - 247) & 511)])) + (0.00145304715f * fVec22[((IOTA - 248) & 511)])) + (0.00230151089f * fVec22[((IOTA - 254) & 511)])) + (0.00455744611f * fVec22[((IOTA - 255) & 511)])) + (0.0059343027f * fVec22[((IOTA - 256) & 511)])) + (0.00696138339f * fVec22[((IOTA - 257) & 511)])) + (0.00820996799f * fVec22[((IOTA - 258) & 511)])) + (0.0101721548f * fVec22[((IOTA - 259) & 511)])) + (0.0130877895f * fVec22[((IOTA - 260) & 511)])) + (0.0173451565f * fVec22[((IOTA - 261) & 511)])) + (0.0218700357f * fVec22[((IOTA - 262) & 511)])) + (0.025422819f * fVec22[((IOTA - 263) & 511)])) + (0.026202552f * fVec22[((IOTA - 264) & 511)])) + (0.0234116316f * fVec22[((IOTA - 265) & 511)])) + (0.0183267482f * fVec22[((IOTA - 266) & 511)])) + (0.0127573544f * fVec22[((IOTA - 267) & 511)])) + (0.00878406689f * fVec22[((IOTA - 268) & 511)])) + (0.00754059898f * fVec22[((IOTA - 269) & 511)])) + (0.00835172646f * fVec22[((IOTA - 270) & 511)])) + (0.00967220962f * fVec22[((IOTA - 271) & 511)])) + (0.009374341f * fVec22[((IOTA - 272) & 511)])) + (0.00679273997f * fVec22[((IOTA - 273) & 511)])) + (0.00324728386f * fVec22[((IOTA - 274) & 511)])) + (0.0044566677f * fVec22[((IOTA - 293) & 511)])) + (0.00748856179f * fVec22[((IOTA - 294) & 511)])) + (0.00662318617f * fVec22[((IOTA - 295) & 511)])) + (0.00268550077f * fVec22[((IOTA - 296) & 511)])) + (0.00159558514f * fVec22[((IOTA - 320) & 511)])) + (0.00257318746f * fVec22[((IOTA - 321) & 511)])) + (0.00217228569f * fVec22[((IOTA - 322) & 511)])) + (0.00044292165f * fVec22[((IOTA - 323) & 511)])) + (0.00186448684f * fVec22[((IOTA - 347) & 511)])) + (0.00351002766f * fVec22[((IOTA - 348) & 511)])) + (0.00440701563f * fVec22[((IOTA - 349) & 511)])) + (0.00434149243f * fVec22[((IOTA - 350) & 511)])) + (0.00212371768f * fVec22[((IOTA - 351) & 511)])) + (0.000318119768f * fVec22[((IOTA - 372) & 511)])) + (0.00284399698f * fVec22[((IOTA - 373) & 511)])) + (0.00278363423f * fVec22[((IOTA - 374) & 511)])) + (0.000530994497f * fVec22[((IOTA - 375) & 511)])) + (0.00468142424f * fVec22[((IOTA - 380) & 511)])) + (0.0104478644f * fVec22[((IOTA - 381) & 511)])) + (0.0141729349f * fVec22[((IOTA - 382) & 511)])) + (0.0161218941f * fVec22[((IOTA - 383) & 511)])) + (0.0172050446f * fVec22[((IOTA - 384) & 511)])) + (0.0170311984f * fVec22[((IOTA - 385) & 511)])) + (0.0158188231f * fVec22[((IOTA - 386) & 511)])) + (0.013857157f * fVec22[((IOTA - 387) & 511)])) + (0.0115778483f * fVec22[((IOTA - 388) & 511)])) + (0.00878033787f * fVec22[((IOTA - 389) & 511)])) + (0.00607068278f * fVec22[((IOTA - 390) & 511)])) + (0.00397298345f * fVec22[((IOTA - 391) & 511)])) + (0.00228164997f * fVec22[((IOTA - 392) & 511)])) + (0.00198560301f * fVec22[((IOTA - 393) & 511)])) + (0.00240836013f * fVec22[((IOTA - 394) & 511)])) + (0.00274196127f * fVec22[((IOTA - 395) & 511)])) + (0.00363647752f * fVec22[((IOTA - 396) & 511)])) + (0.00477088476f * fVec22[((IOTA - 397) & 511)])) + (0.0047119963f * fVec22[((IOTA - 398) & 511)])) + (0.00371817593f * fVec22[((IOTA - 399) & 511)])) + (0.00167194987f * fVec22[((IOTA - 400) & 511)])) + (0.00172867021f * fVec22[((IOTA - 406) & 511)])) + (0.00394895999f * fVec22[((IOTA - 407) & 511)])) + (0.00603828998f * fVec22[((IOTA - 408) & 511)])) + (0.00767359696f * fVec22[((IOTA - 409) & 511)])) + (0.00904581323f * fVec22[((IOTA - 410) & 511)])) + (0.00953526422f * fVec22[((IOTA - 411) & 511)])) + (0.00886593852f * fVec22[((IOTA - 412) & 511)])) + (0.00678107515f * fVec22[((IOTA - 413) & 511)])) + (0.00368365785f * fVec22[((IOTA - 414) & 511)])) + (0.000467639416f * fVec22[((IOTA - 415) & 511)])) + (0.00817419309f * fVec22[((IOTA - 491) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00915270671f * fVec22[((IOTA - 492) & 511)])) + (0.0108681498f * fVec22[((IOTA - 493) & 511)])) + (0.0123179015f * fVec22[((IOTA - 494) & 511)])) + (0.0118287541f * fVec22[((IOTA - 495) & 511)])) + (0.00881520286f * fVec22[((IOTA - 496) & 511)])) + (0.00425818982f * fVec22[((IOTA - 497) & 511)])) - ((((((((((((((((((((((((((((((((((0.00280431891f * fVec22[((IOTA - 442) & 511)]) + ((0.0032693129f * fVec22[((IOTA - 441) & 511)]) + ((0.00382229313f * fVec22[((IOTA - 440) & 511)]) + ((0.00425463403f * fVec22[((IOTA - 439) & 511)]) + ((0.00392688764f * fVec22[((IOTA - 438) & 511)]) + ((0.00207068352f * fVec22[((IOTA - 437) & 511)]) + ((0.000279135071f * fVec22[((IOTA - 418) & 511)]) + ((0.00215199124f * fVec22[((IOTA - 417) & 511)]) + ((0.00194124132f * fVec22[((IOTA - 416) & 511)]) + ((0.000440927222f * fVec22[((IOTA - 405) & 511)]) + ((0.00222705491f * fVec22[((IOTA - 404) & 511)]) + ((0.00284200208f * fVec22[((IOTA - 403) & 511)]) + ((0.00243992964f * fVec22[((IOTA - 402) & 511)]) + ((0.000983109698f * fVec22[((IOTA - 401) & 511)]) + ((0.0010253028f * fVec22[((IOTA - 379) & 511)]) + ((0.00511116348f * fVec22[((IOTA - 378) & 511)]) + ((0.00600208063f * fVec22[((IOTA - 377) & 511)]) + ((0.00316064246f * fVec22[((IOTA - 376) & 511)]) + ((0.00391145004f * fVec22[((IOTA - 371) & 511)]) + ((0.00757533358f * fVec22[((IOTA - 370) & 511)]) + ((0.00856707245f * fVec22[((IOTA - 369) & 511)]) + ((0.00664460799f * fVec22[((IOTA - 368) & 511)]) + ((0.00337841734f * fVec22[((IOTA - 367) & 511)]) + ((0.00121211587f * fVec22[((IOTA - 366) & 511)]) + ((0.00104555395f * fVec22[((IOTA - 365) & 511)]) + ((0.00158379041f * fVec22[((IOTA - 364) & 511)]) + ((0.00233190926f * fVec22[((IOTA - 363) & 511)]) + ((0.00254972745f * fVec22[((IOTA - 362) & 511)]) + ((0.0020372062f * fVec22[((IOTA - 361) & 511)]) + ((0.00180520769f * fVec22[((IOTA - 360) & 511)]) + ((0.00326879276f * fVec22[((IOTA - 359) & 511)]) + ((0.00649920804f * fVec22[((IOTA - 358) & 511)]) + ((0.00975863449f * fVec22[((IOTA - 357) & 511)]) + ((0.0123554543f * fVec22[((IOTA - 356) & 511)]) + ((0.0132642388f * fVec22[((IOTA - 355) & 511)]) + ((0.010520976f * fVec22[((IOTA - 354) & 511)]) + ((0.00546349771f * fVec22[((IOTA - 353) & 511)]) + ((0.00138756726f * fVec22[((IOTA - 352) & 511)]) + ((0.000173326582f * fVec22[((IOTA - 346) & 511)]) + ((0.00200598408f * fVec22[((IOTA - 345) & 511)]) + ((0.00288610347f * fVec22[((IOTA - 344) & 511)]) + ((0.00231772941f * fVec22[((IOTA - 343) & 511)]) + ((0.00163504668f * fVec22[((IOTA - 342) & 511)]) + ((0.00130161969f * fVec22[((IOTA - 341) & 511)]) + ((0.00164259225f * fVec22[((IOTA - 340) & 511)]) + ((0.00355274137f * fVec22[((IOTA - 339) & 511)]) + ((0.00579523342f * fVec22[((IOTA - 338) & 511)]) + ((0.00714672217f * fVec22[((IOTA - 337) & 511)]) + ((0.00808130763f * fVec22[((IOTA - 336) & 511)]) + ((0.00940599665f * fVec22[((IOTA - 335) & 511)]) + ((0.011868475f * fVec22[((IOTA - 334) & 511)]) + ((0.0144483838f * fVec22[((IOTA - 333) & 511)]) + ((0.0171069987f * fVec22[((IOTA - 332) & 511)]) + ((0.0187392272f * fVec22[((IOTA - 331) & 511)]) + ((0.0180183407f * fVec22[((IOTA - 330) & 511)]) + ((0.0152312815f * fVec22[((IOTA - 329) & 511)]) + ((0.010528435f * fVec22[((IOTA - 328) & 511)]) + ((0.00654521724f * fVec22[((IOTA - 327) & 511)]) + ((0.00406864518f * fVec22[((IOTA - 326) & 511)]) + ((0.0024079266f * fVec22[((IOTA - 325) & 511)]) + ((0.00128895696f * fVec22[((IOTA - 324) & 511)]) + ((0.000969362911f * fVec22[((IOTA - 319) & 511)]) + ((0.00592233427f * fVec22[((IOTA - 318) & 511)]) + ((0.0122877639f * fVec22[((IOTA - 317) & 511)]) + ((0.017593069f * fVec22[((IOTA - 316) & 511)]) + ((0.020571582f * fVec22[((IOTA - 315) & 511)]) + ((0.0204203706f * fVec22[((IOTA - 314) & 511)]) + ((0.0175883844f * fVec22[((IOTA - 313) & 511)]) + ((0.0141017307f * fVec22[((IOTA - 312) & 511)]) + ((0.0112722181f * fVec22[((IOTA - 311) & 511)]) + ((0.010601894f * fVec22[((IOTA - 310) & 511)]) + ((0.0112078656f * fVec22[((IOTA - 309) & 511)]) + ((0.0115385167f * fVec22[((IOTA - 308) & 511)]) + ((0.0114481458f * fVec22[((IOTA - 307) & 511)]) + ((0.0105467346f * fVec22[((IOTA - 306) & 511)]) + ((0.00782723632f * fVec22[((IOTA - 305) & 511)]) + ((0.0052430341f * fVec22[((IOTA - 304) & 511)]) + ((0.00362502923f * fVec22[((IOTA - 303) & 511)]) + ((0.00296585029f * fVec22[((IOTA - 302) & 511)]) + ((0.00381058501f * fVec22[((IOTA - 301) & 511)]) + ((0.00567862717f * fVec22[((IOTA - 300) & 511)]) + ((0.00745742628f * fVec22[((IOTA - 299) & 511)]) + ((0.00638676435f * fVec22[((IOTA - 298) & 511)]) + ((0.00233138911f * fVec22[((IOTA - 297) & 511)]) + ((0.00213668356f * fVec22[((IOTA - 292) & 511)]) + ((0.0103259236f * fVec22[((IOTA - 291) & 511)]) + ((0.0164922252f * fVec22[((IOTA - 290) & 511)]) + ((0.0186593495f * fVec22[((IOTA - 289) & 511)]) + ((0.0175466686f * fVec22[((IOTA - 288) & 511)]) + ((0.0145990308f * fVec22[((IOTA - 287) & 511)]) + ((0.0117832646f * fVec22[((IOTA - 286) & 511)]) + ((0.00949472003f * fVec22[((IOTA - 285) & 511)]) + ((0.00774670905f * fVec22[((IOTA - 284) & 511)]) + ((0.00678909756f * fVec22[((IOTA - 283) & 511)]) + ((0.00592931593f * fVec22[((IOTA - 282) & 511)]) + ((0.00523358071f * fVec22[((IOTA - 281) & 511)]) + ((0.00594336586f * fVec22[((IOTA - 280) & 511)]) + ((0.00714143133f * fVec22[((IOTA - 279) & 511)]) + ((0.00707534468f * fVec22[((IOTA - 278) & 511)]) + ((0.0063472162f * fVec22[((IOTA - 277) & 511)]) + ((0.00490570394f * fVec22[((IOTA - 276) & 511)]) + ((0.00122781377f * fVec22[((IOTA - 275) & 511)]) + ((((((((((((((((((((((((((((((((((((((((0.00144060189f * fVec22[((IOTA - 142) & 511)]) + ((0.000580776483f * fVec22[((IOTA - 137) & 511)]) + ((0.00245103054f * fVec22[((IOTA - 136) & 511)]) + ((0.00220107939f * fVec22[((IOTA - 135) & 511)]) + ((0.000526311342f * fVec22[((IOTA - 134) & 511)]) + ((0.00668120757f * fVec22[((IOTA - 128) & 511)]) + ((0.0159613173f * fVec22[((IOTA - 127) & 511)]) + ((0.0210641548f * fVec22[((IOTA - 126) & 511)]) + ((0.0237377733f * fVec22[((IOTA - 125) & 511)]) + ((0.0227529742f * fVec22[((IOTA - 124) & 511)]) + ((0.0168116018f * fVec22[((IOTA - 123) & 511)]) + ((0.0102110952f * fVec22[((IOTA - 122) & 511)]) + ((0.00686177611f * fVec22[((IOTA - 121) & 511)]) + ((0.0062898458f * fVec22[((IOTA - 120) & 511)]) + ((0.00924645923f * fVec22[((IOTA - 119) & 511)]) + ((0.0129866637f * fVec22[((IOTA - 118) & 511)]) + ((0.0147862341f * fVec22[((IOTA - 117) & 511)]) + ((0.0131912567f * fVec22[((IOTA - 116) & 511)]) + ((0.00674911588f * fVec22[((IOTA - 115) & 511)]) + ((0.000250081066f * fVec22[((IOTA - 114) & 511)]) + ((0.000408924185f * fVec22[((IOTA - 111) & 511)]) + ((0.00908445101f * fVec22[((IOTA - 110) & 511)]) + ((0.0210247803f * fVec22[((IOTA - 109) & 511)]) + ((0.0298374668f * fVec22[((IOTA - 108) & 511)]) + ((0.0325081795f * fVec22[((IOTA - 107) & 511)]) + ((0.031796705f * fVec22[((IOTA - 106) & 511)]) + ((0.0280778352f * fVec22[((IOTA - 105) & 511)]) + ((0.0226073135f * fVec22[((IOTA - 104) & 511)]) + ((0.022228051f * fVec22[((IOTA - 103) & 511)]) + ((0.0284449141f * fVec22[((IOTA - 102) & 511)]) + ((0.0333491415f * fVec22[((IOTA - 101) & 511)]) + ((0.041044727f * fVec22[((IOTA - 100) & 511)]) + ((0.0478998683f * fVec22[((IOTA - 99) & 511)]) + ((0.0499722399f * fVec22[((IOTA - 98) & 511)]) + ((0.0534052551f * fVec22[((IOTA - 97) & 511)]) + ((0.0555875562f * fVec22[((IOTA - 96) & 511)]) + ((0.0527854934f * fVec22[((IOTA - 95) & 511)]) + ((0.0492701307f * fVec22[((IOTA - 94) & 511)]) + ((0.0417895056f * fVec22[((IOTA - 93) & 511)]) + ((0.0307644196f * fVec22[((IOTA - 92) & 511)]) + ((0.0255137552f * fVec22[((IOTA - 91) & 511)]) + ((0.0279504322f * fVec22[((IOTA - 90) & 511)]) + ((0.0346041881f * fVec22[((IOTA - 89) & 511)]) + ((((0.0442077108f * fVec22[((IOTA - 86) & 511)]) + ((0.0321822129f * fVec22[((IOTA - 85) & 511)]) + ((0.020731682f * fVec22[((IOTA - 84) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00540369842f * fVec22[((IOTA - 8) & 511)]) + (0.0241577569f * fVec22[((IOTA - 15) & 511)])) + (0.0558953546f * fVec22[((IOTA - 16) & 511)])) + (0.0528957248f * fVec22[((IOTA - 17) & 511)])) + (0.0401180312f * fVec22[((IOTA - 18) & 511)])) + (0.0182038955f * fVec22[((IOTA - 19) & 511)])) + (0.00509052211f * fVec22[((IOTA - 20) & 511)])) + (0.0134675726f * fVec22[((IOTA - 24) & 511)])) + (0.0120192524f * fVec22[((IOTA - 25) & 511)])) + (0.0312638022f * fVec22[((IOTA - 26) & 511)])) + (0.0358901098f * fVec22[((IOTA - 27) & 511)])) + (0.0233929418f * fVec22[((IOTA - 28) & 511)])) + (0.0368416943f * fVec22[((IOTA - 29) & 511)])) + (0.0540926643f * fVec22[((IOTA - 30) & 511)])) + (0.0758819133f * fVec22[((IOTA - 31) & 511)])) + (0.111945048f * fVec22[((IOTA - 32) & 511)])) + (0.108036414f * fVec22[((IOTA - 33) & 511)])) + (0.0898763165f * fVec22[((IOTA - 34) & 511)])) + (0.070718579f * fVec22[((IOTA - 35) & 511)])) + (0.0349841043f * fVec22[((IOTA - 36) & 511)])) + (0.0246284753f * fVec22[((IOTA - 37) & 511)])) + (0.0396706872f * fVec22[((IOTA - 38) & 511)])) + (0.0492512695f * fVec22[((IOTA - 39) & 511)])) + (0.0627084747f * fVec22[((IOTA - 40) & 511)])) + (0.0606393553f * fVec22[((IOTA - 41) & 511)])) + (0.0416219011f * fVec22[((IOTA - 42) & 511)])) + (0.0316532142f * fVec22[((IOTA - 43) & 511)])) + (0.0154292826f * fVec22[((IOTA - 44) & 511)])) + (0.0153340111f * fVec22[((IOTA - 45) & 511)])) + (0.0310433395f * fVec22[((IOTA - 46) & 511)])) + (0.0378755853f * fVec22[((IOTA - 47) & 511)])) + (0.0436854325f * fVec22[((IOTA - 48) & 511)])) + (0.0453586802f * fVec22[((IOTA - 49) & 511)])) + (0.0425000265f * fVec22[((IOTA - 50) & 511)])) + (0.0412020944f * fVec22[((IOTA - 51) & 511)])) + (0.0373451114f * fVec22[((IOTA - 52) & 511)])) + (0.0355697796f * fVec22[((IOTA - 53) & 511)])) + (0.0350110754f * fVec22[((IOTA - 54) & 511)])) + (0.037389297f * fVec22[((IOTA - 55) & 511)])) + (0.0401499495f * fVec22[((IOTA - 56) & 511)])) + (0.0339379422f * fVec22[((IOTA - 57) & 511)])) + (0.0281789601f * fVec22[((IOTA - 58) & 511)])) + (0.0195729472f * fVec22[((IOTA - 59) & 511)])) + (0.00415858254f * fVec22[((IOTA - 60) & 511)])) + (0.00185702788f * fVec22[((IOTA - 64) & 511)])) + (0.0105075762f * fVec22[((IOTA - 65) & 511)])) + (0.019151751f * fVec22[((IOTA - 66) & 511)])) + (0.0172715671f * fVec22[((IOTA - 67) & 511)])) + (0.00696342159f * fVec22[((IOTA - 68) & 511)])) + (0.0156227732f * fVec22[((IOTA - 75) & 511)])) + (0.0296925008f * fVec22[((IOTA - 76) & 511)])) + (0.0330638923f * fVec22[((IOTA - 77) & 511)])) + (0.0275951922f * fVec22[((IOTA - 78) & 511)])) + (0.0178769305f * fVec22[((IOTA - 79) & 511)])) + (0.00888185389f * fVec22[((IOTA - 80) & 511)])) + (0.00125361513f * fVec22[((IOTA - 81) & 511)])) + (0.0110861417f * fVec22[((IOTA - 83) & 511)])) + (0.0452642776f * fVec22[((IOTA - 87) & 511)]))))) + (0.0407811999f * fVec22[((IOTA - 88) & 511)])) + (0.00217020418f * fVec22[((IOTA - 143) & 511)]))))))))))))))))))))))))))))))))))))))))))))) + (0.00197866466f * fVec22[((IOTA - 144) & 511)])) + (0.00202111807f * fVec22[((IOTA - 145) & 511)])) + (0.00130500179f * fVec22[((IOTA - 146) & 511)])) + (0.000573881902f * fVec22[((IOTA - 147) & 511)])) + (0.000794085208f * fVec22[((IOTA - 148) & 511)])) + (0.0020605796f * fVec22[((IOTA - 149) & 511)])) + (0.00284508104f * fVec22[((IOTA - 150) & 511)])) + (0.0032017082f * fVec22[((IOTA - 151) & 511)])) + (0.00186162489f * fVec22[((IOTA - 152) & 511)])) + (0.00262587517f * fVec22[((IOTA - 158) & 511)])) + (0.0104848538f * fVec22[((IOTA - 159) & 511)])) + (0.0154038705f * fVec22[((IOTA - 160) & 511)])) + (0.0159112327f * fVec22[((IOTA - 161) & 511)])) + (0.0134940688f * fVec22[((IOTA - 162) & 511)])) + (0.00794895925f * fVec22[((IOTA - 163) & 511)])) + (0.00661932677f * fVec22[((IOTA - 173) & 511)])) + (0.0111089079f * fVec22[((IOTA - 174) & 511)])) + (0.011745885f * fVec22[((IOTA - 175) & 511)])) + (0.00934680365f * fVec22[((IOTA - 176) & 511)])) + (0.00680440525f * fVec22[((IOTA - 177) & 511)])) + (0.00481624389f * fVec22[((IOTA - 178) & 511)])) + (0.00352854421f * fVec22[((IOTA - 179) & 511)])) + (0.00312738214f * fVec22[((IOTA - 180) & 511)])) + (0.00141887646f * fVec22[((IOTA - 181) & 511)])) + (0.00267387927f * fVec22[((IOTA - 198) & 511)])) + (0.000837665983f * fVec22[((IOTA - 199) & 511)])) + (0.000227445271f * fVec22[((IOTA - 233) & 511)])) + (0.00232995767f * fVec22[((IOTA - 234) & 511)])) + (0.00434053876f * fVec22[((IOTA - 235) & 511)])) + (0.00554549927f * fVec22[((IOTA - 236) & 511)])) + (0.00557581102f * fVec22[((IOTA - 237) & 511)])) + (0.00364900986f * fVec22[((IOTA - 238) & 511)])) + (0.00862977747f * fVec22[((IOTA - 249) & 511)])) + (0.0128183244f * fVec22[((IOTA - 250) & 511)])) + (0.012018472f * fVec22[((IOTA - 251) & 511)])) + (0.00696567632f * fVec22[((IOTA - 252) & 511)])) + (0.00138709042f * fVec22[((IOTA - 253) & 511)])) + (0.00253888639f * fVec22[((IOTA - 443) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00236343499f * fVec22[((IOTA - 444) & 511)])) + (0.00177927595f * fVec22[((IOTA - 445) & 511)])) + (0.0018304456f * fVec22[((IOTA - 446) & 511)])) + (0.00205593975f * fVec22[((IOTA - 447) & 511)])) + (0.00214388222f * fVec22[((IOTA - 448) & 511)])) + (0.00244266121f * fVec22[((IOTA - 449) & 511)])) + (0.00267708814f * fVec22[((IOTA - 450) & 511)])) + (0.00263775699f * fVec22[((IOTA - 451) & 511)])) + (0.00231586443f * fVec22[((IOTA - 452) & 511)])) + (0.00152472826f * fVec22[((IOTA - 453) & 511)])) + (0.000816981308f * fVec22[((IOTA - 454) & 511)])) + (0.000240107533f * fVec22[((IOTA - 455) & 511)])) + (0.000253290404f * fVec22[((IOTA - 466) & 511)])) + (0.0030899588f * fVec22[((IOTA - 481) & 511)])) + (0.00667023612f * fVec22[((IOTA - 482) & 511)])) + (0.00791283697f * fVec22[((IOTA - 483) & 511)])) + (0.00588959409f * fVec22[((IOTA - 484) & 511)])) + (0.00197376451f * fVec22[((IOTA - 485) & 511)])) + (8.58632848e-06f * fVec22[((IOTA - 498) & 511)])) + (0.00330630271f * fVec22[((IOTA - 499) & 511)])) + (0.00511255115f * fVec22[((IOTA - 500) & 511)])) + (0.0049940804f * fVec22[((IOTA - 501) & 511)])) + (0.00448203599f * fVec22[((IOTA - 502) & 511)])) + (0.00461533759f * fVec22[((IOTA - 503) & 511)])) + (0.00554324454f * fVec22[((IOTA - 504) & 511)])) + (0.00842704996f * fVec22[((IOTA - 505) & 511)])) + (0.0117521724f * fVec22[((IOTA - 506) & 511)])) + (0.0137356073f * fVec22[((IOTA - 507) & 511)])) + (0.0145330746f * fVec22[((IOTA - 508) & 511)])) + (0.0141520761f * fVec22[((IOTA - 509) & 511)])) + (0.0126511548f * fVec22[((IOTA - 510) & 511)])) + (0.0105181141f * fVec22[((IOTA - 511) & 511)])))))) : (iSlow47 ? (iSlow59 ? (iSlow65 ? (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0588469654f * fVec21[((IOTA - 4) & 511)]) + ((0.20853965f * fVec21[((IOTA - 3) & 511)]) + ((0.212562367f * fVec21[((IOTA - 2) & 511)]) + ((0.238421783f * fVec21[((IOTA - 1) & 511)]) + ((fSlow69 * fTemp0) + ((0.110896647f * fVec21[((IOTA - 12) & 511)]) + (((0.0778840855f * fVec21[((IOTA - 10) & 511)]) + (0.128314242f * fVec21[((IOTA - 11) & 511)])) + (0.0319869556f * fVec21[((IOTA - 13) & 511)])))))))) + (0.0105160438f * fVec21[((IOTA - 15) & 511)])) + (0.0124113951f * fVec21[((IOTA - 16) & 511)])) + (0.024512196f * fVec21[((IOTA - 17) & 511)])) + (0.028685743f * fVec21[((IOTA - 18) & 511)])) + (0.0191007014f * fVec21[((IOTA - 23) & 511)])) + (0.0472685248f * fVec21[((IOTA - 24) & 511)])) + (0.0601792186f * fVec21[((IOTA - 25) & 511)])) + (0.0458457358f * fVec21[((IOTA - 26) & 511)])) + (0.0181611888f * fVec21[((IOTA - 27) & 511)])) + (0.0132318251f * fVec21[((IOTA - 34) & 511)])) + (0.031582173f * fVec21[((IOTA - 35) & 511)])) + (0.0423160121f * fVec21[((IOTA - 36) & 511)])) + (0.0421964452f * fVec21[((IOTA - 37) & 511)])) + (0.0146987047f * fVec21[((IOTA - 38) & 511)])) + (0.00327800401f * fVec21[((IOTA - 48) & 511)])) + (0.0292782336f * fVec21[((IOTA - 49) & 511)])) + (0.0217878446f * fVec21[((IOTA - 50) & 511)])) + (0.012388641f * fVec21[((IOTA - 57) & 511)])) + (0.0133913774f * fVec21[((IOTA - 58) & 511)])) + (0.0012919358f * fVec21[((IOTA - 63) & 511)])) + (0.00205547875f * fVec21[((IOTA - 64) & 511)])) + (0.00796443224f * fVec21[((IOTA - 72) & 511)])) + (0.0134380944f * fVec21[((IOTA - 73) & 511)])) + (0.0113380719f * fVec21[((IOTA - 74) & 511)])) + (0.00234721275f * fVec21[((IOTA - 75) & 511)])) + (0.00510319183f * fVec21[((IOTA - 79) & 511)])) + (0.00246125693f * fVec21[((IOTA - 80) & 511)])) + (0.00448516896f * fVec21[((IOTA - 95) & 511)])) + (0.0095831994f * fVec21[((IOTA - 96) & 511)])) + (0.00954873674f * fVec21[((IOTA - 97) & 511)])) + (0.0028823358f * fVec21[((IOTA - 98) & 511)])) + (0.00535137858f * fVec21[((IOTA - 128) & 511)])) + (0.00853169523f * fVec21[((IOTA - 129) & 511)])) + (0.00750508765f * fVec21[((IOTA - 130) & 511)])) + (0.00520640146f * fVec21[((IOTA - 131) & 511)])) + (0.000114044175f * fVec21[((IOTA - 132) & 511)])) + (0.00012747338f * fVec21[((IOTA - 141) & 511)])) + (0.00115311518f * fVec21[((IOTA - 142) & 511)])) + (0.00281268405f * fVec21[((IOTA - 149) & 511)])) + (0.00573971355f * fVec21[((IOTA - 150) & 511)])) + (0.00542250881f * fVec21[((IOTA - 151) & 511)])) + (0.00212621689f * fVec21[((IOTA - 152) & 511)])) + (0.000311682001f * fVec21[((IOTA - 153) & 511)])) + (0.000916335732f * fVec21[((IOTA - 162) & 511)])) + (0.00386781013f * fVec21[((IOTA - 163) & 511)])) + (0.00517634396f * fVec21[((IOTA - 164) & 511)])) + (0.0035795765f * fVec21[((IOTA - 165) & 511)])) + (0.000638725236f * fVec21[((IOTA - 166) & 511)])) + (0.000734843314f * fVec21[((IOTA - 174) & 511)])) + (0.00141141191f * fVec21[((IOTA - 175) & 511)])) + (0.000887877773f * fVec21[((IOTA - 176) & 511)])) + (5.42607158e-05f * fVec21[((IOTA - 183) & 511)])) + (0.00245884247f * fVec21[((IOTA - 184) & 511)])) + (0.00469406368f * fVec21[((IOTA - 185) & 511)])) + (0.00651224982f * fVec21[((IOTA - 186) & 511)])) + (0.00609865505f * fVec21[((IOTA - 187) & 511)])) + (0.00363510475f * fVec21[((IOTA - 188) & 511)])) + (0.000935710501f * fVec21[((IOTA - 189) & 511)])) + (0.000677323435f * fVec21[((IOTA - 193) & 511)])) + (0.00252939947f * fVec21[((IOTA - 194) & 511)])) + (0.00385818304f * fVec21[((IOTA - 195) & 511)])) + (0.00277372357f * fVec21[((IOTA - 196) & 511)])) + (0.000627378002f * fVec21[((IOTA - 197) & 511)])) + (0.000981159043f * fVec21[((IOTA - 206) & 511)])) + (0.00561565068f * fVec21[((IOTA - 207) & 511)])) + (0.00880722329f * fVec21[((IOTA - 208) & 511)])) + (0.0094980374f * fVec21[((IOTA - 209) & 511)])) + (0.00649408251f * fVec21[((IOTA - 210) & 511)])) + (0.00153541472f * fVec21[((IOTA - 211) & 511)])) + (0.00151278125f * fVec21[((IOTA - 217) & 511)])) + (0.00487314211f * fVec21[((IOTA - 218) & 511)])) + (0.00741938129f * fVec21[((IOTA - 219) & 511)])) + (0.00843032636f * fVec21[((IOTA - 220) & 511)])) + (0.00733521348f * fVec21[((IOTA - 221) & 511)])) + (0.00503272517f * fVec21[((IOTA - 222) & 511)])) + (0.00263248896f * fVec21[((IOTA - 223) & 511)])) + (0.000272027683f * fVec21[((IOTA - 224) & 511)])) + (6.29820861e-05f * fVec21[((IOTA - 226) & 511)])) + (0.0013066628f * fVec21[((IOTA - 227) & 511)])) + (0.00307734823f * fVec21[((IOTA - 228) & 511)])) + (0.00398085825f * fVec21[((IOTA - 229) & 511)])) + (0.00359735172f * fVec21[((IOTA - 230) & 511)])) + (0.00374344504f * fVec21[((IOTA - 231) & 511)])) + (0.00440332526f * fVec21[((IOTA - 232) & 511)])) + (0.00367889367f * fVec21[((IOTA - 233) & 511)])) + (0.00256651919f * fVec21[((IOTA - 234) & 511)])) + (0.00155481976f * fVec21[((IOTA - 235) & 511)])) + (0.000213874038f * fVec21[((IOTA - 236) & 511)])) + (0.000488316175f * fVec21[((IOTA - 238) & 511)])) + (0.00240041735f * fVec21[((IOTA - 239) & 511)])) + (0.00527258264f * fVec21[((IOTA - 240) & 511)])) + (0.00665770937f * fVec21[((IOTA - 241) & 511)])) + (0.00619407929f * fVec21[((IOTA - 242) & 511)])) + (0.0041943402f * fVec21[((IOTA - 243) & 511)])) + (0.00063274987f * fVec21[((IOTA - 244) & 511)])) + (0.00220099883f * fVec21[((IOTA - 248) & 511)])) + (0.00444249669f * fVec21[((IOTA - 249) & 511)])) + (0.00536541129f * fVec21[((IOTA - 250) & 511)])) + (0.00598364556f * fVec21[((IOTA - 251) & 511)])) + (0.00561462436f * fVec21[((IOTA - 252) & 511)])) + (0.00565560674f * fVec21[((IOTA - 253) & 511)])) + (0.00671079336f * fVec21[((IOTA - 254) & 511)])) + (0.00728113391f * fVec21[((IOTA - 255) & 511)])) + (0.00774313463f * fVec21[((IOTA - 256) & 511)])) + (0.0074780779f * fVec21[((IOTA - 257) & 511)])) + (0.00609521475f * fVec21[((IOTA - 258) & 511)])) + (0.00490479916f * fVec21[((IOTA - 259) & 511)])) + (0.00399283925f * fVec21[((IOTA - 260) & 511)])) + (0.00343378494f * fVec21[((IOTA - 261) & 511)])) + (0.00373451225f * fVec21[((IOTA - 262) & 511)])) + (0.00433762698f * fVec21[((IOTA - 263) & 511)])) + (0.00517432205f * fVec21[((IOTA - 264) & 511)])) + (0.00634038402f * fVec21[((IOTA - 265) & 511)])) + (0.00666766847f * fVec21[((IOTA - 266) & 511)])) + (0.00688685384f * fVec21[((IOTA - 267) & 511)])) + (0.00732920831f * fVec21[((IOTA - 268) & 511)])) + (0.00685066963f * fVec21[((IOTA - 269) & 511)])) + (0.00607520668f * fVec21[((IOTA - 270) & 511)])) + (0.00560976565f * fVec21[((IOTA - 271) & 511)])) + (0.00530375727f * fVec21[((IOTA - 272) & 511)])) + (0.00537189981f * fVec21[((IOTA - 273) & 511)])) + (0.0057493709f * fVec21[((IOTA - 274) & 511)])) + (0.00589163182f * fVec21[((IOTA - 275) & 511)])) + (0.00557566434f * fVec21[((IOTA - 276) & 511)])) + (0.00454459013f * fVec21[((IOTA - 277) & 511)])) + (0.00319368578f * fVec21[((IOTA - 278) & 511)])) + (0.00289540272f * fVec21[((IOTA - 279) & 511)])) + (0.00287608849f * fVec21[((IOTA - 280) & 511)])) + (0.00249191793f * fVec21[((IOTA - 281) & 511)])) + (0.00273198681f * fVec21[((IOTA - 282) & 511)])) + (0.00295962254f * fVec21[((IOTA - 283) & 511)])) + (0.0032133623f * fVec21[((IOTA - 284) & 511)])) + (0.0039226138f * fVec21[((IOTA - 285) & 511)])) + (0.00466626929f * fVec21[((IOTA - 286) & 511)])) + (0.00558764488f * fVec21[((IOTA - 287) & 511)])) + (0.00657740468f * fVec21[((IOTA - 288) & 511)])) + (0.0068820552f * fVec21[((IOTA - 289) & 511)])) + (0.00636117673f * fVec21[((IOTA - 290) & 511)])) + (0.00531972153f * fVec21[((IOTA - 291) & 511)])) + (0.00417200802f * fVec21[((IOTA - 292) & 511)])) + (0.00376861403f * fVec21[((IOTA - 293) & 511)])) + (0.00390876224f * fVec21[((IOTA - 294) & 511)])) + (0.00452814298f * fVec21[((IOTA - 295) & 511)])) + (0.00575920893f * fVec21[((IOTA - 296) & 511)])) + (0.00715562236f * fVec21[((IOTA - 297) & 511)])) + (0.00852457341f * fVec21[((IOTA - 298) & 511)])) + (0.00960939471f * fVec21[((IOTA - 299) & 511)])) + (0.00976786204f * fVec21[((IOTA - 300) & 511)])) + (0.00900522433f * fVec21[((IOTA - 301) & 511)])) + (0.00755814137f * fVec21[((IOTA - 302) & 511)])) + (0.00557789719f * fVec21[((IOTA - 303) & 511)])) + (0.00382190896f * fVec21[((IOTA - 304) & 511)])) + (0.00288942736f * fVec21[((IOTA - 305) & 511)])) + (0.00230761897f * fVec21[((IOTA - 306) & 511)])) + (0.00287626963f * fVec21[((IOTA - 307) & 511)])) + (0.00392010901f * fVec21[((IOTA - 308) & 511)])) + (0.00438832631f * fVec21[((IOTA - 309) & 511)])) + (0.00545784784f * fVec21[((IOTA - 310) & 511)])) + (0.00640843622f * fVec21[((IOTA - 311) & 511)])) + (0.0065284255f * fVec21[((IOTA - 312) & 511)])) + (0.00621200493f * fVec21[((IOTA - 313) & 511)])) + (0.00464598928f * fVec21[((IOTA - 314) & 511)])) + (0.0026045437f * fVec21[((IOTA - 315) & 511)])) + (0.000974217895f * fVec21[((IOTA - 316) & 511)])) + (0.000908308197f * fVec21[((IOTA - 320) & 511)])) + (0.00253353408f * fVec21[((IOTA - 321) & 511)])) + (0.0031094579f * fVec21[((IOTA - 322) & 511)])) + (0.00219982164f * fVec21[((IOTA - 323) & 511)])) + (0.00135054206f * fVec21[((IOTA - 324) & 511)])) + (0.000607369933f * fVec21[((IOTA - 329) & 511)])) + (0.00182814477f * fVec21[((IOTA - 330) & 511)])) + (0.0024420335f * fVec21[((IOTA - 331) & 511)])) + (0.00368468789f * fVec21[((IOTA - 332) & 511)])) + (0.0056200563f * fVec21[((IOTA - 333) & 511)])) + (0.00632692454f * fVec21[((IOTA - 334) & 511)])) + (0.00631759921f * fVec21[((IOTA - 335) & 511)])) + (0.00560665736f * fVec21[((IOTA - 336) & 511)])) + (0.00341685489f * fVec21[((IOTA - 337) & 511)])) + (0.00187024381f * fVec21[((IOTA - 338) & 511)])) + (0.000864067115f * fVec21[((IOTA - 339) & 511)])) + (0.000267229509f * fVec21[((IOTA - 340) & 511)])) + (0.00127238035f * fVec21[((IOTA - 341) & 511)])) + (0.00279789651f * fVec21[((IOTA - 342) & 511)])) + (0.00375660276f * fVec21[((IOTA - 343) & 511)])) + (0.00440027704f * fVec21[((IOTA - 344) & 511)])) + (0.00450333627f * fVec21[((IOTA - 345) & 511)])) + (0.0047662803f * fVec21[((IOTA - 346) & 511)])) + (0.00541270105f * fVec21[((IOTA - 347) & 511)])) + (0.00524330977f * fVec21[((IOTA - 348) & 511)])) + (0.00493540009f * fVec21[((IOTA - 349) & 511)])) + (0.00456656003f * fVec21[((IOTA - 350) & 511)])) + (0.00341160363f * fVec21[((IOTA - 351) & 511)])) + (0.00215343758f * fVec21[((IOTA - 352) & 511)])) + (0.00052597886f * fVec21[((IOTA - 353) & 511)])) + (0.000359575264f * fVec21[((IOTA - 356) & 511)])) + (0.00147457514f * fVec21[((IOTA - 357) & 511)])) + (0.00303211063f * fVec21[((IOTA - 358) & 511)])) + (0.00376248779f * fVec21[((IOTA - 359) & 511)])) + (0.00330730714f * fVec21[((IOTA - 360) & 511)])) + (0.00234464789f * fVec21[((IOTA - 361) & 511)])) + (0.000764659606f * fVec21[((IOTA - 362) & 511)])) + (0.00072017638f * fVec21[((IOTA - 366) & 511)])) + (0.00222118804f * fVec21[((IOTA - 367) & 511)])) + (0.00206589f * fVec21[((IOTA - 368) & 511)])) + (0.00121968891f * fVec21[((IOTA - 369) & 511)])) + (0.000932843424f * fVec21[((IOTA - 374) & 511)])) + (0.00263022538f * fVec21[((IOTA - 375) & 511)])) + (0.00314549077f * fVec21[((IOTA - 376) & 511)])) + (0.00250902912f * fVec21[((IOTA - 377) & 511)])) + (0.00173754944f * fVec21[((IOTA - 378) & 511)])) + (0.000541490503f * fVec21[((IOTA - 379) & 511)])) + (0.000782313757f * fVec21[((IOTA - 382) & 511)])) + (0.00197767885f * fVec21[((IOTA - 383) & 511)])) + (0.0023368313f * fVec21[((IOTA - 384) & 511)])) + (0.00185174448f * fVec21[((IOTA - 385) & 511)])) + (0.00173516525f * fVec21[((IOTA - 386) & 511)])) + (0.00139300292f * fVec21[((IOTA - 387) & 511)])) + (0.000950527843f * fVec21[((IOTA - 388) & 511)])) + (0.00130838295f * fVec21[((IOTA - 389) & 511)])) + (0.00135343941f * fVec21[((IOTA - 390) & 511)])) + (0.00145275611f * fVec21[((IOTA - 391) & 511)])) + (0.00182364834f * fVec21[((IOTA - 392) & 511)])) + (0.000682121608f * fVec21[((IOTA - 393) & 511)])) + (0.000919897109f * fVec21[((IOTA - 399) & 511)])) + (0.00287672225f * fVec21[((IOTA - 400) & 511)])) + (0.00381822698f * fVec21[((IOTA - 401) & 511)])) + (0.00348849827f * fVec21[((IOTA - 402) & 511)])) + (0.00306250062f * fVec21[((IOTA - 403) & 511)])) + (0.00173724769f * fVec21[((IOTA - 404) & 511)])) + (0.000341287348f * fVec21[((IOTA - 405) & 511)])) + (4.86476347e-05f * fVec21[((IOTA - 412) & 511)])) + (0.000381364021f * fVec21[((IOTA - 414) & 511)])) + (5.57093881e-05f * fVec21[((IOTA - 415) & 511)])) + (0.00063253846f * fVec21[((IOTA - 421) & 511)])) + (0.00218316307f * fVec21[((IOTA - 422) & 511)])) + (0.00401840033f * fVec21[((IOTA - 423) & 511)])) + (0.00494001713f * fVec21[((IOTA - 424) & 511)])) + (0.00505016837f * fVec21[((IOTA - 425) & 511)])) + (0.00385546731f * fVec21[((IOTA - 426) & 511)])) + (0.00195872691f * fVec21[((IOTA - 427) & 511)])) + (0.00087490119f * fVec21[((IOTA - 428) & 511)])) + (2.19698995e-05f * fVec21[((IOTA - 447) & 511)])) + (0.00114306575f * fVec21[((IOTA - 448) & 511)])) + (0.00157694006f * fVec21[((IOTA - 449) & 511)])) + (0.00123827858f * fVec21[((IOTA - 450) & 511)])) + (0.000586395618f * fVec21[((IOTA - 451) & 511)])) + (9.83802602e-06f * fVec21[((IOTA - 460) & 511)])) + (0.00164852338f * fVec21[((IOTA - 469) & 511)])) + (0.00240898784f * fVec21[((IOTA - 470) & 511)])) + (0.00254255719f * fVec21[((IOTA - 471) & 511)])) + (0.00190009037f * fVec21[((IOTA - 472) & 511)])) + (0.000615336932f * fVec21[((IOTA - 473) & 511)])) + (6.00563362e-06f * fVec21[((IOTA - 491) & 511)])) + (0.000638212077f * fVec21[((IOTA - 492) & 511)])) + (0.00188406557f * fVec21[((IOTA - 493) & 511)])) + (0.00222873269f * fVec21[((IOTA - 494) & 511)])) + (0.00178088574f * fVec21[((IOTA - 495) & 511)])) + (0.000891468953f * fVec21[((IOTA - 496) & 511)])) - (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.131727472f * fVec21[((IOTA - 5) & 511)]) + ((0.160257101f * fVec21[((IOTA - 8) & 511)]) + ((0.0180587638f * fVec21[((IOTA - 9) & 511)]) + ((0.21274434f * fVec21[((IOTA - 6) & 511)]) + ((0.244547203f * fVec21[((IOTA - 7) & 511)]) + (0.0013864846f * fVec21[((IOTA - 14) & 511)])))))) + (0.00554913748f * fVec21[((IOTA - 19) & 511)])) + (0.0314940214f * fVec21[((IOTA - 20) & 511)])) + (0.029709544f * fVec21[((IOTA - 21) & 511)])) + (0.0107759703f * fVec21[((IOTA - 22) & 511)])) + (0.0139537212f * fVec21[((IOTA - 28) & 511)])) + (0.0424822643f * fVec21[((IOTA - 29) & 511)])) + (0.0613540933f * fVec21[((IOTA - 30) & 511)])) + (0.06849318f * fVec21[((IOTA - 31) & 511)])) + (0.0584236532f * fVec21[((IOTA - 32) & 511)])) + (0.0246722922f * fVec21[((IOTA - 33) & 511)])) + (0.0130889602f * fVec21[((IOTA - 39) & 511)])) + (0.0161909647f * fVec21[((IOTA - 40) & 511)])) + (0.0114445109f * fVec21[((IOTA - 41) & 511)])) + (0.0071592438f * fVec21[((IOTA - 42) & 511)])) + (0.0150122577f * fVec21[((IOTA - 43) & 511)])) + (0.0343186557f * fVec21[((IOTA - 44) & 511)])) + (0.0410336144f * fVec21[((IOTA - 45) & 511)])) + (0.034383297f * fVec21[((IOTA - 46) & 511)])) + (0.0234157257f * fVec21[((IOTA - 47) & 511)])) + (0.00276940828f * fVec21[((IOTA - 51) & 511)])) + (0.0149531383f * fVec21[((IOTA - 52) & 511)])) + (0.0351641923f * fVec21[((IOTA - 53) & 511)])) + (0.0427132212f * fVec21[((IOTA - 54) & 511)])) + (0.0211240109f * fVec21[((IOTA - 55) & 511)])) + (0.00599819142f * fVec21[((IOTA - 56) & 511)])) + (0.0014685397f * fVec21[((IOTA - 59) & 511)])) + (0.00445806887f * fVec21[((IOTA - 60) & 511)])) + (0.0101188663f * fVec21[((IOTA - 61) & 511)])) + (0.010046348f * fVec21[((IOTA - 62) & 511)])) + (0.0079149399f * fVec21[((IOTA - 65) & 511)])) + (0.0253729131f * fVec21[((IOTA - 66) & 511)])) + (0.0382211693f * fVec21[((IOTA - 67) & 511)])) + (0.0378787965f * fVec21[((IOTA - 68) & 511)])) + (0.0312210266f * fVec21[((IOTA - 69) & 511)])) + (0.0168445967f * fVec21[((IOTA - 70) & 511)])) + (0.00176984025f * fVec21[((IOTA - 71) & 511)])) + (0.00104809459f * fVec21[((IOTA - 76) & 511)])) + (0.00505261263f * fVec21[((IOTA - 77) & 511)])) + (0.00555300014f * fVec21[((IOTA - 78) & 511)])) + (0.00543189421f * fVec21[((IOTA - 81) & 511)])) + (0.00725895306f * fVec21[((IOTA - 82) & 511)])) + (0.0168037657f * fVec21[((IOTA - 83) & 511)])) + (0.0229917187f * fVec21[((IOTA - 84) & 511)])) + (0.0231037717f * fVec21[((IOTA - 85) & 511)])) + (0.0190080851f * fVec21[((IOTA - 86) & 511)])) + (0.0112356767f * fVec21[((IOTA - 87) & 511)])) + (0.00671067229f * fVec21[((IOTA - 88) & 511)])) + (0.00495658536f * fVec21[((IOTA - 89) & 511)])) + (0.00549149653f * fVec21[((IOTA - 90) & 511)])) + (0.00831830408f * fVec21[((IOTA - 91) & 511)])) + (0.0143180341f * fVec21[((IOTA - 92) & 511)])) + (0.01169632f * fVec21[((IOTA - 93) & 511)])) + (0.00255028298f * fVec21[((IOTA - 94) & 511)])) + (0.00810937956f * fVec21[((IOTA - 99) & 511)])) + (0.0171839222f * fVec21[((IOTA - 100) & 511)])) + (0.0186342653f * fVec21[((IOTA - 101) & 511)])) + (0.0170358382f * fVec21[((IOTA - 102) & 511)])) + (0.0121758534f * fVec21[((IOTA - 103) & 511)])) + (0.00647579413f * fVec21[((IOTA - 104) & 511)])) + (0.00452738861f * fVec21[((IOTA - 105) & 511)])) + (0.00459658727f * fVec21[((IOTA - 106) & 511)])) + (0.00679499097f * fVec21[((IOTA - 107) & 511)])) + (0.00855834223f * fVec21[((IOTA - 108) & 511)])) + (0.00758439628f * fVec21[((IOTA - 109) & 511)])) + (0.00639011804f * fVec21[((IOTA - 110) & 511)])) + (0.00442499341f * fVec21[((IOTA - 111) & 511)])) + (0.00317606144f * fVec21[((IOTA - 112) & 511)])) + (0.00369866053f * fVec21[((IOTA - 113) & 511)])) + (0.00686400849f * fVec21[((IOTA - 114) & 511)])) + (0.0101603614f * fVec21[((IOTA - 115) & 511)])) + (0.01193491f * fVec21[((IOTA - 116) & 511)])) + (0.0124495411f * fVec21[((IOTA - 117) & 511)])) + (0.0112050753f * fVec21[((IOTA - 118) & 511)])) + (0.0100151729f * fVec21[((IOTA - 119) & 511)])) + (0.011207249f * fVec21[((IOTA - 120) & 511)])) + (0.0118510742f * fVec21[((IOTA - 121) & 511)])) + (0.0128852557f * fVec21[((IOTA - 122) & 511)])) + (0.0144797601f * fVec21[((IOTA - 123) & 511)])) + (0.0141403442f * fVec21[((IOTA - 124) & 511)])) + (0.00990900584f * fVec21[((IOTA - 125) & 511)])) + (0.00529817399f * fVec21[((IOTA - 126) & 511)])) + (0.00124443509f * fVec21[((IOTA - 127) & 511)])) + (0.00393293519f * fVec21[((IOTA - 133) & 511)])) + (0.00593044097f * fVec21[((IOTA - 134) & 511)])) + (0.0063533606f * fVec21[((IOTA - 135) & 511)])) + (0.00527840713f * fVec21[((IOTA - 136) & 511)])) + (0.00475722691f * fVec21[((IOTA - 137) & 511)])) + (0.00347377127f * fVec21[((IOTA - 138) & 511)])) + (0.00147976587f * fVec21[((IOTA - 139) & 511)])) + (0.000672494527f * fVec21[((IOTA - 140) & 511)])) + (0.000258839689f * fVec21[((IOTA - 143) & 511)])) + (0.00430376688f * fVec21[((IOTA - 144) & 511)])) + (0.0071318415f * fVec21[((IOTA - 145) & 511)])) + (0.0079742102f * fVec21[((IOTA - 146) & 511)])) + (0.00580109656f * fVec21[((IOTA - 147) & 511)])) + (0.00119959004f * fVec21[((IOTA - 148) & 511)])) + (0.00211556349f * fVec21[((IOTA - 154) & 511)])) + (0.00601705303f * fVec21[((IOTA - 155) & 511)])) + (0.00849001855f * fVec21[((IOTA - 156) & 511)])) + (0.0104831792f * fVec21[((IOTA - 157) & 511)])) + (0.0114631318f * fVec21[((IOTA - 158) & 511)])) + (0.0104042627f * fVec21[((IOTA - 159) & 511)])) + (0.007653384f * fVec21[((IOTA - 160) & 511)])) + (0.00312445685f * fVec21[((IOTA - 161) & 511)])) + (0.00264712563f * fVec21[((IOTA - 167) & 511)])) + (0.00505913142f * fVec21[((IOTA - 168) & 511)])) + (0.00626858976f * fVec21[((IOTA - 169) & 511)])) + (0.00646643899f * fVec21[((IOTA - 170) & 511)])) + (0.00595926121f * fVec21[((IOTA - 171) & 511)])) + (0.00368151907f * fVec21[((IOTA - 172) & 511)])) + (0.000656167977f * fVec21[((IOTA - 173) & 511)])) + (0.00105256122f * fVec21[((IOTA - 177) & 511)])) + (0.00255764648f * fVec21[((IOTA - 178) & 511)])) + (0.00400475971f * fVec21[((IOTA - 179) & 511)])) + (0.00403635623f * fVec21[((IOTA - 180) & 511)])) + (0.00359904161f * fVec21[((IOTA - 181) & 511)])) + (0.00251542684f * fVec21[((IOTA - 182) & 511)])) + (0.00179663859f * fVec21[((IOTA - 190) & 511)])) + (0.00315391086f * fVec21[((IOTA - 191) & 511)])) + (0.00150912954f * fVec21[((IOTA - 192) & 511)])) + (0.000632960815f * fVec21[((IOTA - 198) & 511)])) + (0.00148513773f * fVec21[((IOTA - 199) & 511)])) + (0.00184501475f * fVec21[((IOTA - 200) & 511)])) + (0.0023709028f * fVec21[((IOTA - 201) & 511)])) + (0.0033432194f * fVec21[((IOTA - 202) & 511)])) + (0.00463765999f * fVec21[((IOTA - 203) & 511)])) + (0.00550987525f * fVec21[((IOTA - 204) & 511)])) + (0.00359889073f * fVec21[((IOTA - 205) & 511)])) + (0.00234350096f * fVec21[((IOTA - 212) & 511)])) + (0.00501995953f * fVec21[((IOTA - 213) & 511)])) + (0.0059750448f * fVec21[((IOTA - 214) & 511)])) + (0.00420698477f * fVec21[((IOTA - 215) & 511)])) + (0.00143172219f * fVec21[((IOTA - 216) & 511)])) + (0.000566991046f * fVec21[((IOTA - 225) & 511)])) + (0.000327706803f * fVec21[((IOTA - 237) & 511)])) + (0.00157654798f * fVec21[((IOTA - 245) & 511)])) + (0.00194490515f * fVec21[((IOTA - 246) & 511)])) + (0.00082160579f * fVec21[((IOTA - 247) & 511)])) + (0.000958887395f * fVec21[((IOTA - 317) & 511)])) + (0.00160847651f * fVec21[((IOTA - 318) & 511)])) + (0.000495860819f * fVec21[((IOTA - 319) & 511)])) + (8.64309259e-05f * fVec21[((IOTA - 325) & 511)])) + (0.0012806491f * fVec21[((IOTA - 326) & 511)])) + (0.000758140814f * fVec21[((IOTA - 327) & 511)])) + (0.00011875201f * fVec21[((IOTA - 328) & 511)])) + (0.00104051968f * fVec21[((IOTA - 354) & 511)])) + (0.000773743261f * fVec21[((IOTA - 355) & 511)])) + (0.000517166685f * fVec21[((IOTA - 363) & 511)])) + (0.000649408437f * fVec21[((IOTA - 364) & 511)])) + (0.000367511995f * fVec21[((IOTA - 365) & 511)])) + (3.09930183e-05f * fVec21[((IOTA - 370) & 511)])) + (0.00196880614f * fVec21[((IOTA - 371) & 511)])) + (0.00211695209f * fVec21[((IOTA - 372) & 511)])) + (0.000645665918f * fVec21[((IOTA - 373) & 511)])) + (0.000102183782f * fVec21[((IOTA - 380) & 511)])) + (1.44555233e-05f * fVec21[((IOTA - 381) & 511)])) + (0.00132320076f * fVec21[((IOTA - 394) & 511)])) + (0.00290246448f * fVec21[((IOTA - 395) & 511)])) + (0.00374911865f * fVec21[((IOTA - 396) & 511)])) + (0.00274903793f * fVec21[((IOTA - 397) & 511)])) + (0.000789858401f * fVec21[((IOTA - 398) & 511)])) + (0.000273808371f * fVec21[((IOTA - 406) & 511)])) + (0.000951915979f * fVec21[((IOTA - 407) & 511)])) + (0.000959008001f * fVec21[((IOTA - 408) & 511)])) + (0.000793208368f * fVec21[((IOTA - 409) & 511)])) + (0.000889597926f * fVec21[((IOTA - 410) & 511)])) + (0.000363588799f * fVec21[((IOTA - 411) & 511)])) + (0.000112957787f * fVec21[((IOTA - 413) & 511)])) + (0.000986983534f * fVec21[((IOTA - 416) & 511)])) + (0.00125053106f * fVec21[((IOTA - 417) & 511)])) + (0.00212289719f * fVec21[((IOTA - 418) & 511)])) + (0.00225803582f * fVec21[((IOTA - 419) & 511)])) + (0.000673792325f * fVec21[((IOTA - 420) & 511)])) + (0.000512066297f * fVec21[((IOTA - 429) & 511)])) + (0.00270072231f * fVec21[((IOTA - 430) & 511)])) + (0.00392599404f * fVec21[((IOTA - 431) & 511)])) + (0.00441105105f * fVec21[((IOTA - 432) & 511)])) + (0.00446784636f * fVec21[((IOTA - 433) & 511)])) + (0.00316374889f * fVec21[((IOTA - 434) & 511)])) + (0.00204386003f * fVec21[((IOTA - 435) & 511)])) + (0.00158674829f * fVec21[((IOTA - 436) & 511)])) + (0.00119575718f * fVec21[((IOTA - 437) & 511)])) + (0.00220489176f * fVec21[((IOTA - 438) & 511)])) + (0.00408690516f * fVec21[((IOTA - 439) & 511)])) + (0.0054296311f * fVec21[((IOTA - 440) & 511)])) + (0.00594115444f * fVec21[((IOTA - 441) & 511)])) + (0.00487763854f * fVec21[((IOTA - 442) & 511)])) + (0.00304934289f * fVec21[((IOTA - 443) & 511)])) + (0.0021196981f * fVec21[((IOTA - 444) & 511)])) + (0.00103777368f * fVec21[((IOTA - 445) & 511)])) + (0.000289621763f * fVec21[((IOTA - 446) & 511)])) + (0.00145677011f * fVec21[((IOTA - 452) & 511)])) + (0.00324806711f * fVec21[((IOTA - 453) & 511)])) + (0.00427832641f * fVec21[((IOTA - 454) & 511)])) + (0.00508647272f * fVec21[((IOTA - 455) & 511)])) + (0.00455937767f * fVec21[((IOTA - 456) & 511)])) + (0.00314464606f * fVec21[((IOTA - 457) & 511)])) + (0.00190446619f * fVec21[((IOTA - 458) & 511)])) + (0.000580752268f * fVec21[((IOTA - 459) & 511)])) + (0.000671498943f * fVec21[((IOTA - 461) & 511)])) + (0.00157594448f * fVec21[((IOTA - 462) & 511)])) + (0.00288517261f * fVec21[((IOTA - 463) & 511)])) + (0.00432184339f * fVec21[((IOTA - 464) & 511)])) + (0.00453007454f * fVec21[((IOTA - 465) & 511)])) + (0.0038620159f * fVec21[((IOTA - 466) & 511)])) + (0.00255459873f * fVec21[((IOTA - 467) & 511)])) + (0.000329457223f * fVec21[((IOTA - 468) & 511)])) + (0.000933145173f * fVec21[((IOTA - 474) & 511)])) + (0.00294208899f * fVec21[((IOTA - 475) & 511)])) + (0.00355917588f * fVec21[((IOTA - 476) & 511)])) + (0.00318520563f * fVec21[((IOTA - 477) & 511)])) + (0.00296825357f * fVec21[((IOTA - 478) & 511)])) + (0.00216584094f * fVec21[((IOTA - 479) & 511)])) + (0.00176187325f * fVec21[((IOTA - 480) & 511)])) + (0.00185977202f * fVec21[((IOTA - 481) & 511)])) + (0.00157612562f * fVec21[((IOTA - 482) & 511)])) + (0.00168781541f * fVec21[((IOTA - 483) & 511)])) + (0.00191584323f * fVec21[((IOTA - 484) & 511)])) + (0.00205532787f * fVec21[((IOTA - 485) & 511)])) + (0.00253615947f * fVec21[((IOTA - 486) & 511)])) + (0.00215491652f * fVec21[((IOTA - 487) & 511)])) + (0.00163213629f * fVec21[((IOTA - 488) & 511)])) + (0.0015431405f * fVec21[((IOTA - 489) & 511)])) + (0.000699775759f * fVec21[((IOTA - 490) & 511)])) + (0.00117004523f * fVec21[((IOTA - 497) & 511)])) + (0.00300760614f * fVec21[((IOTA - 498) & 511)])) + (0.004086392f * fVec21[((IOTA - 499) & 511)])) + (0.00494967448f * fVec21[((IOTA - 500) & 511)])) + (0.0045465217f * fVec21[((IOTA - 501) & 511)])) + (0.00339482445f * fVec21[((IOTA - 502) & 511)])) + (0.00305169681f * fVec21[((IOTA - 503) & 511)])) + (0.00266728457f * fVec21[((IOTA - 504) & 511)])) + (0.00293243164f * fVec21[((IOTA - 505) & 511)])) + (0.0041264086f * fVec21[((IOTA - 506) & 511)])) + (0.00485099107f * fVec21[((IOTA - 507) & 511)])) + (0.00526926341f * fVec21[((IOTA - 508) & 511)])) + (0.00537953479f * fVec21[((IOTA - 509) & 511)])) + (0.00431197509f * fVec21[((IOTA - 510) & 511)])) + (0.00349221006f * fVec21[((IOTA - 511) & 511)]))) : (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00534325838f * fVec20[((IOTA - 212) & 511)]) + ((0.00597864483f * fVec20[((IOTA - 211) & 511)]) + ((0.0067919041f * fVec20[((IOTA - 210) & 511)]) + ((0.00707894051f * fVec20[((IOTA - 209) & 511)]) + ((0.00602981495f * fVec20[((IOTA - 208) & 511)]) + ((0.00431451062f * fVec20[((IOTA - 207) & 511)]) + ((0.00134983752f * fVec20[((IOTA - 206) & 511)]) + ((0.000427052379f * fVec20[((IOTA - 200) & 511)]) + ((0.0020238352f * fVec20[((IOTA - 199) & 511)]) + ((0.00244623888f * fVec20[((IOTA - 198) & 511)]) + ((0.00127572333f * fVec20[((IOTA - 197) & 511)]) + ((0.00182990171f * fVec20[((IOTA - 191) & 511)]) + ((0.00410768623f * fVec20[((IOTA - 190) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((0.0177719183f * fVec20[((IOTA - 17) & 511)]) + ((0.0123650208f * fVec20[((IOTA - 16) & 511)]) + ((0.0188159104f * fVec20[((IOTA - 15) & 511)]) + ((0.0187869594f * fVec20[((IOTA - 14) & 511)]) + ((0.060170874f * fVec20[((IOTA - 13) & 511)]) + ((0.104806647f * fVec20[((IOTA - 12) & 511)]) + ((0.0991005152f * fVec20[((IOTA - 11) & 511)]) + ((0.0392112173f * fVec20[((IOTA - 10) & 511)]) + ((0.121634103f * fVec20[((IOTA - 4) & 511)]) + ((0.24463281f * fVec20[((IOTA - 3) & 511)]) + ((0.227472067f * fVec20[((IOTA - 2) & 511)]) + ((0.227598399f * fVec20[((IOTA - 1) & 511)]) + ((fSlow67 * fTemp0) + ((0.0287851691f * fVec20[((IOTA - 23) & 511)]) + ((0.0499430448f * fVec20[((IOTA - 24) & 511)]) + ((0.0171706155f * fVec20[((IOTA - 18) & 511)]) + (0.0553259142f * fVec20[((IOTA - 25) & 511)]))))))))))))))))) + (0.0475571565f * fVec20[((IOTA - 26) & 511)])) + (0.0325178504f * fVec20[((IOTA - 27) & 511)])) + (0.00364778796f * fVec20[((IOTA - 28) & 511)])) + (0.014908649f * fVec20[((IOTA - 35) & 511)])) + (0.0375797749f * fVec20[((IOTA - 36) & 511)])) + (0.0471522324f * fVec20[((IOTA - 37) & 511)])) + (0.0296405423f * fVec20[((IOTA - 38) & 511)])) + (0.000458207447f * fVec20[((IOTA - 39) & 511)])) + (0.00631211139f * fVec20[((IOTA - 49) & 511)])) + (0.0184871536f * fVec20[((IOTA - 50) & 511)])) + (0.0216613375f * fVec20[((IOTA - 51) & 511)])) + (0.019576218f * fVec20[((IOTA - 52) & 511)])) + (0.00793370977f * fVec20[((IOTA - 63) & 511)])) + (0.00115686981f * fVec20[((IOTA - 74) & 511)])) + (0.000570299104f * fVec20[((IOTA - 78) & 511)])) + (0.0037244074f * fVec20[((IOTA - 79) & 511)])) + (0.00250175595f * fVec20[((IOTA - 80) & 511)])) + (0.00016679382f * fVec20[((IOTA - 81) & 511)])) + (0.000335036777f * fVec20[((IOTA - 99) & 511)])) + (0.000971177593f * fVec20[((IOTA - 100) & 511)])) + (0.000169692095f * fVec20[((IOTA - 101) & 511)])) + (0.00154579384f * fVec20[((IOTA - 126) & 511)])) + (0.00896297023f * fVec20[((IOTA - 127) & 511)])) + (0.0139829963f * fVec20[((IOTA - 128) & 511)])) + (0.0157418624f * fVec20[((IOTA - 129) & 511)])) + (0.0126401326f * fVec20[((IOTA - 130) & 511)])) + (0.00455113128f * fVec20[((IOTA - 131) & 511)])) + (0.00187554723f * fVec20[((IOTA - 138) & 511)])) + (0.00510546006f * fVec20[((IOTA - 139) & 511)])) + (0.00583687751f * fVec20[((IOTA - 140) & 511)])) + (0.00567808375f * fVec20[((IOTA - 141) & 511)])) + (0.00292784255f * fVec20[((IOTA - 142) & 511)])) + (0.00676775305f * fVec20[((IOTA - 151) & 511)])) + (0.00886286423f * fVec20[((IOTA - 152) & 511)])) + (0.00854144245f * fVec20[((IOTA - 153) & 511)])) + (0.00567449117f * fVec20[((IOTA - 154) & 511)])) + (0.000420803204f * fVec20[((IOTA - 162) & 511)])) + (0.00678251544f * fVec20[((IOTA - 163) & 511)])) + (0.0097240936f * fVec20[((IOTA - 164) & 511)])) + (0.00716159772f * fVec20[((IOTA - 165) & 511)])) + (0.00220110454f * fVec20[((IOTA - 166) & 511)])) + (0.00121993432f * fVec20[((IOTA - 177) & 511)])) + (0.0022619958f * fVec20[((IOTA - 178) & 511)])) + (0.0010579708f * fVec20[((IOTA - 179) & 511)])) + (0.00332570262f * fVec20[((IOTA - 185) & 511)])) + (0.00656280015f * fVec20[((IOTA - 186) & 511)])) + (0.00771221332f * fVec20[((IOTA - 187) & 511)])) + (0.00769986631f * fVec20[((IOTA - 188) & 511)])) + (0.00678082462f * fVec20[((IOTA - 189) & 511)])) + (0.00272781076f * fVec20[((IOTA - 213) & 511)]))))))))))))))) + (0.000912278891f * fVec20[((IOTA - 219) & 511)])) + (0.00638154615f * fVec20[((IOTA - 220) & 511)])) + (0.00975265261f * fVec20[((IOTA - 221) & 511)])) + (0.00977520365f * fVec20[((IOTA - 222) & 511)])) + (0.00767157925f * fVec20[((IOTA - 223) & 511)])) + (0.00522105349f * fVec20[((IOTA - 224) & 511)])) + (0.00337475957f * fVec20[((IOTA - 225) & 511)])) + (0.00293855974f * fVec20[((IOTA - 226) & 511)])) + (0.00407345174f * fVec20[((IOTA - 227) & 511)])) + (0.00553740328f * fVec20[((IOTA - 228) & 511)])) + (0.00582283968f * fVec20[((IOTA - 229) & 511)])) + (0.00433826912f * fVec20[((IOTA - 230) & 511)])) + (0.0028753439f * fVec20[((IOTA - 231) & 511)])) + (0.002317362f * fVec20[((IOTA - 232) & 511)])) + (0.00195883866f * fVec20[((IOTA - 233) & 511)])) + (0.00284307217f * fVec20[((IOTA - 234) & 511)])) + (0.00471701939f * fVec20[((IOTA - 235) & 511)])) + (0.00635017967f * fVec20[((IOTA - 236) & 511)])) + (0.00772311166f * fVec20[((IOTA - 237) & 511)])) + (0.00811309181f * fVec20[((IOTA - 238) & 511)])) + (0.00693629775f * fVec20[((IOTA - 239) & 511)])) + (0.00546561414f * fVec20[((IOTA - 240) & 511)])) + (0.00417108275f * fVec20[((IOTA - 241) & 511)])) + (0.00342417881f * fVec20[((IOTA - 242) & 511)])) + (0.0026846407f * fVec20[((IOTA - 243) & 511)])) + (0.00161380926f * fVec20[((IOTA - 244) & 511)])) + (0.00136342226f * fVec20[((IOTA - 245) & 511)])) + (0.00191865722f * fVec20[((IOTA - 246) & 511)])) + (0.00248949928f * fVec20[((IOTA - 247) & 511)])) + (0.00341675244f * fVec20[((IOTA - 248) & 511)])) + (0.00352826994f * fVec20[((IOTA - 249) & 511)])) + (0.00439568842f * fVec20[((IOTA - 250) & 511)])) + (0.00684733083f * fVec20[((IOTA - 251) & 511)])) + (0.00785310566f * fVec20[((IOTA - 252) & 511)])) + (0.00831146352f * fVec20[((IOTA - 253) & 511)])) + (0.00863360986f * fVec20[((IOTA - 254) & 511)])) + (0.00846775156f * fVec20[((IOTA - 255) & 511)])) + (0.00826965179f * fVec20[((IOTA - 256) & 511)])) + (0.00740425615f * fVec20[((IOTA - 257) & 511)])) + (0.00572074065f * fVec20[((IOTA - 258) & 511)])) + (0.00529380888f * fVec20[((IOTA - 259) & 511)])) + (0.00524426904f * fVec20[((IOTA - 260) & 511)])) + (0.00488284696f * fVec20[((IOTA - 261) & 511)])) + (0.00529190712f * fVec20[((IOTA - 262) & 511)])) + (0.00557227153f * fVec20[((IOTA - 263) & 511)])) + (0.00623555249f * fVec20[((IOTA - 264) & 511)])) + (0.00883439556f * fVec20[((IOTA - 265) & 511)])) + (0.0111137806f * fVec20[((IOTA - 266) & 511)])) + (0.0128325569f * fVec20[((IOTA - 267) & 511)])) + (0.0140963551f * fVec20[((IOTA - 268) & 511)])) + (0.0132648628f * fVec20[((IOTA - 269) & 511)])) + (0.0108452197f * fVec20[((IOTA - 270) & 511)])) + (0.00873755012f * fVec20[((IOTA - 271) & 511)])) + (0.00740893558f * fVec20[((IOTA - 272) & 511)])) + (0.00702354359f * fVec20[((IOTA - 273) & 511)])) + (0.00686151953f * fVec20[((IOTA - 274) & 511)])) + (0.00650477735f * fVec20[((IOTA - 275) & 511)])) + (0.00768459076f * fVec20[((IOTA - 276) & 511)])) + (0.00875213183f * fVec20[((IOTA - 277) & 511)])) + (0.00783804059f * fVec20[((IOTA - 278) & 511)])) + (0.00668443134f * fVec20[((IOTA - 279) & 511)])) + (0.00612952886f * fVec20[((IOTA - 280) & 511)])) + (0.00540544745f * fVec20[((IOTA - 281) & 511)])) + (0.00509386789f * fVec20[((IOTA - 282) & 511)])) + (0.00505878823f * fVec20[((IOTA - 283) & 511)])) + (0.00549785607f * fVec20[((IOTA - 284) & 511)])) + (0.00691733928f * fVec20[((IOTA - 285) & 511)])) + (0.00777346687f * fVec20[((IOTA - 286) & 511)])) + (0.00728627807f * fVec20[((IOTA - 287) & 511)])) + (0.00618622359f * fVec20[((IOTA - 288) & 511)])) + (0.0047978349f * fVec20[((IOTA - 289) & 511)])) + (0.0042736046f * fVec20[((IOTA - 290) & 511)])) + (0.00477172155f * fVec20[((IOTA - 291) & 511)])) + (0.00531491078f * fVec20[((IOTA - 292) & 511)])) + (0.00478415936f * fVec20[((IOTA - 293) & 511)])) + (0.00420607161f * fVec20[((IOTA - 294) & 511)])) + (0.00441132626f * fVec20[((IOTA - 295) & 511)])) + (0.0055255089f * fVec20[((IOTA - 296) & 511)])) + (0.00808933377f * fVec20[((IOTA - 297) & 511)])) + (0.0116308257f * fVec20[((IOTA - 298) & 511)])) + (0.0149317142f * fVec20[((IOTA - 299) & 511)])) + (0.0167070031f * fVec20[((IOTA - 300) & 511)])) + (0.0154460119f * fVec20[((IOTA - 301) & 511)])) + (0.0119915847f * fVec20[((IOTA - 302) & 511)])) + (0.00825473852f * fVec20[((IOTA - 303) & 511)])) + (0.00498379907f * fVec20[((IOTA - 304) & 511)])) + (0.00247126538f * fVec20[((IOTA - 305) & 511)])) + (0.000661227852f * fVec20[((IOTA - 306) & 511)])) + (0.000575008336f * fVec20[((IOTA - 307) & 511)])) + (0.00165788503f * fVec20[((IOTA - 308) & 511)])) + (0.00340950675f * fVec20[((IOTA - 309) & 511)])) + (0.00610903045f * fVec20[((IOTA - 310) & 511)])) + (0.00922042131f * fVec20[((IOTA - 311) & 511)])) + (0.0117918849f * fVec20[((IOTA - 312) & 511)])) + (0.0129019916f * fVec20[((IOTA - 313) & 511)])) + (0.0111608151f * fVec20[((IOTA - 314) & 511)])) + (0.00732525205f * fVec20[((IOTA - 315) & 511)])) + (0.00294185011f * fVec20[((IOTA - 316) & 511)])) + (0.00087378826f * fVec20[((IOTA - 321) & 511)])) + (0.00311573828f * fVec20[((IOTA - 322) & 511)])) + (0.00340078212f * fVec20[((IOTA - 323) & 511)])) + (0.00311567821f * fVec20[((IOTA - 324) & 511)])) + (0.00245248759f * fVec20[((IOTA - 325) & 511)])) + (0.00104640843f * fVec20[((IOTA - 326) & 511)])) + (0.000183005352f * fVec20[((IOTA - 327) & 511)])) + (1.94716267e-05f * fVec20[((IOTA - 330) & 511)])) + (0.00089618843f * fVec20[((IOTA - 331) & 511)])) + (0.00252451841f * fVec20[((IOTA - 332) & 511)])) + (0.0042971517f * fVec20[((IOTA - 333) & 511)])) + (0.00488692243f * fVec20[((IOTA - 334) & 511)])) + (0.00531892618f * fVec20[((IOTA - 335) & 511)])) + (0.0054593347f * fVec20[((IOTA - 336) & 511)])) + (0.00555029418f * fVec20[((IOTA - 337) & 511)])) + (0.00658643851f * fVec20[((IOTA - 338) & 511)])) + (0.0066165668f * fVec20[((IOTA - 339) & 511)])) + (0.00606957357f * fVec20[((IOTA - 340) & 511)])) + (0.00566860428f * fVec20[((IOTA - 341) & 511)])) + (0.00446651177f * fVec20[((IOTA - 342) & 511)])) + (0.0034090844f * fVec20[((IOTA - 343) & 511)])) + (0.00351305492f * fVec20[((IOTA - 344) & 511)])) + (0.00384386489f * fVec20[((IOTA - 345) & 511)])) + (0.00496571558f * fVec20[((IOTA - 346) & 511)])) + (0.00732449722f * fVec20[((IOTA - 347) & 511)])) + (0.00899506174f * fVec20[((IOTA - 348) & 511)])) + (0.00870524812f * fVec20[((IOTA - 349) & 511)])) + (0.00718608079f * fVec20[((IOTA - 350) & 511)])) + (0.0046056523f * fVec20[((IOTA - 351) & 511)])) + (0.00171762891f * fVec20[((IOTA - 352) & 511)])) + (0.00162020931f * fVec20[((IOTA - 356) & 511)])) + (0.00448637595f * fVec20[((IOTA - 357) & 511)])) + (0.00665825792f * fVec20[((IOTA - 358) & 511)])) + (0.00740890531f * fVec20[((IOTA - 359) & 511)])) + (0.00653726049f * fVec20[((IOTA - 360) & 511)])) + (0.00441138679f * fVec20[((IOTA - 361) & 511)])) + (0.00164605118f * fVec20[((IOTA - 362) & 511)])) + (0.000327761285f * fVec20[((IOTA - 369) & 511)])) + (0.000681665726f * fVec20[((IOTA - 370) & 511)])) + (5.14723361e-05f * fVec20[((IOTA - 371) & 511)])) + (0.000321753323f * fVec20[((IOTA - 372) & 511)])) + (0.0012872559f * fVec20[((IOTA - 373) & 511)])) + (0.00221061427f * fVec20[((IOTA - 374) & 511)])) + (0.00325626787f * fVec20[((IOTA - 375) & 511)])) + (0.00334067596f * fVec20[((IOTA - 376) & 511)])) + (0.00284476252f * fVec20[((IOTA - 377) & 511)])) + (0.00216524024f * fVec20[((IOTA - 378) & 511)])) + (0.00106624281f * fVec20[((IOTA - 379) & 511)])) + (0.000246039592f * fVec20[((IOTA - 382) & 511)])) + (0.00214534579f * fVec20[((IOTA - 383) & 511)])) + (0.00302822096f * fVec20[((IOTA - 384) & 511)])) + (0.0026440667f * fVec20[((IOTA - 385) & 511)])) + (0.00236548344f * fVec20[((IOTA - 386) & 511)])) + (0.00206815265f * fVec20[((IOTA - 387) & 511)])) + (0.00233885646f * fVec20[((IOTA - 388) & 511)])) + (0.00310625928f * fVec20[((IOTA - 389) & 511)])) + (0.00393681694f * fVec20[((IOTA - 390) & 511)])) + (0.0046427846f * fVec20[((IOTA - 391) & 511)])) + (0.0044751456f * fVec20[((IOTA - 392) & 511)])) + (0.00286272494f * fVec20[((IOTA - 393) & 511)])) + (0.000594631303f * fVec20[((IOTA - 394) & 511)])) + (0.000940837897f * fVec20[((IOTA - 400) & 511)])) + (0.0033766008f * fVec20[((IOTA - 401) & 511)])) + (0.00472939666f * fVec20[((IOTA - 402) & 511)])) + (0.00513954367f * fVec20[((IOTA - 403) & 511)])) + (0.00358360633f * fVec20[((IOTA - 404) & 511)])) + (0.00107065029f * fVec20[((IOTA - 405) & 511)])) + (0.000257873908f * fVec20[((IOTA - 414) & 511)])) + (0.00177670876f * fVec20[((IOTA - 415) & 511)])) + (0.002670452f * fVec20[((IOTA - 416) & 511)])) + (0.00358381774f * fVec20[((IOTA - 417) & 511)])) + (0.00294529181f * fVec20[((IOTA - 418) & 511)])) + (0.00123735331f * fVec20[((IOTA - 419) & 511)])) + (0.000170899555f * fVec20[((IOTA - 423) & 511)])) + (0.00304766232f * fVec20[((IOTA - 424) & 511)])) + (0.00554546388f * fVec20[((IOTA - 425) & 511)])) + (0.00687314244f * fVec20[((IOTA - 426) & 511)])) + (0.00641291216f * fVec20[((IOTA - 427) & 511)])) + (0.00410590507f * fVec20[((IOTA - 428) & 511)])) + (0.000443294179f * fVec20[((IOTA - 429) & 511)])) + (0.000151155982f * fVec20[((IOTA - 449) & 511)])) + (0.000902890228f * fVec20[((IOTA - 469) & 511)])) + (0.00157148438f * fVec20[((IOTA - 470) & 511)])) + (0.0019419631f * fVec20[((IOTA - 471) & 511)])) + (0.00179071631f * fVec20[((IOTA - 472) & 511)])) + (0.00144357374f * fVec20[((IOTA - 473) & 511)])) + (0.000846014358f * fVec20[((IOTA - 474) & 511)])) + (0.0011728094f * fVec20[((IOTA - 492) & 511)])) + (0.00238700816f * fVec20[((IOTA - 493) & 511)])) + (0.0032724794f * fVec20[((IOTA - 494) & 511)])) + (0.00287525356f * fVec20[((IOTA - 495) & 511)])) + (0.00112025067f * fVec20[((IOTA - 496) & 511)])) - ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0149785969f * fVec20[((IOTA - 157) & 511)]) + ((0.00740848249f * fVec20[((IOTA - 156) & 511)]) + ((0.000392244663f * fVec20[((IOTA - 155) & 511)]) + ((0.000203926116f * fVec20[((IOTA - 150) & 511)]) + ((0.00765711861f * fVec20[((IOTA - 149) & 511)]) + ((0.0120792519f * fVec20[((IOTA - 148) & 511)]) + ((0.014049774f * fVec20[((IOTA - 147) & 511)]) + ((0.0142942145f * fVec20[((IOTA - 146) & 511)]) + ((0.0104281604f * fVec20[((IOTA - 145) & 511)]) + ((0.00486914115f * fVec20[((IOTA - 144) & 511)]) + ((0.00121649308f * fVec20[((IOTA - 143) & 511)]) + ((0.00291576702f * fVec20[((IOTA - 137) & 511)]) + ((0.00798551366f * fVec20[((IOTA - 136) & 511)]) + ((0.0131948842f * fVec20[((IOTA - 135) & 511)]) + ((0.0143101532f * fVec20[((IOTA - 134) & 511)]) + ((0.0109884962f * fVec20[((IOTA - 133) & 511)]) + ((0.00486352621f * fVec20[((IOTA - 132) & 511)]) + ((0.0096300561f * fVec20[((IOTA - 125) & 511)]) + ((0.0216025598f * fVec20[((IOTA - 124) & 511)]) + ((0.0297726188f * fVec20[((IOTA - 123) & 511)]) + ((0.0330552422f * fVec20[((IOTA - 122) & 511)]) + ((0.0309071485f * fVec20[((IOTA - 121) & 511)]) + ((0.0240218099f * fVec20[((IOTA - 120) & 511)]) + ((0.0148015693f * fVec20[((IOTA - 119) & 511)]) + ((0.00748772873f * fVec20[((IOTA - 118) & 511)]) + ((0.0045942408f * fVec20[((IOTA - 117) & 511)]) + ((0.00502443314f * fVec20[((IOTA - 116) & 511)]) + ((0.00780465174f * fVec20[((IOTA - 115) & 511)]) + ((0.0123286135f * fVec20[((IOTA - 114) & 511)]) + ((0.0140619408f * fVec20[((IOTA - 113) & 511)]) + ((0.0127111673f * fVec20[((IOTA - 112) & 511)]) + ((0.0112531027f * fVec20[((IOTA - 111) & 511)]) + ((0.00753092906f * fVec20[((IOTA - 110) & 511)]) + ((0.00338025391f * fVec20[((IOTA - 109) & 511)]) + ((0.00642966712f * fVec20[((IOTA - 108) & 511)]) + ((0.0127559677f * fVec20[((IOTA - 107) & 511)]) + ((0.0181671809f * fVec20[((IOTA - 106) & 511)]) + ((0.0229541473f * fVec20[((IOTA - 105) & 511)]) + ((0.0202234685f * fVec20[((IOTA - 104) & 511)]) + ((((0.0047585289f * fVec20[((IOTA - 98) & 511)]) + ((0.0100293644f * fVec20[((IOTA - 97) & 511)]) + ((0.00976780802f * fVec20[((IOTA - 96) & 511)]) + ((0.00994308479f * fVec20[((IOTA - 95) & 511)]) + ((0.00581028126f * fVec20[((IOTA - 94) & 511)]) + ((0.00378801581f * fVec20[((IOTA - 93) & 511)]) + ((0.00681916485f * fVec20[((IOTA - 92) & 511)]) + ((0.00982000399f * fVec20[((IOTA - 91) & 511)]) + ((0.0154280197f * fVec20[((IOTA - 90) & 511)]) + ((0.0225743409f * fVec20[((IOTA - 89) & 511)]) + ((0.0257327668f * fVec20[((IOTA - 88) & 511)]) + ((0.022880638f * fVec20[((IOTA - 87) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((0.0642051995f * fVec20[((IOTA - 9) & 511)]) + ((0.172513887f * fVec20[((IOTA - 8) & 511)]) + ((0.22009474f * fVec20[((IOTA - 7) & 511)]) + ((0.148747072f * fVec20[((IOTA - 6) & 511)]) + ((0.0536835454f * fVec20[((IOTA - 5) & 511)]) + ((0.0134006515f * fVec20[((IOTA - 21) & 511)]) + (((0.00165347755f * fVec20[((IOTA - 19) & 511)]) + (0.00344211096f * fVec20[((IOTA - 20) & 511)])) + (0.00936898217f * fVec20[((IOTA - 22) & 511)])))))))) + (0.0325268731f * fVec20[((IOTA - 29) & 511)])) + (0.0571489297f * fVec20[((IOTA - 30) & 511)])) + (0.0805239752f * fVec20[((IOTA - 31) & 511)])) + (0.0829934552f * fVec20[((IOTA - 32) & 511)])) + (0.0491939075f * fVec20[((IOTA - 33) & 511)])) + (0.0171140395f * fVec20[((IOTA - 34) & 511)])) + (0.00969378464f * fVec20[((IOTA - 40) & 511)])) + (0.00923319161f * fVec20[((IOTA - 41) & 511)])) + (0.0128158629f * fVec20[((IOTA - 42) & 511)])) + (0.0191974379f * fVec20[((IOTA - 43) & 511)])) + (0.0370014161f * fVec20[((IOTA - 44) & 511)])) + (0.0499767959f * fVec20[((IOTA - 45) & 511)])) + (0.0552876629f * fVec20[((IOTA - 46) & 511)])) + (0.0477183945f * fVec20[((IOTA - 47) & 511)])) + (0.0209581479f * fVec20[((IOTA - 48) & 511)])) + (0.00170271564f * fVec20[((IOTA - 53) & 511)])) + (0.0185260363f * fVec20[((IOTA - 54) & 511)])) + (0.0254191048f * fVec20[((IOTA - 55) & 511)])) + (0.0375251323f * fVec20[((IOTA - 56) & 511)])) + (0.0340223759f * fVec20[((IOTA - 57) & 511)])) + (0.0308672693f * fVec20[((IOTA - 58) & 511)])) + (0.025953237f * fVec20[((IOTA - 59) & 511)])) + (0.00832359958f * fVec20[((IOTA - 60) & 511)])) + (0.00633433042f * fVec20[((IOTA - 61) & 511)])) + (3.85814346e-05f * fVec20[((IOTA - 62) & 511)])) + (0.00544728944f * fVec20[((IOTA - 64) & 511)])) + (0.00772395683f * fVec20[((IOTA - 65) & 511)])) + (0.0142295789f * fVec20[((IOTA - 66) & 511)])) + (0.0287619829f * fVec20[((IOTA - 67) & 511)])) + (0.0299068391f * fVec20[((IOTA - 68) & 511)])) + (0.030361725f * fVec20[((IOTA - 69) & 511)])) + (0.0289965514f * fVec20[((IOTA - 70) & 511)])) + (0.0213528685f * fVec20[((IOTA - 71) & 511)])) + (0.0148808453f * fVec20[((IOTA - 72) & 511)])) + (0.00285946485f * fVec20[((IOTA - 73) & 511)])) + (0.00295084668f * fVec20[((IOTA - 75) & 511)])) + (0.00160912983f * fVec20[((IOTA - 76) & 511)])) + (0.00086910883f * fVec20[((IOTA - 77) & 511)])) + (0.00446424773f * fVec20[((IOTA - 82) & 511)])) + (0.0081406245f * fVec20[((IOTA - 83) & 511)])) + (0.0105724633f * fVec20[((IOTA - 84) & 511)])) + (0.0165699758f * fVec20[((IOTA - 85) & 511)])) + (0.0202426091f * fVec20[((IOTA - 86) & 511)])) + (0.0051420792f * fVec20[((IOTA - 102) & 511)])))))))))))))) + (0.012979487f * fVec20[((IOTA - 103) & 511)])) + (0.0206894055f * fVec20[((IOTA - 158) & 511)]))))))))))))))))))))))))))))))))))))))))) + (0.0206654053f * fVec20[((IOTA - 159) & 511)])) + (0.0159206726f * fVec20[((IOTA - 160) & 511)])) + (0.00799689442f * fVec20[((IOTA - 161) & 511)])) + (0.00258438336f * fVec20[((IOTA - 167) & 511)])) + (0.00671791099f * fVec20[((IOTA - 168) & 511)])) + (0.00769391889f * fVec20[((IOTA - 169) & 511)])) + (0.00606142264f * fVec20[((IOTA - 170) & 511)])) + (0.00617390685f * fVec20[((IOTA - 171) & 511)])) + (0.00717192236f * fVec20[((IOTA - 172) & 511)])) + (0.00712020881f * fVec20[((IOTA - 173) & 511)])) + (0.00603047898f * fVec20[((IOTA - 174) & 511)])) + (0.00464809826f * fVec20[((IOTA - 175) & 511)])) + (0.0019358648f * fVec20[((IOTA - 176) & 511)])) + (0.00150029873f * fVec20[((IOTA - 180) & 511)])) + (0.00393569982f * fVec20[((IOTA - 181) & 511)])) + (0.00538316835f * fVec20[((IOTA - 182) & 511)])) + (0.00418551313f * fVec20[((IOTA - 183) & 511)])) + (0.000570238568f * fVec20[((IOTA - 184) & 511)])) + (0.000131472945f * fVec20[((IOTA - 192) & 511)])) + (0.00223428244f * fVec20[((IOTA - 193) & 511)])) + (0.00228394289f * fVec20[((IOTA - 194) & 511)])) + (0.00142564159f * fVec20[((IOTA - 195) & 511)])) + (0.000422252342f * fVec20[((IOTA - 196) & 511)])) + (0.00165522844f * fVec20[((IOTA - 201) & 511)])) + (0.00346321287f * fVec20[((IOTA - 202) & 511)])) + (0.00412459206f * fVec20[((IOTA - 203) & 511)])) + (0.00369406771f * fVec20[((IOTA - 204) & 511)])) + (0.00183817325f * fVec20[((IOTA - 205) & 511)])) + (0.000643084291f * fVec20[((IOTA - 214) & 511)])) + (0.00342934113f * fVec20[((IOTA - 215) & 511)])) + (0.00582286995f * fVec20[((IOTA - 216) & 511)])) + (0.00626731105f * fVec20[((IOTA - 217) & 511)])) + (0.00383444596f * fVec20[((IOTA - 218) & 511)])) + (0.000419293996f * fVec20[((IOTA - 317) & 511)])) + (0.00155898603f * fVec20[((IOTA - 318) & 511)])) + (0.00160526577f * fVec20[((IOTA - 319) & 511)])) + (0.00116435671f * fVec20[((IOTA - 320) & 511)])) + (0.00036072731f * fVec20[((IOTA - 328) & 511)])) + (0.000599582214f * fVec20[((IOTA - 329) & 511)])) + (0.0007021036f * fVec20[((IOTA - 353) & 511)])) + (0.00187092833f * fVec20[((IOTA - 354) & 511)])) + (0.000845440663f * fVec20[((IOTA - 355) & 511)])) + (0.000491717365f * fVec20[((IOTA - 363) & 511)])) + (0.0014650384f * fVec20[((IOTA - 364) & 511)])) + (0.00199246919f * fVec20[((IOTA - 365) & 511)])) + (0.00176762184f * fVec20[((IOTA - 366) & 511)])) + (0.00091037713f * fVec20[((IOTA - 367) & 511)])) + (0.000462162308f * fVec20[((IOTA - 368) & 511)])) + (5.92912547e-05f * fVec20[((IOTA - 380) & 511)])) + (0.000578027219f * fVec20[((IOTA - 381) & 511)])) + (0.00202670321f * fVec20[((IOTA - 395) & 511)])) + (0.00442488119f * fVec20[((IOTA - 396) & 511)])) + (0.0051042526f * fVec20[((IOTA - 397) & 511)])) + (0.00414880365f * fVec20[((IOTA - 398) & 511)])) + (0.00205601659f * fVec20[((IOTA - 399) & 511)])) + (0.00139258476f * fVec20[((IOTA - 406) & 511)])) + (0.00321346009f * fVec20[((IOTA - 407) & 511)])) + (0.0031567351f * fVec20[((IOTA - 408) & 511)])) + (0.0024358537f * fVec20[((IOTA - 409) & 511)])) + (0.00257644337f * fVec20[((IOTA - 410) & 511)])) + (0.00246408023f * fVec20[((IOTA - 411) & 511)])) + (0.00196303474f * fVec20[((IOTA - 412) & 511)])) + (0.00143841188f * fVec20[((IOTA - 413) & 511)])) + (0.000618540682f * fVec20[((IOTA - 420) & 511)])) + (0.00229764869f * fVec20[((IOTA - 421) & 511)])) + (0.0021233079f * fVec20[((IOTA - 422) & 511)])) + (0.00384187279f * fVec20[((IOTA - 430) & 511)])) + (0.00708902348f * fVec20[((IOTA - 431) & 511)])) + (0.00847517792f * fVec20[((IOTA - 432) & 511)])) + (0.00837310962f * fVec20[((IOTA - 433) & 511)])) + (0.00619096356f * fVec20[((IOTA - 434) & 511)])) + (0.00365458056f * fVec20[((IOTA - 435) & 511)])) + (0.00268572755f * fVec20[((IOTA - 436) & 511)])) + (0.00258891145f * fVec20[((IOTA - 437) & 511)])) + (0.00341684278f * fVec20[((IOTA - 438) & 511)])) + (0.00462554675f * fVec20[((IOTA - 439) & 511)])) + (0.0051718154f * fVec20[((IOTA - 440) & 511)])) + (0.00590933114f * fVec20[((IOTA - 441) & 511)])) + (0.00588300638f * fVec20[((IOTA - 442) & 511)])) + (0.00474735908f * fVec20[((IOTA - 443) & 511)])) + (0.00360425562f * fVec20[((IOTA - 444) & 511)])) + (0.00283262692f * fVec20[((IOTA - 445) & 511)])) + (0.00252152979f * fVec20[((IOTA - 446) & 511)])) + (0.00172318378f * fVec20[((IOTA - 447) & 511)])) + (0.000369542744f * fVec20[((IOTA - 448) & 511)])) + (1.51246786e-05f * fVec20[((IOTA - 450) & 511)])) + (0.000490962528f * fVec20[((IOTA - 451) & 511)])) + (0.00177580304f * fVec20[((IOTA - 452) & 511)])) + (0.00259999093f * fVec20[((IOTA - 453) & 511)])) + (0.00296829594f * fVec20[((IOTA - 454) & 511)])) + (0.00397476414f * fVec20[((IOTA - 455) & 511)])) + (0.00465320004f * fVec20[((IOTA - 456) & 511)])) + (0.00433500856f * fVec20[((IOTA - 457) & 511)])) + (0.00397612294f * fVec20[((IOTA - 458) & 511)])) + (0.00269701798f * fVec20[((IOTA - 459) & 511)])) + (0.00137586007f * fVec20[((IOTA - 460) & 511)])) + (0.00196741195f * fVec20[((IOTA - 461) & 511)])) + (0.00343966577f * fVec20[((IOTA - 462) & 511)])) + (0.00481471093f * fVec20[((IOTA - 463) & 511)])) + (0.00563168339f * fVec20[((IOTA - 464) & 511)])) + (0.00530431466f * fVec20[((IOTA - 465) & 511)])) + (0.00436782418f * fVec20[((IOTA - 466) & 511)])) + (0.00294800894f * fVec20[((IOTA - 467) & 511)])) + (0.000731055159f * fVec20[((IOTA - 468) & 511)])) + (0.000933652744f * fVec20[((IOTA - 475) & 511)])) + (0.00275537325f * fVec20[((IOTA - 476) & 511)])) + (0.0041902829f * fVec20[((IOTA - 477) & 511)])) + (0.00520780077f * fVec20[((IOTA - 478) & 511)])) + (0.00517404964f * fVec20[((IOTA - 479) & 511)])) + (0.00495729316f * fVec20[((IOTA - 480) & 511)])) + (0.00476882374f * fVec20[((IOTA - 481) & 511)])) + (0.00410345988f * fVec20[((IOTA - 482) & 511)])) + (0.00337210298f * fVec20[((IOTA - 483) & 511)])) + (0.00243609538f * fVec20[((IOTA - 484) & 511)])) + (0.00158739416f * fVec20[((IOTA - 485) & 511)])) + (0.00150470668f * fVec20[((IOTA - 486) & 511)])) + (0.00126739126f * fVec20[((IOTA - 487) & 511)])) + (0.00132239563f * fVec20[((IOTA - 488) & 511)])) + (0.00170902535f * fVec20[((IOTA - 489) & 511)])) + (0.00124918763f * fVec20[((IOTA - 490) & 511)])) + (5.14420681e-05f * fVec20[((IOTA - 491) & 511)])) + (0.000874784309f * fVec20[((IOTA - 497) & 511)])) + (0.00220998004f * fVec20[((IOTA - 498) & 511)])) + (0.00272609014f * fVec20[((IOTA - 499) & 511)])) + (0.00306704361f * fVec20[((IOTA - 500) & 511)])) + (0.00367242238f * fVec20[((IOTA - 501) & 511)])) + (0.00484239403f * fVec20[((IOTA - 502) & 511)])) + (0.00644171238f * fVec20[((IOTA - 503) & 511)])) + (0.00708627608f * fVec20[((IOTA - 504) & 511)])) + (0.00710484246f * fVec20[((IOTA - 505) & 511)])) + (0.00693922583f * fVec20[((IOTA - 506) & 511)])) + (0.006346195f * fVec20[((IOTA - 507) & 511)])) + (0.00575029571f * fVec20[((IOTA - 508) & 511)])) + (0.00560173579f * fVec20[((IOTA - 509) & 511)])) + (0.0055472753f * fVec20[((IOTA - 510) & 511)])) + (0.0059929844f * fVec20[((IOTA - 511) & 511)])))) : (iSlow60 ? ((((((((((((((((((0.00598346535f * fVec19[((IOTA - 426) & 511)]) + ((0.0055861189f * fVec19[((IOTA - 425) & 511)]) + ((0.00437896047f * fVec19[((IOTA - 424) & 511)]) + ((0.00323364278f * fVec19[((IOTA - 423) & 511)]) + ((0.00268276967f * fVec19[((IOTA - 422) & 511)]) + ((0.00275103422f * fVec19[((IOTA - 421) & 511)]) + ((0.0027286429f * fVec19[((IOTA - 420) & 511)]) + ((0.0027902415f * fVec19[((IOTA - 419) & 511)]) + ((0.00314947125f * fVec19[((IOTA - 418) & 511)]) + ((0.00276403269f * fVec19[((IOTA - 417) & 511)]) + ((0.00114334794f * fVec19[((IOTA - 416) & 511)]) + ((5.23575582e-05f * fVec19[((IOTA - 409) & 511)]) + ((0.000363016967f * fVec19[((IOTA - 403) & 511)]) + ((0.00243046647f * fVec19[((IOTA - 402) & 511)]) + ((0.00336250616f * fVec19[((IOTA - 401) & 511)]) + ((0.00185520202f * fVec19[((IOTA - 400) & 511)]) + ((0.00300860917f * fVec19[((IOTA - 394) & 511)]) + ((0.00668704743f * fVec19[((IOTA - 393) & 511)]) + ((0.00845683552f * fVec19[((IOTA - 392) & 511)]) + ((0.00778255286f * fVec19[((IOTA - 391) & 511)]) + ((0.00649400987f * fVec19[((IOTA - 390) & 511)]) + ((0.00500103738f * fVec19[((IOTA - 389) & 511)]) + ((0.00345685892f * fVec19[((IOTA - 388) & 511)]) + ((0.00263862358f * fVec19[((IOTA - 387) & 511)]) + ((0.00287289824f * fVec19[((IOTA - 386) & 511)]) + ((0.00345352571f * fVec19[((IOTA - 385) & 511)]) + ((0.00372694759f * fVec19[((IOTA - 384) & 511)]) + ((0.00241425633f * fVec19[((IOTA - 383) & 511)]) + ((0.000985397026f * fVec19[((IOTA - 382) & 511)]) + ((5.51450066e-05f * fVec19[((IOTA - 381) & 511)]) + ((0.000234153587f * fVec19[((IOTA - 378) & 511)]) + ((0.00252360664f * fVec19[((IOTA - 377) & 511)]) + ((0.00457808794f * fVec19[((IOTA - 376) & 511)]) + ((0.0048042126f * fVec19[((IOTA - 375) & 511)]) + ((((0.000659163576f * fVec19[((IOTA - 367) & 511)]) + ((0.000862078741f * fVec19[((IOTA - 366) & 511)]) + ((0.000634772237f * fVec19[((IOTA - 365) & 511)]) + ((0.000992032699f * fVec19[((IOTA - 362) & 511)]) + ((0.00459835818f * fVec19[((IOTA - 361) & 511)]) + ((0.00826964527f * fVec19[((IOTA - 360) & 511)]) + ((0.00988411903f * fVec19[((IOTA - 359) & 511)]) + ((0.00941772014f * fVec19[((IOTA - 358) & 511)]) + ((0.00707872771f * fVec19[((IOTA - 357) & 511)]) + ((0.00341949938f * fVec19[((IOTA - 356) & 511)]) + ((0.000542389695f * fVec19[((IOTA - 355) & 511)]) + ((0.00139459036f * fVec19[((IOTA - 353) & 511)]) + ((0.00433511706f * fVec19[((IOTA - 352) & 511)]) + ((0.00703482423f * fVec19[((IOTA - 351) & 511)]) + ((0.00897813682f * fVec19[((IOTA - 350) & 511)]) + ((0.00955467392f * fVec19[((IOTA - 349) & 511)]) + ((0.00912869442f * fVec19[((IOTA - 348) & 511)]) + ((0.00872510672f * fVec19[((IOTA - 347) & 511)]) + ((0.00909239613f * fVec19[((IOTA - 346) & 511)]) + ((0.00989663228f * fVec19[((IOTA - 345) & 511)]) + ((0.0107830726f * fVec19[((IOTA - 344) & 511)]) + ((0.0116769038f * fVec19[((IOTA - 343) & 511)]) + ((0.0118527617f * fVec19[((IOTA - 342) & 511)]) + ((0.0109285694f * fVec19[((IOTA - 341) & 511)]) + ((0.00902149454f * fVec19[((IOTA - 340) & 511)]) + ((0.00634723995f * fVec19[((IOTA - 339) & 511)]) + ((0.00428045681f * fVec19[((IOTA - 338) & 511)]) + ((0.00294407178f * fVec19[((IOTA - 337) & 511)]) + ((0.00297012925f * fVec19[((IOTA - 336) & 511)]) + ((0.00355466502f * fVec19[((IOTA - 335) & 511)]) + ((0.00373934023f * fVec19[((IOTA - 334) & 511)]) + ((0.00358605525f * fVec19[((IOTA - 333) & 511)]) + ((0.00281445077f * fVec19[((IOTA - 332) & 511)]) + ((0.00182917481f * fVec19[((IOTA - 331) & 511)]) + ((0.00128496718f * fVec19[((IOTA - 330) & 511)]) + ((0.000390862115f * fVec19[((IOTA - 329) & 511)]) + ((0.000379075762f * fVec19[((IOTA - 327) & 511)]) + ((0.00151284924f * fVec19[((IOTA - 326) & 511)]) + ((0.00290671224f * fVec19[((IOTA - 325) & 511)]) + ((0.00451494427f * fVec19[((IOTA - 324) & 511)]) + ((0.00543534895f * fVec19[((IOTA - 323) & 511)]) + ((0.00569443917f * fVec19[((IOTA - 322) & 511)]) + ((0.00499912864f * fVec19[((IOTA - 321) & 511)]) + ((0.00366543978f * fVec19[((IOTA - 320) & 511)]) + ((0.00224173162f * fVec19[((IOTA - 319) & 511)]) + ((0.00177390873f * fVec19[((IOTA - 318) & 511)]) + ((0.00416492531f * fVec19[((IOTA - 317) & 511)]) + ((0.0122258691f * fVec19[((IOTA - 315) & 511)]) + ((0.0140149277f * fVec19[((IOTA - 314) & 511)]) + ((0.0132194469f * fVec19[((IOTA - 313) & 511)]) + ((0.0100327982f * fVec19[((IOTA - 312) & 511)]) + ((0.00761439092f * fVec19[((IOTA - 311) & 511)]) + ((0.00591901829f * fVec19[((IOTA - 310) & 511)]) + ((0.00486944709f * fVec19[((IOTA - 309) & 511)]) + ((0.00572073925f * fVec19[((IOTA - 308) & 511)]) + ((0.00729036937f * fVec19[((IOTA - 307) & 511)]) + ((0.00901361741f * fVec19[((IOTA - 306) & 511)]) + ((0.010953567f * fVec19[((IOTA - 305) & 511)]) + ((0.0113023734f * fVec19[((IOTA - 304) & 511)]) + ((0.012042406f * fVec19[((IOTA - 303) & 511)]) + ((0.0145553173f * fVec19[((IOTA - 302) & 511)]) + ((0.0171579458f * fVec19[((IOTA - 301) & 511)]) + ((0.0185508691f * fVec19[((IOTA - 300) & 511)]) + ((0.018251542f * fVec19[((IOTA - 299) & 511)]) + ((0.016104253f * fVec19[((IOTA - 298) & 511)]) + ((0.0134581756f * fVec19[((IOTA - 297) & 511)]) + ((0.00990784355f * fVec19[((IOTA - 296) & 511)]) + (((0.00617619976f * fVec19[((IOTA - 295) & 511)]) + ((0.00457699737f * fVec19[((IOTA - 294) & 511)]) + ((0.00485229772f * fVec19[((IOTA - 293) & 511)]) + ((0.0053935661f * fVec19[((IOTA - 292) & 511)]) + ((0.00662387349f * fVec19[((IOTA - 291) & 511)]) + ((0.00752715906f * fVec19[((IOTA - 290) & 511)]) + ((0.00844283774f * fVec19[((IOTA - 289) & 511)]) + ((0.00950695202f * fVec19[((IOTA - 288) & 511)]) + ((0.0090699736f * fVec19[((IOTA - 287) & 511)]) + ((0.00885924138f * fVec19[((IOTA - 286) & 511)]) + ((0.00983624626f * fVec19[((IOTA - 285) & 511)]) + ((0.0103344284f * fVec19[((IOTA - 284) & 511)]) + ((0.0105542205f * fVec19[((IOTA - 283) & 511)]) + ((0.0114064217f * fVec19[((IOTA - 282) & 511)]) + ((0.0122987386f * fVec19[((IOTA - 281) & 511)]) + ((0.0132435355f * fVec19[((IOTA - 280) & 511)]) + ((0.0120891575f * fVec19[((IOTA - 279) & 511)]) + ((0.00890556909f * fVec19[((IOTA - 278) & 511)]) + ((0.00743544288f * fVec19[((IOTA - 277) & 511)]) + ((0.00725543406f * fVec19[((IOTA - 276) & 511)]) + ((0.00854218937f * fVec19[((IOTA - 275) & 511)]) + ((0.0123999696f * fVec19[((IOTA - 274) & 511)]) + ((0.0155708622f * fVec19[((IOTA - 273) & 511)]) + ((0.0175418984f * fVec19[((IOTA - 272) & 511)]) + ((0.0193478037f * fVec19[((IOTA - 271) & 511)]) + ((0.018577138f * fVec19[((IOTA - 270) & 511)]) + ((0.016423244f * fVec19[((IOTA - 269) & 511)]) + ((0.0151064331f * fVec19[((IOTA - 268) & 511)]) + ((0.0141655151f * fVec19[((IOTA - 267) & 511)]) + ((0.0152545068f * fVec19[((IOTA - 266) & 511)]) + ((0.0168114416f * fVec19[((IOTA - 265) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((fSlow64 * fTemp0) + (0.218374327f * fVec19[((IOTA - 1) & 511)])) + (0.24149707f * fVec19[((IOTA - 2) & 511)])) + (0.245528042f * fVec19[((IOTA - 3) & 511)])) + (0.187073469f * fVec19[((IOTA - 4) & 511)])) + (0.0675452426f * fVec19[((IOTA - 5) & 511)])) + (0.0050580306f * fVec19[((IOTA - 10) & 511)])) + (0.0635567829f * fVec19[((IOTA - 11) & 511)])) + (0.10262277f * fVec19[((IOTA - 12) & 511)])) + (0.072542794f * fVec19[((IOTA - 13) & 511)])) + (0.0272923671f * fVec19[((IOTA - 14) & 511)])) + (0.00609523943f * fVec19[((IOTA - 15) & 511)])) + (0.00352742616f * fVec19[((IOTA - 18) & 511)])) + (0.0187547244f * fVec19[((IOTA - 19) & 511)])) + (0.0445825383f * fVec19[((IOTA - 20) & 511)])) + (0.0294455644f * fVec19[((IOTA - 21) & 511)])) + (0.0277732499f * fVec19[((IOTA - 22) & 511)])) + (0.0444103777f * fVec19[((IOTA - 23) & 511)])) + (0.0539321154f * fVec19[((IOTA - 24) & 511)])) + (0.0541100651f * fVec19[((IOTA - 25) & 511)])) + (0.0442530625f * fVec19[((IOTA - 26) & 511)])) + (0.0251847412f * fVec19[((IOTA - 27) & 511)])) + (0.00492528873f * fVec19[((IOTA - 36) & 511)])) + (0.0120184086f * fVec19[((IOTA - 37) & 511)])) + (0.0219735205f * fVec19[((IOTA - 51) & 511)])) + (0.0247018598f * fVec19[((IOTA - 52) & 511)])) + (0.0169479698f * fVec19[((IOTA - 53) & 511)])) + (0.0095688533f * fVec19[((IOTA - 63) & 511)])) + (0.0173196234f * fVec19[((IOTA - 64) & 511)])) + (0.0168367717f * fVec19[((IOTA - 65) & 511)])) + (0.00425888365f * fVec19[((IOTA - 79) & 511)])) + (0.0054559526f * fVec19[((IOTA - 80) & 511)])) + (0.00242201285f * fVec19[((IOTA - 99) & 511)])) + (0.00981703587f * fVec19[((IOTA - 100) & 511)])) + (0.0146710612f * fVec19[((IOTA - 101) & 511)])) + (0.0113370065f * fVec19[((IOTA - 102) & 511)])) + (0.00100345537f * fVec19[((IOTA - 103) & 511)])) + (0.00722143799f * fVec19[((IOTA - 112) & 511)])) + (0.00893265754f * fVec19[((IOTA - 113) & 511)])) + (0.00452051917f * fVec19[((IOTA - 114) & 511)])) + (0.00336053688f * fVec19[((IOTA - 127) & 511)])) + (0.00480518211f * fVec19[((IOTA - 128) & 511)])) + (0.00145912822f * fVec19[((IOTA - 129) & 511)])) + (0.000177675858f * fVec19[((IOTA - 134) & 511)])) + (0.00383572234f * fVec19[((IOTA - 135) & 511)])) + (0.00722228643f * fVec19[((IOTA - 136) & 511)])) + (0.0072864606f * fVec19[((IOTA - 137) & 511)])) + (0.00728800567f * fVec19[((IOTA - 138) & 511)])) + (0.00465638191f * fVec19[((IOTA - 139) & 511)])) + (0.0017075832f * fVec19[((IOTA - 150) & 511)])) + (0.00270606996f * fVec19[((IOTA - 151) & 511)])) + (0.00238159345f * fVec19[((IOTA - 152) & 511)])) + (0.00140192313f * fVec19[((IOTA - 153) & 511)])) + (0.00945383683f * fVec19[((IOTA - 162) & 511)])) + (0.0131311845f * fVec19[((IOTA - 163) & 511)])) + (0.0100844586f * fVec19[((IOTA - 164) & 511)])) + (0.00198364118f * fVec19[((IOTA - 165) & 511)])) + (0.000284268986f * fVec19[((IOTA - 172) & 511)])) + (0.00136071583f * fVec19[((IOTA - 186) & 511)])) + (0.00391265238f * fVec19[((IOTA - 187) & 511)])) + (0.00689235609f * fVec19[((IOTA - 188) & 511)])) + (0.00813566148f * fVec19[((IOTA - 189) & 511)])) + (0.00682681892f * fVec19[((IOTA - 190) & 511)])) + (0.00468286313f * fVec19[((IOTA - 191) & 511)])) + (0.00178969465f * fVec19[((IOTA - 192) & 511)])) + (0.000141104218f * fVec19[((IOTA - 195) & 511)])) + (0.000642468687f * fVec19[((IOTA - 196) & 511)])) + (0.00237877574f * fVec19[((IOTA - 197) & 511)])) + (0.00322146248f * fVec19[((IOTA - 198) & 511)])) + (0.000179311726f * fVec19[((IOTA - 199) & 511)])) + (0.00127242319f * fVec19[((IOTA - 203) & 511)])) + (0.0036592586f * fVec19[((IOTA - 204) & 511)])) + (0.00405799877f * fVec19[((IOTA - 205) & 511)])) + (0.00412311219f * fVec19[((IOTA - 206) & 511)])) + (0.00419480074f * fVec19[((IOTA - 207) & 511)])) + (0.00391916698f * fVec19[((IOTA - 208) & 511)])) + (0.00589199131f * fVec19[((IOTA - 209) & 511)])) + (0.00814693328f * fVec19[((IOTA - 210) & 511)])) + (0.0100275567f * fVec19[((IOTA - 211) & 511)])) + (0.0120202266f * fVec19[((IOTA - 212) & 511)])) + (0.0118446425f * fVec19[((IOTA - 213) & 511)])) + (0.00884551648f * fVec19[((IOTA - 214) & 511)])) + (0.00355160469f * fVec19[((IOTA - 215) & 511)])) + (0.00180445053f * fVec19[((IOTA - 221) & 511)])) + (0.00661145058f * fVec19[((IOTA - 222) & 511)])) + (0.0112461373f * fVec19[((IOTA - 223) & 511)])) + (0.0137099335f * fVec19[((IOTA - 224) & 511)])) + (0.0133219194f * fVec19[((IOTA - 225) & 511)])) + (0.0117649548f * fVec19[((IOTA - 226) & 511)])) + (0.0101743266f * fVec19[((IOTA - 227) & 511)])) + (0.00809433311f * fVec19[((IOTA - 228) & 511)])) + (0.00520274043f * fVec19[((IOTA - 229) & 511)])) + (0.0020278478f * fVec19[((IOTA - 230) & 511)])) + (0.00117713166f * fVec19[((IOTA - 233) & 511)])) + (0.00480742427f * fVec19[((IOTA - 234) & 511)])) + (0.0091895964f * fVec19[((IOTA - 235) & 511)])) + (0.0120619191f * fVec19[((IOTA - 236) & 511)])) + (0.0130407102f * fVec19[((IOTA - 237) & 511)])) + (0.0131923594f * fVec19[((IOTA - 238) & 511)])) + (0.0128149502f * fVec19[((IOTA - 239) & 511)])) + (0.0111730555f * fVec19[((IOTA - 240) & 511)])) + (0.0087481644f * fVec19[((IOTA - 241) & 511)])) + (0.00725600962f * fVec19[((IOTA - 242) & 511)])) + (0.00524173584f * fVec19[((IOTA - 243) & 511)])) + (0.00286314171f * fVec19[((IOTA - 244) & 511)])) + (0.00102190813f * fVec19[((IOTA - 245) & 511)])) + (0.000263877679f * fVec19[((IOTA - 246) & 511)])) + (0.000570446718f * fVec19[((IOTA - 247) & 511)])) + (0.00330408895f * fVec19[((IOTA - 248) & 511)])) + (0.00701458426f * fVec19[((IOTA - 249) & 511)])) + (0.00883624516f * fVec19[((IOTA - 250) & 511)])) + (0.0099108126f * fVec19[((IOTA - 251) & 511)])) + (0.0105499793f * fVec19[((IOTA - 252) & 511)])) + (0.0102539845f * fVec19[((IOTA - 253) & 511)])) + (0.00918771792f * fVec19[((IOTA - 254) & 511)])) + (0.00745913712f * fVec19[((IOTA - 255) & 511)])) + (0.00639435556f * fVec19[((IOTA - 256) & 511)])) + (0.00540114101f * fVec19[((IOTA - 257) & 511)])) + (0.00351042813f * fVec19[((IOTA - 258) & 511)])) + (0.00316516636f * fVec19[((IOTA - 259) & 511)])) + (0.00429088017f * fVec19[((IOTA - 260) & 511)])) + (0.00688163051f * fVec19[((IOTA - 261) & 511)])) + (0.0110774916f * fVec19[((IOTA - 262) & 511)])) + (0.014165001f * fVec19[((IOTA - 263) & 511)])) + (0.0158924293f * fVec19[((IOTA - 264) & 511)])) + (0.00870250352f * fVec19[((IOTA - 316) & 511)]))))))))))))))))))))))))))))))))) + (0.000559235923f * fVec19[((IOTA - 373) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00295110093f * fVec19[((IOTA - 374) & 511)])) + (0.00475388533f * fVec19[((IOTA - 427) & 511)])))))))))))))))))))))))))))))))))))) + (0.00219822163f * fVec19[((IOTA - 428) & 511)])) + (0.000596322585f * fVec19[((IOTA - 452) & 511)])) + (0.000227699988f * fVec19[((IOTA - 453) & 511)])) + (0.000922465231f * fVec19[((IOTA - 470) & 511)])) + (0.00164604513f * fVec19[((IOTA - 471) & 511)])) + (0.00183987059f * fVec19[((IOTA - 472) & 511)])) + (0.00157678081f * fVec19[((IOTA - 473) & 511)])) + (0.000627591275f * fVec19[((IOTA - 474) & 511)])) + (0.000312235206f * fVec19[((IOTA - 486) & 511)])) + (6.15683384e-05f * fVec19[((IOTA - 487) & 511)])) + (0.000942038838f * fVec19[((IOTA - 496) & 511)])) + (0.00139843859f * fVec19[((IOTA - 497) & 511)])) + (0.00203242339f * fVec19[((IOTA - 498) & 511)])) + (0.00174073083f * fVec19[((IOTA - 499) & 511)])) + (4.85698693e-05f * fVec19[((IOTA - 500) & 511)])) - ((((((((((((((((((((((((((0.00971935131f * fVec19[((IOTA - 479) & 511)]) + ((0.0071424474f * fVec19[((IOTA - 478) & 511)]) + ((0.0040506362f * fVec19[((IOTA - 477) & 511)]) + ((0.00151260663f * fVec19[((IOTA - 476) & 511)]) + ((0.000412162859f * fVec19[((IOTA - 475) & 511)]) + ((0.000399861019f * fVec19[((IOTA - 469) & 511)]) + ((0.00238522934f * fVec19[((IOTA - 468) & 511)]) + ((0.00441507716f * fVec19[((IOTA - 467) & 511)]) + ((0.00539474795f * fVec19[((IOTA - 466) & 511)]) + ((0.00586623698f * fVec19[((IOTA - 465) & 511)]) + ((0.00582851423f * fVec19[((IOTA - 464) & 511)]) + ((0.0045794514f * fVec19[((IOTA - 463) & 511)]) + ((0.00349152135f * fVec19[((IOTA - 462) & 511)]) + ((0.00394083094f * fVec19[((IOTA - 461) & 511)]) + ((0.00510947872f * fVec19[((IOTA - 460) & 511)]) + ((0.00651846174f * fVec19[((IOTA - 459) & 511)]) + ((0.00798843708f * fVec19[((IOTA - 458) & 511)]) + ((0.00823816471f * fVec19[((IOTA - 457) & 511)]) + ((0.00724289007f * fVec19[((IOTA - 456) & 511)]) + ((0.00489092944f * fVec19[((IOTA - 455) & 511)]) + ((0.00190571137f * fVec19[((IOTA - 454) & 511)]) + ((0.000773331616f * fVec19[((IOTA - 451) & 511)]) + ((0.00349291507f * fVec19[((IOTA - 450) & 511)]) + ((0.00563890021f * fVec19[((IOTA - 449) & 511)]) + ((0.0059766476f * fVec19[((IOTA - 448) & 511)]) + ((0.00500633987f * fVec19[((IOTA - 447) & 511)]) + ((0.00397812948f * fVec19[((IOTA - 446) & 511)]) + ((0.00376409478f * fVec19[((IOTA - 445) & 511)]) + ((0.00466731982f * fVec19[((IOTA - 444) & 511)]) + ((0.00604233705f * fVec19[((IOTA - 443) & 511)]) + ((0.00739344768f * fVec19[((IOTA - 442) & 511)]) + ((0.00833233539f * fVec19[((IOTA - 441) & 511)]) + ((0.00791229494f * fVec19[((IOTA - 440) & 511)]) + ((0.00676028104f * fVec19[((IOTA - 439) & 511)]) + ((0.00502521638f * fVec19[((IOTA - 438) & 511)]) + ((0.00328706065f * fVec19[((IOTA - 437) & 511)]) + ((0.00312026264f * fVec19[((IOTA - 436) & 511)]) + ((0.00454348605f * fVec19[((IOTA - 435) & 511)]) + ((0.00693822978f * fVec19[((IOTA - 434) & 511)]) + ((0.0089236591f * fVec19[((IOTA - 433) & 511)]) + ((0.00939163286f * fVec19[((IOTA - 432) & 511)]) + ((0.00857097283f * fVec19[((IOTA - 431) & 511)]) + ((0.00571283093f * fVec19[((IOTA - 430) & 511)]) + ((0.00142495055f * fVec19[((IOTA - 429) & 511)]) + ((0.000326930545f * fVec19[((IOTA - 415) & 511)]) + ((0.00148282247f * fVec19[((IOTA - 414) & 511)]) + ((0.00212853309f * fVec19[((IOTA - 413) & 511)]) + ((0.00154469395f * fVec19[((IOTA - 412) & 511)]) + ((0.000611502677f * fVec19[((IOTA - 411) & 511)]) + ((2.98754312e-05f * fVec19[((IOTA - 410) & 511)]) + ((0.00147297513f * fVec19[((IOTA - 408) & 511)]) + ((0.00346940244f * fVec19[((IOTA - 407) & 511)]) + ((0.00368019566f * fVec19[((IOTA - 406) & 511)]) + ((0.00295291888f * fVec19[((IOTA - 405) & 511)]) + ((0.00176766701f * fVec19[((IOTA - 404) & 511)]) + ((0.00135002006f * fVec19[((IOTA - 399) & 511)]) + ((0.00378388027f * fVec19[((IOTA - 398) & 511)]) + ((0.00479200203f * fVec19[((IOTA - 397) & 511)]) + ((0.00383096561f * fVec19[((IOTA - 396) & 511)]) + ((0.00081184227f * fVec19[((IOTA - 395) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00249976106f * fVec19[((IOTA - 126) & 511)]) + ((0.0113246739f * fVec19[((IOTA - 125) & 511)]) + ((0.0205813535f * fVec19[((IOTA - 124) & 511)]) + ((0.025473889f * fVec19[((IOTA - 123) & 511)]) + ((0.0281575974f * fVec19[((IOTA - 122) & 511)]) + ((0.0327234119f * fVec19[((IOTA - 121) & 511)]) + ((0.0357067846f * fVec19[((IOTA - 120) & 511)]) + ((0.0364321806f * fVec19[((IOTA - 119) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((0.0582006648f * fVec19[((IOTA - 59) & 511)]) + ((0.0596905798f * fVec19[((IOTA - 58) & 511)]) + ((0.0520763695f * fVec19[((IOTA - 57) & 511)]) + ((0.035821043f * fVec19[((IOTA - 56) & 511)]) + ((0.0217447598f * fVec19[((IOTA - 55) & 511)]) + ((0.00305878511f * fVec19[((IOTA - 54) & 511)]) + ((0.00344316335f * fVec19[((IOTA - 50) & 511)]) + ((0.0290220082f * fVec19[((IOTA - 49) & 511)]) + ((0.050407961f * fVec19[((IOTA - 48) & 511)]) + ((0.073924087f * fVec19[((IOTA - 47) & 511)]) + ((0.0654335842f * fVec19[((IOTA - 46) & 511)]) + ((0.0349062122f * fVec19[((IOTA - 45) & 511)]) + ((0.0209279787f * fVec19[((IOTA - 44) & 511)]) + ((0.00659348303f * fVec19[((IOTA - 43) & 511)]) + ((0.00351036759f * fVec19[((IOTA - 42) & 511)]) + ((0.00921265408f * fVec19[((IOTA - 41) & 511)]) + ((0.0105872173f * fVec19[((IOTA - 40) & 511)]) + ((0.00853673555f * fVec19[((IOTA - 39) & 511)]) + ((0.00218116306f * fVec19[((IOTA - 38) & 511)]) + ((0.00175600173f * fVec19[((IOTA - 35) & 511)]) + ((0.00903009996f * fVec19[((IOTA - 34) & 511)]) + ((0.0349204838f * fVec19[((IOTA - 33) & 511)]) + ((0.0730561614f * fVec19[((IOTA - 32) & 511)]) + ((0.0728403628f * fVec19[((IOTA - 31) & 511)]) + ((0.0581118278f * fVec19[((IOTA - 30) & 511)]) + ((0.0477793068f * fVec19[((IOTA - 29) & 511)]) + ((0.0185375065f * fVec19[((IOTA - 28) & 511)]) + ((0.0149567239f * fVec19[((IOTA - 17) & 511)]) + ((0.0179418214f * fVec19[((IOTA - 16) & 511)]) + ((0.0685493946f * fVec19[((IOTA - 9) & 511)]) + ((0.12923789f * fVec19[((IOTA - 8) & 511)]) + ((0.13908273f * fVec19[((IOTA - 7) & 511)]) + ((0.0575176254f * fVec19[((IOTA - 6) & 511)]) + ((0.0476028435f * fVec19[((IOTA - 60) & 511)]) + (0.0319073908f * fVec19[((IOTA - 61) & 511)]))))))))))))))))))))))))))))))))))) + (0.0103840902f * fVec19[((IOTA - 62) & 511)])) + (8.79289582e-05f * fVec19[((IOTA - 66) & 511)])) + (0.0317888297f * fVec19[((IOTA - 67) & 511)])) + (0.0472745486f * fVec19[((IOTA - 68) & 511)])) + (0.0580119006f * fVec19[((IOTA - 69) & 511)])) + (0.0536500886f * fVec19[((IOTA - 70) & 511)])) + (0.0337772891f * fVec19[((IOTA - 71) & 511)])) + (0.0170515943f * fVec19[((IOTA - 72) & 511)])) + (0.00876158662f * fVec19[((IOTA - 73) & 511)])) + (0.003177498f * fVec19[((IOTA - 74) & 511)])) + (0.00654467056f * fVec19[((IOTA - 75) & 511)])) + (0.0146336714f * fVec19[((IOTA - 76) & 511)])) + (0.0132846814f * fVec19[((IOTA - 77) & 511)])) + (0.00194052514f * fVec19[((IOTA - 78) & 511)])) + (0.000714974944f * fVec19[((IOTA - 81) & 511)])) + (0.0115655232f * fVec19[((IOTA - 82) & 511)])) + (0.0126037635f * fVec19[((IOTA - 83) & 511)])) + (0.0102971308f * fVec19[((IOTA - 84) & 511)])) + (0.0085968487f * fVec19[((IOTA - 85) & 511)])) + (0.00610581413f * fVec19[((IOTA - 86) & 511)])) + (0.00545713445f * fVec19[((IOTA - 87) & 511)])) + (0.0137465959f * fVec19[((IOTA - 88) & 511)])) + (0.0219848212f * fVec19[((IOTA - 89) & 511)])) + (0.0260033086f * fVec19[((IOTA - 90) & 511)])) + (0.0286258142f * fVec19[((IOTA - 91) & 511)])) + (0.0325092897f * fVec19[((IOTA - 92) & 511)])) + (0.0327704996f * fVec19[((IOTA - 93) & 511)])) + (0.0324193276f * fVec19[((IOTA - 94) & 511)])) + (0.0271873195f * fVec19[((IOTA - 95) & 511)])) + (0.0219194051f * fVec19[((IOTA - 96) & 511)])) + (0.0148069542f * fVec19[((IOTA - 97) & 511)])) + (0.00584060326f * fVec19[((IOTA - 98) & 511)])) + (0.0135132298f * fVec19[((IOTA - 104) & 511)])) + (0.029303642f * fVec19[((IOTA - 105) & 511)])) + (0.0400809869f * fVec19[((IOTA - 106) & 511)])) + (0.0425648428f * fVec19[((IOTA - 107) & 511)])) + (0.0380020551f * fVec19[((IOTA - 108) & 511)])) + (0.0306574497f * fVec19[((IOTA - 109) & 511)])) + (0.0177683868f * fVec19[((IOTA - 110) & 511)])) + (0.00150572881f * fVec19[((IOTA - 111) & 511)])) + (0.0105619468f * fVec19[((IOTA - 115) & 511)])) + (0.0251875594f * fVec19[((IOTA - 116) & 511)])) + (0.0351218544f * fVec19[((IOTA - 117) & 511)])) + (0.037927974f * fVec19[((IOTA - 118) & 511)])) + (0.00090804277f * fVec19[((IOTA - 130) & 511)])))))))))) + (0.00312335324f * fVec19[((IOTA - 131) & 511)])) + (0.00459199538f * fVec19[((IOTA - 132) & 511)])) + (0.00213504722f * fVec19[((IOTA - 133) & 511)])) + (0.00156305544f * fVec19[((IOTA - 140) & 511)])) + (0.00697555859f * fVec19[((IOTA - 141) & 511)])) + (0.0111257881f * fVec19[((IOTA - 142) & 511)])) + (0.0137982871f * fVec19[((IOTA - 143) & 511)])) + (0.0153033789f * fVec19[((IOTA - 144) & 511)])) + (0.0153959133f * fVec19[((IOTA - 145) & 511)])) + (0.0153599791f * fVec19[((IOTA - 146) & 511)])) + (0.0125624351f * fVec19[((IOTA - 147) & 511)])) + (0.00645507546f * fVec19[((IOTA - 148) & 511)])) + (0.00114937732f * fVec19[((IOTA - 149) & 511)])) + (0.00194655452f * fVec19[((IOTA - 154) & 511)])) + (0.00579979038f * fVec19[((IOTA - 155) & 511)])) + (0.0114409933f * fVec19[((IOTA - 156) & 511)])) + (0.0187070016f * fVec19[((IOTA - 157) & 511)])) + (0.0238685049f * fVec19[((IOTA - 158) & 511)])) + (0.0232967846f * fVec19[((IOTA - 159) & 511)])) + (0.0150117474f * fVec19[((IOTA - 160) & 511)])) + (0.00166649744f * fVec19[((IOTA - 161) & 511)])) + (0.00812366325f * fVec19[((IOTA - 166) & 511)])) + (0.0147209037f * fVec19[((IOTA - 167) & 511)])) + (0.0150019303f * fVec19[((IOTA - 168) & 511)])) + (0.0109281763f * fVec19[((IOTA - 169) & 511)])) + (0.00471695f * fVec19[((IOTA - 170) & 511)])) + (0.000628167298f * fVec19[((IOTA - 171) & 511)])) + (0.00182711426f * fVec19[((IOTA - 173) & 511)])) + (0.00419071037f * fVec19[((IOTA - 174) & 511)])) + (0.00479063811f * fVec19[((IOTA - 175) & 511)])) + (0.00390262343f * fVec19[((IOTA - 176) & 511)])) + (0.00256360183f * fVec19[((IOTA - 177) & 511)])) + (0.00116982963f * fVec19[((IOTA - 178) & 511)])) + (0.00196779473f * fVec19[((IOTA - 179) & 511)])) + (0.00408929819f * fVec19[((IOTA - 180) & 511)])) + (0.0049504675f * fVec19[((IOTA - 181) & 511)])) + (0.00551046105f * fVec19[((IOTA - 182) & 511)])) + (0.00454584928f * fVec19[((IOTA - 183) & 511)])) + (0.00245937193f * fVec19[((IOTA - 184) & 511)])) + (0.000812205952f * fVec19[((IOTA - 185) & 511)])) + (0.00111759361f * fVec19[((IOTA - 193) & 511)])) + (0.00121536944f * fVec19[((IOTA - 194) & 511)])) + (0.0016832226f * fVec19[((IOTA - 200) & 511)])) + (0.00113653066f * fVec19[((IOTA - 201) & 511)])) + (0.000978094991f * fVec19[((IOTA - 202) & 511)])) + (0.00266840775f * fVec19[((IOTA - 216) & 511)])) + (0.00750964601f * fVec19[((IOTA - 217) & 511)])) + (0.0109134801f * fVec19[((IOTA - 218) & 511)])) + (0.00964466296f * fVec19[((IOTA - 219) & 511)])) + (0.00361359771f * fVec19[((IOTA - 220) & 511)])) + (1.33318827e-05f * fVec19[((IOTA - 231) & 511)])) + (0.000264665112f * fVec19[((IOTA - 232) & 511)])) + (0.000200127717f * fVec19[((IOTA - 328) & 511)])) + (0.000321355648f * fVec19[((IOTA - 354) & 511)])) + (0.000599140301f * fVec19[((IOTA - 363) & 511)])) + (0.000267028809f * fVec19[((IOTA - 364) & 511)])) + (0.00035429094f * fVec19[((IOTA - 368) & 511)])) + (0.00155011751f * fVec19[((IOTA - 369) & 511)])) + (0.00259344699f * fVec19[((IOTA - 370) & 511)])) + (0.0027254615f * fVec19[((IOTA - 371) & 511)])) + (0.0015264838f * fVec19[((IOTA - 372) & 511)])) + (0.00133723393f * fVec19[((IOTA - 379) & 511)])) + (0.00128778536f * fVec19[((IOTA - 380) & 511)])) + (0.011398999f * fVec19[((IOTA - 480) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.010686174f * fVec19[((IOTA - 481) & 511)])) + (0.00801855512f * fVec19[((IOTA - 482) & 511)])) + (0.00523522124f * fVec19[((IOTA - 483) & 511)])) + (0.00221761316f * fVec19[((IOTA - 484) & 511)])) + (2.89054587e-05f * fVec19[((IOTA - 485) & 511)])) + (0.000620258972f * fVec19[((IOTA - 488) & 511)])) + (0.00168076856f * fVec19[((IOTA - 489) & 511)])) + (0.00189701514f * fVec19[((IOTA - 490) & 511)])) + (0.00162598724f * fVec19[((IOTA - 491) & 511)])) + (0.00102696801f * fVec19[((IOTA - 492) & 511)])) + (0.000652012881f * fVec19[((IOTA - 493) & 511)])) + (0.00079332944f * fVec19[((IOTA - 494) & 511)])) + (0.00010550255f * fVec19[((IOTA - 495) & 511)])) + (0.00277194055f * fVec19[((IOTA - 501) & 511)])) + (0.00634969398f * fVec19[((IOTA - 502) & 511)])) + (0.0101101827f * fVec19[((IOTA - 503) & 511)])) + (0.0125378929f * fVec19[((IOTA - 504) & 511)])) + (0.0133648841f * fVec19[((IOTA - 505) & 511)])) + (0.0129640233f * fVec19[((IOTA - 506) & 511)])) + (0.0102149881f * fVec19[((IOTA - 507) & 511)])) + (0.00691471715f * fVec19[((IOTA - 508) & 511)])) + (0.00481490837f * fVec19[((IOTA - 509) & 511)])) + (0.00374155166f * fVec19[((IOTA - 510) & 511)])) + (0.00476721674f * fVec19[((IOTA - 511) & 511)]))) : (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.220582098f * fVec18[((IOTA - 2) & 511)]) + ((0.0943954661f * fVec18[((IOTA - 12) & 511)]) + (((0.182253242f * fVec18[((IOTA - 3) & 511)]) + ((0.101127967f * fVec18[((IOTA - 10) & 511)]) + ((0.245783672f * fVec18[((IOTA - 1) & 511)]) + ((fSlow62 * fTemp0) + ((0.046030432f * fVec18[((IOTA - 4) & 511)]) + (0.121913739f * fVec18[((IOTA - 11) & 511)])))))) + (0.0309976842f * fVec18[((IOTA - 13) & 511)])))) + (0.005838071f * fVec18[((IOTA - 15) & 511)])) + (0.0192708895f * fVec18[((IOTA - 16) & 511)])) + (0.0288049392f * fVec18[((IOTA - 17) & 511)])) + (0.011771745f * fVec18[((IOTA - 18) & 511)])) + (0.0345543213f * fVec18[((IOTA - 23) & 511)])) + (0.0666719154f * fVec18[((IOTA - 24) & 511)])) + (0.0601064488f * fVec18[((IOTA - 25) & 511)])) + (0.025798535f * fVec18[((IOTA - 26) & 511)])) + (0.0201624073f * fVec18[((IOTA - 34) & 511)])) + (0.0321785882f * fVec18[((IOTA - 35) & 511)])) + (0.0391798206f * fVec18[((IOTA - 36) & 511)])) + (0.0323197208f * fVec18[((IOTA - 37) & 511)])) + (0.012728231f * fVec18[((IOTA - 38) & 511)])) + (0.0326717421f * fVec18[((IOTA - 49) & 511)])) + (0.0346459225f * fVec18[((IOTA - 50) & 511)])) + (0.0114995241f * fVec18[((IOTA - 51) & 511)])) + (0.0154918963f * fVec18[((IOTA - 57) & 511)])) + (0.0359833352f * fVec18[((IOTA - 58) & 511)])) + (0.0325015523f * fVec18[((IOTA - 59) & 511)])) + (0.0242364295f * fVec18[((IOTA - 60) & 511)])) + (0.00372734014f * fVec18[((IOTA - 61) & 511)])) + (0.000112406444f * fVec18[((IOTA - 71) & 511)])) + (0.0114911832f * fVec18[((IOTA - 72) & 511)])) + (0.016619632f * fVec18[((IOTA - 73) & 511)])) + (0.0170231853f * fVec18[((IOTA - 74) & 511)])) + (0.00782996509f * fVec18[((IOTA - 75) & 511)])) + (0.000984299928f * fVec18[((IOTA - 80) & 511)])) + (0.000495516695f * fVec18[((IOTA - 81) & 511)])) + (0.00125027215f * fVec18[((IOTA - 89) & 511)])) + (0.00302523933f * fVec18[((IOTA - 90) & 511)])) + (0.000487357844f * fVec18[((IOTA - 91) & 511)])) + (0.00283873407f * fVec18[((IOTA - 95) & 511)])) + (0.00980854407f * fVec18[((IOTA - 96) & 511)])) + (0.00921897031f * fVec18[((IOTA - 97) & 511)])) + (0.000248016324f * fVec18[((IOTA - 105) & 511)])) + (0.00169510581f * fVec18[((IOTA - 106) & 511)])) + (0.000302460045f * fVec18[((IOTA - 107) & 511)])) + (0.000906440429f * fVec18[((IOTA - 128) & 511)])) + (0.00610395195f * fVec18[((IOTA - 129) & 511)])) + (0.00669131055f * fVec18[((IOTA - 130) & 511)])) + (0.00485371007f * fVec18[((IOTA - 131) & 511)])) + (0.000232698862f * fVec18[((IOTA - 137) & 511)])) + (0.000924638938f * fVec18[((IOTA - 138) & 511)])) + (0.000935588498f * fVec18[((IOTA - 139) & 511)])) + (0.00331177562f * fVec18[((IOTA - 148) & 511)])) + (0.007817287f * fVec18[((IOTA - 149) & 511)])) + (0.0105985133f * fVec18[((IOTA - 150) & 511)])) + (0.00957084075f * fVec18[((IOTA - 151) & 511)])) + (0.0046439413f * fVec18[((IOTA - 152) & 511)])) + (0.00293931179f * fVec18[((IOTA - 162) & 511)])) + (0.00563588459f * fVec18[((IOTA - 163) & 511)])) + (0.00533066457f * fVec18[((IOTA - 164) & 511)])) + (0.00248273974f * fVec18[((IOTA - 165) & 511)])) + (0.00071975356f * fVec18[((IOTA - 173) & 511)])) + (0.00244000368f * fVec18[((IOTA - 174) & 511)])) + (0.00282936217f * fVec18[((IOTA - 175) & 511)])) + (0.0014210958f * fVec18[((IOTA - 176) & 511)])) + (0.000457360409f * fVec18[((IOTA - 182) & 511)])) + (0.0033102897f * fVec18[((IOTA - 183) & 511)])) + (0.00433344347f * fVec18[((IOTA - 184) & 511)])) + (0.00461637042f * fVec18[((IOTA - 185) & 511)])) + (0.00393923186f * fVec18[((IOTA - 186) & 511)])) + (0.00243590912f * fVec18[((IOTA - 187) & 511)])) + (0.000678776298f * fVec18[((IOTA - 188) & 511)])) + (0.00129485875f * fVec18[((IOTA - 193) & 511)])) + (0.00299284561f * fVec18[((IOTA - 194) & 511)])) + (0.00413137861f * fVec18[((IOTA - 195) & 511)])) + (0.00332788145f * fVec18[((IOTA - 196) & 511)])) + (0.00150477886f * fVec18[((IOTA - 197) & 511)])) + (8.16206448e-05f * fVec18[((IOTA - 198) & 511)])) + (0.00295887515f * fVec18[((IOTA - 207) & 511)])) + (0.00639761612f * fVec18[((IOTA - 208) & 511)])) + (0.00769432494f * fVec18[((IOTA - 209) & 511)])) + (0.00581319956f * fVec18[((IOTA - 210) & 511)])) + (0.00148369884f * fVec18[((IOTA - 211) & 511)])) + (0.00140119903f * fVec18[((IOTA - 217) & 511)])) + (0.00617516879f * fVec18[((IOTA - 218) & 511)])) + (0.0101459147f * fVec18[((IOTA - 219) & 511)])) + (0.0114593664f * fVec18[((IOTA - 220) & 511)])) + (0.0101974169f * fVec18[((IOTA - 221) & 511)])) + (0.00661390601f * fVec18[((IOTA - 222) & 511)])) + (0.00215947255f * fVec18[((IOTA - 223) & 511)])) + (0.000939986669f * fVec18[((IOTA - 228) & 511)])) + (0.00389082404f * fVec18[((IOTA - 229) & 511)])) + (0.00615493814f * fVec18[((IOTA - 230) & 511)])) + (0.00717633311f * fVec18[((IOTA - 231) & 511)])) + (0.00681915553f * fVec18[((IOTA - 232) & 511)])) + (0.00479253288f * fVec18[((IOTA - 233) & 511)])) + (0.00234895013f * fVec18[((IOTA - 234) & 511)])) + (0.000443165656f * fVec18[((IOTA - 235) & 511)])) + (0.00200527022f * fVec18[((IOTA - 239) & 511)])) + (0.00548507925f * fVec18[((IOTA - 240) & 511)])) + (0.00788170937f * fVec18[((IOTA - 241) & 511)])) + (0.00829954818f * fVec18[((IOTA - 242) & 511)])) + (0.00763469422f * fVec18[((IOTA - 243) & 511)])) + (0.00472713914f * fVec18[((IOTA - 244) & 511)])) + (0.00056712795f * fVec18[((IOTA - 245) & 511)])) + (0.00343309948f * fVec18[((IOTA - 250) & 511)])) + (0.00698045595f * fVec18[((IOTA - 251) & 511)])) + (0.0094710812f * fVec18[((IOTA - 252) & 511)])) + (0.0106862299f * fVec18[((IOTA - 253) & 511)])) + (0.00968473218f * fVec18[((IOTA - 254) & 511)])) + (0.00712971436f * fVec18[((IOTA - 255) & 511)])) + (0.00547749642f * fVec18[((IOTA - 256) & 511)])) + (0.00493578566f * fVec18[((IOTA - 257) & 511)])) + (0.00434311898f * fVec18[((IOTA - 258) & 511)])) + (0.00453247502f * fVec18[((IOTA - 259) & 511)])) + (0.00504312711f * fVec18[((IOTA - 260) & 511)])) + (0.00453032181f * fVec18[((IOTA - 261) & 511)])) + (0.00407675281f * fVec18[((IOTA - 262) & 511)])) + (0.00458115619f * fVec18[((IOTA - 263) & 511)])) + (0.0054615424f * fVec18[((IOTA - 264) & 511)])) + (0.006377446f * fVec18[((IOTA - 265) & 511)])) + (0.00662021525f * fVec18[((IOTA - 266) & 511)])) + (0.00557249319f * fVec18[((IOTA - 267) & 511)])) + (0.00498959282f * fVec18[((IOTA - 268) & 511)])) + (0.00467224f * fVec18[((IOTA - 269) & 511)])) + (0.00433614291f * fVec18[((IOTA - 270) & 511)])) + (0.00488540623f * fVec18[((IOTA - 271) & 511)])) + (0.00489875162f * fVec18[((IOTA - 272) & 511)])) + (0.00431409245f * fVec18[((IOTA - 273) & 511)])) + (0.00395897729f * fVec18[((IOTA - 274) & 511)])) + (0.00369622046f * fVec18[((IOTA - 275) & 511)])) + (0.00368587766f * fVec18[((IOTA - 276) & 511)])) + (0.00435843598f * fVec18[((IOTA - 277) & 511)])) + (0.00504676672f * fVec18[((IOTA - 278) & 511)])) + (0.00498816743f * fVec18[((IOTA - 279) & 511)])) + (0.00401154114f * fVec18[((IOTA - 280) & 511)])) + (0.00189022487f * fVec18[((IOTA - 281) & 511)])) + (0.00162931811f * fVec18[((IOTA - 285) & 511)])) + (0.00389431184f * fVec18[((IOTA - 286) & 511)])) + (0.00601141201f * fVec18[((IOTA - 287) & 511)])) + (0.00799214467f * fVec18[((IOTA - 288) & 511)])) + (0.00851465575f * fVec18[((IOTA - 289) & 511)])) + (0.00769029092f * fVec18[((IOTA - 290) & 511)])) + (0.0064338618f * fVec18[((IOTA - 291) & 511)])) + (0.0045780018f * fVec18[((IOTA - 292) & 511)])) + (0.00294264825f * fVec18[((IOTA - 293) & 511)])) + (0.00215540826f * fVec18[((IOTA - 294) & 511)])) + (0.00233894074f * fVec18[((IOTA - 295) & 511)])) + (0.00373689411f * fVec18[((IOTA - 296) & 511)])) + (0.00570846675f * fVec18[((IOTA - 297) & 511)])) + (0.00727436272f * fVec18[((IOTA - 298) & 511)])) + (0.00843421835f * fVec18[((IOTA - 299) & 511)])) + (0.00852675736f * fVec18[((IOTA - 300) & 511)])) + (0.00698573329f * fVec18[((IOTA - 301) & 511)])) + (0.00485701626f * fVec18[((IOTA - 302) & 511)])) + (0.0032008253f * fVec18[((IOTA - 303) & 511)])) + (0.00267388532f * fVec18[((IOTA - 304) & 511)])) + (0.00378445303f * fVec18[((IOTA - 305) & 511)])) + (0.00496381149f * fVec18[((IOTA - 306) & 511)])) + (0.00576476101f * fVec18[((IOTA - 307) & 511)])) + (0.00636637537f * fVec18[((IOTA - 308) & 511)])) + (0.00567097776f * fVec18[((IOTA - 309) & 511)])) + (0.00451864442f * fVec18[((IOTA - 310) & 511)])) + (0.00339691481f * fVec18[((IOTA - 311) & 511)])) + (0.00209662691f * fVec18[((IOTA - 312) & 511)])) + (0.00170584302f * fVec18[((IOTA - 313) & 511)])) + (0.00116513297f * fVec18[((IOTA - 314) & 511)])) + (0.00149428472f * fVec18[((IOTA - 320) & 511)])) + (0.00301256077f * fVec18[((IOTA - 321) & 511)])) + (0.00366664771f * fVec18[((IOTA - 322) & 511)])) + (0.0023695752f * fVec18[((IOTA - 323) & 511)])) + (0.000864037778f * fVec18[((IOTA - 324) & 511)])) + (0.000331941992f * fVec18[((IOTA - 328) & 511)])) + (0.000966404565f * fVec18[((IOTA - 329) & 511)])) + (0.00178703899f * fVec18[((IOTA - 330) & 511)])) + (0.0027898713f * fVec18[((IOTA - 331) & 511)])) + (0.00400729477f * fVec18[((IOTA - 332) & 511)])) + (0.00564098032f * fVec18[((IOTA - 333) & 511)])) + (0.00648084423f * fVec18[((IOTA - 334) & 511)])) + (0.00609430671f * fVec18[((IOTA - 335) & 511)])) + (0.00471785804f * fVec18[((IOTA - 336) & 511)])) + (0.00222450215f * fVec18[((IOTA - 337) & 511)])) + (0.000364759937f * fVec18[((IOTA - 338) & 511)])) + (0.000170035288f * fVec18[((IOTA - 340) & 511)])) + (0.00176049909f * fVec18[((IOTA - 341) & 511)])) + (0.00340137351f * fVec18[((IOTA - 342) & 511)])) + (0.00438027456f * fVec18[((IOTA - 343) & 511)])) + (0.00530430675f * fVec18[((IOTA - 344) & 511)])) + (0.00540828146f * fVec18[((IOTA - 345) & 511)])) + (0.0045567397f * fVec18[((IOTA - 346) & 511)])) + (0.00406085933f * fVec18[((IOTA - 347) & 511)])) + (0.00323722232f * fVec18[((IOTA - 348) & 511)])) + (0.00225519715f * fVec18[((IOTA - 349) & 511)])) + (0.00196447503f * fVec18[((IOTA - 350) & 511)])) + (0.0016607712f * fVec18[((IOTA - 351) & 511)])) + (0.00171503332f * fVec18[((IOTA - 352) & 511)])) + (0.00214327592f * fVec18[((IOTA - 353) & 511)])) + (0.00196125964f * fVec18[((IOTA - 354) & 511)])) + (0.00156504661f * fVec18[((IOTA - 355) & 511)])) + (0.0010750806f * fVec18[((IOTA - 356) & 511)])) + (0.000242920592f * fVec18[((IOTA - 357) & 511)])) + (0.00032802904f * fVec18[((IOTA - 358) & 511)])) + (0.00101717887f * fVec18[((IOTA - 359) & 511)])) + (0.00101514673f * fVec18[((IOTA - 360) & 511)])) + (0.00071881339f * fVec18[((IOTA - 361) & 511)])) + (0.000928400084f * fVec18[((IOTA - 365) & 511)])) + (0.00317094894f * fVec18[((IOTA - 366) & 511)])) + (0.00555690285f * fVec18[((IOTA - 367) & 511)])) + (0.00585269043f * fVec18[((IOTA - 368) & 511)])) + (0.00397917815f * fVec18[((IOTA - 369) & 511)])) + (0.00105915684f * fVec18[((IOTA - 370) & 511)])) + (0.000918148085f * fVec18[((IOTA - 375) & 511)])) + (0.00329788402f * fVec18[((IOTA - 376) & 511)])) + (0.00390504906f * fVec18[((IOTA - 377) & 511)])) + (0.00366106676f * fVec18[((IOTA - 378) & 511)])) + (0.0027342136f * fVec18[((IOTA - 379) & 511)])) + (0.0016281656f * fVec18[((IOTA - 380) & 511)])) + (0.00095979264f * fVec18[((IOTA - 381) & 511)])) + (0.000722907949f * fVec18[((IOTA - 382) & 511)])) + (0.00101053622f * fVec18[((IOTA - 383) & 511)])) + (0.00156759424f * fVec18[((IOTA - 384) & 511)])) + (0.00200557336f * fVec18[((IOTA - 385) & 511)])) + (0.00220460491f * fVec18[((IOTA - 386) & 511)])) + (0.00175767858f * fVec18[((IOTA - 387) & 511)])) + (0.00119197601f * fVec18[((IOTA - 388) & 511)])) + (0.000948752277f * fVec18[((IOTA - 389) & 511)])) + (0.000438949559f * fVec18[((IOTA - 390) & 511)])) + (0.00156832254f * fVec18[((IOTA - 399) & 511)])) + (0.00344762811f * fVec18[((IOTA - 400) & 511)])) + (0.00449295389f * fVec18[((IOTA - 401) & 511)])) + (0.00397532573f * fVec18[((IOTA - 402) & 511)])) + (0.00253524259f * fVec18[((IOTA - 403) & 511)])) + (0.000759092625f * fVec18[((IOTA - 404) & 511)])) + (0.000256387517f * fVec18[((IOTA - 409) & 511)])) + (0.00103012985f * fVec18[((IOTA - 410) & 511)])) + (0.00125627778f * fVec18[((IOTA - 411) & 511)])) + (0.00145594636f * fVec18[((IOTA - 412) & 511)])) + (0.00115764141f * fVec18[((IOTA - 413) & 511)])) + (0.000783114694f * fVec18[((IOTA - 414) & 511)])) + (0.000380835496f * fVec18[((IOTA - 421) & 511)])) + (0.00178446062f * fVec18[((IOTA - 422) & 511)])) + (0.0033925469f * fVec18[((IOTA - 423) & 511)])) + (0.00428094063f * fVec18[((IOTA - 424) & 511)])) + (0.00424260227f * fVec18[((IOTA - 425) & 511)])) + (0.00329824816f * fVec18[((IOTA - 426) & 511)])) + (0.00144481473f * fVec18[((IOTA - 427) & 511)])) + (0.000741713215f * fVec18[((IOTA - 448) & 511)])) + (0.00103913853f * fVec18[((IOTA - 449) & 511)])) + (0.000474466942f * fVec18[((IOTA - 450) & 511)])) + (0.000643137377f * fVec18[((IOTA - 469) & 511)])) + (0.00154472515f * fVec18[((IOTA - 470) & 511)])) + (0.00217727711f * fVec18[((IOTA - 471) & 511)])) + (0.00175795145f * fVec18[((IOTA - 472) & 511)])) + (0.000111951493f * fVec18[((IOTA - 473) & 511)])) + (4.64366749e-05f * fVec18[((IOTA - 480) & 511)])) + (0.000967102125f * fVec18[((IOTA - 481) & 511)])) + (0.000954514835f * fVec18[((IOTA - 482) & 511)])) + (0.000201488379f * fVec18[((IOTA - 492) & 511)])) + (0.0010391688f * fVec18[((IOTA - 493) & 511)])) + (0.00185488909f * fVec18[((IOTA - 494) & 511)])) + (0.00209790096f * fVec18[((IOTA - 495) & 511)])) + (0.00153580774f * fVec18[((IOTA - 496) & 511)])) - (((((((((((((((((((((((((((((((((((((((((((((0.00312363263f * fVec18[((IOTA - 454) & 511)]) + ((0.0033959439f * fVec18[((IOTA - 453) & 511)]) + ((0.00237336662f * fVec18[((IOTA - 452) & 511)]) + ((0.000659940764f * fVec18[((IOTA - 451) & 511)]) + ((1.51959248e-05f * fVec18[((IOTA - 447) & 511)]) + ((0.000560182147f * fVec18[((IOTA - 446) & 511)]) + ((0.00144338934f * fVec18[((IOTA - 445) & 511)]) + ((0.00238219276f * fVec18[((IOTA - 444) & 511)]) + ((0.00310343225f * fVec18[((IOTA - 443) & 511)]) + ((0.00376619399f * fVec18[((IOTA - 442) & 511)]) + ((0.0038154819f * fVec18[((IOTA - 441) & 511)]) + ((0.00360628916f * fVec18[((IOTA - 440) & 511)]) + ((0.00320179574f * fVec18[((IOTA - 439) & 511)]) + ((0.00224376237f * fVec18[((IOTA - 438) & 511)]) + ((0.00166522991f * fVec18[((IOTA - 437) & 511)]) + ((0.00161679136f * fVec18[((IOTA - 436) & 511)]) + ((0.00178582547f * fVec18[((IOTA - 435) & 511)]) + ((0.0026417044f * fVec18[((IOTA - 434) & 511)]) + ((0.00330667989f * fVec18[((IOTA - 433) & 511)]) + ((0.00326124439f * fVec18[((IOTA - 432) & 511)]) + ((0.00328232441f * fVec18[((IOTA - 431) & 511)]) + ((0.00269466219f * fVec18[((IOTA - 430) & 511)]) + ((0.00137065584f * fVec18[((IOTA - 429) & 511)]) + ((0.000126995612f * fVec18[((IOTA - 428) & 511)]) + ((0.00119237043f * fVec18[((IOTA - 420) & 511)]) + ((0.00257810019f * fVec18[((IOTA - 419) & 511)]) + ((0.00290497718f * fVec18[((IOTA - 418) & 511)]) + ((0.00251058349f * fVec18[((IOTA - 417) & 511)]) + ((0.00154050905f * fVec18[((IOTA - 416) & 511)]) + ((3.01185064e-05f * fVec18[((IOTA - 415) & 511)]) + ((0.0011976175f * fVec18[((IOTA - 408) & 511)]) + ((0.00190830184f * fVec18[((IOTA - 407) & 511)]) + ((0.00186289661f * fVec18[((IOTA - 406) & 511)]) + ((0.00101099117f * fVec18[((IOTA - 405) & 511)]) + ((0.000193177722f * fVec18[((IOTA - 398) & 511)]) + ((0.00159034273f * fVec18[((IOTA - 397) & 511)]) + ((0.00217521423f * fVec18[((IOTA - 396) & 511)]) + ((0.00241346378f * fVec18[((IOTA - 395) & 511)]) + ((0.00232547382f * fVec18[((IOTA - 394) & 511)]) + ((0.00128706358f * fVec18[((IOTA - 393) & 511)]) + ((0.000334550161f * fVec18[((IOTA - 392) & 511)]) + ((8.37133266e-05f * fVec18[((IOTA - 391) & 511)]) + ((0.00202653185f * fVec18[((IOTA - 374) & 511)]) + ((0.00378038874f * fVec18[((IOTA - 373) & 511)]) + ((0.00420738803f * fVec18[((IOTA - 372) & 511)]) + ((0.00232990226f * fVec18[((IOTA - 371) & 511)]) + ((0.000570191536f * fVec18[((IOTA - 364) & 511)]) + ((0.00112115312f * fVec18[((IOTA - 363) & 511)]) + ((0.000205795281f * fVec18[((IOTA - 362) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.154255897f * fVec18[((IOTA - 8) & 511)]) + ((0.22937426f * fVec18[((IOTA - 6) & 511)]) + ((0.236211583f * fVec18[((IOTA - 7) & 511)]) + ((0.14770098f * fVec18[((IOTA - 5) & 511)]) + (0.0034413496f * fVec18[((IOTA - 9) & 511)]))))) + (0.00530958455f * fVec18[((IOTA - 14) & 511)])) + (0.0154134911f * fVec18[((IOTA - 19) & 511)])) + (0.0361245573f * fVec18[((IOTA - 20) & 511)])) + (0.0303503014f * fVec18[((IOTA - 21) & 511)])) + (0.0021255021f * fVec18[((IOTA - 22) & 511)])) + (5.36250882e-05f * fVec18[((IOTA - 27) & 511)])) + (0.0360528529f * fVec18[((IOTA - 28) & 511)])) + (0.0633609295f * fVec18[((IOTA - 29) & 511)])) + (0.0534778908f * fVec18[((IOTA - 30) & 511)])) + (0.0462115668f * fVec18[((IOTA - 31) & 511)])) + (0.0391295329f * fVec18[((IOTA - 32) & 511)])) + (0.00282693561f * fVec18[((IOTA - 33) & 511)])) + (0.0151314437f * fVec18[((IOTA - 39) & 511)])) + (0.0235592928f * fVec18[((IOTA - 40) & 511)])) + (0.0154607464f * fVec18[((IOTA - 41) & 511)])) + (0.00975240115f * fVec18[((IOTA - 42) & 511)])) + (0.00921733305f * fVec18[((IOTA - 43) & 511)])) + (0.0230373871f * fVec18[((IOTA - 44) & 511)])) + (0.0350506268f * fVec18[((IOTA - 45) & 511)])) + (0.0290810727f * fVec18[((IOTA - 46) & 511)])) + (0.0214990024f * fVec18[((IOTA - 47) & 511)])) + (0.00248210272f * fVec18[((IOTA - 48) & 511)])) + (0.0117626153f * fVec18[((IOTA - 52) & 511)])) + (0.0483381301f * fVec18[((IOTA - 53) & 511)])) + (0.0610439777f * fVec18[((IOTA - 54) & 511)])) + (0.042769853f * fVec18[((IOTA - 55) & 511)])) + (0.0198728386f * fVec18[((IOTA - 56) & 511)])) + (0.0121607091f * fVec18[((IOTA - 62) & 511)])) + (0.0169848464f * fVec18[((IOTA - 63) & 511)])) + (0.0202478208f * fVec18[((IOTA - 64) & 511)])) + (0.0236564428f * fVec18[((IOTA - 65) & 511)])) + (0.0284127295f * fVec18[((IOTA - 66) & 511)])) + (0.0312609263f * fVec18[((IOTA - 67) & 511)])) + (0.0299481731f * fVec18[((IOTA - 68) & 511)])) + (0.0221749265f * fVec18[((IOTA - 69) & 511)])) + (0.0129468571f * fVec18[((IOTA - 70) & 511)])) + (0.00253942842f * fVec18[((IOTA - 76) & 511)])) + (0.011139011f * fVec18[((IOTA - 77) & 511)])) + (0.0144959493f * fVec18[((IOTA - 78) & 511)])) + (0.0046499772f * fVec18[((IOTA - 79) & 511)])) + (0.00260667223f * fVec18[((IOTA - 82) & 511)])) + (0.0118054729f * fVec18[((IOTA - 83) & 511)])) + (0.021785114f * fVec18[((IOTA - 84) & 511)])) + (0.0277492702f * fVec18[((IOTA - 85) & 511)])) + (0.0270417407f * fVec18[((IOTA - 86) & 511)])) + (0.0165789574f * fVec18[((IOTA - 87) & 511)])) + (0.00425079139f * fVec18[((IOTA - 88) & 511)])) + (0.00865423866f * fVec18[((IOTA - 92) & 511)])) + (0.00955804065f * fVec18[((IOTA - 93) & 511)])) + (0.0025568991f * fVec18[((IOTA - 94) & 511)])) + (0.000447260216f * fVec18[((IOTA - 98) & 511)])) + (0.0114381956f * fVec18[((IOTA - 99) & 511)])) + (0.0204046909f * fVec18[((IOTA - 100) & 511)])) + (0.022542052f * fVec18[((IOTA - 101) & 511)])) + (0.0188641213f * fVec18[((IOTA - 102) & 511)])) + (0.0113403173f * fVec18[((IOTA - 103) & 511)])) + (0.00311195524f * fVec18[((IOTA - 104) & 511)])) + (0.00353076495f * fVec18[((IOTA - 108) & 511)])) + (0.00605827337f * fVec18[((IOTA - 109) & 511)])) + (0.00609433698f * fVec18[((IOTA - 110) & 511)])) + (0.00514719263f * fVec18[((IOTA - 111) & 511)])) + (0.00619518757f * fVec18[((IOTA - 112) & 511)])) + (0.00788192172f * fVec18[((IOTA - 113) & 511)])) + (0.00737460656f * fVec18[((IOTA - 114) & 511)])) + (0.00801022165f * fVec18[((IOTA - 115) & 511)])) + (0.00890428759f * fVec18[((IOTA - 116) & 511)])) + (0.00892542768f * fVec18[((IOTA - 117) & 511)])) + (0.0108069172f * fVec18[((IOTA - 118) & 511)])) + (0.0127987508f * fVec18[((IOTA - 119) & 511)])) + (0.0129291434f * fVec18[((IOTA - 120) & 511)])) + (0.0121332891f * fVec18[((IOTA - 121) & 511)])) + (0.00983917806f * fVec18[((IOTA - 122) & 511)])) + (0.00706198532f * fVec18[((IOTA - 123) & 511)])) + (0.00650468422f * fVec18[((IOTA - 124) & 511)])) + (0.00592236035f * fVec18[((IOTA - 125) & 511)])) + (0.00406637928f * fVec18[((IOTA - 126) & 511)])) + (0.00340659032f * fVec18[((IOTA - 127) & 511)])) + (0.000260967296f * fVec18[((IOTA - 132) & 511)])) + (0.00549690844f * fVec18[((IOTA - 133) & 511)])) + (0.00776930293f * fVec18[((IOTA - 134) & 511)])) + (0.00732844276f * fVec18[((IOTA - 135) & 511)])) + (0.0031158682f * fVec18[((IOTA - 136) & 511)])) + (0.000679413322f * fVec18[((IOTA - 140) & 511)])) + (0.00215750095f * fVec18[((IOTA - 141) & 511)])) + (0.00285480963f * fVec18[((IOTA - 142) & 511)])) + (0.00534222042f * fVec18[((IOTA - 143) & 511)])) + (0.00835593417f * fVec18[((IOTA - 144) & 511)])) + (0.00901833177f * fVec18[((IOTA - 145) & 511)])) + (0.00716935704f * fVec18[((IOTA - 146) & 511)])) + (0.00268580578f * fVec18[((IOTA - 147) & 511)])) + (0.000842320733f * fVec18[((IOTA - 153) & 511)])) + (0.00574622862f * fVec18[((IOTA - 154) & 511)])) + (0.0092999544f * fVec18[((IOTA - 155) & 511)])) + (0.0109798945f * fVec18[((IOTA - 156) & 511)])) + (0.0124609852f * fVec18[((IOTA - 157) & 511)])) + (0.0126247723f * fVec18[((IOTA - 158) & 511)])) + (0.0103488592f * fVec18[((IOTA - 159) & 511)])) + (0.00648866966f * fVec18[((IOTA - 160) & 511)])) + (0.00155570451f * fVec18[((IOTA - 161) & 511)])) + (0.000790788326f * fVec18[((IOTA - 166) & 511)])) + (0.00454023993f * fVec18[((IOTA - 167) & 511)])) + (0.00696516875f * fVec18[((IOTA - 168) & 511)])) + (0.00736386934f * fVec18[((IOTA - 169) & 511)])) + (0.00639649387f * fVec18[((IOTA - 170) & 511)])) + (0.00450147688f * fVec18[((IOTA - 171) & 511)])) + (0.00211755512f * fVec18[((IOTA - 172) & 511)])) + (0.00189805031f * fVec18[((IOTA - 177) & 511)])) + (0.00455137109f * fVec18[((IOTA - 178) & 511)])) + (0.00666273898f * fVec18[((IOTA - 179) & 511)])) + (0.00630474277f * fVec18[((IOTA - 180) & 511)])) + (0.00308535527f * fVec18[((IOTA - 181) & 511)])) + (0.000990366098f * fVec18[((IOTA - 189) & 511)])) + (0.0019475501f * fVec18[((IOTA - 190) & 511)])) + (0.0021881354f * fVec18[((IOTA - 191) & 511)])) + (0.000967648346f * fVec18[((IOTA - 192) & 511)])) + (0.00205201004f * fVec18[((IOTA - 199) & 511)])) + (0.00341568934f * fVec18[((IOTA - 200) & 511)])) + (0.00288144033f * fVec18[((IOTA - 201) & 511)])) + (0.00286794314f * fVec18[((IOTA - 202) & 511)])) + (0.00266524125f * fVec18[((IOTA - 203) & 511)])) + (0.00234603835f * fVec18[((IOTA - 204) & 511)])) + (0.00269393437f * fVec18[((IOTA - 205) & 511)])) + (0.000970195979f * fVec18[((IOTA - 206) & 511)])) + (0.0026621474f * fVec18[((IOTA - 212) & 511)])) + (0.00553903822f * fVec18[((IOTA - 213) & 511)])) + (0.00746675162f * fVec18[((IOTA - 214) & 511)])) + (0.00659591984f * fVec18[((IOTA - 215) & 511)])) + (0.0028847158f * fVec18[((IOTA - 216) & 511)])) + (0.00148415379f * fVec18[((IOTA - 224) & 511)])) + (0.00398773141f * fVec18[((IOTA - 225) & 511)])) + (0.0041740844f * fVec18[((IOTA - 226) & 511)])) + (0.00192807801f * fVec18[((IOTA - 227) & 511)])) + (0.00164236035f * fVec18[((IOTA - 236) & 511)])) + (0.00239311205f * fVec18[((IOTA - 237) & 511)])) + (0.000775986817f * fVec18[((IOTA - 238) & 511)])) + (0.00242068293f * fVec18[((IOTA - 246) & 511)])) + (0.00413322868f * fVec18[((IOTA - 247) & 511)])) + (0.0038812696f * fVec18[((IOTA - 248) & 511)])) + (0.000901829917f * fVec18[((IOTA - 249) & 511)])) + (0.000281623099f * fVec18[((IOTA - 282) & 511)])) + (0.00119325006f * fVec18[((IOTA - 283) & 511)])) + (0.000443954021f * fVec18[((IOTA - 284) & 511)])) + (0.000359755475f * fVec18[((IOTA - 315) & 511)])) + (0.00154930493f * fVec18[((IOTA - 316) & 511)])) + (0.00228595268f * fVec18[((IOTA - 317) & 511)])) + (0.00176756643f * fVec18[((IOTA - 318) & 511)])) + (8.42595473e-05f * fVec18[((IOTA - 319) & 511)])) + (0.0003612414f * fVec18[((IOTA - 325) & 511)])) + (0.00129561685f * fVec18[((IOTA - 326) & 511)])) + (0.000756605528f * fVec18[((IOTA - 327) & 511)])) + (0.000150775071f * fVec18[((IOTA - 339) & 511)])) + (0.00262217131f * fVec18[((IOTA - 455) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00211424939f * fVec18[((IOTA - 456) & 511)])) + (0.0013081436f * fVec18[((IOTA - 457) & 511)])) + (0.00109755574f * fVec18[((IOTA - 458) & 511)])) + (0.00144563382f * fVec18[((IOTA - 459) & 511)])) + (0.00156362122f * fVec18[((IOTA - 460) & 511)])) + (0.00162252365f * fVec18[((IOTA - 461) & 511)])) + (0.00172674097f * fVec18[((IOTA - 462) & 511)])) + (0.00195037108f * fVec18[((IOTA - 463) & 511)])) + (0.00262359669f * fVec18[((IOTA - 464) & 511)])) + (0.00288159167f * fVec18[((IOTA - 465) & 511)])) + (0.00250454806f * fVec18[((IOTA - 466) & 511)])) + (0.00193945179f * fVec18[((IOTA - 467) & 511)])) + (0.000789059792f * fVec18[((IOTA - 468) & 511)])) + (0.00150380842f * fVec18[((IOTA - 474) & 511)])) + (0.0030278475f * fVec18[((IOTA - 475) & 511)])) + (0.00387177616f * fVec18[((IOTA - 476) & 511)])) + (0.00390429096f * fVec18[((IOTA - 477) & 511)])) + (0.0033453824f * fVec18[((IOTA - 478) & 511)])) + (0.00172916753f * fVec18[((IOTA - 479) & 511)])) + (0.000140280463f * fVec18[((IOTA - 483) & 511)])) + (0.00154317822f * fVec18[((IOTA - 484) & 511)])) + (0.0024353629f * fVec18[((IOTA - 485) & 511)])) + (0.00305757206f * fVec18[((IOTA - 486) & 511)])) + (0.00257712975f * fVec18[((IOTA - 487) & 511)])) + (0.00141051039f * fVec18[((IOTA - 488) & 511)])) + (0.00089233648f * fVec18[((IOTA - 489) & 511)])) + (0.00042366283f * fVec18[((IOTA - 490) & 511)])) + (6.3482672e-05f * fVec18[((IOTA - 491) & 511)])) + (0.000257206615f * fVec18[((IOTA - 497) & 511)])) + (0.00271765329f * fVec18[((IOTA - 498) & 511)])) + (0.0044608335f * fVec18[((IOTA - 499) & 511)])) + (0.00539475353f * fVec18[((IOTA - 500) & 511)])) + (0.00533812586f * fVec18[((IOTA - 501) & 511)])) + (0.00396173773f * fVec18[((IOTA - 502) & 511)])) + (0.00267955754f * fVec18[((IOTA - 503) & 511)])) + (0.00171466917f * fVec18[((IOTA - 504) & 511)])) + (0.0012918557f * fVec18[((IOTA - 505) & 511)])) + (0.00189395528f * fVec18[((IOTA - 506) & 511)])) + (0.00286903465f * fVec18[((IOTA - 507) & 511)])) + (0.00389692048f * fVec18[((IOTA - 508) & 511)])) + (0.00474639935f * fVec18[((IOTA - 509) & 511)])) + (0.00463105086f * fVec18[((IOTA - 510) & 511)])) + (0.00392898032f * fVec18[((IOTA - 511) & 511)]))))) : (iSlow48 ? (iSlow54 ? ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0188684836f * fVec17[((IOTA - 269) & 511)]) + ((0.0242995229f * fVec17[((IOTA - 268) & 511)]) + ((0.0293037593f * fVec17[((IOTA - 267) & 511)]) + ((0.0314958058f * fVec17[((IOTA - 266) & 511)]) + ((0.0315779373f * fVec17[((IOTA - 265) & 511)]) + ((0.0286011491f * fVec17[((IOTA - 264) & 511)]) + ((0.0234530773f * fVec17[((IOTA - 263) & 511)]) + ((0.018174611f * fVec17[((IOTA - 262) & 511)]) + ((0.0137777459f * fVec17[((IOTA - 261) & 511)]) + ((0.0111938901f * fVec17[((IOTA - 260) & 511)]) + ((0.0103726592f * fVec17[((IOTA - 259) & 511)]) + ((0.00980489515f * fVec17[((IOTA - 258) & 511)]) + ((0.00821360759f * fVec17[((IOTA - 257) & 511)]) + ((0.00469048228f * fVec17[((IOTA - 256) & 511)]) + ((0.000504855067f * fVec17[((IOTA - 255) & 511)]) + ((0.00225408096f * fVec17[((IOTA - 247) & 511)]) + ((0.0071548433f * fVec17[((IOTA - 246) & 511)]) + ((0.0123268813f * fVec17[((IOTA - 245) & 511)]) + ((0.016536599f * fVec17[((IOTA - 244) & 511)]) + ((0.0171368979f * fVec17[((IOTA - 243) & 511)]) + ((0.0132384822f * fVec17[((IOTA - 242) & 511)]) + ((0.00580853596f * fVec17[((IOTA - 241) & 511)]) + ((0.00986102223f * (fVec17[((IOTA - 207) & 511)] - fVec17[((IOTA - 238) & 511)])) + ((0.000680975616f * fVec17[((IOTA - 235) & 511)]) + ((0.00618149759f * fVec17[((IOTA - 234) & 511)]) + ((0.0101535991f * fVec17[((IOTA - 233) & 511)]) + ((0.0124502033f * fVec17[((IOTA - 232) & 511)]) + ((0.0142550571f * fVec17[((IOTA - 231) & 511)]) + ((0.0149018317f * fVec17[((IOTA - 230) & 511)]) + ((0.014819867f * fVec17[((IOTA - 229) & 511)]) + ((0.0149609968f * fVec17[((IOTA - 228) & 511)]) + ((0.0151129439f * fVec17[((IOTA - 227) & 511)]) + ((0.0139279459f * fVec17[((IOTA - 226) & 511)]) + ((0.0104620298f * fVec17[((IOTA - 225) & 511)]) + ((7.58073293e-05f * fVec17[((IOTA - 221) & 511)]) + ((0.00710166991f * fVec17[((IOTA - 220) & 511)]) + ((0.0139980521f * fVec17[((IOTA - 219) & 511)]) + ((0.0168037955f * fVec17[((IOTA - 218) & 511)]) + ((0.0129789822f * fVec17[((IOTA - 217) & 511)]) + ((0.00636951812f * fVec17[((IOTA - 216) & 511)]) + ((0.000297196209f * fVec17[((IOTA - 215) & 511)]) + ((0.00407957193f * fVec17[((IOTA - 212) & 511)]) + ((0.0045618345f * fVec17[((IOTA - 224) & 511)]) + ((0.0105502363f * fVec17[((IOTA - 211) & 511)]) + ((0.0153065808f * fVec17[((IOTA - 210) & 511)]) + ((0.0152646005f * fVec17[((IOTA - 209) & 511)]) + ((0.0124645988f * fVec17[((IOTA - 208) & 511)]) + ((0.00800590683f * fVec17[((IOTA - 206) & 511)]) + ((0.00733312778f * fVec17[((IOTA - 205) & 511)]) + ((0.00730820512f * fVec17[((IOTA - 204) & 511)]) + ((0.00853081606f * fVec17[((IOTA - 203) & 511)]) + ((0.0087404307f * fVec17[((IOTA - 202) & 511)]) + ((0.00635062857f * fVec17[((IOTA - 201) & 511)]) + ((0.00270501385f * fVec17[((IOTA - 200) & 511)]) + ((0.00226132059f * fVec17[((IOTA - 196) & 511)]) + ((0.00833921786f * fVec17[((IOTA - 195) & 511)]) + ((0.0159586817f * fVec17[((IOTA - 194) & 511)]) + ((0.0223089773f * fVec17[((IOTA - 193) & 511)]) + ((0.0267134979f * fVec17[((IOTA - 192) & 511)]) + ((0.0292034466f * fVec17[((IOTA - 191) & 511)]) + ((0.0298007932f * fVec17[((IOTA - 190) & 511)]) + ((0.0289945826f * fVec17[((IOTA - 189) & 511)]) + ((0.0260618553f * fVec17[((IOTA - 188) & 511)]) + ((0.0220746081f * fVec17[((IOTA - 187) & 511)]) + ((0.0179034583f * fVec17[((IOTA - 186) & 511)]) + ((0.0140409078f * fVec17[((IOTA - 185) & 511)]) + ((0.00942956097f * fVec17[((IOTA - 184) & 511)]) + ((0.0044812425f * fVec17[((IOTA - 183) & 511)]) + ((0.00166206015f * fVec17[((IOTA - 172) & 511)]) + ((0.00460614543f * fVec17[((IOTA - 171) & 511)]) + ((0.00686467858f * fVec17[((IOTA - 170) & 511)]) + ((0.00776625285f * fVec17[((IOTA - 169) & 511)]) + ((0.00599647313f * fVec17[((IOTA - 168) & 511)]) + ((0.00258997129f * fVec17[((IOTA - 167) & 511)]) + ((((((((((((((((((((((((((((((0.0306290574f * fVec17[((IOTA - 24) & 511)]) + ((0.0167565718f * fVec17[((IOTA - 23) & 511)]) + ((0.00986713823f * fVec17[((IOTA - 22) & 511)]) + ((0.00281676929f * fVec17[((IOTA - 20) & 511)]) + ((0.0340878591f * fVec17[((IOTA - 19) & 511)]) + ((0.049862016f * fVec17[((IOTA - 18) & 511)]) + ((0.0332610495f * fVec17[((IOTA - 17) & 511)]) + ((0.0234470852f * fVec17[((IOTA - 16) & 511)]) + ((0.0109217837f * fVec17[((IOTA - 15) & 511)]) + ((0.0121953618f * fVec17[((IOTA - 14) & 511)]) + ((0.0826487914f * fVec17[((IOTA - 13) & 511)]) + ((0.173208922f * fVec17[((IOTA - 12) & 511)]) + ((0.220692322f * fVec17[((IOTA - 11) & 511)]) + ((0.186379462f * fVec17[((IOTA - 10) & 511)]) + ((0.0756424814f * fVec17[((IOTA - 9) & 511)]) + ((0.0593351386f * fVec17[((IOTA - 5) & 511)]) + ((0.229251102f * fVec17[((IOTA - 4) & 511)]) + ((0.337154984f * fVec17[((IOTA - 3) & 511)]) + ((0.309833527f * fVec17[((IOTA - 2) & 511)]) + ((0.256866038f * fVec17[((IOTA - 1) & 511)]) + ((fSlow58 * fTemp0) + (0.00918487273f * fVec17[((IOTA - 25) & 511)])))))))))))))))))))))) + (0.0085035637f * fVec17[((IOTA - 57) & 511)])) + (0.0154185034f * fVec17[((IOTA - 58) & 511)])) + (0.0185332187f * fVec17[((IOTA - 59) & 511)])) + (0.0217006058f * fVec17[((IOTA - 60) & 511)])) + (0.0244819671f * fVec17[((IOTA - 61) & 511)])) + (0.0286070984f * fVec17[((IOTA - 62) & 511)])) + (0.0273491628f * fVec17[((IOTA - 63) & 511)])) + (0.0142725315f * fVec17[((IOTA - 64) & 511)])) + (0.00642448058f * fVec17[((IOTA - 72) & 511)])) + (0.0093234228f * fVec17[((IOTA - 73) & 511)])) + (0.000678021926f * fVec17[((IOTA - 74) & 511)])) + (7.87614845e-05f * fVec17[((IOTA - 90) & 511)])) + (0.00123251323f * fVec17[((IOTA - 118) & 511)])) + (0.00437123468f * fVec17[((IOTA - 119) & 511)])) + (0.0034865113f * fVec17[((IOTA - 120) & 511)])) + (0.00111572351f * fVec17[((IOTA - 121) & 511)])) + (0.00262795808f * fVec17[((IOTA - 130) & 511)])) + (0.00820212439f * fVec17[((IOTA - 131) & 511)])) + (0.00932496227f * fVec17[((IOTA - 132) & 511)])) + (0.00572511461f * fVec17[((IOTA - 133) & 511)])) + (0.000909687486f * fVec17[((IOTA - 134) & 511)])) + (0.000621894374f * fVec17[((IOTA - 139) & 511)])) + (0.00210508751f * fVec17[((IOTA - 140) & 511)])) + (0.00282517355f * fVec17[((IOTA - 141) & 511)])) + (0.000107761007f * fVec17[((IOTA - 142) & 511)])) + (0.00480336091f * fVec17[((IOTA - 150) & 511)])) + (0.00482133497f * fVec17[((IOTA - 151) & 511)])) + (0.0147570409f * fVec17[((IOTA - 270) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.0120729133f * fVec17[((IOTA - 271) & 511)])) + (0.0109143769f * fVec17[((IOTA - 272) & 511)])) + (0.0114781056f * fVec17[((IOTA - 273) & 511)])) + (0.0119973561f * fVec17[((IOTA - 274) & 511)])) + (0.0115179643f * fVec17[((IOTA - 275) & 511)])) + (0.0111135487f * fVec17[((IOTA - 276) & 511)])) + (0.0108130649f * fVec17[((IOTA - 277) & 511)])) + (0.01043199f * fVec17[((IOTA - 278) & 511)])) + (0.0113558657f * fVec17[((IOTA - 279) & 511)])) + (0.0122625986f * fVec17[((IOTA - 280) & 511)])) + (0.0122283977f * fVec17[((IOTA - 281) & 511)])) + (0.010493068f * fVec17[((IOTA - 282) & 511)])) + (0.00607552566f * fVec17[((IOTA - 283) & 511)])) + (0.000219558366f * fVec17[((IOTA - 284) & 511)])) + (0.00274620438f * fVec17[((IOTA - 299) & 511)])) + (0.00862717722f * fVec17[((IOTA - 300) & 511)])) + (0.0145048629f * fVec17[((IOTA - 301) & 511)])) + (0.0195544939f * fVec17[((IOTA - 302) & 511)])) + (0.0225291606f * fVec17[((IOTA - 303) & 511)])) + (0.0230980888f * fVec17[((IOTA - 304) & 511)])) + (0.0197811257f * fVec17[((IOTA - 305) & 511)])) + (0.0136426911f * fVec17[((IOTA - 306) & 511)])) + (0.00772077683f * fVec17[((IOTA - 307) & 511)])) + (0.00314625213f * fVec17[((IOTA - 308) & 511)])) + (0.00260648923f * fVec17[((IOTA - 316) & 511)])) + (0.00582634332f * fVec17[((IOTA - 317) & 511)])) + (0.00734248897f * fVec17[((IOTA - 318) & 511)])) + (0.0058899601f * fVec17[((IOTA - 319) & 511)])) + (0.00256650522f * fVec17[((IOTA - 320) & 511)])) + (0.00371310068f * fVec17[((IOTA - 324) & 511)])) + (0.00822721235f * fVec17[((IOTA - 325) & 511)])) + (0.0116116209f * fVec17[((IOTA - 326) & 511)])) + (0.0119846668f * fVec17[((IOTA - 327) & 511)])) + (0.00896323379f * fVec17[((IOTA - 328) & 511)])) + (0.00470184069f * fVec17[((IOTA - 329) & 511)])) + (0.000900284387f * fVec17[((IOTA - 330) & 511)])) + (4.41032462e-05f * fVec17[((IOTA - 336) & 511)])) + (0.000887760893f * fVec17[((IOTA - 339) & 511)])) + (0.00302238902f * fVec17[((IOTA - 340) & 511)])) + (0.00572544709f * fVec17[((IOTA - 341) & 511)])) + (0.00875008292f * fVec17[((IOTA - 342) & 511)])) + (0.0111384708f * fVec17[((IOTA - 343) & 511)])) + (0.0119110225f * fVec17[((IOTA - 344) & 511)])) + (0.0110456049f * fVec17[((IOTA - 345) & 511)])) + (0.00879160687f * fVec17[((IOTA - 346) & 511)])) + (0.00599239534f * fVec17[((IOTA - 347) & 511)])) + (0.00312549016f * fVec17[((IOTA - 348) & 511)])) + (0.000629216898f * fVec17[((IOTA - 349) & 511)])) + (0.00064348802f * fVec17[((IOTA - 386) & 511)])) + (0.00108763902f * fVec17[((IOTA - 387) & 511)])) + (0.000917260069f * fVec17[((IOTA - 388) & 511)])) + (0.000341174193f * fVec17[((IOTA - 389) & 511)])) + (0.000127108302f * fVec17[((IOTA - 396) & 511)])) + (0.00190508459f * fVec17[((IOTA - 397) & 511)])) + (0.00396232447f * fVec17[((IOTA - 398) & 511)])) + (0.00595453335f * fVec17[((IOTA - 399) & 511)])) + (0.00713495538f * fVec17[((IOTA - 400) & 511)])) + (0.0071980725f * fVec17[((IOTA - 401) & 511)])) + (0.00589536875f * fVec17[((IOTA - 402) & 511)])) + (0.00417888723f * fVec17[((IOTA - 403) & 511)])) + (0.00303699309f * fVec17[((IOTA - 404) & 511)])) + (0.00297828624f * fVec17[((IOTA - 405) & 511)])) + (0.0036324258f * fVec17[((IOTA - 406) & 511)])) + (0.00412251009f * fVec17[((IOTA - 407) & 511)])) + (0.00368322711f * fVec17[((IOTA - 408) & 511)])) + (0.00270534679f * fVec17[((IOTA - 409) & 511)])) + (0.00133444974f * fVec17[((IOTA - 410) & 511)])) + (8.83308239e-05f * fVec17[((IOTA - 411) & 511)])) + (3.93600203e-05f * fVec17[((IOTA - 413) & 511)])) + (0.00141058955f * fVec17[((IOTA - 414) & 511)])) + (0.00291629229f * fVec17[((IOTA - 415) & 511)])) + (0.00292931497f * fVec17[((IOTA - 416) & 511)])) + (0.00148460781f * fVec17[((IOTA - 417) & 511)])) + (9.88156535e-05f * fVec17[((IOTA - 426) & 511)])) + (0.000893918332f * fVec17[((IOTA - 427) & 511)])) + (0.00127403671f * fVec17[((IOTA - 428) & 511)])) + (0.00154955592f * fVec17[((IOTA - 429) & 511)])) + (0.00204754574f * fVec17[((IOTA - 430) & 511)])) + (0.00190279633f * fVec17[((IOTA - 431) & 511)])) + (0.00112304604f * fVec17[((IOTA - 432) & 511)])) + (0.000391019043f * fVec17[((IOTA - 433) & 511)])) + (1.41463242e-05f * fVec17[((IOTA - 441) & 511)])) + (0.000552535988f * fVec17[((IOTA - 442) & 511)])) + (0.000581993721f * fVec17[((IOTA - 443) & 511)])) + (0.000367969275f * fVec17[((IOTA - 444) & 511)])) + (0.00102664391f * fVec17[((IOTA - 445) & 511)])) + (0.00289727794f * fVec17[((IOTA - 446) & 511)])) + (0.00562355248f * fVec17[((IOTA - 447) & 511)])) + (0.00819222163f * fVec17[((IOTA - 448) & 511)])) + (0.00975471735f * fVec17[((IOTA - 449) & 511)])) + (0.0104497559f * fVec17[((IOTA - 450) & 511)])) + (0.0096391337f * fVec17[((IOTA - 451) & 511)])) + (0.0079200305f * fVec17[((IOTA - 452) & 511)])) + (0.00601532077f * fVec17[((IOTA - 453) & 511)])) + (0.00346674817f * fVec17[((IOTA - 454) & 511)])) + (7.8054145e-05f * fVec17[((IOTA - 455) & 511)])) + (0.000888426322f * fVec17[((IOTA - 468) & 511)])) + (0.00185361737f * fVec17[((IOTA - 469) & 511)])) + (0.00178155443f * fVec17[((IOTA - 470) & 511)])) + (0.000913640019f * fVec17[((IOTA - 471) & 511)])) + (0.000396635849f * fVec17[((IOTA - 478) & 511)])) + (0.000774674118f * fVec17[((IOTA - 479) & 511)])) + (0.000688464846f * fVec17[((IOTA - 480) & 511)])) + (0.000212110579f * fVec17[((IOTA - 481) & 511)])) + (0.000433291309f * fVec17[((IOTA - 486) & 511)])) + (0.00307539618f * fVec17[((IOTA - 487) & 511)])) + (0.00500798272f * fVec17[((IOTA - 488) & 511)])) + (0.00597130088f * fVec17[((IOTA - 489) & 511)])) + (0.00644245464f * fVec17[((IOTA - 490) & 511)])) + (0.00702357432f * fVec17[((IOTA - 491) & 511)])) + (0.00726955291f * fVec17[((IOTA - 492) & 511)])) + (0.00728931604f * fVec17[((IOTA - 493) & 511)])) + (0.00735846628f * fVec17[((IOTA - 494) & 511)])) + (0.00673557306f * fVec17[((IOTA - 495) & 511)])) + (0.00543823652f * fVec17[((IOTA - 496) & 511)])) + (0.00418725004f * fVec17[((IOTA - 497) & 511)])) + (0.00283474335f * fVec17[((IOTA - 498) & 511)])) + (0.00155966636f * fVec17[((IOTA - 499) & 511)])) + (0.00080617005f * fVec17[((IOTA - 500) & 511)])) + (0.000475397334f * fVec17[((IOTA - 501) & 511)])) + (0.00028263405f * fVec17[((IOTA - 502) & 511)])) - ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00604144949f * fVec17[((IOTA - 163) & 511)]) + ((0.00712230662f * fVec17[((IOTA - 162) & 511)]) + ((0.00994847901f * fVec17[((IOTA - 161) & 511)]) + ((0.0145388143f * fVec17[((IOTA - 160) & 511)]) + ((0.0192548856f * fVec17[((IOTA - 159) & 511)]) + ((0.0234356858f * fVec17[((IOTA - 158) & 511)]) + ((0.025245782f * fVec17[((IOTA - 157) & 511)]) + ((0.0254615955f * fVec17[((IOTA - 156) & 511)]) + ((0.0233413633f * fVec17[((IOTA - 155) & 511)]) + ((0.0174846053f * fVec17[((IOTA - 154) & 511)]) + ((0.00970212556f * fVec17[((IOTA - 153) & 511)]) + ((0.00163222803f * fVec17[((IOTA - 152) & 511)]) + ((0.000645693392f * fVec17[((IOTA - 149) & 511)]) + ((0.00872495212f * fVec17[((IOTA - 148) & 511)]) + ((0.0180787481f * fVec17[((IOTA - 147) & 511)]) + ((0.0235099941f * fVec17[((IOTA - 146) & 511)]) + ((0.0215117112f * fVec17[((IOTA - 145) & 511)]) + ((0.0152999237f * fVec17[((IOTA - 144) & 511)]) + ((0.00681108935f * fVec17[((IOTA - 143) & 511)]) + ((0.00237677898f * fVec17[((IOTA - 138) & 511)]) + ((0.00386558939f * fVec17[((IOTA - 137) & 511)]) + ((0.00418388005f * fVec17[((IOTA - 136) & 511)]) + ((0.00286187092f * fVec17[((IOTA - 135) & 511)]) + (((((((((((((((((((((0.0139238266f * fVec17[((IOTA - 106) & 511)]) + ((0.0141292801f * fVec17[((IOTA - 105) & 511)]) + ((0.0132090244f * fVec17[((IOTA - 104) & 511)]) + ((0.0163728762f * fVec17[((IOTA - 103) & 511)]) + ((0.0213479474f * fVec17[((IOTA - 102) & 511)]) + ((0.0241256058f * fVec17[((IOTA - 101) & 511)]) + ((0.0244475175f * fVec17[((IOTA - 100) & 511)]) + ((0.0242218841f * fVec17[((IOTA - 99) & 511)]) + ((0.0199805871f * fVec17[((IOTA - 98) & 511)]) + ((0.0211912151f * fVec17[((IOTA - 97) & 511)]) + ((0.0240548756f * fVec17[((IOTA - 96) & 511)]) + ((0.0276276376f * fVec17[((IOTA - 95) & 511)]) + ((0.0293769874f * fVec17[((IOTA - 94) & 511)]) + ((0.0224027596f * fVec17[((IOTA - 93) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((0.00591933401f * fVec17[((IOTA - 21) & 511)]) + ((0.0557778105f * fVec17[((IOTA - 8) & 511)]) + ((0.12084876f * fVec17[((IOTA - 7) & 511)]) + ((0.0576576814f * fVec17[((IOTA - 6) & 511)]) + ((((((0.0347777791f * fVec17[((IOTA - 26) & 511)]) + ((0.071709156f * fVec17[((IOTA - 29) & 511)]) + ((0.0593365505f * fVec17[((IOTA - 28) & 511)]) + (((0.0531078316f * fVec17[((IOTA - 27) & 511)]) + (0.0715043321f * fVec17[((IOTA - 30) & 511)])) + (0.0690328926f * fVec17[((IOTA - 31) & 511)]))))) + (0.084463343f * fVec17[((IOTA - 32) & 511)])) + (0.0904382169f * fVec17[((IOTA - 33) & 511)])) + (0.0834011212f * fVec17[((IOTA - 34) & 511)])) + (0.0901615322f * fVec17[((IOTA - 35) & 511)])))))) + (0.0789931491f * fVec17[((IOTA - 36) & 511)])) + (0.0728281289f * fVec17[((IOTA - 37) & 511)])) + (0.0824469998f * fVec17[((IOTA - 38) & 511)])) + (0.0848504081f * fVec17[((IOTA - 39) & 511)])) + (0.0921056047f * fVec17[((IOTA - 40) & 511)])) + (0.0834896192f * fVec17[((IOTA - 41) & 511)])) + (0.0628968775f * fVec17[((IOTA - 42) & 511)])) + (0.0484417714f * fVec17[((IOTA - 43) & 511)])) + (0.0346066505f * fVec17[((IOTA - 44) & 511)])) + (0.0219937656f * fVec17[((IOTA - 45) & 511)])) + (0.0128856162f * fVec17[((IOTA - 46) & 511)])) + (0.0124896038f * fVec17[((IOTA - 47) & 511)])) + (0.00789053179f * fVec17[((IOTA - 48) & 511)])) + (0.00439524185f * fVec17[((IOTA - 49) & 511)])) + (0.0201737676f * fVec17[((IOTA - 50) & 511)])) + (0.0328439847f * fVec17[((IOTA - 51) & 511)])) + (0.0436605029f * fVec17[((IOTA - 52) & 511)])) + (0.0534270778f * fVec17[((IOTA - 53) & 511)])) + (0.043347083f * fVec17[((IOTA - 54) & 511)])) + (0.0279835407f * fVec17[((IOTA - 55) & 511)])) + (0.0118020959f * fVec17[((IOTA - 56) & 511)])) + (0.00317504397f * fVec17[((IOTA - 65) & 511)])) + (0.0303238723f * fVec17[((IOTA - 66) & 511)])) + (0.0506816246f * fVec17[((IOTA - 67) & 511)])) + (0.0523941927f * fVec17[((IOTA - 68) & 511)])) + (0.0457339697f * fVec17[((IOTA - 69) & 511)])) + (0.0285846312f * fVec17[((IOTA - 70) & 511)])) + (0.00473620789f * fVec17[((IOTA - 71) & 511)])) + (0.0158829987f * fVec17[((IOTA - 75) & 511)])) + (0.0333386064f * fVec17[((IOTA - 76) & 511)])) + (0.0422357246f * fVec17[((IOTA - 77) & 511)])) + (0.0414566025f * fVec17[((IOTA - 78) & 511)])) + (0.0339043736f * fVec17[((IOTA - 79) & 511)])) + (0.0237231031f * fVec17[((IOTA - 80) & 511)])) + (0.0143644828f * fVec17[((IOTA - 81) & 511)])) + (0.00936948135f * fVec17[((IOTA - 82) & 511)])) + (0.0100368522f * fVec17[((IOTA - 83) & 511)])) + (0.0167796221f * fVec17[((IOTA - 84) & 511)])) + (0.0284157507f * fVec17[((IOTA - 85) & 511)])) + (0.0325987972f * fVec17[((IOTA - 86) & 511)])) + (0.0269285217f * fVec17[((IOTA - 87) & 511)])) + (0.0195338149f * fVec17[((IOTA - 88) & 511)])) + (0.0100094322f * fVec17[((IOTA - 89) & 511)])) + (0.00316443434f * fVec17[((IOTA - 91) & 511)])) + (0.0121916588f * fVec17[((IOTA - 92) & 511)])) + (0.014288092f * fVec17[((IOTA - 107) & 511)])))))))))))))))) + (0.0136616211f * fVec17[((IOTA - 108) & 511)])) + (0.010012636f * fVec17[((IOTA - 109) & 511)])) + (0.00769556314f * fVec17[((IOTA - 110) & 511)])) + (0.00954793207f * fVec17[((IOTA - 111) & 511)])) + (0.0128217917f * fVec17[((IOTA - 112) & 511)])) + (0.0180202071f * fVec17[((IOTA - 113) & 511)])) + (0.0196198579f * fVec17[((IOTA - 114) & 511)])) + (0.0168710314f * fVec17[((IOTA - 115) & 511)])) + (0.0115275346f * fVec17[((IOTA - 116) & 511)])) + (0.00453021331f * fVec17[((IOTA - 117) & 511)])) + (0.00248420751f * fVec17[((IOTA - 122) & 511)])) + (0.00915183686f * fVec17[((IOTA - 123) & 511)])) + (0.0164718162f * fVec17[((IOTA - 124) & 511)])) + (0.0201416463f * fVec17[((IOTA - 125) & 511)])) + (0.0209882595f * fVec17[((IOTA - 126) & 511)])) + (0.0188618675f * fVec17[((IOTA - 127) & 511)])) + (0.0104745943f * fVec17[((IOTA - 128) & 511)])) + (0.00237116218f * fVec17[((IOTA - 129) & 511)])) + (0.0041212202f * fVec17[((IOTA - 164) & 511)]))))))))))))))))))))))))) + (0.00248724455f * fVec17[((IOTA - 165) & 511)])) + (0.000609911513f * fVec17[((IOTA - 166) & 511)])) + (0.00133162038f * fVec17[((IOTA - 173) & 511)])) + (0.0033091004f * fVec17[((IOTA - 174) & 511)])) + (0.00456191786f * fVec17[((IOTA - 175) & 511)])) + (0.00518826395f * fVec17[((IOTA - 176) & 511)])) + (0.00524522364f * fVec17[((IOTA - 177) & 511)])) + (0.00619189907f * fVec17[((IOTA - 178) & 511)])) + (0.00685943617f * fVec17[((IOTA - 179) & 511)])) + (0.00643966673f * fVec17[((IOTA - 180) & 511)])) + (0.00431997515f * fVec17[((IOTA - 181) & 511)])) + (9.49879177e-05f * fVec17[((IOTA - 182) & 511)])) + (0.0018234523f * fVec17[((IOTA - 197) & 511)])) + (0.00343583431f * fVec17[((IOTA - 198) & 511)])) + (0.00101532647f * fVec17[((IOTA - 199) & 511)])) + (0.00124212448f * fVec17[((IOTA - 213) & 511)])) + (0.0030142758f * fVec17[((IOTA - 214) & 511)])) + (0.00369096594f * fVec17[((IOTA - 222) & 511)])) + (0.00146234827f * fVec17[((IOTA - 223) & 511)])) + (0.00451511052f * fVec17[((IOTA - 236) & 511)])) + (0.00868247263f * fVec17[((IOTA - 237) & 511)])) + (0.00784176867f * fVec17[((IOTA - 239) & 511)])) + (0.00243993802f * fVec17[((IOTA - 240) & 511)])) + (0.000573214609f * fVec17[((IOTA - 248) & 511)])) + (0.001168855f * fVec17[((IOTA - 249) & 511)])) + (0.00105655892f * fVec17[((IOTA - 250) & 511)])) + (0.00155708659f * fVec17[((IOTA - 251) & 511)])) + (0.00311005441f * fVec17[((IOTA - 252) & 511)])) + (0.0036569736f * fVec17[((IOTA - 253) & 511)])) + (0.00251778401f * fVec17[((IOTA - 254) & 511)])) + (0.00448831543f * fVec17[((IOTA - 285) & 511)])) + (0.00731864851f * fVec17[((IOTA - 286) & 511)])) + (0.00786598399f * fVec17[((IOTA - 287) & 511)])) + (0.00705457106f * fVec17[((IOTA - 288) & 511)])) + (0.00538735185f * fVec17[((IOTA - 289) & 511)])) + (0.00436948705f * fVec17[((IOTA - 290) & 511)])) + (0.00378200132f * fVec17[((IOTA - 291) & 511)])) + (0.00411323179f * fVec17[((IOTA - 292) & 511)])) + (0.00566490972f * fVec17[((IOTA - 293) & 511)])) + (0.00613023806f * fVec17[((IOTA - 294) & 511)])) + (0.00559372082f * fVec17[((IOTA - 295) & 511)])) + (0.00519554503f * fVec17[((IOTA - 296) & 511)])) + (0.00411373097f * fVec17[((IOTA - 297) & 511)])) + (0.00176903093f * fVec17[((IOTA - 298) & 511)])) + (3.00817192e-05f * fVec17[((IOTA - 309) & 511)])) + (0.00214061979f * fVec17[((IOTA - 310) & 511)])) + (0.00370207522f * fVec17[((IOTA - 311) & 511)])) + (0.0045003402f * fVec17[((IOTA - 312) & 511)])) + (0.00462203939f * fVec17[((IOTA - 313) & 511)])) + (0.00376481796f * fVec17[((IOTA - 314) & 511)])) + (0.00119527522f * fVec17[((IOTA - 315) & 511)])) + (0.000399756711f * fVec17[((IOTA - 321) & 511)])) + (0.0016100104f * fVec17[((IOTA - 322) & 511)])) + (0.000132600311f * fVec17[((IOTA - 323) & 511)])) + (0.00179299619f * fVec17[((IOTA - 331) & 511)])) + (0.00332187349f * fVec17[((IOTA - 332) & 511)])) + (0.00343054999f * fVec17[((IOTA - 333) & 511)])) + (0.00220981147f * fVec17[((IOTA - 334) & 511)])) + (0.000576085411f * fVec17[((IOTA - 335) & 511)])) + (0.000118995085f * fVec17[((IOTA - 337) & 511)])) + (0.000168506987f * fVec17[((IOTA - 338) & 511)])) + (0.00184063567f * fVec17[((IOTA - 350) & 511)])) + (0.00404395675f * fVec17[((IOTA - 351) & 511)])) + (0.00534154288f * fVec17[((IOTA - 352) & 511)])) + (0.00566852931f * fVec17[((IOTA - 353) & 511)])) + (0.0053409189f * fVec17[((IOTA - 354) & 511)])) + (0.0043601254f * fVec17[((IOTA - 355) & 511)])) + (0.00292848283f * fVec17[((IOTA - 356) & 511)])) + (0.00156253716f * fVec17[((IOTA - 357) & 511)])) + (0.000647773501f * fVec17[((IOTA - 358) & 511)])) + (0.000675109215f * fVec17[((IOTA - 359) & 511)])) + (0.00190970302f * fVec17[((IOTA - 360) & 511)])) + (0.00435625622f * fVec17[((IOTA - 361) & 511)])) + (0.00841827039f * fVec17[((IOTA - 362) & 511)])) + (0.0134799257f * fVec17[((IOTA - 363) & 511)])) + (0.017512273f * fVec17[((IOTA - 364) & 511)])) + (0.0200977512f * fVec17[((IOTA - 365) & 511)])) + (0.0206026062f * fVec17[((IOTA - 366) & 511)])) + (0.0184901953f * fVec17[((IOTA - 367) & 511)])) + (0.0154713439f * fVec17[((IOTA - 368) & 511)])) + (0.013111582f * fVec17[((IOTA - 369) & 511)])) + (0.0120325964f * fVec17[((IOTA - 370) & 511)])) + (0.0135133769f * fVec17[((IOTA - 371) & 511)])) + (0.0167038143f * fVec17[((IOTA - 372) & 511)])) + (0.0198703296f * fVec17[((IOTA - 373) & 511)])) + (0.0219280273f * fVec17[((IOTA - 374) & 511)])) + (0.0214193035f * fVec17[((IOTA - 375) & 511)])) + (0.0184820835f * fVec17[((IOTA - 376) & 511)])) + (0.0142934602f * fVec17[((IOTA - 377) & 511)])) + (0.0101743201f * fVec17[((IOTA - 378) & 511)])) + (0.00747808535f * fVec17[((IOTA - 379) & 511)])) + (0.00677060615f * fVec17[((IOTA - 380) & 511)])) + (0.00670024892f * fVec17[((IOTA - 381) & 511)])) + (0.00605002046f * fVec17[((IOTA - 382) & 511)])) + (0.00490072044f * fVec17[((IOTA - 383) & 511)])) + (0.00308533991f * fVec17[((IOTA - 384) & 511)])) + (0.000954539515f * fVec17[((IOTA - 385) & 511)])) + (0.00103854341f * fVec17[((IOTA - 390) & 511)])) + (0.001942073f * fVec17[((IOTA - 391) & 511)])) + (0.00168332132f * fVec17[((IOTA - 392) & 511)])) + (0.00147445593f * fVec17[((IOTA - 393) & 511)])) + (0.00152142998f * fVec17[((IOTA - 394) & 511)])) + (0.00106338225f * fVec17[((IOTA - 395) & 511)])) + (0.000483718701f * fVec17[((IOTA - 412) & 511)])) + (0.000451514963f * fVec17[((IOTA - 418) & 511)])) + (0.00270493049f * fVec17[((IOTA - 419) & 511)])) + (0.00440439489f * fVec17[((IOTA - 420) & 511)])) + (0.004506581f * fVec17[((IOTA - 421) & 511)])) + (0.00357334409f * fVec17[((IOTA - 422) & 511)])) + (0.00210525421f * fVec17[((IOTA - 423) & 511)])) + (0.00091401441f * fVec17[((IOTA - 424) & 511)])) + (0.000441154931f * fVec17[((IOTA - 425) & 511)])) + (0.000333643518f * fVec17[((IOTA - 434) & 511)])) + (0.000687507913f * fVec17[((IOTA - 435) & 511)])) + (0.000564019661f * fVec17[((IOTA - 436) & 511)])) + (0.000579580199f * fVec17[((IOTA - 437) & 511)])) + (0.000563520472f * fVec17[((IOTA - 438) & 511)])) + (0.000381533056f * fVec17[((IOTA - 439) & 511)])) + (0.000268279575f * fVec17[((IOTA - 440) & 511)])) + (0.0035384777f * fVec17[((IOTA - 456) & 511)])) + (0.00677118823f * fVec17[((IOTA - 457) & 511)])) + (0.00913145021f * fVec17[((IOTA - 458) & 511)])) + (0.0103099998f * fVec17[((IOTA - 459) & 511)])) + (0.0101826414f * fVec17[((IOTA - 460) & 511)])) + (0.00882430933f * fVec17[((IOTA - 461) & 511)])) + (0.00690566096f * fVec17[((IOTA - 462) & 511)])) + (0.0053028902f * fVec17[((IOTA - 463) & 511)])) + (0.00408564648f * fVec17[((IOTA - 464) & 511)])) + (0.00304294284f * fVec17[((IOTA - 465) & 511)])) + (0.00192817627f * fVec17[((IOTA - 466) & 511)])) + (0.000677771866f * fVec17[((IOTA - 467) & 511)])) + (0.000932487659f * fVec17[((IOTA - 472) & 511)])) + (0.00292482134f * fVec17[((IOTA - 473) & 511)])) + (0.00387416035f * fVec17[((IOTA - 474) & 511)])) + (0.00399665022f * fVec17[((IOTA - 475) & 511)])) + (0.00313239684f * fVec17[((IOTA - 476) & 511)])) + (0.00116178207f * fVec17[((IOTA - 477) & 511)])) + (0.000754952431f * fVec17[((IOTA - 482) & 511)])) + (0.0015350352f * fVec17[((IOTA - 483) & 511)])) + (0.00211523985f * fVec17[((IOTA - 484) & 511)])) + (0.00172001822f * fVec17[((IOTA - 485) & 511)])) + (0.000547168776f * fVec17[((IOTA - 503) & 511)])) + (0.00253517553f * fVec17[((IOTA - 504) & 511)])) + (0.00515926443f * fVec17[((IOTA - 505) & 511)])) + (0.00780906575f * fVec17[((IOTA - 506) & 511)])) + (0.00991465338f * fVec17[((IOTA - 507) & 511)])) + (0.0107281459f * fVec17[((IOTA - 508) & 511)])) + (0.0101964129f * fVec17[((IOTA - 509) & 511)])) + (0.00861789845f * fVec17[((IOTA - 510) & 511)])) + (0.00730421115f * fVec17[((IOTA - 511) & 511)]))) : ((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00215608999f * fVec16[((IOTA - 369) & 511)]) + ((0.00283820461f * fVec16[((IOTA - 368) & 511)]) + ((0.00281120697f * fVec16[((IOTA - 367) & 511)]) + ((0.00159577141f * fVec16[((IOTA - 366) & 511)]) + ((0.000710098073f * fVec16[((IOTA - 365) & 511)]) + ((0.000341473147f * fVec16[((IOTA - 364) & 511)]) + ((0.000505491626f * fVec16[((IOTA - 362) & 511)]) + ((0.0014574565f * fVec16[((IOTA - 361) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((0.00564771658f * fVec16[((IOTA - 309) & 511)]) + ((0.00542403292f * fVec16[((IOTA - 308) & 511)]) + ((0.00422360608f * fVec16[((IOTA - 307) & 511)]) + ((0.00315117044f * fVec16[((IOTA - 306) & 511)]) + ((0.00336095458f * fVec16[((IOTA - 305) & 511)]) + ((0.00396509748f * fVec16[((IOTA - 304) & 511)]) + ((0.00524719432f * fVec16[((IOTA - 303) & 511)]) + ((0.00756711699f * fVec16[((IOTA - 302) & 511)]) + ((0.00969161745f * fVec16[((IOTA - 301) & 511)]) + ((0.0107356077f * fVec16[((IOTA - 300) & 511)]) + ((0.0106238583f * fVec16[((IOTA - 299) & 511)]) + ((0.00887769088f * fVec16[((IOTA - 298) & 511)]) + ((0.00638974318f * fVec16[((IOTA - 297) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((fSlow56 * fTemp0) + (0.24973768f * fVec16[((IOTA - 1) & 511)])) + (0.214394778f * fVec16[((IOTA - 2) & 511)])) + (0.199169815f * fVec16[((IOTA - 3) & 511)])) + (0.0473606884f * fVec16[((IOTA - 4) & 511)])) + (0.00129383896f * fVec16[((IOTA - 9) & 511)])) + (0.0876072049f * fVec16[((IOTA - 10) & 511)])) + (0.120615445f * fVec16[((IOTA - 11) & 511)])) + (0.0945523381f * fVec16[((IOTA - 12) & 511)])) + (0.0214398112f * fVec16[((IOTA - 13) & 511)])) + (0.00248387968f * fVec16[((IOTA - 15) & 511)])) + (0.0243848637f * fVec16[((IOTA - 16) & 511)])) + (0.0271589961f * fVec16[((IOTA - 17) & 511)])) + (0.0185448993f * fVec16[((IOTA - 18) & 511)])) + (0.00136053097f * fVec16[((IOTA - 19) & 511)])) + (0.0253882967f * fVec16[((IOTA - 23) & 511)])) + (0.0433388241f * fVec16[((IOTA - 24) & 511)])) + (0.0433986746f * fVec16[((IOTA - 25) & 511)])) + (0.0257696509f * fVec16[((IOTA - 26) & 511)])) + (0.0164593849f * fVec16[((IOTA - 27) & 511)])) + (0.0233307034f * fVec16[((IOTA - 35) & 511)])) + (0.0423667021f * fVec16[((IOTA - 36) & 511)])) + (0.0443573892f * fVec16[((IOTA - 37) & 511)])) + (0.0230309907f * fVec16[((IOTA - 38) & 511)])) + (0.0337314941f * fVec16[((IOTA - 49) & 511)])) + (0.0358946733f * fVec16[((IOTA - 50) & 511)])) + (0.0159677938f * fVec16[((IOTA - 51) & 511)])) + (0.00546366582f * fVec16[((IOTA - 57) & 511)])) + (0.0256485622f * fVec16[((IOTA - 58) & 511)])) + (0.0237389319f * fVec16[((IOTA - 59) & 511)])) + (0.0200051293f * fVec16[((IOTA - 60) & 511)])) + (0.00442710333f * fVec16[((IOTA - 61) & 511)])) + (0.00181624992f * fVec16[((IOTA - 71) & 511)])) + (0.0072864187f * fVec16[((IOTA - 72) & 511)])) + (0.0129883764f * fVec16[((IOTA - 73) & 511)])) + (0.0121210404f * fVec16[((IOTA - 74) & 511)])) + (0.00753075071f * fVec16[((IOTA - 80) & 511)])) + (0.0114996387f * fVec16[((IOTA - 81) & 511)])) + (0.017207576f * fVec16[((IOTA - 82) & 511)])) + (0.0079477923f * fVec16[((IOTA - 83) & 511)])) + (0.00137369055f * fVec16[((IOTA - 93) & 511)])) + (0.00621922221f * fVec16[((IOTA - 94) & 511)])) + (0.00866084918f * fVec16[((IOTA - 95) & 511)])) + (0.0139520215f * fVec16[((IOTA - 96) & 511)])) + (0.0123466039f * fVec16[((IOTA - 97) & 511)])) + (0.00566244777f * fVec16[((IOTA - 98) & 511)])) + (0.00819798f * fVec16[((IOTA - 106) & 511)])) + (0.0163434744f * fVec16[((IOTA - 107) & 511)])) + (0.0145488912f * fVec16[((IOTA - 108) & 511)])) + (0.00816762354f * fVec16[((IOTA - 109) & 511)])) + (0.0015529641f * fVec16[((IOTA - 117) & 511)])) + (0.00288856262f * fVec16[((IOTA - 118) & 511)])) + (0.00144737866f * fVec16[((IOTA - 119) & 511)])) + (0.00319989491f * fVec16[((IOTA - 128) & 511)])) + (0.00988226384f * fVec16[((IOTA - 129) & 511)])) + (0.0129409153f * fVec16[((IOTA - 130) & 511)])) + (0.0125511177f * fVec16[((IOTA - 131) & 511)])) + (0.00723445788f * fVec16[((IOTA - 132) & 511)])) + (0.00112106791f * fVec16[((IOTA - 133) & 511)])) + (8.71866941e-05f * fVec16[((IOTA - 147) & 511)])) + (0.000438922551f * fVec16[((IOTA - 148) & 511)])) + (0.000638783444f * fVec16[((IOTA - 162) & 511)])) + (0.00214659749f * fVec16[((IOTA - 163) & 511)])) + (0.00134059088f * fVec16[((IOTA - 164) & 511)])) + (0.000196902081f * fVec16[((IOTA - 173) & 511)])) + (0.000540317036f * fVec16[((IOTA - 174) & 511)])) + (0.00085266633f * fVec16[((IOTA - 175) & 511)])) + (0.000621493906f * fVec16[((IOTA - 182) & 511)])) + (0.00339143444f * fVec16[((IOTA - 183) & 511)])) + (0.00343901897f * fVec16[((IOTA - 184) & 511)])) + (0.00199123938f * fVec16[((IOTA - 185) & 511)])) + (0.00179113261f * fVec16[((IOTA - 186) & 511)])) + (0.0014986922f * fVec16[((IOTA - 187) & 511)])) + (0.00160816079f * fVec16[((IOTA - 188) & 511)])) + (0.0016110884f * fVec16[((IOTA - 189) & 511)])) + (0.000717587303f * fVec16[((IOTA - 190) & 511)])) + (0.000261529349f * fVec16[((IOTA - 192) & 511)])) + (0.00112177711f * fVec16[((IOTA - 193) & 511)])) + (0.00216062041f * fVec16[((IOTA - 194) & 511)])) + (0.00318796793f * fVec16[((IOTA - 195) & 511)])) + (0.0026333821f * fVec16[((IOTA - 196) & 511)])) + (0.000727264211f * fVec16[((IOTA - 197) & 511)])) + (0.00134530617f * fVec16[((IOTA - 207) & 511)])) + (0.00329151936f * fVec16[((IOTA - 208) & 511)])) + (0.00537404465f * fVec16[((IOTA - 209) & 511)])) + (0.00513128424f * fVec16[((IOTA - 210) & 511)])) + (0.00280827936f * fVec16[((IOTA - 211) & 511)])) + (0.000413281377f * fVec16[((IOTA - 212) & 511)])) + (0.00109302299f * fVec16[((IOTA - 217) & 511)])) + (0.00391147239f * fVec16[((IOTA - 218) & 511)])) + (0.00614100369f * fVec16[((IOTA - 219) & 511)])) + (0.00770697324f * fVec16[((IOTA - 220) & 511)])) + (0.00719611952f * fVec16[((IOTA - 221) & 511)])) + (0.00501851784f * fVec16[((IOTA - 222) & 511)])) + (0.00233841455f * fVec16[((IOTA - 223) & 511)])) + (0.000625685323f * fVec16[((IOTA - 227) & 511)])) + (0.00366923586f * fVec16[((IOTA - 228) & 511)])) + (0.00626985729f * fVec16[((IOTA - 229) & 511)])) + (0.00752840843f * fVec16[((IOTA - 230) & 511)])) + (0.00742948009f * fVec16[((IOTA - 231) & 511)])) + (0.00609992212f * fVec16[((IOTA - 232) & 511)])) + (0.00372187467f * fVec16[((IOTA - 233) & 511)])) + (0.00148352934f * fVec16[((IOTA - 234) & 511)])) + (0.00116082467f * fVec16[((IOTA - 238) & 511)])) + (0.00292064482f * fVec16[((IOTA - 239) & 511)])) + (0.00511097442f * fVec16[((IOTA - 240) & 511)])) + (0.00620701769f * fVec16[((IOTA - 241) & 511)])) + (0.00656664325f * fVec16[((IOTA - 242) & 511)])) + (0.0061593717f * fVec16[((IOTA - 243) & 511)])) + (0.00373475673f * fVec16[((IOTA - 244) & 511)])) + (0.0010870439f * fVec16[((IOTA - 245) & 511)])) + (0.0023924401f * fVec16[((IOTA - 250) & 511)])) + (0.00555618433f * fVec16[((IOTA - 251) & 511)])) + (0.00786331762f * fVec16[((IOTA - 252) & 511)])) + (0.00912667625f * fVec16[((IOTA - 253) & 511)])) + (0.00971100293f * fVec16[((IOTA - 254) & 511)])) + (0.00876415335f * fVec16[((IOTA - 255) & 511)])) + (0.00753827067f * fVec16[((IOTA - 256) & 511)])) + (0.00635103462f * fVec16[((IOTA - 257) & 511)])) + (0.00479477271f * fVec16[((IOTA - 258) & 511)])) + (0.00430533802f * fVec16[((IOTA - 259) & 511)])) + (0.00412920769f * fVec16[((IOTA - 260) & 511)])) + (0.00382967899f * fVec16[((IOTA - 261) & 511)])) + (0.00432293536f * fVec16[((IOTA - 262) & 511)])) + (0.00498104235f * fVec16[((IOTA - 263) & 511)])) + (0.00597945089f * fVec16[((IOTA - 264) & 511)])) + (0.00733813271f * fVec16[((IOTA - 265) & 511)])) + (0.0078436546f * fVec16[((IOTA - 266) & 511)])) + (0.0084059462f * fVec16[((IOTA - 267) & 511)])) + (0.0089780055f * fVec16[((IOTA - 268) & 511)])) + (0.00823409948f * fVec16[((IOTA - 269) & 511)])) + (0.00668104319f * fVec16[((IOTA - 270) & 511)])) + (0.00503044482f * fVec16[((IOTA - 271) & 511)])) + (0.00355455885f * fVec16[((IOTA - 272) & 511)])) + (0.00281727826f * fVec16[((IOTA - 273) & 511)])) + (0.00286150351f * fVec16[((IOTA - 274) & 511)])) + (0.00340407016f * fVec16[((IOTA - 275) & 511)])) + (0.00468921801f * fVec16[((IOTA - 276) & 511)])) + (0.00579241104f * fVec16[((IOTA - 277) & 511)])) + (0.0058871177f * fVec16[((IOTA - 278) & 511)])) + (0.00554031273f * fVec16[((IOTA - 279) & 511)])) + (0.00428111432f * fVec16[((IOTA - 280) & 511)])) + (0.00207589893f * fVec16[((IOTA - 281) & 511)])) + (0.000257492065f * fVec16[((IOTA - 282) & 511)])) + (0.00118510984f * fVec16[((IOTA - 285) & 511)])) + (0.00322716963f * fVec16[((IOTA - 286) & 511)])) + (0.00619761785f * fVec16[((IOTA - 287) & 511)])) + (0.00903085992f * fVec16[((IOTA - 288) & 511)])) + (0.00994331576f * fVec16[((IOTA - 289) & 511)])) + (0.00932249986f * fVec16[((IOTA - 290) & 511)])) + (0.00736337341f * fVec16[((IOTA - 291) & 511)])) + (0.00429686252f * fVec16[((IOTA - 292) & 511)])) + (0.00203608116f * fVec16[((IOTA - 293) & 511)])) + (0.00117928488f * fVec16[((IOTA - 294) & 511)])) + (0.00162936421f * fVec16[((IOTA - 295) & 511)])) + (0.0037359898f * fVec16[((IOTA - 296) & 511)])) + (0.00597122218f * fVec16[((IOTA - 310) & 511)]))))))))))))))) + (0.00593125029f * fVec16[((IOTA - 311) & 511)])) + (0.00554616842f * fVec16[((IOTA - 312) & 511)])) + (0.00538476976f * fVec16[((IOTA - 313) & 511)])) + (0.00413663546f * fVec16[((IOTA - 314) & 511)])) + (0.0021580006f * fVec16[((IOTA - 315) & 511)])) + (0.000430478249f * fVec16[((IOTA - 316) & 511)])) + (0.00019979896f * fVec16[((IOTA - 320) & 511)])) + (0.00223396905f * fVec16[((IOTA - 321) & 511)])) + (0.00301442668f * fVec16[((IOTA - 322) & 511)])) + (0.00245395442f * fVec16[((IOTA - 323) & 511)])) + (0.0019082441f * fVec16[((IOTA - 324) & 511)])) + (0.000451342668f * fVec16[((IOTA - 325) & 511)])) + (0.00100223022f * fVec16[((IOTA - 329) & 511)])) + (0.00212129531f * fVec16[((IOTA - 330) & 511)])) + (0.00238168426f * fVec16[((IOTA - 331) & 511)])) + (0.00314636249f * fVec16[((IOTA - 332) & 511)])) + (0.00474725012f * fVec16[((IOTA - 333) & 511)])) + (0.00578405941f * fVec16[((IOTA - 334) & 511)])) + (0.00610953756f * fVec16[((IOTA - 335) & 511)])) + (0.00583093474f * fVec16[((IOTA - 336) & 511)])) + (0.0046452703f * fVec16[((IOTA - 337) & 511)])) + (0.00356377382f * fVec16[((IOTA - 338) & 511)])) + (0.00244067144f * fVec16[((IOTA - 339) & 511)])) + (0.00164696155f * fVec16[((IOTA - 340) & 511)])) + (0.00148426881f * fVec16[((IOTA - 341) & 511)])) + (0.00159891509f * fVec16[((IOTA - 342) & 511)])) + (0.00253386796f * fVec16[((IOTA - 343) & 511)])) + (0.0036872956f * fVec16[((IOTA - 344) & 511)])) + (0.00403477903f * fVec16[((IOTA - 345) & 511)])) + (0.00461620791f * fVec16[((IOTA - 346) & 511)])) + (0.00559233502f * fVec16[((IOTA - 347) & 511)])) + (0.005700232f * fVec16[((IOTA - 348) & 511)])) + (0.00544665381f * fVec16[((IOTA - 349) & 511)])) + (0.00483258767f * fVec16[((IOTA - 350) & 511)])) + (0.00360309845f * fVec16[((IOTA - 351) & 511)])) + (0.00257507293f * fVec16[((IOTA - 352) & 511)])) + (0.00116128661f * fVec16[((IOTA - 353) & 511)])) + (0.000183434226f * fVec16[((IOTA - 356) & 511)])) + (0.00105006155f * fVec16[((IOTA - 357) & 511)])) + (0.00205272343f * fVec16[((IOTA - 358) & 511)])) + (0.00242729625f * fVec16[((IOTA - 359) & 511)])) + (0.00207398832f * fVec16[((IOTA - 360) & 511)])) + (0.000715768896f * fVec16[((IOTA - 370) & 511)])))))))))) + (0.00156849669f * fVec16[((IOTA - 375) & 511)])) + (0.00346093113f * fVec16[((IOTA - 376) & 511)])) + (0.00413420051f * fVec16[((IOTA - 377) & 511)])) + (0.00415201392f * fVec16[((IOTA - 378) & 511)])) + (0.00297602639f * fVec16[((IOTA - 379) & 511)])) + (0.00165001256f * fVec16[((IOTA - 380) & 511)])) + (0.000726062339f * fVec16[((IOTA - 381) & 511)])) + (0.000652497634f * fVec16[((IOTA - 382) & 511)])) + (0.0017227456f * fVec16[((IOTA - 383) & 511)])) + (0.00239505945f * fVec16[((IOTA - 384) & 511)])) + (0.00232608663f * fVec16[((IOTA - 385) & 511)])) + (0.00219310354f * fVec16[((IOTA - 386) & 511)])) + (0.00136687979f * fVec16[((IOTA - 387) & 511)])) + (0.0006602332f * fVec16[((IOTA - 388) & 511)])) + (0.000968422275f * fVec16[((IOTA - 389) & 511)])) + (0.00134203956f * fVec16[((IOTA - 390) & 511)])) + (0.00176068349f * fVec16[((IOTA - 391) & 511)])) + (0.00235024886f * fVec16[((IOTA - 392) & 511)])) + (0.00145736383f * fVec16[((IOTA - 393) & 511)])) + (0.000778362155f * fVec16[((IOTA - 399) & 511)])) + (0.00273305038f * fVec16[((IOTA - 400) & 511)])) + (0.00374514284f * fVec16[((IOTA - 401) & 511)])) + (0.00336009171f * fVec16[((IOTA - 402) & 511)])) + (0.00259069772f * fVec16[((IOTA - 403) & 511)])) + (0.00130024925f * fVec16[((IOTA - 404) & 511)])) + (0.000358023215f * fVec16[((IOTA - 408) & 511)])) + (0.00134989852f * fVec16[((IOTA - 409) & 511)])) + (0.00116609456f * fVec16[((IOTA - 410) & 511)])) + (0.000896490645f * fVec16[((IOTA - 411) & 511)])) + (0.000384342391f * fVec16[((IOTA - 412) & 511)])) + (0.00028507458f * fVec16[((IOTA - 415) & 511)])) + (0.00018281769f * fVec16[((IOTA - 416) & 511)])) + (0.000188180245f * fVec16[((IOTA - 417) & 511)])) + (0.00194470305f * fVec16[((IOTA - 423) & 511)])) + (0.00366316456f * fVec16[((IOTA - 424) & 511)])) + (0.00507408427f * fVec16[((IOTA - 425) & 511)])) + (0.00485939998f * fVec16[((IOTA - 426) & 511)])) + (0.00296554808f * fVec16[((IOTA - 427) & 511)])) + (0.00112439645f * fVec16[((IOTA - 428) & 511)])) + (9.47373919e-05f * fVec16[((IOTA - 448) & 511)])) + (0.00056306133f * fVec16[((IOTA - 449) & 511)])) + (0.000581922475f * fVec16[((IOTA - 450) & 511)])) + (0.000465149526f * fVec16[((IOTA - 451) & 511)])) + (0.000480096787f * fVec16[((IOTA - 469) & 511)])) + (0.00200427603f * fVec16[((IOTA - 470) & 511)])) + (0.00277752196f * fVec16[((IOTA - 471) & 511)])) + (0.00213651964f * fVec16[((IOTA - 472) & 511)])) + (0.000757220201f * fVec16[((IOTA - 473) & 511)])) + (0.00152655225f * fVec16[((IOTA - 493) & 511)])) + (0.00271687051f * fVec16[((IOTA - 494) & 511)])) + (0.00306188781f * fVec16[((IOTA - 495) & 511)])) + (0.0023121261f * fVec16[((IOTA - 496) & 511)])) + (5.54742292e-05f * fVec16[((IOTA - 497) & 511)])) - ((((((((((((((((((((((((((0.000271606725f * fVec16[((IOTA - 481) & 511)]) + ((0.000337497797f * fVec16[((IOTA - 480) & 511)]) + ((0.00138885342f * fVec16[((IOTA - 479) & 511)]) + ((0.00284489198f * fVec16[((IOTA - 478) & 511)]) + ((0.00350068742f * fVec16[((IOTA - 477) & 511)]) + ((0.00396981277f * fVec16[((IOTA - 476) & 511)]) + ((0.00310873287f * fVec16[((IOTA - 475) & 511)]) + ((0.000922810286f * fVec16[((IOTA - 474) & 511)]) + ((0.00152014196f * fVec16[((IOTA - 468) & 511)]) + ((0.0032054116f * fVec16[((IOTA - 467) & 511)]) + ((0.00387390424f * fVec16[((IOTA - 466) & 511)]) + ((0.00410125498f * fVec16[((IOTA - 465) & 511)]) + ((0.00373108964f * fVec16[((IOTA - 464) & 511)]) + ((0.00231240317f * fVec16[((IOTA - 463) & 511)]) + ((0.00105095515f * fVec16[((IOTA - 462) & 511)]) + ((0.000355465338f * fVec16[((IOTA - 461) & 511)]) + ((6.09597191e-05f * fVec16[((IOTA - 460) & 511)]) + ((0.000885272864f * fVec16[((IOTA - 459) & 511)]) + ((0.00203685137f * fVec16[((IOTA - 458) & 511)]) + ((0.00303390436f * fVec16[((IOTA - 457) & 511)]) + ((0.00417836383f * fVec16[((IOTA - 456) & 511)]) + ((0.00418462045f * fVec16[((IOTA - 455) & 511)]) + ((0.00306672649f * fVec16[((IOTA - 454) & 511)]) + ((0.00206683809f * fVec16[((IOTA - 453) & 511)]) + ((0.000712717883f * fVec16[((IOTA - 452) & 511)]) + ((0.000596931204f * fVec16[((IOTA - 447) & 511)]) + ((0.000733551104f * fVec16[((IOTA - 446) & 511)]) + ((0.00133566f * fVec16[((IOTA - 445) & 511)]) + ((0.00241204072f * fVec16[((IOTA - 444) & 511)]) + ((0.00351668242f * fVec16[((IOTA - 443) & 511)]) + ((0.0050324481f * fVec16[((IOTA - 442) & 511)]) + ((0.00572960218f * fVec16[((IOTA - 441) & 511)]) + ((0.00531277666f * fVec16[((IOTA - 440) & 511)]) + ((0.00465593347f * fVec16[((IOTA - 439) & 511)]) + ((0.00358701125f * fVec16[((IOTA - 438) & 511)]) + ((0.00245900871f * fVec16[((IOTA - 437) & 511)]) + ((0.00181871559f * fVec16[((IOTA - 436) & 511)]) + ((0.00151524181f * fVec16[((IOTA - 435) & 511)]) + ((0.0021492173f * fVec16[((IOTA - 434) & 511)]) + ((0.0031173001f * fVec16[((IOTA - 433) & 511)]) + ((0.00343720056f * fVec16[((IOTA - 432) & 511)]) + ((0.00346684828f * fVec16[((IOTA - 431) & 511)]) + ((((0.000196963549f * fVec16[((IOTA - 422) & 511)]) + ((0.00158304349f * fVec16[((IOTA - 421) & 511)]) + ((0.00200134795f * fVec16[((IOTA - 420) & 511)]) + ((0.0021992363f * fVec16[((IOTA - 419) & 511)]) + ((0.00104926014f * fVec16[((IOTA - 418) & 511)]) + ((1.12489797e-05f * fVec16[((IOTA - 414) & 511)]) + ((0.000370412134f * fVec16[((IOTA - 413) & 511)]) + ((0.000677306671f * fVec16[((IOTA - 407) & 511)]) + ((0.00070790993f * fVec16[((IOTA - 406) & 511)]) + ((0.000126141589f * fVec16[((IOTA - 405) & 511)]) + ((0.00114581548f * fVec16[((IOTA - 398) & 511)]) + ((0.00304244133f * fVec16[((IOTA - 397) & 511)]) + ((0.00341254519f * fVec16[((IOTA - 396) & 511)]) + ((0.002126134f * fVec16[((IOTA - 395) & 511)]) + ((0.000515107065f * fVec16[((IOTA - 394) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00344280945f * fVec16[((IOTA - 52) & 511)]) + ((0.00250770245f * fVec16[((IOTA - 48) & 511)]) + ((0.032563027f * fVec16[((IOTA - 47) & 511)]) + ((0.0371380001f * fVec16[((IOTA - 46) & 511)]) + ((0.0405723639f * fVec16[((IOTA - 45) & 511)]) + ((0.0293948464f * fVec16[((IOTA - 44) & 511)]) + ((0.00491247f * fVec16[((IOTA - 43) & 511)]) + ((0.0043655578f * fVec16[((IOTA - 42) & 511)]) + ((0.0176386703f * fVec16[((IOTA - 41) & 511)]) + ((0.0230345353f * fVec16[((IOTA - 40) & 511)]) + ((0.00992972404f * fVec16[((IOTA - 39) & 511)]) + ((0.00419435883f * fVec16[((IOTA - 34) & 511)]) + ((0.0312992074f * fVec16[((IOTA - 33) & 511)]) + ((0.0575992502f * fVec16[((IOTA - 32) & 511)]) + ((0.0533585101f * fVec16[((IOTA - 31) & 511)]) + ((0.0370307826f * fVec16[((IOTA - 30) & 511)]) + ((0.0308520552f * fVec16[((IOTA - 29) & 511)]) + ((0.00601393729f * fVec16[((IOTA - 28) & 511)]) + ((0.00328184245f * fVec16[((IOTA - 22) & 511)]) + ((0.0351948366f * fVec16[((IOTA - 21) & 511)]) + ((0.0299937185f * fVec16[((IOTA - 20) & 511)]) + ((0.0153579488f * fVec16[((IOTA - 14) & 511)]) + ((0.145786837f * fVec16[((IOTA - 8) & 511)]) + ((0.240315467f * fVec16[((IOTA - 7) & 511)]) + ((0.214572385f * fVec16[((IOTA - 6) & 511)]) + ((0.139316171f * fVec16[((IOTA - 5) & 511)]) + ((0.0541440807f * fVec16[((IOTA - 54) & 511)]) + ((0.0335667059f * fVec16[((IOTA - 53) & 511)]) + (0.0426739678f * fVec16[((IOTA - 55) & 511)]))))))))))))))))))))))))))))) + (0.0259698797f * fVec16[((IOTA - 56) & 511)])) + (0.0114189852f * fVec16[((IOTA - 62) & 511)])) + (0.0188990086f * fVec16[((IOTA - 63) & 511)])) + (0.024418395f * fVec16[((IOTA - 64) & 511)])) + (0.0261838548f * fVec16[((IOTA - 65) & 511)])) + (0.0304152891f * fVec16[((IOTA - 66) & 511)])) + (0.0290783346f * fVec16[((IOTA - 67) & 511)])) + (0.0213463064f * fVec16[((IOTA - 68) & 511)])) + (0.0155045856f * fVec16[((IOTA - 69) & 511)])) + (0.00696026254f * fVec16[((IOTA - 70) & 511)])) + (0.00245623523f * fVec16[((IOTA - 75) & 511)])) + (0.0128501225f * fVec16[((IOTA - 76) & 511)])) + (0.0200171173f * fVec16[((IOTA - 77) & 511)])) + (0.0236857999f * fVec16[((IOTA - 78) & 511)])) + (0.00697496301f * fVec16[((IOTA - 79) & 511)])) + (0.00676943175f * fVec16[((IOTA - 84) & 511)])) + (0.0209830441f * fVec16[((IOTA - 85) & 511)])) + (0.0332383625f * fVec16[((IOTA - 86) & 511)])) + (0.0343914218f * fVec16[((IOTA - 87) & 511)])) + (0.0315758996f * fVec16[((IOTA - 88) & 511)])) + (0.0249085706f * fVec16[((IOTA - 89) & 511)])) + (0.0143615734f * fVec16[((IOTA - 90) & 511)])) + (0.00626202952f * fVec16[((IOTA - 91) & 511)])) + (0.00396768609f * fVec16[((IOTA - 92) & 511)])) + (0.000140595715f * fVec16[((IOTA - 99) & 511)])) + (0.0124599859f * fVec16[((IOTA - 100) & 511)])) + (0.0254527703f * fVec16[((IOTA - 101) & 511)])) + (0.0327245817f * fVec16[((IOTA - 102) & 511)])) + (0.0312528536f * fVec16[((IOTA - 103) & 511)])) + (0.0207944028f * fVec16[((IOTA - 104) & 511)])) + (0.00739132613f * fVec16[((IOTA - 105) & 511)])) + (0.00478981109f * fVec16[((IOTA - 110) & 511)])) + (0.017807588f * fVec16[((IOTA - 111) & 511)])) + (0.0240434222f * fVec16[((IOTA - 112) & 511)])) + (0.0240483843f * fVec16[((IOTA - 113) & 511)])) + (0.0197538324f * fVec16[((IOTA - 114) & 511)])) + (0.0111222621f * fVec16[((IOTA - 115) & 511)])) + (0.00222441554f * fVec16[((IOTA - 116) & 511)])) + (0.00556764891f * fVec16[((IOTA - 120) & 511)])) + (0.0118824095f * fVec16[((IOTA - 121) & 511)])) + (0.0162295066f * fVec16[((IOTA - 122) & 511)])) + (0.0196893588f * fVec16[((IOTA - 123) & 511)])) + (0.0219766144f * fVec16[((IOTA - 124) & 511)])) + (0.0199162178f * fVec16[((IOTA - 125) & 511)])) + (0.0123736933f * fVec16[((IOTA - 126) & 511)])) + (0.00485237315f * fVec16[((IOTA - 127) & 511)])) + (0.00562204421f * fVec16[((IOTA - 134) & 511)])) + (0.0098893512f * fVec16[((IOTA - 135) & 511)])) + (0.00990016945f * fVec16[((IOTA - 136) & 511)])) + (0.0101570133f * fVec16[((IOTA - 137) & 511)])) + (0.00844120234f * fVec16[((IOTA - 138) & 511)])) + (0.00552915595f * fVec16[((IOTA - 139) & 511)])) + (0.00450522918f * fVec16[((IOTA - 140) & 511)])) + (0.00194559665f * fVec16[((IOTA - 141) & 511)])) + (0.000999087002f * fVec16[((IOTA - 142) & 511)])) + (0.00193336187f * fVec16[((IOTA - 143) & 511)])) + (0.00163919525f * fVec16[((IOTA - 144) & 511)])) + (0.00183686754f * fVec16[((IOTA - 145) & 511)])) + (0.00127577875f * fVec16[((IOTA - 146) & 511)])) + (0.000367114786f * fVec16[((IOTA - 149) & 511)])) + (0.000944876578f * fVec16[((IOTA - 150) & 511)])) + (0.0023501562f * fVec16[((IOTA - 151) & 511)])) + (0.00334878126f * fVec16[((IOTA - 152) & 511)])) + (0.00196673861f * fVec16[((IOTA - 153) & 511)])) + (0.00111052813f * fVec16[((IOTA - 154) & 511)])) + (0.000803078525f * fVec16[((IOTA - 155) & 511)])) + (0.00130027998f * fVec16[((IOTA - 156) & 511)])) + (0.00416844012f * fVec16[((IOTA - 157) & 511)])) + (0.0069485819f * fVec16[((IOTA - 158) & 511)])) + (0.00810515322f * fVec16[((IOTA - 159) & 511)])) + (0.00601695757f * fVec16[((IOTA - 160) & 511)])) + (0.00208009034f * fVec16[((IOTA - 161) & 511)])) + (0.00174835604f * fVec16[((IOTA - 165) & 511)])) + (0.00439776387f * fVec16[((IOTA - 166) & 511)])) + (0.00604383182f * fVec16[((IOTA - 167) & 511)])) + (0.00601652637f * fVec16[((IOTA - 168) & 511)])) + (0.00414655916f * fVec16[((IOTA - 169) & 511)])) + (0.00239915866f * fVec16[((IOTA - 170) & 511)])) + (0.00216949591f * fVec16[((IOTA - 171) & 511)])) + (0.00111490441f * fVec16[((IOTA - 172) & 511)])) + (0.000643560197f * fVec16[((IOTA - 176) & 511)])) + (0.0035512303f * fVec16[((IOTA - 177) & 511)])) + (0.00577789545f * fVec16[((IOTA - 178) & 511)])) + (0.00738392957f * fVec16[((IOTA - 179) & 511)])) + (0.00592594966f * fVec16[((IOTA - 180) & 511)])) + (0.00221553957f * fVec16[((IOTA - 181) & 511)])) + (2.16038898e-05f * fVec16[((IOTA - 191) & 511)])) + (0.0017630565f * fVec16[((IOTA - 198) & 511)])) + (0.00445397757f * fVec16[((IOTA - 199) & 511)])) + (0.00540144276f * fVec16[((IOTA - 200) & 511)])) + (0.00496008527f * fVec16[((IOTA - 201) & 511)])) + (0.00414865464f * fVec16[((IOTA - 202) & 511)])) + (0.00275597954f * fVec16[((IOTA - 203) & 511)])) + (0.00240988331f * fVec16[((IOTA - 204) & 511)])) + (0.00230476027f * fVec16[((IOTA - 205) & 511)])) + (0.000636348501f * fVec16[((IOTA - 206) & 511)])) + (0.00197980599f * fVec16[((IOTA - 213) & 511)])) + (0.0036709616f * fVec16[((IOTA - 214) & 511)])) + (0.00364609109f * fVec16[((IOTA - 215) & 511)])) + (0.00180164166f * fVec16[((IOTA - 216) & 511)])) + (0.000306370668f * fVec16[((IOTA - 224) & 511)])) + (0.00172243733f * fVec16[((IOTA - 225) & 511)])) + (0.00137886824f * fVec16[((IOTA - 226) & 511)])) + (0.00028683152f * fVec16[((IOTA - 235) & 511)])) + (0.000993909314f * fVec16[((IOTA - 236) & 511)])) + (0.000254995655f * fVec16[((IOTA - 237) & 511)])) + (0.00120394025f * fVec16[((IOTA - 246) & 511)])) + (0.00275258953f * fVec16[((IOTA - 247) & 511)])) + (0.00223523285f * fVec16[((IOTA - 248) & 511)])) + (0.000307541806f * fVec16[((IOTA - 249) & 511)])) + (0.000845331233f * fVec16[((IOTA - 283) & 511)])) + (0.000503888819f * fVec16[((IOTA - 284) & 511)])) + (0.00145594636f * fVec16[((IOTA - 317) & 511)])) + (0.00203993358f * fVec16[((IOTA - 318) & 511)])) + (0.00123525225f * fVec16[((IOTA - 319) & 511)])) + (0.000904565211f * fVec16[((IOTA - 326) & 511)])) + (0.000735585578f * fVec16[((IOTA - 327) & 511)])) + (4.64748591e-05f * fVec16[((IOTA - 328) & 511)])) + (0.000287293922f * fVec16[((IOTA - 354) & 511)])) + (0.000435594469f * fVec16[((IOTA - 355) & 511)])) + (1.28205866e-05f * fVec16[((IOTA - 363) & 511)])) + (0.00145271001f * fVec16[((IOTA - 371) & 511)])) + (0.00244147284f * fVec16[((IOTA - 372) & 511)])) + (0.00204378599f * fVec16[((IOTA - 373) & 511)])) + (0.000787669327f * fVec16[((IOTA - 374) & 511)])) + (0.000726432074f * fVec16[((IOTA - 429) & 511)]))))))))))))))))) + (0.002642042f * fVec16[((IOTA - 430) & 511)])) + (0.00058703823f * fVec16[((IOTA - 482) & 511)])))))))))))))))))))))))))))))))))))))))))))) + (0.00120578939f * fVec16[((IOTA - 483) & 511)])) + (0.00153589062f * fVec16[((IOTA - 484) & 511)])) + (0.00171091082f * fVec16[((IOTA - 485) & 511)])) + (0.0020867167f * fVec16[((IOTA - 486) & 511)])) + (0.00190204987f * fVec16[((IOTA - 487) & 511)])) + (0.00195280835f * fVec16[((IOTA - 488) & 511)])) + (0.0023911763f * fVec16[((IOTA - 489) & 511)])) + (0.00197610771f * fVec16[((IOTA - 490) & 511)])) + (0.00135375094f * fVec16[((IOTA - 491) & 511)])) + (0.000323968008f * fVec16[((IOTA - 492) & 511)])) + (0.0022379756f * fVec16[((IOTA - 498) & 511)])) + (0.00402843021f * fVec16[((IOTA - 499) & 511)])) + (0.0052746227f * fVec16[((IOTA - 500) & 511)])) + (0.00507491641f * fVec16[((IOTA - 501) & 511)])) + (0.00388373528f * fVec16[((IOTA - 502) & 511)])) + (0.00291158399f * fVec16[((IOTA - 503) & 511)])) + (0.00200483063f * fVec16[((IOTA - 504) & 511)])) + (0.00162991881f * fVec16[((IOTA - 505) & 511)])) + (0.00208160048f * fVec16[((IOTA - 506) & 511)])) + (0.00287731364f * fVec16[((IOTA - 507) & 511)])) + (0.00414107321f * fVec16[((IOTA - 508) & 511)])) + (0.00535925152f * fVec16[((IOTA - 509) & 511)])) + (0.00542791607f * fVec16[((IOTA - 510) & 511)])) + (0.00502184639f * fVec16[((IOTA - 511) & 511)])))) : (iSlow49 ? ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.068408072f * fVec15[((IOTA - 13) & 511)]) + ((fSlow53 * fTemp0) + ((0.144228145f * fVec15[((IOTA - 4) & 511)]) + ((0.106624626f * fVec15[((IOTA - 12) & 511)]) + ((0.093828544f * fVec15[((IOTA - 11) & 511)]) + ((0.0288538411f * fVec15[((IOTA - 14) & 511)]) + (((((0.218755811f * fVec15[((IOTA - 1) & 511)]) + (0.226279855f * fVec15[((IOTA - 2) & 511)])) + (0.258332998f * fVec15[((IOTA - 3) & 511)])) + (0.0148076266f * fVec15[((IOTA - 10) & 511)])) + (0.0119582918f * fVec15[((IOTA - 15) & 511)])))))))) + (0.000938726589f * fVec15[((IOTA - 16) & 511)])) + (0.018972408f * fVec15[((IOTA - 17) & 511)])) + (0.0202880166f * fVec15[((IOTA - 18) & 511)])) + (0.0129112368f * fVec15[((IOTA - 19) & 511)])) + (0.00481410604f * fVec15[((IOTA - 20) & 511)])) + (0.00486702612f * fVec15[((IOTA - 23) & 511)])) + (0.0218426883f * fVec15[((IOTA - 24) & 511)])) + (0.0421515554f * fVec15[((IOTA - 25) & 511)])) + (0.0318875685f * fVec15[((IOTA - 26) & 511)])) + (0.0316007473f * fVec15[((IOTA - 27) & 511)])) + (0.0237826891f * fVec15[((IOTA - 28) & 511)])) + (0.0251331087f * fVec15[((IOTA - 36) & 511)])) + (0.0333082154f * fVec15[((IOTA - 37) & 511)])) + (0.0270554814f * fVec15[((IOTA - 38) & 511)])) + (0.013695443f * fVec15[((IOTA - 39) & 511)])) + (0.015158047f * fVec15[((IOTA - 49) & 511)])) + (0.0129585462f * fVec15[((IOTA - 50) & 511)])) + (0.00754612358f * fVec15[((IOTA - 51) & 511)])) + (0.00347385602f * fVec15[((IOTA - 52) & 511)])) + (0.00568789383f * fVec15[((IOTA - 62) & 511)])) + (0.0206551421f * fVec15[((IOTA - 63) & 511)])) + (0.0069704419f * fVec15[((IOTA - 64) & 511)])) + (0.00619994383f * fVec15[((IOTA - 72) & 511)])) + (0.0135017429f * fVec15[((IOTA - 73) & 511)])) + (0.0111574763f * fVec15[((IOTA - 74) & 511)])) + (0.0050323857f * fVec15[((IOTA - 81) & 511)])) + (0.00386434933f * fVec15[((IOTA - 82) & 511)])) + (0.00803078897f * fVec15[((IOTA - 95) & 511)])) + (0.0129583552f * fVec15[((IOTA - 96) & 511)])) + (0.0107800858f * fVec15[((IOTA - 97) & 511)])) + (0.00533862133f * fVec15[((IOTA - 98) & 511)])) + (0.000796894077f * fVec15[((IOTA - 99) & 511)])) + (0.0013513444f * fVec15[((IOTA - 108) & 511)])) + (0.0101783909f * fVec15[((IOTA - 109) & 511)])) + (0.00850372296f * fVec15[((IOTA - 110) & 511)])) + (0.00182759343f * fVec15[((IOTA - 111) & 511)])) + (0.00236843107f * fVec15[((IOTA - 119) & 511)])) + (0.00732892798f * fVec15[((IOTA - 120) & 511)])) + (0.00462764222f * fVec15[((IOTA - 121) & 511)])) + (0.00363574037f * fVec15[((IOTA - 129) & 511)])) + (0.0104804812f * fVec15[((IOTA - 130) & 511)])) + (0.0135468207f * fVec15[((IOTA - 131) & 511)])) + (0.0130864792f * fVec15[((IOTA - 132) & 511)])) + (0.0101937242f * fVec15[((IOTA - 133) & 511)])) + (0.00451921998f * fVec15[((IOTA - 134) & 511)])) + (0.00326536316f * fVec15[((IOTA - 143) & 511)])) + (0.00636810903f * fVec15[((IOTA - 144) & 511)])) + (0.00619968912f * fVec15[((IOTA - 145) & 511)])) + (0.00406085514f * fVec15[((IOTA - 146) & 511)])) + (0.0011787801f * fVec15[((IOTA - 147) & 511)])) + (0.000373596791f * fVec15[((IOTA - 154) & 511)])) + (0.00287365867f * fVec15[((IOTA - 155) & 511)])) + (0.0038859956f * fVec15[((IOTA - 156) & 511)])) + (0.001967513f * fVec15[((IOTA - 157) & 511)])) + (0.00187385082f * fVec15[((IOTA - 166) & 511)])) + (0.00380011182f * fVec15[((IOTA - 167) & 511)])) + (0.00436629355f * fVec15[((IOTA - 168) & 511)])) + (0.00269503752f * fVec15[((IOTA - 169) & 511)])) + (0.00285322405f * fVec15[((IOTA - 179) & 511)])) + (0.00451354543f * fVec15[((IOTA - 180) & 511)])) + (0.00475618104f * fVec15[((IOTA - 181) & 511)])) + (0.00302336551f * fVec15[((IOTA - 182) & 511)])) + (0.000884435605f * fVec15[((IOTA - 183) & 511)])) + (0.0013440121f * fVec15[((IOTA - 189) & 511)])) + (0.00312512508f * fVec15[((IOTA - 190) & 511)])) + (0.00475796591f * fVec15[((IOTA - 191) & 511)])) + (0.00567281479f * fVec15[((IOTA - 192) & 511)])) + (0.00501603168f * fVec15[((IOTA - 193) & 511)])) + (0.00391723728f * fVec15[((IOTA - 194) & 511)])) + (0.00148603553f * fVec15[((IOTA - 195) & 511)])) + (0.00194860855f * fVec15[((IOTA - 208) & 511)])) + (0.00383317098f * fVec15[((IOTA - 209) & 511)])) + (0.00479198154f * fVec15[((IOTA - 210) & 511)])) + (0.00508042844f * fVec15[((IOTA - 211) & 511)])) + (0.00586705748f * fVec15[((IOTA - 212) & 511)])) + (0.00580463698f * fVec15[((IOTA - 213) & 511)])) + (0.00456879241f * fVec15[((IOTA - 214) & 511)])) + (0.0030923211f * fVec15[((IOTA - 215) & 511)])) + (0.000636731274f * fVec15[((IOTA - 216) & 511)])) + (0.00136604067f * fVec15[((IOTA - 220) & 511)])) + (0.0045910445f * fVec15[((IOTA - 221) & 511)])) + (0.00608862052f * fVec15[((IOTA - 222) & 511)])) + (0.0060500144f * fVec15[((IOTA - 223) & 511)])) + (0.00421349425f * fVec15[((IOTA - 224) & 511)])) + (0.002649609f * fVec15[((IOTA - 225) & 511)])) + (0.00286345743f * fVec15[((IOTA - 226) & 511)])) + (0.00387305208f * fVec15[((IOTA - 227) & 511)])) + (0.00560430577f * fVec15[((IOTA - 228) & 511)])) + (0.0075154556f * fVec15[((IOTA - 229) & 511)])) + (0.00737540843f * fVec15[((IOTA - 230) & 511)])) + (0.00553273596f * fVec15[((IOTA - 231) & 511)])) + (0.0038220766f * fVec15[((IOTA - 232) & 511)])) + (0.00261948258f * fVec15[((IOTA - 233) & 511)])) + (0.00230148388f * fVec15[((IOTA - 234) & 511)])) + (0.00298861647f * fVec15[((IOTA - 235) & 511)])) + (0.00372627843f * fVec15[((IOTA - 236) & 511)])) + (0.00463369954f * fVec15[((IOTA - 237) & 511)])) + (0.00601641322f * fVec15[((IOTA - 238) & 511)])) + (0.00723230094f * fVec15[((IOTA - 239) & 511)])) + (0.00802830234f * fVec15[((IOTA - 240) & 511)])) + (0.00765190041f * fVec15[((IOTA - 241) & 511)])) + (0.0060795988f * fVec15[((IOTA - 242) & 511)])) + (0.0028172317f * fVec15[((IOTA - 243) & 511)])) + (0.00206726417f * fVec15[((IOTA - 248) & 511)])) + (0.00453002704f * fVec15[((IOTA - 249) & 511)])) + (0.00649403315f * fVec15[((IOTA - 250) & 511)])) + (0.00833801366f * fVec15[((IOTA - 251) & 511)])) + (0.00893333275f * fVec15[((IOTA - 252) & 511)])) + (0.00935334619f * fVec15[((IOTA - 253) & 511)])) + (0.00949406251f * fVec15[((IOTA - 254) & 511)])) + (0.00833762996f * fVec15[((IOTA - 255) & 511)])) + (0.00749661494f * fVec15[((IOTA - 256) & 511)])) + (0.00722496863f * fVec15[((IOTA - 257) & 511)])) + (0.00622490561f * fVec15[((IOTA - 258) & 511)])) + (0.00667421659f * fVec15[((IOTA - 259) & 511)])) + (0.00811134838f * fVec15[((IOTA - 260) & 511)])) + (0.00884948857f * fVec15[((IOTA - 261) & 511)])) + (0.00904583558f * fVec15[((IOTA - 262) & 511)])) + (0.00802253187f * fVec15[((IOTA - 263) & 511)])) + (0.00637980876f * fVec15[((IOTA - 264) & 511)])) + (0.00624014437f * fVec15[((IOTA - 265) & 511)])) + (0.00705116102f * fVec15[((IOTA - 266) & 511)])) + (0.00850480702f * fVec15[((IOTA - 267) & 511)])) + (0.0113587324f * fVec15[((IOTA - 268) & 511)])) + (0.0135926316f * fVec15[((IOTA - 269) & 511)])) + (0.0134331379f * fVec15[((IOTA - 270) & 511)])) + (0.0115197245f * fVec15[((IOTA - 271) & 511)])) + (0.00876459386f * fVec15[((IOTA - 272) & 511)])) + (0.0064392006f * fVec15[((IOTA - 273) & 511)])) + (0.00558457198f * fVec15[((IOTA - 274) & 511)])) + (0.00487161707f * fVec15[((IOTA - 275) & 511)])) + (0.00513889547f * fVec15[((IOTA - 276) & 511)])) + (0.00656965189f * fVec15[((IOTA - 277) & 511)])) + (0.00702132192f * fVec15[((IOTA - 278) & 511)])) + (0.00633865222f * fVec15[((IOTA - 279) & 511)])) + (0.00510921562f * fVec15[((IOTA - 280) & 511)])) + (0.00406506285f * fVec15[((IOTA - 281) & 511)])) + (0.00382800633f * fVec15[((IOTA - 282) & 511)])) + (0.00394809665f * fVec15[((IOTA - 283) & 511)])) + (0.00511584664f * fVec15[((IOTA - 284) & 511)])) + (0.0068942816f * fVec15[((IOTA - 285) & 511)])) + (0.00827077869f * fVec15[((IOTA - 286) & 511)])) + (0.0090666851f * fVec15[((IOTA - 287) & 511)])) + (0.00870475546f * fVec15[((IOTA - 288) & 511)])) + (0.00734231761f * fVec15[((IOTA - 289) & 511)])) + (0.00593964709f * fVec15[((IOTA - 290) & 511)])) + (0.00486842869f * fVec15[((IOTA - 291) & 511)])) + (0.00476156874f * fVec15[((IOTA - 292) & 511)])) + (0.00537939509f * fVec15[((IOTA - 293) & 511)])) + (0.00607507164f * fVec15[((IOTA - 294) & 511)])) + (0.00688117929f * fVec15[((IOTA - 295) & 511)])) + (0.00750334142f * fVec15[((IOTA - 296) & 511)])) + (0.00782637671f * fVec15[((IOTA - 297) & 511)])) + (0.00842730794f * fVec15[((IOTA - 298) & 511)])) + (0.00950729288f * fVec15[((IOTA - 299) & 511)])) + (0.0109465607f * fVec15[((IOTA - 300) & 511)])) + (0.012521062f * fVec15[((IOTA - 301) & 511)])) + (0.0126128756f * fVec15[((IOTA - 302) & 511)])) + (0.0112701077f * fVec15[((IOTA - 303) & 511)])) + (0.00994751789f * fVec15[((IOTA - 304) & 511)])) + (0.00807054341f * fVec15[((IOTA - 305) & 511)])) + (0.00540811848f * fVec15[((IOTA - 306) & 511)])) + (0.00420125248f * fVec15[((IOTA - 307) & 511)])) + (0.00407851627f * fVec15[((IOTA - 308) & 511)])) + (0.00423007179f * fVec15[((IOTA - 309) & 511)])) + (0.00551552093f * fVec15[((IOTA - 310) & 511)])) + (0.00707666483f * fVec15[((IOTA - 311) & 511)])) + (0.00859830994f * fVec15[((IOTA - 312) & 511)])) + (0.0104063293f * fVec15[((IOTA - 313) & 511)])) + (0.010464414f * fVec15[((IOTA - 314) & 511)])) + (0.00875098072f * fVec15[((IOTA - 315) & 511)])) + (0.00589523884f * fVec15[((IOTA - 316) & 511)])) + (0.00196410203f * fVec15[((IOTA - 317) & 511)])) + (0.000857178587f * fVec15[((IOTA - 321) & 511)])) + (0.00237958878f * fVec15[((IOTA - 322) & 511)])) + (0.00300089037f * fVec15[((IOTA - 323) & 511)])) + (0.00317084044f * fVec15[((IOTA - 324) & 511)])) + (0.00226453552f * fVec15[((IOTA - 325) & 511)])) + (0.00128525775f * fVec15[((IOTA - 326) & 511)])) + (0.000947684981f * fVec15[((IOTA - 327) & 511)])) + (0.000912968069f * fVec15[((IOTA - 328) & 511)])) + (0.00162888784f * fVec15[((IOTA - 329) & 511)])) + (0.00241860934f * fVec15[((IOTA - 330) & 511)])) + (0.00248906342f * fVec15[((IOTA - 331) & 511)])) + (0.00282424549f * fVec15[((IOTA - 332) & 511)])) + (0.00352126081f * fVec15[((IOTA - 333) & 511)])) + (0.00419650273f * fVec15[((IOTA - 334) & 511)])) + (0.00528764585f * fVec15[((IOTA - 335) & 511)])) + (0.00624291785f * fVec15[((IOTA - 336) & 511)])) + (0.00679510413f * fVec15[((IOTA - 337) & 511)])) + (0.00736032939f * fVec15[((IOTA - 338) & 511)])) + (0.00673625432f * fVec15[((IOTA - 339) & 511)])) + (0.00605262863f * fVec15[((IOTA - 340) & 511)])) + (0.00533380732f * fVec15[((IOTA - 341) & 511)])) + (0.0036358363f * fVec15[((IOTA - 342) & 511)])) + (0.00237547653f * fVec15[((IOTA - 343) & 511)])) + (0.0023862836f * fVec15[((IOTA - 344) & 511)])) + (0.00324875396f * fVec15[((IOTA - 345) & 511)])) + (0.00495931786f * fVec15[((IOTA - 346) & 511)])) + (0.00691930717f * fVec15[((IOTA - 347) & 511)])) + (0.00842743553f * fVec15[((IOTA - 348) & 511)])) + (0.0093645677f * fVec15[((IOTA - 349) & 511)])) + (0.00872952677f * fVec15[((IOTA - 350) & 511)])) + (0.006518804f * fVec15[((IOTA - 351) & 511)])) + (0.00360994972f * fVec15[((IOTA - 352) & 511)])) + (0.000446250662f * fVec15[((IOTA - 353) & 511)])) + (0.00244800234f * fVec15[((IOTA - 357) & 511)])) + (0.00490633398f * fVec15[((IOTA - 358) & 511)])) + (0.00652686926f * fVec15[((IOTA - 359) & 511)])) + (0.0070770476f * fVec15[((IOTA - 360) & 511)])) + (0.00607287185f * fVec15[((IOTA - 361) & 511)])) + (0.00406117365f * fVec15[((IOTA - 362) & 511)])) + (0.00229880586f * fVec15[((IOTA - 363) & 511)])) + (0.00144487899f * fVec15[((IOTA - 364) & 511)])) + (0.000303812791f * fVec15[((IOTA - 365) & 511)])) + (0.000784812029f * fVec15[((IOTA - 372) & 511)])) + (0.00204619206f * fVec15[((IOTA - 373) & 511)])) + (0.00261559337f * fVec15[((IOTA - 374) & 511)])) + (0.00332019618f * fVec15[((IOTA - 375) & 511)])) + (0.00354969734f * fVec15[((IOTA - 376) & 511)])) + (0.00324996561f * fVec15[((IOTA - 377) & 511)])) + (0.00239938591f * fVec15[((IOTA - 378) & 511)])) + (0.00115703791f * fVec15[((IOTA - 379) & 511)])) + (0.000665167812f * fVec15[((IOTA - 380) & 511)])) + (0.000592737459f * fVec15[((IOTA - 381) & 511)])) + (0.000906528439f * fVec15[((IOTA - 382) & 511)])) + (0.00253280206f * fVec15[((IOTA - 383) & 511)])) + (0.00421604468f * fVec15[((IOTA - 384) & 511)])) + (0.00465292297f * fVec15[((IOTA - 385) & 511)])) + (0.00430454267f * fVec15[((IOTA - 386) & 511)])) + (0.00254912442f * fVec15[((IOTA - 387) & 511)])) + (0.000995217357f * fVec15[((IOTA - 388) & 511)])) + (0.000569337513f * fVec15[((IOTA - 389) & 511)])) + (0.00060175918f * fVec15[((IOTA - 390) & 511)])) + (0.0017641848f * fVec15[((IOTA - 391) & 511)])) + (0.00343464408f * fVec15[((IOTA - 392) & 511)])) + (0.00344401645f * fVec15[((IOTA - 393) & 511)])) + (0.00224269787f * fVec15[((IOTA - 394) & 511)])) + (0.000444210134f * fVec15[((IOTA - 395) & 511)])) + (0.00132740289f * fVec15[((IOTA - 401) & 511)])) + (0.00170332706f * fVec15[((IOTA - 402) & 511)])) + (0.00166051276f * fVec15[((IOTA - 403) & 511)])) + (0.00170868263f * fVec15[((IOTA - 404) & 511)])) + (0.0020039198f * fVec15[((IOTA - 405) & 511)])) + (0.00215936452f * fVec15[((IOTA - 406) & 511)])) + (0.00203548046f * fVec15[((IOTA - 407) & 511)])) + (0.00233849604f * fVec15[((IOTA - 408) & 511)])) + (0.00205798727f * fVec15[((IOTA - 409) & 511)])) + (0.000800273381f * fVec15[((IOTA - 410) & 511)])) + (0.000792494975f * fVec15[((IOTA - 417) & 511)])) + (0.00194717385f * fVec15[((IOTA - 418) & 511)])) + (0.00223023305f * fVec15[((IOTA - 419) & 511)])) + (0.00231831614f * fVec15[((IOTA - 420) & 511)])) + (0.00158342766f * fVec15[((IOTA - 421) & 511)])) + (0.000705049373f * fVec15[((IOTA - 422) & 511)])) + (0.000748182181f * fVec15[((IOTA - 423) & 511)])) + (0.00123042474f * fVec15[((IOTA - 424) & 511)])) + (0.0018962943f * fVec15[((IOTA - 425) & 511)])) + (0.00250544958f * fVec15[((IOTA - 426) & 511)])) + (0.00320338923f * fVec15[((IOTA - 427) & 511)])) + (0.00359126832f * fVec15[((IOTA - 428) & 511)])) + (0.00266150013f * fVec15[((IOTA - 429) & 511)])) + (0.000530763529f * fVec15[((IOTA - 430) & 511)])) + (0.000426804181f * fVec15[((IOTA - 451) & 511)])) + (0.000509946141f * fVec15[((IOTA - 452) & 511)])) + (0.000547340605f * fVec15[((IOTA - 469) & 511)])) + (0.00181356631f * fVec15[((IOTA - 470) & 511)])) + (0.00229313131f * fVec15[((IOTA - 471) & 511)])) + (0.00146368798f * fVec15[((IOTA - 472) & 511)])) + (0.000101600308f * fVec15[((IOTA - 473) & 511)])) + (0.00121719483f * fVec15[((IOTA - 493) & 511)])) + (0.00210351124f * fVec15[((IOTA - 494) & 511)])) + (0.00256627565f * fVec15[((IOTA - 495) & 511)])) + (0.0021936032f * fVec15[((IOTA - 496) & 511)])) + (0.000865785871f * fVec15[((IOTA - 497) & 511)])) - (((((((0.00564951077f * fVec15[((IOTA - 505) & 511)]) + ((0.00532488106f * fVec15[((IOTA - 504) & 511)]) + ((0.00515563227f * fVec15[((IOTA - 503) & 511)]) + ((0.00431257626f * fVec15[((IOTA - 502) & 511)]) + ((0.00363443326f * fVec15[((IOTA - 501) & 511)]) + ((0.0029104799f * fVec15[((IOTA - 500) & 511)]) + ((0.0015036012f * fVec15[((IOTA - 499) & 511)]) + ((0.000200681854f * fVec15[((IOTA - 498) & 511)]) + ((8.71908851e-05f * fVec15[((IOTA - 492) & 511)]) + ((0.00146212569f * fVec15[((IOTA - 491) & 511)]) + ((0.00285832491f * fVec15[((IOTA - 490) & 511)]) + ((0.00371387741f * fVec15[((IOTA - 489) & 511)]) + ((0.00329124974f * fVec15[((IOTA - 488) & 511)]) + ((0.00269522844f * fVec15[((IOTA - 487) & 511)]) + ((0.00242386945f * fVec15[((IOTA - 486) & 511)]) + ((0.00198887242f * fVec15[((IOTA - 485) & 511)]) + ((0.00248778798f * fVec15[((IOTA - 484) & 511)]) + ((0.00345976511f * fVec15[((IOTA - 483) & 511)]) + ((0.00432229973f * fVec15[((IOTA - 482) & 511)]) + ((0.00454944186f * fVec15[((IOTA - 481) & 511)]) + ((0.00364163844f * fVec15[((IOTA - 480) & 511)]) + ((0.00279931538f * fVec15[((IOTA - 479) & 511)]) + ((0.00222372962f * fVec15[((IOTA - 478) & 511)]) + ((0.00134538254f * fVec15[((IOTA - 477) & 511)]) + ((0.00147978729f * fVec15[((IOTA - 476) & 511)]) + ((0.00173951034f * fVec15[((IOTA - 475) & 511)]) + ((0.000997671857f * fVec15[((IOTA - 474) & 511)]) + ((0.00158170611f * fVec15[((IOTA - 468) & 511)]) + ((0.00416911812f * fVec15[((IOTA - 467) & 511)]) + ((0.00586575037f * fVec15[((IOTA - 466) & 511)]) + ((0.00594098587f * fVec15[((IOTA - 465) & 511)]) + ((0.00474212179f * fVec15[((IOTA - 464) & 511)]) + ((0.00294315629f * fVec15[((IOTA - 463) & 511)]) + ((0.0016014399f * fVec15[((IOTA - 462) & 511)]) + ((0.0015091165f * fVec15[((IOTA - 461) & 511)]) + ((0.00222248631f * fVec15[((IOTA - 460) & 511)]) + ((0.00359117286f * fVec15[((IOTA - 459) & 511)]) + ((0.00470064674f * fVec15[((IOTA - 457) & 511)]) + ((0.00454156753f * fVec15[((IOTA - 456) & 511)]) + ((0.00348692667f * fVec15[((IOTA - 455) & 511)]) + ((0.00140608149f * fVec15[((IOTA - 454) & 511)]) + ((7.06133433e-05f * fVec15[((IOTA - 453) & 511)]) + ((0.000949852634f * fVec15[((IOTA - 450) & 511)]) + ((0.00191373238f * fVec15[((IOTA - 449) & 511)]) + ((0.00212365948f * fVec15[((IOTA - 448) & 511)]) + ((0.00207485165f * fVec15[((IOTA - 447) & 511)]) + ((0.00150532275f * fVec15[((IOTA - 446) & 511)]) + ((0.00198329333f * fVec15[((IOTA - 445) & 511)]) + ((0.00401826389f * fVec15[((IOTA - 444) & 511)]) + ((0.00606879126f * fVec15[((IOTA - 443) & 511)]) + ((0.00754233031f * fVec15[((IOTA - 442) & 511)]) + ((0.00800267141f * fVec15[((IOTA - 441) & 511)]) + ((0.00734014995f * fVec15[((IOTA - 440) & 511)]) + ((0.00599352363f * fVec15[((IOTA - 439) & 511)]) + ((0.00425736094f * fVec15[((IOTA - 438) & 511)]) + ((0.00319879875f * fVec15[((IOTA - 437) & 511)]) + ((0.00368748093f * fVec15[((IOTA - 436) & 511)]) + ((0.00467147678f * fVec15[((IOTA - 435) & 511)]) + ((0.00516930874f * fVec15[((IOTA - 434) & 511)]) + ((0.00488306163f * fVec15[((IOTA - 433) & 511)]) + ((0.00335708121f * fVec15[((IOTA - 432) & 511)]) + ((0.00155020924f * fVec15[((IOTA - 431) & 511)]) + ((0.00134904869f * fVec15[((IOTA - 416) & 511)]) + ((0.00263217092f * fVec15[((IOTA - 415) & 511)]) + ((0.00334069505f * fVec15[((IOTA - 414) & 511)]) + ((0.00324668176f * fVec15[((IOTA - 413) & 511)]) + ((0.00170259364f * fVec15[((IOTA - 412) & 511)]) + ((0.0003464357f * fVec15[((IOTA - 411) & 511)]) + ((0.000121620484f * fVec15[((IOTA - 400) & 511)]) + ((0.0019989782f * fVec15[((IOTA - 399) & 511)]) + ((0.00320517458f * fVec15[((IOTA - 398) & 511)]) + ((0.00328818895f * fVec15[((IOTA - 397) & 511)]) + ((0.00184751814f * fVec15[((IOTA - 396) & 511)]) + ((0.000509085134f * fVec15[((IOTA - 371) & 511)]) + ((0.000996237621f * fVec15[((IOTA - 370) & 511)]) + ((0.00182644604f * fVec15[((IOTA - 369) & 511)]) + ((0.00247188006f * fVec15[((IOTA - 368) & 511)]) + ((0.00173361227f * fVec15[((IOTA - 367) & 511)]) + ((0.000829124358f * fVec15[((IOTA - 366) & 511)]) + ((0.000363267958f * fVec15[((IOTA - 356) & 511)]) + ((0.00218285993f * fVec15[((IOTA - 355) & 511)]) + ((0.00202317489f * fVec15[((IOTA - 354) & 511)]) + ((0.00464409217f * fVec15[((IOTA - 458) & 511)]) + ((0.00102515239f * fVec15[((IOTA - 320) & 511)]) + ((0.00170845957f * fVec15[((IOTA - 319) & 511)]) + ((0.000833077822f * fVec15[((IOTA - 318) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.21769397f * fVec15[((IOTA - 7) & 511)]) + ((0.132713139f * fVec15[((IOTA - 6) & 511)]) + ((0.0302847568f * fVec15[((IOTA - 5) & 511)]) + ((0.194019422f * fVec15[((IOTA - 8) & 511)]) + (0.0920871198f * fVec15[((IOTA - 9) & 511)]))))) + (0.0148624908f * fVec15[((IOTA - 21) & 511)])) + (0.00650021806f * fVec15[((IOTA - 22) & 511)])) + (0.00251239911f * fVec15[((IOTA - 29) & 511)])) + (0.0282259081f * fVec15[((IOTA - 30) & 511)])) + (0.0580869205f * fVec15[((IOTA - 31) & 511)])) + (0.0691758543f * fVec15[((IOTA - 32) & 511)])) + (0.0539982691f * fVec15[((IOTA - 33) & 511)])) + (0.0405293591f * fVec15[((IOTA - 34) & 511)])) + (0.00574279064f * fVec15[((IOTA - 35) & 511)])) + (0.00068190461f * fVec15[((IOTA - 40) & 511)])) + (0.00563031947f * fVec15[((IOTA - 41) & 511)])) + (0.00645590527f * fVec15[((IOTA - 42) & 511)])) + (0.0203572903f * fVec15[((IOTA - 43) & 511)])) + (0.0395238474f * fVec15[((IOTA - 44) & 511)])) + (0.0454251729f * fVec15[((IOTA - 45) & 511)])) + (0.0442300402f * fVec15[((IOTA - 46) & 511)])) + (0.0351129547f * fVec15[((IOTA - 47) & 511)])) + (0.00723348046f * fVec15[((IOTA - 48) & 511)])) + (0.0130111473f * fVec15[((IOTA - 53) & 511)])) + (0.0189498384f * fVec15[((IOTA - 54) & 511)])) + (0.0152507536f * fVec15[((IOTA - 55) & 511)])) + (0.021289099f * fVec15[((IOTA - 56) & 511)])) + (0.0231747143f * fVec15[((IOTA - 57) & 511)])) + (0.0299102031f * fVec15[((IOTA - 58) & 511)])) + (0.0312205181f * fVec15[((IOTA - 59) & 511)])) + (0.0169370249f * fVec15[((IOTA - 60) & 511)])) + (0.00953521952f * fVec15[((IOTA - 61) & 511)])) + (0.0107946862f * fVec15[((IOTA - 65) & 511)])) + (0.0283832978f * fVec15[((IOTA - 66) & 511)])) + (0.045857016f * fVec15[((IOTA - 67) & 511)])) + (0.0452962518f * fVec15[((IOTA - 68) & 511)])) + (0.0357788205f * fVec15[((IOTA - 69) & 511)])) + (0.0200874936f * fVec15[((IOTA - 70) & 511)])) + (0.00327763706f * fVec15[((IOTA - 71) & 511)])) + (0.00376504427f * fVec15[((IOTA - 75) & 511)])) + (0.0159293097f * fVec15[((IOTA - 76) & 511)])) + (0.0228884351f * fVec15[((IOTA - 77) & 511)])) + (0.0197178498f * fVec15[((IOTA - 78) & 511)])) + (0.00949368067f * fVec15[((IOTA - 79) & 511)])) + (0.00092769647f * fVec15[((IOTA - 80) & 511)])) + (0.00179360993f * fVec15[((IOTA - 83) & 511)])) + (0.00883861817f * fVec15[((IOTA - 84) & 511)])) + (0.010395905f * fVec15[((IOTA - 85) & 511)])) + (0.00720294006f * fVec15[((IOTA - 86) & 511)])) + (0.0100087589f * fVec15[((IOTA - 87) & 511)])) + (0.0175071266f * fVec15[((IOTA - 88) & 511)])) + (0.0269629993f * fVec15[((IOTA - 89) & 511)])) + (0.0350461677f * fVec15[((IOTA - 90) & 511)])) + (0.0385838114f * fVec15[((IOTA - 91) & 511)])) + (0.0346524529f * fVec15[((IOTA - 92) & 511)])) + (0.020367492f * fVec15[((IOTA - 93) & 511)])) + (0.00193238165f * fVec15[((IOTA - 94) & 511)])) + (0.00434993906f * fVec15[((IOTA - 100) & 511)])) + (0.00803404115f * fVec15[((IOTA - 101) & 511)])) + (0.0120941307f * fVec15[((IOTA - 102) & 511)])) + (0.0192106143f * fVec15[((IOTA - 103) & 511)])) + (0.0250227097f * fVec15[((IOTA - 104) & 511)])) + (0.0266696736f * fVec15[((IOTA - 105) & 511)])) + (0.0208930913f * fVec15[((IOTA - 106) & 511)])) + (0.0108738113f * fVec15[((IOTA - 107) & 511)])) + (0.00943757221f * fVec15[((IOTA - 112) & 511)])) + (0.0214484651f * fVec15[((IOTA - 113) & 511)])) + (0.0294889137f * fVec15[((IOTA - 114) & 511)])) + (0.0329210386f * fVec15[((IOTA - 115) & 511)])) + (0.0295457561f * fVec15[((IOTA - 116) & 511)])) + (0.0200876854f * fVec15[((IOTA - 117) & 511)])) + (0.00801459514f * fVec15[((IOTA - 118) & 511)])) + (0.00596840261f * fVec15[((IOTA - 122) & 511)])) + (0.0185009725f * fVec15[((IOTA - 123) & 511)])) + (0.0285996646f * fVec15[((IOTA - 124) & 511)])) + (0.0319049433f * fVec15[((IOTA - 125) & 511)])) + (0.0269027129f * fVec15[((IOTA - 126) & 511)])) + (0.0181259103f * fVec15[((IOTA - 127) & 511)])) + (0.00714297453f * fVec15[((IOTA - 128) & 511)])) + (0.000240691006f * fVec15[((IOTA - 135) & 511)])) + (0.00618272927f * fVec15[((IOTA - 136) & 511)])) + (0.0122064427f * fVec15[((IOTA - 137) & 511)])) + (0.0157730356f * fVec15[((IOTA - 138) & 511)])) + (0.0177503359f * fVec15[((IOTA - 139) & 511)])) + (0.0149816256f * fVec15[((IOTA - 140) & 511)])) + (0.00904532522f * fVec15[((IOTA - 141) & 511)])) + (0.00274164556f * fVec15[((IOTA - 142) & 511)])) + (0.00314265862f * fVec15[((IOTA - 148) & 511)])) + (0.0085610114f * fVec15[((IOTA - 149) & 511)])) + (0.0111977085f * fVec15[((IOTA - 150) & 511)])) + (0.0116311116f * fVec15[((IOTA - 151) & 511)])) + (0.00977339223f * fVec15[((IOTA - 152) & 511)])) + (0.00457861135f * fVec15[((IOTA - 153) & 511)])) + (0.00309353229f * fVec15[((IOTA - 158) & 511)])) + (0.00776201254f * fVec15[((IOTA - 159) & 511)])) + (0.0101135466f * fVec15[((IOTA - 160) & 511)])) + (0.0103365444f * fVec15[((IOTA - 161) & 511)])) + (0.00931627024f * fVec15[((IOTA - 162) & 511)])) + (0.00707398681f * fVec15[((IOTA - 163) & 511)])) + (0.00306643452f * fVec15[((IOTA - 164) & 511)])) + (0.000155157875f * fVec15[((IOTA - 165) & 511)])) + (0.000462828204f * fVec15[((IOTA - 170) & 511)])) + (0.0040884628f * fVec15[((IOTA - 171) & 511)])) + (0.00699441554f * fVec15[((IOTA - 172) & 511)])) + (0.00999846123f * fVec15[((IOTA - 173) & 511)])) + (0.0109392926f * fVec15[((IOTA - 174) & 511)])) + (0.00948523171f * fVec15[((IOTA - 175) & 511)])) + (0.00770963402f * fVec15[((IOTA - 176) & 511)])) + (0.00439951196f * fVec15[((IOTA - 177) & 511)])) + (1.66730024e-05f * fVec15[((IOTA - 178) & 511)])) + (0.0015522493f * fVec15[((IOTA - 184) & 511)])) + (0.0036013741f * fVec15[((IOTA - 185) & 511)])) + (0.00324607641f * fVec15[((IOTA - 186) & 511)])) + (0.00166618731f * fVec15[((IOTA - 187) & 511)])) + (0.000267629046f * fVec15[((IOTA - 188) & 511)])) + (0.00240665441f * fVec15[((IOTA - 196) & 511)])) + (0.00470558787f * fVec15[((IOTA - 197) & 511)])) + (0.00472442899f * fVec15[((IOTA - 198) & 511)])) + (0.00423781853f * fVec15[((IOTA - 199) & 511)])) + (0.00354440557f * fVec15[((IOTA - 200) & 511)])) + (0.00274075288f * fVec15[((IOTA - 201) & 511)])) + (0.00263947109f * fVec15[((IOTA - 202) & 511)])) + (0.0031070495f * fVec15[((IOTA - 203) & 511)])) + (0.00390171213f * fVec15[((IOTA - 204) & 511)])) + (0.00431490364f * fVec15[((IOTA - 205) & 511)])) + (0.00302566076f * fVec15[((IOTA - 206) & 511)])) + (0.00045533618f * fVec15[((IOTA - 207) & 511)])) + (0.00174333574f * fVec15[((IOTA - 217) & 511)])) + (0.00266016088f * fVec15[((IOTA - 218) & 511)])) + (0.00177751062f * fVec15[((IOTA - 219) & 511)])) + (0.000684837345f * fVec15[((IOTA - 244) & 511)])) + (0.00278815767f * fVec15[((IOTA - 245) & 511)])) + (0.00355951628f * fVec15[((IOTA - 246) & 511)])) + (0.00155368401f * fVec15[((IOTA - 247) & 511)])) + (0.00585373165f * fVec15[((IOTA - 506) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00564823579f * fVec15[((IOTA - 507) & 511)])) + (0.00565671595f * fVec15[((IOTA - 508) & 511)])) + (0.00567766046f * fVec15[((IOTA - 509) & 511)])) + (0.00564447418f * fVec15[((IOTA - 510) & 511)])) + (0.00580046093f * fVec15[((IOTA - 511) & 511)]))) : ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0083594108f * fVec14[((IOTA - 341) & 511)]) + ((0.00689386204f * fVec14[((IOTA - 340) & 511)]) + ((0.0063899341f * fVec14[((IOTA - 339) & 511)]) + ((0.00662315823f * fVec14[((IOTA - 338) & 511)]) + ((0.00568963122f * fVec14[((IOTA - 337) & 511)]) + ((0.0050467765f * fVec14[((IOTA - 336) & 511)]) + ((0.00430937251f * fVec14[((IOTA - 335) & 511)]) + ((0.0031568259f * fVec14[((IOTA - 334) & 511)]) + ((0.00315692043f * fVec14[((IOTA - 333) & 511)]) + ((0.00406783354f * fVec14[((IOTA - 332) & 511)]) + ((0.0050080684f * fVec14[((IOTA - 331) & 511)]) + ((0.00548160356f * fVec14[((IOTA - 330) & 511)]) + ((0.00483969366f * fVec14[((IOTA - 329) & 511)]) + ((0.00349978032f * fVec14[((IOTA - 328) & 511)]) + ((0.00179061387f * fVec14[((IOTA - 327) & 511)]) + ((0.00104149338f * fVec14[((IOTA - 326) & 511)]) + ((0.00177348033f * fVec14[((IOTA - 325) & 511)]) + ((0.00279402919f * fVec14[((IOTA - 324) & 511)]) + ((0.0038672071f * fVec14[((IOTA - 323) & 511)]) + ((0.00487112626f * fVec14[((IOTA - 322) & 511)]) + ((0.00367580866f * fVec14[((IOTA - 321) & 511)]) + ((0.00181423547f * fVec14[((IOTA - 320) & 511)]) + ((0.0011897427f * fVec14[((IOTA - 319) & 511)]) + ((((((((((((((((((((((((((((((((((((((((0.00809188746f * fVec14[((IOTA - 280) & 511)]) + ((0.00717010908f * fVec14[((IOTA - 279) & 511)]) + ((0.00603901083f * fVec14[((IOTA - 278) & 511)]) + ((0.00554758683f * fVec14[((IOTA - 277) & 511)]) + ((0.00594452443f * fVec14[((IOTA - 276) & 511)]) + ((0.00691940496f * fVec14[((IOTA - 275) & 511)]) + ((0.00992202852f * fVec14[((IOTA - 274) & 511)]) + ((0.0144899162f * fVec14[((IOTA - 273) & 511)]) + ((0.0183603037f * fVec14[((IOTA - 272) & 511)]) + ((0.020269813f * fVec14[((IOTA - 271) & 511)]) + ((0.0201926809f * fVec14[((IOTA - 270) & 511)]) + ((0.0192400049f * fVec14[((IOTA - 269) & 511)]) + ((0.0166002102f * fVec14[((IOTA - 268) & 511)]) + ((0.0143837444f * fVec14[((IOTA - 267) & 511)]) + ((0.0136632221f * fVec14[((IOTA - 266) & 511)]) + ((0.0122067444f * fVec14[((IOTA - 265) & 511)]) + ((0.010771526f * fVec14[((IOTA - 264) & 511)]) + ((0.00981793553f * fVec14[((IOTA - 263) & 511)]) + ((0.00773312245f * fVec14[((IOTA - 262) & 511)]) + ((0.00550635904f * fVec14[((IOTA - 261) & 511)]) + ((0.00497751776f * fVec14[((IOTA - 260) & 511)]) + ((0.00418077642f * fVec14[((IOTA - 259) & 511)]) + ((0.00464139786f * fVec14[((IOTA - 258) & 511)]) + ((0.00858951733f * fVec14[((IOTA - 257) & 511)]) + ((0.0116466284f * fVec14[((IOTA - 256) & 511)]) + ((0.0133908801f * fVec14[((IOTA - 255) & 511)]) + ((0.0151801407f * fVec14[((IOTA - 254) & 511)]) + ((0.0149474517f * fVec14[((IOTA - 253) & 511)]) + ((0.0132757965f * fVec14[((IOTA - 252) & 511)]) + ((0.0111824786f * fVec14[((IOTA - 251) & 511)]) + ((0.00738645159f * fVec14[((IOTA - 250) & 511)]) + ((0.00203974312f * fVec14[((IOTA - 249) & 511)]) + ((0.00475556916f * fVec14[((IOTA - 243) & 511)]) + ((0.0104896724f * fVec14[((IOTA - 242) & 511)]) + ((0.0152570838f * fVec14[((IOTA - 241) & 511)]) + ((0.0176402219f * fVec14[((IOTA - 240) & 511)]) + ((0.0159402527f * fVec14[((IOTA - 239) & 511)]) + ((0.0130169969f * fVec14[((IOTA - 238) & 511)]) + ((0.0100673493f * fVec14[((IOTA - 237) & 511)]) + ((0.00621333858f * fVec14[((IOTA - 236) & 511)]) + ((0.00355902361f * fVec14[((IOTA - 235) & 511)]) + ((0.00253960863f * fVec14[((IOTA - 234) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((0.0113946646f * fVec14[((IOTA - 100) & 511)]) + ((0.0049995333f * fVec14[((IOTA - 99) & 511)]) + ((0.00716308551f * fVec14[((IOTA - 74) & 511)]) + ((0.00413066708f * fVec14[((IOTA - 73) & 511)]) + (((((((((((((((((((((((0.00797428377f * fVec14[((IOTA - 16) & 511)]) + ((0.0276659019f * fVec14[((IOTA - 15) & 511)]) + ((0.0390019231f * fVec14[((IOTA - 14) & 511)]) + ((0.0768951103f * fVec14[((IOTA - 13) & 511)]) + ((0.0896160826f * fVec14[((IOTA - 12) & 511)]) + ((0.0552691594f * fVec14[((IOTA - 11) & 511)]) + ((0.0528197251f * fVec14[((IOTA - 5) & 511)]) + ((0.18527782f * fVec14[((IOTA - 4) & 511)]) + ((0.255220503f * fVec14[((IOTA - 3) & 511)]) + ((0.234922484f * fVec14[((IOTA - 2) & 511)]) + ((0.22788462f * fVec14[((IOTA - 1) & 511)]) + ((fSlow51 * fTemp0) + ((0.0142134801f * fVec14[((IOTA - 22) & 511)]) + (((0.017579468f * fVec14[((IOTA - 20) & 511)]) + (0.00875754561f * fVec14[((IOTA - 21) & 511)])) + (0.0371138602f * fVec14[((IOTA - 23) & 511)]))))))))))))))) + (0.0439911559f * fVec14[((IOTA - 24) & 511)])) + (0.0568639673f * fVec14[((IOTA - 25) & 511)])) + (0.0533517785f * fVec14[((IOTA - 26) & 511)])) + (0.028127186f * fVec14[((IOTA - 27) & 511)])) + (0.00169294653f * fVec14[((IOTA - 28) & 511)])) + (0.000152343884f * fVec14[((IOTA - 36) & 511)])) + (0.0147604942f * fVec14[((IOTA - 37) & 511)])) + (0.00692642853f * fVec14[((IOTA - 38) & 511)])) + (0.00327921752f * fVec14[((IOTA - 39) & 511)])) + (0.0042403657f * fVec14[((IOTA - 42) & 511)])) + (0.00486246496f * fVec14[((IOTA - 43) & 511)])) + (0.0167122707f * fVec14[((IOTA - 51) & 511)])) + (0.0286255702f * fVec14[((IOTA - 52) & 511)])) + (0.027912166f * fVec14[((IOTA - 53) & 511)])) + (0.0221847091f * fVec14[((IOTA - 54) & 511)])) + (0.00507480744f * fVec14[((IOTA - 55) & 511)])) + (0.00495651038f * fVec14[((IOTA - 63) & 511)])) + (0.0183670446f * fVec14[((IOTA - 64) & 511)])) + (0.0176919065f * fVec14[((IOTA - 65) & 511)])) + (0.00165480515f * fVec14[((IOTA - 66) & 511)])) + (0.0138830924f * fVec14[((IOTA - 101) & 511)])))))) + (0.00920298696f * fVec14[((IOTA - 102) & 511)])) + (0.00164674222f * fVec14[((IOTA - 134) & 511)])) + (0.00291997986f * fVec14[((IOTA - 135) & 511)])) + (0.00306520564f * fVec14[((IOTA - 136) & 511)])) + (0.000264940318f * fVec14[((IOTA - 137) & 511)])) + (0.00134498393f * fVec14[((IOTA - 154) & 511)])) + (0.00164419133f * fVec14[((IOTA - 155) & 511)])) + (0.000379363541f * fVec14[((IOTA - 163) & 511)])) + (0.000601942185f * fVec14[((IOTA - 164) & 511)])) + (0.000182421878f * fVec14[((IOTA - 179) & 511)])) + (0.00248452276f * fVec14[((IOTA - 180) & 511)])) + (0.00470961723f * fVec14[((IOTA - 181) & 511)])) + (0.00446240883f * fVec14[((IOTA - 182) & 511)])) + (0.00107787084f * fVec14[((IOTA - 183) & 511)])) + (0.00139282551f * fVec14[((IOTA - 187) & 511)])) + (0.00563857704f * fVec14[((IOTA - 188) & 511)])) + (0.0091649713f * fVec14[((IOTA - 189) & 511)])) + (0.00951639749f * fVec14[((IOTA - 190) & 511)])) + (0.00594307575f * fVec14[((IOTA - 191) & 511)])) + (0.00174072525f * fVec14[((IOTA - 192) & 511)])) + (0.00220723636f * fVec14[((IOTA - 195) & 511)])) + (0.00443418883f * fVec14[((IOTA - 196) & 511)])) + (0.00451796688f * fVec14[((IOTA - 197) & 511)])) + (0.00260190666f * fVec14[((IOTA - 198) & 511)])) + (0.000744553749f * fVec14[((IOTA - 206) & 511)])) + (0.00250990828f * fVec14[((IOTA - 207) & 511)])) + (0.0031765108f * fVec14[((IOTA - 208) & 511)])) + (0.0028356663f * fVec14[((IOTA - 209) & 511)])) + (0.00182903837f * fVec14[((IOTA - 210) & 511)])) + (0.00135714142f * fVec14[((IOTA - 211) & 511)])) + (0.00355483452f * fVec14[((IOTA - 212) & 511)])) + (0.00870995596f * fVec14[((IOTA - 213) & 511)])) + (0.0130311698f * fVec14[((IOTA - 214) & 511)])) + (0.0127190184f * fVec14[((IOTA - 215) & 511)])) + (0.00867228769f * fVec14[((IOTA - 216) & 511)])) + (0.00269324332f * fVec14[((IOTA - 217) & 511)])) + (0.00292127114f * fVec14[((IOTA - 223) & 511)])) + (0.00618218957f * fVec14[((IOTA - 224) & 511)])) + (0.00856479257f * fVec14[((IOTA - 225) & 511)])) + (0.0106346775f * fVec14[((IOTA - 226) & 511)])) + (0.0111948885f * fVec14[((IOTA - 227) & 511)])) + (0.0102578653f * fVec14[((IOTA - 228) & 511)])) + (0.00877650641f * fVec14[((IOTA - 229) & 511)])) + (0.00770638278f * fVec14[((IOTA - 230) & 511)])) + (0.00617998466f * fVec14[((IOTA - 231) & 511)])) + (0.00357439322f * fVec14[((IOTA - 232) & 511)])) + (0.0022001816f * fVec14[((IOTA - 233) & 511)])) + (0.00926399324f * fVec14[((IOTA - 281) & 511)])))))))))))))))))))))))))))))))))))))))))))) + (0.0101943705f * fVec14[((IOTA - 282) & 511)])) + (0.0106241889f * fVec14[((IOTA - 283) & 511)])) + (0.0108085647f * fVec14[((IOTA - 284) & 511)])) + (0.0105291996f * fVec14[((IOTA - 285) & 511)])) + (0.00967538729f * fVec14[((IOTA - 286) & 511)])) + (0.0087648835f * fVec14[((IOTA - 287) & 511)])) + (0.00822010636f * fVec14[((IOTA - 288) & 511)])) + (0.00823916122f * fVec14[((IOTA - 289) & 511)])) + (0.00827849843f * fVec14[((IOTA - 290) & 511)])) + (0.00763047859f * fVec14[((IOTA - 291) & 511)])) + (0.00703058392f * fVec14[((IOTA - 292) & 511)])) + (0.00742380507f * fVec14[((IOTA - 293) & 511)])) + (0.00768099772f * fVec14[((IOTA - 294) & 511)])) + (0.00815755595f * fVec14[((IOTA - 295) & 511)])) + (0.0094633596f * fVec14[((IOTA - 296) & 511)])) + (0.0106536057f * fVec14[((IOTA - 297) & 511)])) + (0.0121823344f * fVec14[((IOTA - 298) & 511)])) + (0.0145272696f * fVec14[((IOTA - 299) & 511)])) + (0.0162321851f * fVec14[((IOTA - 300) & 511)])) + (0.0168243628f * fVec14[((IOTA - 301) & 511)])) + (0.0165185407f * fVec14[((IOTA - 302) & 511)])) + (0.0142576369f * fVec14[((IOTA - 303) & 511)])) + (0.0114151044f * fVec14[((IOTA - 304) & 511)])) + (0.0100789703f * fVec14[((IOTA - 305) & 511)])) + (0.00855584815f * fVec14[((IOTA - 306) & 511)])) + (0.00753649604f * fVec14[((IOTA - 307) & 511)])) + (0.00737095578f * fVec14[((IOTA - 308) & 511)])) + (0.00644883048f * fVec14[((IOTA - 309) & 511)])) + (0.00663241791f * fVec14[((IOTA - 310) & 511)])) + (0.00832429342f * fVec14[((IOTA - 311) & 511)])) + (0.0107154949f * fVec14[((IOTA - 312) & 511)])) + (0.0135604525f * fVec14[((IOTA - 313) & 511)])) + (0.0149172787f * fVec14[((IOTA - 314) & 511)])) + (0.0138561632f * fVec14[((IOTA - 315) & 511)])) + (0.0107447226f * fVec14[((IOTA - 316) & 511)])) + (0.00572181959f * fVec14[((IOTA - 317) & 511)])) + (0.00200670445f * fVec14[((IOTA - 318) & 511)])) + (0.00873908959f * fVec14[((IOTA - 342) & 511)]))))))))))))))))))))))))) + (0.00913668796f * fVec14[((IOTA - 343) & 511)])) + (0.0098209288f * fVec14[((IOTA - 344) & 511)])) + (0.00936581753f * fVec14[((IOTA - 345) & 511)])) + (0.00914012082f * fVec14[((IOTA - 346) & 511)])) + (0.00970533956f * fVec14[((IOTA - 347) & 511)])) + (0.00978225097f * fVec14[((IOTA - 348) & 511)])) + (0.00969270989f * fVec14[((IOTA - 349) & 511)])) + (0.00917772762f * fVec14[((IOTA - 350) & 511)])) + (0.0074673635f * fVec14[((IOTA - 351) & 511)])) + (0.0045805485f * fVec14[((IOTA - 352) & 511)])) + (0.00173420552f * fVec14[((IOTA - 353) & 511)])) + (0.000991509762f * fVec14[((IOTA - 356) & 511)])) + (0.00338268001f * fVec14[((IOTA - 357) & 511)])) + (0.00612373371f * fVec14[((IOTA - 358) & 511)])) + (0.00791828521f * fVec14[((IOTA - 359) & 511)])) + (0.0087586157f * fVec14[((IOTA - 360) & 511)])) + (0.00866819266f * fVec14[((IOTA - 361) & 511)])) + (0.00644328725f * fVec14[((IOTA - 362) & 511)])) + (0.00376528734f * fVec14[((IOTA - 363) & 511)])) + (0.00263526011f * fVec14[((IOTA - 364) & 511)])) + (0.0020197751f * fVec14[((IOTA - 365) & 511)])) + (0.00177766941f * fVec14[((IOTA - 366) & 511)])) + (0.00130397687f * fVec14[((IOTA - 367) & 511)])) + (0.00233529694f * fVec14[((IOTA - 374) & 511)])) + (0.00505975261f * fVec14[((IOTA - 375) & 511)])) + (0.0065483246f * fVec14[((IOTA - 376) & 511)])) + (0.00607929379f * fVec14[((IOTA - 377) & 511)])) + (0.00393170957f * fVec14[((IOTA - 378) & 511)])) + (0.00151490234f * fVec14[((IOTA - 379) & 511)])) + (0.00180425122f * fVec14[((IOTA - 383) & 511)])) + (0.003310272f * fVec14[((IOTA - 384) & 511)])) + (0.00381082995f * fVec14[((IOTA - 385) & 511)])) + (0.00350951264f * fVec14[((IOTA - 386) & 511)])) + (0.00253853761f * fVec14[((IOTA - 387) & 511)])) + (0.00214928482f * fVec14[((IOTA - 388) & 511)])) + (0.00303229271f * fVec14[((IOTA - 389) & 511)])) + (0.00432093116f * fVec14[((IOTA - 390) & 511)])) + (0.00545309996f * fVec14[((IOTA - 391) & 511)])) + (0.00664375629f * fVec14[((IOTA - 392) & 511)])) + (0.00628987281f * fVec14[((IOTA - 393) & 511)])) + (0.00360982586f * fVec14[((IOTA - 394) & 511)])) + (0.000194547698f * fVec14[((IOTA - 395) & 511)])) + (0.00256864727f * fVec14[((IOTA - 401) & 511)])) + (0.00378390122f * fVec14[((IOTA - 402) & 511)])) + (0.00367372995f * fVec14[((IOTA - 403) & 511)])) + (0.00287009077f * fVec14[((IOTA - 404) & 511)])) + (0.0012338995f * fVec14[((IOTA - 405) & 511)])) + (0.00151197333f * fVec14[((IOTA - 417) & 511)])) + (0.00391397765f * fVec14[((IOTA - 418) & 511)])) + (0.00475150626f * fVec14[((IOTA - 419) & 511)])) + (0.00492737722f * fVec14[((IOTA - 420) & 511)])) + (0.00345370267f * fVec14[((IOTA - 421) & 511)])) + (0.00130542554f * fVec14[((IOTA - 422) & 511)])) + (0.00164919905f * fVec14[((IOTA - 425) & 511)])) + (0.00368884811f * fVec14[((IOTA - 426) & 511)])) + (0.00538825104f * fVec14[((IOTA - 427) & 511)])) + (0.00568736345f * fVec14[((IOTA - 428) & 511)])) + (0.00337055419f * fVec14[((IOTA - 429) & 511)])) + (0.000979069155f * fVec14[((IOTA - 453) & 511)])) + (0.0018039681f * fVec14[((IOTA - 454) & 511)])) + (3.5400968e-05f * fVec14[((IOTA - 471) & 511)])) + (7.19986856e-05f * fVec14[((IOTA - 474) & 511)])) + (0.000248468015f * fVec14[((IOTA - 498) & 511)])) + (0.00127226068f * fVec14[((IOTA - 499) & 511)])) + (0.00103160366f * fVec14[((IOTA - 500) & 511)])) - (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0104785226f * fVec14[((IOTA - 10) & 511)]) + ((0.0777538046f * fVec14[((IOTA - 9) & 511)]) + ((0.131542489f * fVec14[((IOTA - 8) & 511)]) + ((0.155207679f * fVec14[((IOTA - 7) & 511)]) + ((0.0682933405f * fVec14[((IOTA - 6) & 511)]) + (((0.000910472125f * fVec14[((IOTA - 17) & 511)]) + (0.00217385124f * fVec14[((IOTA - 18) & 511)])) + (0.000858725049f * fVec14[((IOTA - 19) & 511)]))))))) + (0.0208215211f * fVec14[((IOTA - 29) & 511)])) + (0.0367100239f * fVec14[((IOTA - 30) & 511)])) + (0.0586043447f * fVec14[((IOTA - 31) & 511)])) + (0.0749782622f * fVec14[((IOTA - 32) & 511)])) + (0.0578253344f * fVec14[((IOTA - 33) & 511)])) + (0.0299232174f * fVec14[((IOTA - 34) & 511)])) + (0.0155302128f * fVec14[((IOTA - 35) & 511)])) + (0.00305169402f * fVec14[((IOTA - 40) & 511)])) + (0.00873953011f * fVec14[((IOTA - 41) & 511)])) + (0.0163016953f * fVec14[((IOTA - 44) & 511)])) + (0.033174213f * fVec14[((IOTA - 45) & 511)])) + (0.0555965565f * fVec14[((IOTA - 46) & 511)])) + (0.0720166415f * fVec14[((IOTA - 47) & 511)])) + (0.0604717471f * fVec14[((IOTA - 48) & 511)])) + (0.0385134257f * fVec14[((IOTA - 49) & 511)])) + (0.0112748556f * fVec14[((IOTA - 50) & 511)])) + (0.0204704721f * fVec14[((IOTA - 56) & 511)])) + (0.0429874249f * fVec14[((IOTA - 57) & 511)])) + (0.0631103441f * fVec14[((IOTA - 58) & 511)])) + (0.0735234842f * fVec14[((IOTA - 59) & 511)])) + (0.0624632053f * fVec14[((IOTA - 60) & 511)])) + (0.044000037f * fVec14[((IOTA - 61) & 511)])) + (0.0199519619f * fVec14[((IOTA - 62) & 511)])) + (0.0272468869f * fVec14[((IOTA - 67) & 511)])) + (0.0419010818f * fVec14[((IOTA - 68) & 511)])) + (0.0475371704f * fVec14[((IOTA - 69) & 511)])) + (0.0488021262f * fVec14[((IOTA - 70) & 511)])) + (0.0309741274f * fVec14[((IOTA - 71) & 511)])) + (0.00874097832f * fVec14[((IOTA - 72) & 511)])) + (0.0018111174f * fVec14[((IOTA - 75) & 511)])) + (0.0161651615f * fVec14[((IOTA - 76) & 511)])) + (0.0267441235f * fVec14[((IOTA - 77) & 511)])) + (0.0262226835f * fVec14[((IOTA - 78) & 511)])) + (0.0177545194f * fVec14[((IOTA - 79) & 511)])) + (0.011242982f * fVec14[((IOTA - 80) & 511)])) + (0.00479323789f * fVec14[((IOTA - 81) & 511)])) + (0.00353461457f * fVec14[((IOTA - 82) & 511)])) + (0.00122980494f * fVec14[((IOTA - 83) & 511)])) + (0.0013598185f * fVec14[((IOTA - 84) & 511)])) + (0.00142145529f * fVec14[((IOTA - 85) & 511)])) + (0.00118073495f * fVec14[((IOTA - 86) & 511)])) + (0.0034285062f * fVec14[((IOTA - 87) & 511)])) + (0.0116274152f * fVec14[((IOTA - 88) & 511)])) + (0.023193825f * fVec14[((IOTA - 89) & 511)])) + (0.0306212194f * fVec14[((IOTA - 90) & 511)])) + (0.0349473469f * fVec14[((IOTA - 91) & 511)])) + (0.0391827375f * fVec14[((IOTA - 92) & 511)])) + (0.0366356f * fVec14[((IOTA - 93) & 511)])) + (0.0313841999f * fVec14[((IOTA - 94) & 511)])) + (0.026190497f * fVec14[((IOTA - 95) & 511)])) + (0.0178696048f * fVec14[((IOTA - 96) & 511)])) + (0.0132446475f * fVec14[((IOTA - 97) & 511)])) + (0.00608175015f * fVec14[((IOTA - 98) & 511)])) + (0.00494492007f * fVec14[((IOTA - 103) & 511)])) + (0.0194003806f * fVec14[((IOTA - 104) & 511)])) + (0.0315180235f * fVec14[((IOTA - 105) & 511)])) + (0.0350702107f * fVec14[((IOTA - 106) & 511)])) + (0.0293316059f * fVec14[((IOTA - 107) & 511)])) + (0.0198231749f * fVec14[((IOTA - 108) & 511)])) + (0.0114088682f * fVec14[((IOTA - 109) & 511)])) + (0.00867131073f * fVec14[((IOTA - 110) & 511)])) + (0.0063892412f * fVec14[((IOTA - 111) & 511)])) + (0.0055497596f * fVec14[((IOTA - 112) & 511)])) + (0.00666495273f * fVec14[((IOTA - 113) & 511)])) + (0.00844268501f * fVec14[((IOTA - 114) & 511)])) + (0.0139347445f * fVec14[((IOTA - 115) & 511)])) + (0.0220371522f * fVec14[((IOTA - 116) & 511)])) + (0.0294344071f * fVec14[((IOTA - 117) & 511)])) + (0.0325725861f * fVec14[((IOTA - 118) & 511)])) + (0.0335448533f * fVec14[((IOTA - 119) & 511)])) + (0.0328518264f * fVec14[((IOTA - 120) & 511)])) + (0.0276766419f * fVec14[((IOTA - 121) & 511)])) + (0.0238530263f * fVec14[((IOTA - 122) & 511)])) + (0.0185917951f * fVec14[((IOTA - 123) & 511)])) + (0.0125830211f * fVec14[((IOTA - 124) & 511)])) + (0.00961318426f * fVec14[((IOTA - 125) & 511)])) + (0.00549533544f * fVec14[((IOTA - 126) & 511)])) + (0.00404062122f * fVec14[((IOTA - 127) & 511)])) + (0.00351341814f * fVec14[((IOTA - 128) & 511)])) + (0.00283680018f * fVec14[((IOTA - 129) & 511)])) + (0.00545199774f * fVec14[((IOTA - 130) & 511)])) + (0.00573592959f * fVec14[((IOTA - 131) & 511)])) + (0.00462429598f * fVec14[((IOTA - 132) & 511)])) + (0.00195495738f * fVec14[((IOTA - 133) & 511)])) + (0.00450672302f * fVec14[((IOTA - 138) & 511)])) + (0.00718191965f * fVec14[((IOTA - 139) & 511)])) + (0.00895747915f * fVec14[((IOTA - 140) & 511)])) + (0.0107212272f * fVec14[((IOTA - 141) & 511)])) + (0.0103775803f * fVec14[((IOTA - 142) & 511)])) + (0.00652996311f * fVec14[((IOTA - 143) & 511)])) + (0.00374928769f * fVec14[((IOTA - 144) & 511)])) + (0.00273569953f * fVec14[((IOTA - 145) & 511)])) + (0.00114212139f * fVec14[((IOTA - 146) & 511)])) + (0.00183836091f * fVec14[((IOTA - 147) & 511)])) + (0.0049302117f * fVec14[((IOTA - 148) & 511)])) + (0.00861713849f * fVec14[((IOTA - 149) & 511)])) + (0.0119972359f * fVec14[((IOTA - 150) & 511)])) + (0.0126509881f * fVec14[((IOTA - 151) & 511)])) + (0.00857115537f * fVec14[((IOTA - 152) & 511)])) + (0.00227743993f * fVec14[((IOTA - 153) & 511)])) + (0.00196594931f * fVec14[((IOTA - 156) & 511)])) + (0.00864290167f * fVec14[((IOTA - 157) & 511)])) + (0.0128848422f * fVec14[((IOTA - 158) & 511)])) + (0.0138877854f * fVec14[((IOTA - 159) & 511)])) + (0.0127065461f * fVec14[((IOTA - 160) & 511)])) + (0.00750711095f * fVec14[((IOTA - 161) & 511)])) + (0.00169820618f * fVec14[((IOTA - 162) & 511)])) + (0.00161805004f * fVec14[((IOTA - 165) & 511)])) + (0.00477474974f * fVec14[((IOTA - 166) & 511)])) + (0.00693981396f * fVec14[((IOTA - 167) & 511)])) + (0.00572799286f * fVec14[((IOTA - 168) & 511)])) + (0.00264303992f * fVec14[((IOTA - 169) & 511)])) + (0.000495487358f * fVec14[((IOTA - 170) & 511)])) + (0.000305632595f * fVec14[((IOTA - 171) & 511)])) + (0.00230628997f * fVec14[((IOTA - 172) & 511)])) + (0.00555936573f * fVec14[((IOTA - 173) & 511)])) + (0.00856995769f * fVec14[((IOTA - 174) & 511)])) + (0.010522333f * fVec14[((IOTA - 175) & 511)])) + (0.0108008794f * fVec14[((IOTA - 176) & 511)])) + (0.00767142279f * fVec14[((IOTA - 177) & 511)])) + (0.00309106335f * fVec14[((IOTA - 178) & 511)])) + (0.00172831584f * fVec14[((IOTA - 184) & 511)])) + (0.0032434701f * fVec14[((IOTA - 185) & 511)])) + (0.00252228603f * fVec14[((IOTA - 186) & 511)])) + (0.00104061142f * fVec14[((IOTA - 193) & 511)])) + (0.000994407572f * fVec14[((IOTA - 194) & 511)])) + (0.000950566027f * fVec14[((IOTA - 199) & 511)])) + (0.0034276559f * fVec14[((IOTA - 200) & 511)])) + (0.00469440501f * fVec14[((IOTA - 201) & 511)])) + (0.0061838273f * fVec14[((IOTA - 202) & 511)])) + (0.00486889016f * fVec14[((IOTA - 203) & 511)])) + (0.00234121829f * fVec14[((IOTA - 204) & 511)])) + (0.00094325887f * fVec14[((IOTA - 205) & 511)])) + (0.00445812568f * fVec14[((IOTA - 218) & 511)])) + (0.00917722285f * fVec14[((IOTA - 219) & 511)])) + (0.00881282054f * fVec14[((IOTA - 220) & 511)])) + (0.00674362853f * fVec14[((IOTA - 221) & 511)])) + (0.00224446412f * fVec14[((IOTA - 222) & 511)])) + (0.00165726198f * fVec14[((IOTA - 244) & 511)])) + (0.00580087351f * fVec14[((IOTA - 245) & 511)])) + (0.00692009786f * fVec14[((IOTA - 246) & 511)])) + (0.00578852743f * fVec14[((IOTA - 247) & 511)])) + (0.00262398506f * fVec14[((IOTA - 248) & 511)])) + (0.000123777427f * fVec14[((IOTA - 354) & 511)])) + (0.000295522157f * fVec14[((IOTA - 355) & 511)])) + (0.000514636748f * fVec14[((IOTA - 368) & 511)])) + (0.00212408835f * fVec14[((IOTA - 369) & 511)])) + (0.00289982278f * fVec14[((IOTA - 370) & 511)])) + (0.00317543978f * fVec14[((IOTA - 371) & 511)])) + (0.0021741977f * fVec14[((IOTA - 372) & 511)])) + (0.000210452825f * fVec14[((IOTA - 373) & 511)])) + (0.00024670409f * fVec14[((IOTA - 380) & 511)])) + (0.00107909879f * fVec14[((IOTA - 381) & 511)])) + (0.000160784461f * fVec14[((IOTA - 382) & 511)])) + (0.00290048402f * fVec14[((IOTA - 396) & 511)])) + (0.00432152953f * fVec14[((IOTA - 397) & 511)])) + (0.0041553909f * fVec14[((IOTA - 398) & 511)])) + (0.00308615016f * fVec14[((IOTA - 399) & 511)])) + (0.000432622153f * fVec14[((IOTA - 400) & 511)])) + (0.000699546654f * fVec14[((IOTA - 406) & 511)])) + (0.00222799182f * fVec14[((IOTA - 407) & 511)])) + (0.00217526872f * fVec14[((IOTA - 408) & 511)])) + (0.00109286234f * fVec14[((IOTA - 409) & 511)])) + (0.000470259227f * fVec14[((IOTA - 410) & 511)])) + (0.000290073454f * fVec14[((IOTA - 411) & 511)])) + (0.000782411546f * fVec14[((IOTA - 412) & 511)])) + (0.00183618767f * fVec14[((IOTA - 413) & 511)])) + (0.00226348732f * fVec14[((IOTA - 414) & 511)])) + (0.00250745146f * fVec14[((IOTA - 415) & 511)])) + (0.00164044322f * fVec14[((IOTA - 416) & 511)])) + (0.000136659015f * fVec14[((IOTA - 423) & 511)])) + (7.14003108e-05f * fVec14[((IOTA - 424) & 511)])) + (8.69277865e-05f * fVec14[((IOTA - 430) & 511)])) + (0.00301487558f * fVec14[((IOTA - 431) & 511)])) + (0.00586112449f * fVec14[((IOTA - 432) & 511)])) + (0.00824744441f * fVec14[((IOTA - 433) & 511)])) + (0.00886359066f * fVec14[((IOTA - 434) & 511)])) + (0.00820643641f * fVec14[((IOTA - 435) & 511)])) + (0.00636653276f * fVec14[((IOTA - 436) & 511)])) + (0.00413857214f * fVec14[((IOTA - 437) & 511)])) + (0.00354437809f * fVec14[((IOTA - 438) & 511)])) + (0.00412868243f * fVec14[((IOTA - 439) & 511)])) + (0.00530853588f * fVec14[((IOTA - 440) & 511)])) + (0.00765088806f * fVec14[((IOTA - 441) & 511)])) + (0.00912692491f * fVec14[((IOTA - 442) & 511)])) + (0.0088295443f * fVec14[((IOTA - 443) & 511)])) + (0.00705004809f * fVec14[((IOTA - 444) & 511)])) + (0.0041978783f * fVec14[((IOTA - 445) & 511)])) + (0.00248316862f * fVec14[((IOTA - 446) & 511)])) + (0.00252861669f * fVec14[((IOTA - 447) & 511)])) + (0.0038962774f * fVec14[((IOTA - 448) & 511)])) + (0.00600622408f * fVec14[((IOTA - 449) & 511)])) + (0.00642357115f * fVec14[((IOTA - 450) & 511)])) + (0.0042237048f * fVec14[((IOTA - 451) & 511)])) + (0.00144762779f * fVec14[((IOTA - 452) & 511)])) + (6.33690506e-05f * fVec14[((IOTA - 455) & 511)])) + (0.00285632722f * fVec14[((IOTA - 456) & 511)])) + (0.00560128642f * fVec14[((IOTA - 457) & 511)])) + (0.00834782049f * fVec14[((IOTA - 458) & 511)])) + (0.00900645461f * fVec14[((IOTA - 459) & 511)])) + (0.00775019312f * fVec14[((IOTA - 460) & 511)])) + (0.00630795117f * fVec14[((IOTA - 461) & 511)])) + (0.00433428539f * fVec14[((IOTA - 462) & 511)])) + (0.00360683352f * fVec14[((IOTA - 463) & 511)])) + (0.00457065925f * fVec14[((IOTA - 464) & 511)])) + (0.0048080408f * fVec14[((IOTA - 465) & 511)])) + (0.00479610404f * fVec14[((IOTA - 466) & 511)])) + (0.00463330373f * fVec14[((IOTA - 467) & 511)])) + (0.0030244505f * fVec14[((IOTA - 468) & 511)])) + (0.00125065492f * fVec14[((IOTA - 469) & 511)])) + (0.00034245057f * fVec14[((IOTA - 470) & 511)])) + (5.94318844e-05f * fVec14[((IOTA - 472) & 511)])) + (4.32119705e-05f * fVec14[((IOTA - 473) & 511)])) + (0.000377442222f * fVec14[((IOTA - 475) & 511)])) + (0.000448244158f * fVec14[((IOTA - 476) & 511)])) + (0.00094562117f * fVec14[((IOTA - 477) & 511)])) + (0.00240285508f * fVec14[((IOTA - 478) & 511)])) + (0.00382538093f * fVec14[((IOTA - 479) & 511)])) + (0.00623040926f * fVec14[((IOTA - 480) & 511)])) + (0.0084909983f * fVec14[((IOTA - 481) & 511)])) + (0.00908424892f * fVec14[((IOTA - 482) & 511)])) + (0.00829323847f * fVec14[((IOTA - 483) & 511)])) + (0.00642857887f * fVec14[((IOTA - 484) & 511)])) + (0.00413835188f * fVec14[((IOTA - 485) & 511)])) + (0.00239202054f * fVec14[((IOTA - 486) & 511)])) + (0.00109733501f * fVec14[((IOTA - 487) & 511)])) + (0.000674413051f * fVec14[((IOTA - 488) & 511)])) + (0.000854504295f * fVec14[((IOTA - 489) & 511)])) + (0.00108158728f * fVec14[((IOTA - 490) & 511)])) + (0.00143188005f * fVec14[((IOTA - 491) & 511)])) + (0.0013385904f * fVec14[((IOTA - 492) & 511)])) + (0.000809403136f * fVec14[((IOTA - 493) & 511)])) + (0.0007795766f * fVec14[((IOTA - 494) & 511)])) + (0.000759262126f * fVec14[((IOTA - 495) & 511)])) + (0.000395299867f * fVec14[((IOTA - 496) & 511)])) + (0.000417472795f * fVec14[((IOTA - 497) & 511)])) + (0.000419268385f * fVec14[((IOTA - 501) & 511)])) + (0.00309994491f * fVec14[((IOTA - 502) & 511)])) + (0.00689197239f * fVec14[((IOTA - 503) & 511)])) + (0.00984250195f * fVec14[((IOTA - 504) & 511)])) + (0.011489654f * fVec14[((IOTA - 505) & 511)])) + (0.0117546897f * fVec14[((IOTA - 506) & 511)])) + (0.0104896408f * fVec14[((IOTA - 507) & 511)])) + (0.00843638554f * fVec14[((IOTA - 508) & 511)])) + (0.00664980337f * fVec14[((IOTA - 509) & 511)])) + (0.00586276222f * fVec14[((IOTA - 510) & 511)])) + (0.00660032406f * fVec14[((IOTA - 511) & 511)]))))))) : (iSlow3 ? (iSlow26 ? (iSlow38 ? (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0314344987f * fVec13[((IOTA - 35) & 511)]) + ((0.017386457f * fVec13[((IOTA - 34) & 511)]) + ((0.0262753218f * fVec13[((IOTA - 26) & 511)]) + ((0.0637594014f * fVec13[((IOTA - 25) & 511)]) + ((0.0600885972f * fVec13[((IOTA - 24) & 511)]) + ((0.037186455f * fVec13[((IOTA - 23) & 511)]) + ((0.000433333684f * fVec13[((IOTA - 22) & 511)]) + ((0.0136180473f * fVec13[((IOTA - 18) & 511)]) + ((0.0362094678f * fVec13[((IOTA - 17) & 511)]) + ((0.0303998552f * fVec13[((IOTA - 16) & 511)]) + ((0.00705458364f * fVec13[((IOTA - 15) & 511)]) + ((0.00252684392f * fVec13[((IOTA - 13) & 511)]) + ((0.0744278431f * fVec13[((IOTA - 12) & 511)]) + ((0.122671127f * fVec13[((IOTA - 11) & 511)]) + ((0.118603081f * fVec13[((IOTA - 10) & 511)]) + ((0.0227467176f * fVec13[((IOTA - 9) & 511)]) + ((0.0262582339f * fVec13[((IOTA - 4) & 511)]) + ((0.17232655f * fVec13[((IOTA - 3) & 511)]) + ((0.222791761f * fVec13[((IOTA - 2) & 511)]) + ((0.262775749f * fVec13[((IOTA - 1) & 511)]) + ((fSlow45 * fTemp0) + (((0.0412835851f * fVec13[((IOTA - 36) & 511)]) + (0.0415426493f * fVec13[((IOTA - 37) & 511)])) + (0.012934858f * fVec13[((IOTA - 38) & 511)]))))))))))))))))))))))) + (0.0135653522f * fVec13[((IOTA - 49) & 511)])) + (0.0149546918f * fVec13[((IOTA - 50) & 511)])) + (0.000359916594f * fVec13[((IOTA - 51) & 511)])) + (0.00455066655f * fVec13[((IOTA - 57) & 511)])) + (0.0175215825f * fVec13[((IOTA - 58) & 511)])) + (0.012879503f * fVec13[((IOTA - 59) & 511)])) + (0.0135226771f * fVec13[((IOTA - 60) & 511)])) + (0.00367728714f * fVec13[((IOTA - 61) & 511)])) + (0.00388690084f * fVec13[((IOTA - 73) & 511)])) + (0.0079435287f * fVec13[((IOTA - 74) & 511)])) + (0.00608265586f * fVec13[((IOTA - 75) & 511)])) + (0.00761915278f * fVec13[((IOTA - 80) & 511)])) + (0.0103389099f * fVec13[((IOTA - 81) & 511)])) + (0.0150220115f * fVec13[((IOTA - 82) & 511)])) + (0.0040917797f * fVec13[((IOTA - 83) & 511)])) + (0.000767859165f * fVec13[((IOTA - 91) & 511)])) + (0.00230247527f * fVec13[((IOTA - 93) & 511)])) + (0.0065991669f * fVec13[((IOTA - 94) & 511)])) + (0.0086509753f * fVec13[((IOTA - 95) & 511)])) + (0.0109363934f * fVec13[((IOTA - 96) & 511)])) + (0.00936565269f * fVec13[((IOTA - 97) & 511)])) + (0.00302814599f * fVec13[((IOTA - 98) & 511)])) + (0.00933088921f * fVec13[((IOTA - 106) & 511)])) + (0.012992546f * fVec13[((IOTA - 107) & 511)])) + (0.0082604792f * fVec13[((IOTA - 108) & 511)])) + (0.0018048049f * fVec13[((IOTA - 109) & 511)])) + (0.000701252371f * fVec13[((IOTA - 128) & 511)])) + (0.00397909293f * fVec13[((IOTA - 129) & 511)])) + (0.00486278487f * fVec13[((IOTA - 130) & 511)])) + (0.00366525631f * fVec13[((IOTA - 131) & 511)])) + (0.00385855883f * fVec13[((IOTA - 148) & 511)])) + (0.00644098362f * fVec13[((IOTA - 149) & 511)])) + (0.00721344771f * fVec13[((IOTA - 150) & 511)])) + (0.00570727093f * fVec13[((IOTA - 151) & 511)])) + (0.00219750637f * fVec13[((IOTA - 152) & 511)])) + (0.00217519607f * fVec13[((IOTA - 161) & 511)])) + (0.00365371211f * fVec13[((IOTA - 162) & 511)])) + (0.00268363254f * fVec13[((IOTA - 163) & 511)])) + (0.000212921295f * fVec13[((IOTA - 164) & 511)])) + (0.000486190896f * fVec13[((IOTA - 172) & 511)])) + (0.00345638813f * fVec13[((IOTA - 173) & 511)])) + (0.00494080596f * fVec13[((IOTA - 174) & 511)])) + (0.00495481491f * fVec13[((IOTA - 175) & 511)])) + (0.00243277056f * fVec13[((IOTA - 176) & 511)])) + (0.00209292676f * fVec13[((IOTA - 182) & 511)])) + (0.00439553149f * fVec13[((IOTA - 183) & 511)])) + (0.00460751262f * fVec13[((IOTA - 184) & 511)])) + (0.00351641234f * fVec13[((IOTA - 185) & 511)])) + (0.00255473191f * fVec13[((IOTA - 186) & 511)])) + (0.00199599983f * fVec13[((IOTA - 187) & 511)])) + (0.00166410068f * fVec13[((IOTA - 188) & 511)])) + (0.000805897173f * fVec13[((IOTA - 189) & 511)])) + (0.000258968677f * fVec13[((IOTA - 190) & 511)])) + (0.000636785757f * fVec13[((IOTA - 192) & 511)])) + (0.00201704539f * fVec13[((IOTA - 193) & 511)])) + (0.00297201332f * fVec13[((IOTA - 194) & 511)])) + (0.00282829301f * fVec13[((IOTA - 195) & 511)])) + (0.00135266315f * fVec13[((IOTA - 196) & 511)])) + (0.00124169514f * fVec13[((IOTA - 207) & 511)])) + (0.00371415727f * fVec13[((IOTA - 208) & 511)])) + (0.0045307558f * fVec13[((IOTA - 209) & 511)])) + (0.00283782696f * fVec13[((IOTA - 210) & 511)])) + (0.00170155475f * fVec13[((IOTA - 217) & 511)])) + (0.00369888404f * fVec13[((IOTA - 218) & 511)])) + (0.00546587817f * fVec13[((IOTA - 219) & 511)])) + (0.00685213646f * fVec13[((IOTA - 220) & 511)])) + (0.00627628248f * fVec13[((IOTA - 221) & 511)])) + (0.00396112818f * fVec13[((IOTA - 222) & 511)])) + (0.000584220514f * fVec13[((IOTA - 223) & 511)])) + (0.00293070031f * fVec13[((IOTA - 228) & 511)])) + (0.00521819387f * fVec13[((IOTA - 229) & 511)])) + (0.0063895206f * fVec13[((IOTA - 230) & 511)])) + (0.00691439817f * fVec13[((IOTA - 231) & 511)])) + (0.00541610131f * fVec13[((IOTA - 232) & 511)])) + (0.00232173735f * fVec13[((IOTA - 233) & 511)])) + (0.000124587677f * fVec13[((IOTA - 234) & 511)])) + (0.00201386726f * fVec13[((IOTA - 238) & 511)])) + (0.00379538909f * fVec13[((IOTA - 239) & 511)])) + (0.00559912389f * fVec13[((IOTA - 240) & 511)])) + (0.00609144382f * fVec13[((IOTA - 241) & 511)])) + (0.00521932915f * fVec13[((IOTA - 242) & 511)])) + (0.0045139906f * fVec13[((IOTA - 243) & 511)])) + (0.00289013283f * fVec13[((IOTA - 244) & 511)])) + (0.000715358648f * fVec13[((IOTA - 245) & 511)])) + (0.000978413504f * fVec13[((IOTA - 249) & 511)])) + (0.00300126337f * fVec13[((IOTA - 250) & 511)])) + (0.00545342593f * fVec13[((IOTA - 251) & 511)])) + (0.00752576068f * fVec13[((IOTA - 252) & 511)])) + (0.00834842306f * fVec13[((IOTA - 253) & 511)])) + (0.00805109181f * fVec13[((IOTA - 254) & 511)])) + (0.00662724953f * fVec13[((IOTA - 255) & 511)])) + (0.00532092527f * fVec13[((IOTA - 256) & 511)])) + (0.00498108147f * fVec13[((IOTA - 257) & 511)])) + (0.00448785396f * fVec13[((IOTA - 258) & 511)])) + (0.00421056291f * fVec13[((IOTA - 259) & 511)])) + (0.00507791108f * fVec13[((IOTA - 260) & 511)])) + (0.00565545121f * fVec13[((IOTA - 261) & 511)])) + (0.0055244104f * fVec13[((IOTA - 262) & 511)])) + (0.00599218206f * fVec13[((IOTA - 263) & 511)])) + (0.00671506394f * fVec13[((IOTA - 264) & 511)])) + (0.00748460973f * fVec13[((IOTA - 265) & 511)])) + (0.00745334895f * fVec13[((IOTA - 266) & 511)])) + (0.00613661576f * fVec13[((IOTA - 267) & 511)])) + (0.00443155877f * fVec13[((IOTA - 268) & 511)])) + (0.00292068021f * fVec13[((IOTA - 269) & 511)])) + (0.00236561242f * fVec13[((IOTA - 270) & 511)])) + (0.00304303039f * fVec13[((IOTA - 271) & 511)])) + (0.00416169409f * fVec13[((IOTA - 272) & 511)])) + (0.00485188887f * fVec13[((IOTA - 273) & 511)])) + (0.00445244228f * fVec13[((IOTA - 274) & 511)])) + (0.00345590198f * fVec13[((IOTA - 275) & 511)])) + (0.0032180436f * fVec13[((IOTA - 276) & 511)])) + (0.00348933507f * fVec13[((IOTA - 277) & 511)])) + (0.0040959632f * fVec13[((IOTA - 278) & 511)])) + (0.00497647654f * fVec13[((IOTA - 279) & 511)])) + (0.0046115336f * fVec13[((IOTA - 280) & 511)])) + (0.00248339027f * fVec13[((IOTA - 281) & 511)])) + (0.000330861658f * fVec13[((IOTA - 282) & 511)])) + (0.000920237973f * fVec13[((IOTA - 285) & 511)])) + (0.00341659924f * fVec13[((IOTA - 286) & 511)])) + (0.00551688718f * fVec13[((IOTA - 287) & 511)])) + (0.00711788284f * fVec13[((IOTA - 288) & 511)])) + (0.007441286f * fVec13[((IOTA - 289) & 511)])) + (0.0064547006f * fVec13[((IOTA - 290) & 511)])) + (0.00486447103f * fVec13[((IOTA - 291) & 511)])) + (0.00343796937f * fVec13[((IOTA - 292) & 511)])) + (0.00261287484f * fVec13[((IOTA - 293) & 511)])) + (0.00228489935f * fVec13[((IOTA - 294) & 511)])) + (0.00286993058f * fVec13[((IOTA - 295) & 511)])) + (0.00425638352f * fVec13[((IOTA - 296) & 511)])) + (0.00592317572f * fVec13[((IOTA - 297) & 511)])) + (0.00735642249f * fVec13[((IOTA - 298) & 511)])) + (0.00871514902f * fVec13[((IOTA - 299) & 511)])) + (0.00952137075f * fVec13[((IOTA - 300) & 511)])) + (0.00901870616f * fVec13[((IOTA - 301) & 511)])) + (0.00730735902f * fVec13[((IOTA - 302) & 511)])) + (0.004904876f * fVec13[((IOTA - 303) & 511)])) + (0.00251095416f * fVec13[((IOTA - 304) & 511)])) + (0.00137880025f * fVec13[((IOTA - 305) & 511)])) + (0.00191405462f * fVec13[((IOTA - 306) & 511)])) + (0.00377703505f * fVec13[((IOTA - 307) & 511)])) + (0.00603109552f * fVec13[((IOTA - 308) & 511)])) + (0.007130465f * fVec13[((IOTA - 309) & 511)])) + (0.0072093294f * fVec13[((IOTA - 310) & 511)])) + (0.00642425101f * fVec13[((IOTA - 311) & 511)])) + (0.00464324793f * fVec13[((IOTA - 312) & 511)])) + (0.0029999339f * fVec13[((IOTA - 313) & 511)])) + (0.00133411447f * fVec13[((IOTA - 314) & 511)])) + (0.000146995299f * fVec13[((IOTA - 319) & 511)])) + (0.00285147922f * fVec13[((IOTA - 320) & 511)])) + (0.00533772307f * fVec13[((IOTA - 321) & 511)])) + (0.00634340849f * fVec13[((IOTA - 322) & 511)])) + (0.0047869361f * fVec13[((IOTA - 323) & 511)])) + (0.00247122999f * fVec13[((IOTA - 324) & 511)])) + (0.00132899079f * fVec13[((IOTA - 330) & 511)])) + (0.00208887318f * fVec13[((IOTA - 331) & 511)])) + (0.00322099449f * fVec13[((IOTA - 332) & 511)])) + (0.00526385242f * fVec13[((IOTA - 333) & 511)])) + (0.00660552271f * fVec13[((IOTA - 334) & 511)])) + (0.00710033951f * fVec13[((IOTA - 335) & 511)])) + (0.00672414387f * fVec13[((IOTA - 336) & 511)])) + (0.00461075548f * fVec13[((IOTA - 337) & 511)])) + (0.00197449978f * fVec13[((IOTA - 338) & 511)])) + (0.000229751226f * fVec13[((IOTA - 339) & 511)])) + (0.00122947013f * fVec13[((IOTA - 341) & 511)])) + (0.00286532566f * fVec13[((IOTA - 342) & 511)])) + (0.00443817442f * fVec13[((IOTA - 343) & 511)])) + (0.00551101752f * fVec13[((IOTA - 344) & 511)])) + (0.00521997735f * fVec13[((IOTA - 345) & 511)])) + (0.00432428764f * fVec13[((IOTA - 346) & 511)])) + (0.00365351746f * fVec13[((IOTA - 347) & 511)])) + (0.00268214056f * fVec13[((IOTA - 348) & 511)])) + (0.0021142317f * fVec13[((IOTA - 349) & 511)])) + (0.00231269002f * fVec13[((IOTA - 350) & 511)])) + (0.0024046232f * fVec13[((IOTA - 351) & 511)])) + (0.00279362779f * fVec13[((IOTA - 352) & 511)])) + (0.00268924236f * fVec13[((IOTA - 353) & 511)])) + (0.00164568145f * fVec13[((IOTA - 354) & 511)])) + (0.00085317716f * fVec13[((IOTA - 355) & 511)])) + (0.000318344217f * fVec13[((IOTA - 356) & 511)])) + (0.000282997731f * fVec13[((IOTA - 358) & 511)])) + (0.000697361305f * fVec13[((IOTA - 359) & 511)])) + (0.000739679672f * fVec13[((IOTA - 360) & 511)])) + (0.0005862955f * fVec13[((IOTA - 361) & 511)])) + (3.25962901e-08f * fVec13[((IOTA - 364) & 511)])) + (0.00133440644f * fVec13[((IOTA - 365) & 511)])) + (0.00326214544f * fVec13[((IOTA - 366) & 511)])) + (0.00512532052f * fVec13[((IOTA - 367) & 511)])) + (0.00507855974f * fVec13[((IOTA - 368) & 511)])) + (0.00336020719f * fVec13[((IOTA - 369) & 511)])) + (0.000581009779f * fVec13[((IOTA - 370) & 511)])) + (0.00140675297f * fVec13[((IOTA - 375) & 511)])) + (0.00389805576f * fVec13[((IOTA - 376) & 511)])) + (0.0051283366f * fVec13[((IOTA - 377) & 511)])) + (0.00525065418f * fVec13[((IOTA - 378) & 511)])) + (0.00393813662f * fVec13[((IOTA - 379) & 511)])) + (0.00217830902f * fVec13[((IOTA - 380) & 511)])) + (0.000651248731f * fVec13[((IOTA - 381) & 511)])) + (0.000216682907f * fVec13[((IOTA - 384) & 511)])) + (0.000690908171f * fVec13[((IOTA - 385) & 511)])) + (0.00123760942f * fVec13[((IOTA - 386) & 511)])) + (0.00146055082f * fVec13[((IOTA - 387) & 511)])) + (0.00175337447f * fVec13[((IOTA - 388) & 511)])) + (0.00221748184f * fVec13[((IOTA - 389) & 511)])) + (0.0018431996f * fVec13[((IOTA - 390) & 511)])) + (0.00135078235f * fVec13[((IOTA - 391) & 511)])) + (0.000832423102f * fVec13[((IOTA - 392) & 511)])) + (3.28170136e-05f * fVec13[((IOTA - 398) & 511)])) + (0.00205871509f * fVec13[((IOTA - 399) & 511)])) + (0.00407041004f * fVec13[((IOTA - 400) & 511)])) + (0.00483895f * fVec13[((IOTA - 401) & 511)])) + (0.00388706289f * fVec13[((IOTA - 402) & 511)])) + (0.00241117366f * fVec13[((IOTA - 403) & 511)])) + (0.000678877346f * fVec13[((IOTA - 404) & 511)])) + (0.000977440737f * fVec13[((IOTA - 410) & 511)])) + (0.00184987951f * fVec13[((IOTA - 411) & 511)])) + (0.00241837231f * fVec13[((IOTA - 412) & 511)])) + (0.00251030549f * fVec13[((IOTA - 413) & 511)])) + (0.00254925154f * fVec13[((IOTA - 414) & 511)])) + (0.00171514181f * fVec13[((IOTA - 415) & 511)])) + (1.80946663e-05f * fVec13[((IOTA - 416) & 511)])) + (0.000390852802f * fVec13[((IOTA - 422) & 511)])) + (0.00243980717f * fVec13[((IOTA - 423) & 511)])) + (0.00391971739f * fVec13[((IOTA - 424) & 511)])) + (0.00441981992f * fVec13[((IOTA - 425) & 511)])) + (0.00353625836f * fVec13[((IOTA - 426) & 511)])) + (0.001969798f * fVec13[((IOTA - 427) & 511)])) + (0.000709943008f * fVec13[((IOTA - 428) & 511)])) + (0.000264124945f * fVec13[((IOTA - 446) & 511)])) + (0.000688086729f * fVec13[((IOTA - 447) & 511)])) + (0.00111636147f * fVec13[((IOTA - 448) & 511)])) + (0.000541026238f * fVec13[((IOTA - 449) & 511)])) + (0.000562591013f * fVec13[((IOTA - 468) & 511)])) + (0.00108578196f * fVec13[((IOTA - 469) & 511)])) + (0.000977213494f * fVec13[((IOTA - 470) & 511)])) + (0.000573583879f * fVec13[((IOTA - 471) & 511)])) + (0.000231924001f * fVec13[((IOTA - 481) & 511)])) + (0.000462291762f * fVec13[((IOTA - 482) & 511)])) + (0.000468679704f * fVec13[((IOTA - 493) & 511)])) + (0.000683514401f * fVec13[((IOTA - 494) & 511)])) + (0.000636656303f * fVec13[((IOTA - 495) & 511)])) + (0.000268989243f * fVec13[((IOTA - 496) & 511)])) - ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00119824195f * fVec13[((IOTA - 417) & 511)]) + ((0.0002829656f * fVec13[((IOTA - 409) & 511)]) + ((0.00155092729f * fVec13[((IOTA - 408) & 511)]) + ((0.00203977711f * fVec13[((IOTA - 407) & 511)]) + ((0.00199548062f * fVec13[((IOTA - 406) & 511)]) + ((0.00110329315f * fVec13[((IOTA - 405) & 511)]) + ((0.00234774454f * fVec13[((IOTA - 397) & 511)]) + ((0.0037503792f * fVec13[((IOTA - 396) & 511)]) + ((0.00352192484f * fVec13[((IOTA - 395) & 511)]) + ((0.00262072217f * fVec13[((IOTA - 394) & 511)]) + ((0.000883010682f * fVec13[((IOTA - 393) & 511)]) + ((0.000409564003f * fVec13[((IOTA - 383) & 511)]) + ((0.000457297545f * fVec13[((IOTA - 382) & 511)]) + ((0.00154113397f * fVec13[((IOTA - 374) & 511)]) + ((0.00340755191f * fVec13[((IOTA - 373) & 511)]) + ((0.00397552596f * fVec13[((IOTA - 372) & 511)]) + ((0.00248951931f * fVec13[((IOTA - 371) & 511)]) + ((0.000677093863f * fVec13[((IOTA - 363) & 511)]) + ((2.73366459e-05f * fVec13[((IOTA - 357) & 511)]) + ((8.486351e-05f * fVec13[((IOTA - 340) & 511)]) + ((0.000103931408f * fVec13[((IOTA - 329) & 511)]) + ((0.000894262921f * fVec13[((IOTA - 328) & 511)]) + ((0.00161562068f * fVec13[((IOTA - 327) & 511)]) + ((0.0019288091f * fVec13[((IOTA - 326) & 511)]) + ((3.75192612e-05f * fVec13[((IOTA - 325) & 511)]) + ((0.00221764389f * fVec13[((IOTA - 318) & 511)]) + ((0.00288980873f * fVec13[((IOTA - 317) & 511)]) + ((0.00217406126f * fVec13[((IOTA - 316) & 511)]) + ((0.000788483303f * fVec13[((IOTA - 315) & 511)]) + ((0.000108892564f * fVec13[((IOTA - 362) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0138028543f * fVec13[((IOTA - 113) & 511)]) + ((0.0149136372f * fVec13[((IOTA - 112) & 511)]) + ((0.0130736809f * fVec13[((IOTA - 111) & 511)]) + ((0.0070287385f * fVec13[((IOTA - 110) & 511)]) + ((0.00268976111f * fVec13[((IOTA - 105) & 511)]) + ((0.0134717328f * fVec13[((IOTA - 104) & 511)]) + ((0.0236413367f * fVec13[((IOTA - 103) & 511)]) + ((0.0294538364f * fVec13[((IOTA - 102) & 511)]) + ((0.025039399f * fVec13[((IOTA - 101) & 511)]) + ((0.0163708162f * fVec13[((IOTA - 100) & 511)]) + ((0.00679227477f * fVec13[((IOTA - 99) & 511)]) + (((((((((((((((((((((((((((((((((((((((0.015391333f * fVec13[((IOTA - 33) & 511)]) + ((0.0433029644f * fVec13[((IOTA - 32) & 511)]) + ((0.049587518f * fVec13[((IOTA - 31) & 511)]) + ((0.0553181693f * fVec13[((IOTA - 30) & 511)]) + ((0.0482104681f * fVec13[((IOTA - 29) & 511)]) + ((0.0217030905f * fVec13[((IOTA - 28) & 511)]) + ((0.00213005627f * fVec13[((IOTA - 27) & 511)]) + ((0.0430112109f * fVec13[((IOTA - 21) & 511)]) + ((0.0442363992f * fVec13[((IOTA - 20) & 511)]) + ((0.0195396021f * fVec13[((IOTA - 19) & 511)]) + ((0.0232451987f * fVec13[((IOTA - 14) & 511)]) + ((0.125784755f * fVec13[((IOTA - 8) & 511)]) + ((0.226226747f * fVec13[((IOTA - 7) & 511)]) + ((0.241699636f * fVec13[((IOTA - 6) & 511)]) + ((0.171446621f * fVec13[((IOTA - 5) & 511)]) + ((0.0139499465f * fVec13[((IOTA - 39) & 511)]) + (0.0233669318f * fVec13[((IOTA - 40) & 511)]))))))))))))))))) + (0.0206779819f * fVec13[((IOTA - 41) & 511)])) + (0.00732110813f * fVec13[((IOTA - 42) & 511)])) + (0.00506746909f * fVec13[((IOTA - 43) & 511)])) + (0.0196994394f * fVec13[((IOTA - 44) & 511)])) + (0.0266253166f * fVec13[((IOTA - 45) & 511)])) + (0.0251856167f * fVec13[((IOTA - 46) & 511)])) + (0.0206401385f * fVec13[((IOTA - 47) & 511)])) + (0.00655256817f * fVec13[((IOTA - 48) & 511)])) + (0.0052689435f * fVec13[((IOTA - 52) & 511)])) + (0.0170939248f * fVec13[((IOTA - 53) & 511)])) + (0.0298854187f * fVec13[((IOTA - 54) & 511)])) + (0.0221344791f * fVec13[((IOTA - 55) & 511)])) + (0.013261795f * fVec13[((IOTA - 56) & 511)])) + (0.00990496017f * fVec13[((IOTA - 62) & 511)])) + (0.0162232034f * fVec13[((IOTA - 63) & 511)])) + (0.022763418f * fVec13[((IOTA - 64) & 511)])) + (0.0258617364f * fVec13[((IOTA - 65) & 511)])) + (0.0270429216f * fVec13[((IOTA - 66) & 511)])) + (0.0181121919f * fVec13[((IOTA - 67) & 511)])) + (0.0108295437f * fVec13[((IOTA - 68) & 511)])) + (0.0085001532f * fVec13[((IOTA - 69) & 511)])) + (0.00942765456f * fVec13[((IOTA - 70) & 511)])) + (0.0103356671f * fVec13[((IOTA - 71) & 511)])) + (0.00243296521f * fVec13[((IOTA - 72) & 511)])) + (0.00291996682f * fVec13[((IOTA - 76) & 511)])) + (0.0119950008f * fVec13[((IOTA - 77) & 511)])) + (0.0161830261f * fVec13[((IOTA - 78) & 511)])) + (0.00321548199f * fVec13[((IOTA - 79) & 511)])) + (0.0145645197f * fVec13[((IOTA - 84) & 511)])) + (0.0277317874f * fVec13[((IOTA - 85) & 511)])) + (0.038560424f * fVec13[((IOTA - 86) & 511)])) + (0.0362660885f * fVec13[((IOTA - 87) & 511)])) + (0.0256163888f * fVec13[((IOTA - 88) & 511)])) + (0.0159484111f * fVec13[((IOTA - 89) & 511)])) + (0.00495783053f * fVec13[((IOTA - 90) & 511)])) + (0.000587592833f * fVec13[((IOTA - 92) & 511)])) + (0.00924615562f * fVec13[((IOTA - 114) & 511)]))))))))))))) + (0.00539719593f * fVec13[((IOTA - 115) & 511)])) + (0.00487964693f * fVec13[((IOTA - 116) & 511)])) + (0.00540831871f * fVec13[((IOTA - 117) & 511)])) + (0.00727110449f * fVec13[((IOTA - 118) & 511)])) + (0.00938339066f * fVec13[((IOTA - 119) & 511)])) + (0.0119901365f * fVec13[((IOTA - 120) & 511)])) + (0.0118619492f * fVec13[((IOTA - 121) & 511)])) + (0.0100908689f * fVec13[((IOTA - 122) & 511)])) + (0.0103158858f * fVec13[((IOTA - 123) & 511)])) + (0.0101565029f * fVec13[((IOTA - 124) & 511)])) + (0.00860028993f * fVec13[((IOTA - 125) & 511)])) + (0.0058390256f * fVec13[((IOTA - 126) & 511)])) + (0.0029026824f * fVec13[((IOTA - 127) & 511)])) + (0.000786051154f * fVec13[((IOTA - 132) & 511)])) + (0.00354562979f * fVec13[((IOTA - 133) & 511)])) + (0.0052611283f * fVec13[((IOTA - 134) & 511)])) + (0.00625462085f * fVec13[((IOTA - 135) & 511)])) + (0.00367615186f * fVec13[((IOTA - 136) & 511)])) + (0.00161951222f * fVec13[((IOTA - 137) & 511)])) + (0.000941737555f * fVec13[((IOTA - 138) & 511)])) + (0.000415951945f * fVec13[((IOTA - 139) & 511)])) + (0.00210589776f * fVec13[((IOTA - 140) & 511)])) + (0.00492932647f * fVec13[((IOTA - 141) & 511)])) + (0.00672359252f * fVec13[((IOTA - 142) & 511)])) + (0.00819377415f * fVec13[((IOTA - 143) & 511)])) + (0.00889405422f * fVec13[((IOTA - 144) & 511)])) + (0.00721967407f * fVec13[((IOTA - 145) & 511)])) + (0.00380573375f * fVec13[((IOTA - 146) & 511)])) + (1.48518011e-05f * fVec13[((IOTA - 147) & 511)])) + (0.00155546702f * fVec13[((IOTA - 153) & 511)])) + (0.00578765944f * fVec13[((IOTA - 154) & 511)])) + (0.00899591018f * fVec13[((IOTA - 155) & 511)])) + (0.0095655052f * fVec13[((IOTA - 156) & 511)])) + (0.00941792689f * fVec13[((IOTA - 157) & 511)])) + (0.0075588692f * fVec13[((IOTA - 158) & 511)])) + (0.00440023374f * fVec13[((IOTA - 159) & 511)])) + (0.00134520512f * fVec13[((IOTA - 160) & 511)])) + (0.00376503682f * fVec13[((IOTA - 165) & 511)])) + (0.00641773315f * fVec13[((IOTA - 166) & 511)])) + (0.00722067943f * fVec13[((IOTA - 167) & 511)])) + (0.0074118413f * fVec13[((IOTA - 168) & 511)])) + (0.00625426415f * fVec13[((IOTA - 169) & 511)])) + (0.00396751612f * fVec13[((IOTA - 170) & 511)])) + (0.00216695946f * fVec13[((IOTA - 171) & 511)])) + (0.00200822484f * fVec13[((IOTA - 177) & 511)])) + (0.00530866766f * fVec13[((IOTA - 178) & 511)])) + (0.00736290775f * fVec13[((IOTA - 179) & 511)])) + (0.00627511507f * fVec13[((IOTA - 180) & 511)])) + (0.00190769881f * fVec13[((IOTA - 181) & 511)])) + (2.61045061e-05f * fVec13[((IOTA - 191) & 511)])) + (0.000702419784f * fVec13[((IOTA - 197) & 511)])) + (0.00226028683f * fVec13[((IOTA - 198) & 511)])) + (0.00323451683f * fVec13[((IOTA - 199) & 511)])) + (0.00286279619f * fVec13[((IOTA - 200) & 511)])) + (0.00180357276f * fVec13[((IOTA - 201) & 511)])) + (0.00158980815f * fVec13[((IOTA - 202) & 511)])) + (0.00148503389f * fVec13[((IOTA - 203) & 511)])) + (0.00180467544f * fVec13[((IOTA - 204) & 511)])) + (0.002163684f * fVec13[((IOTA - 205) & 511)])) + (0.000978121534f * fVec13[((IOTA - 206) & 511)])) + (0.000492871273f * fVec13[((IOTA - 211) & 511)])) + (0.00363256875f * fVec13[((IOTA - 212) & 511)])) + (0.00530351186f * fVec13[((IOTA - 213) & 511)])) + (0.00534560299f * fVec13[((IOTA - 214) & 511)])) + (0.00398042239f * fVec13[((IOTA - 215) & 511)])) + (0.00131715462f * fVec13[((IOTA - 216) & 511)])) + (0.0023848745f * fVec13[((IOTA - 224) & 511)])) + (0.00362952054f * fVec13[((IOTA - 225) & 511)])) + (0.00295446999f * fVec13[((IOTA - 226) & 511)])) + (0.000469717663f * fVec13[((IOTA - 227) & 511)])) + (0.00138259446f * fVec13[((IOTA - 235) & 511)])) + (0.00182776386f * fVec13[((IOTA - 236) & 511)])) + (0.00013561314f * fVec13[((IOTA - 237) & 511)])) + (0.000307708047f * fVec13[((IOTA - 246) & 511)])) + (0.000508598518f * fVec13[((IOTA - 247) & 511)])) + (0.000288186595f * fVec13[((IOTA - 248) & 511)])) + (0.00101700239f * fVec13[((IOTA - 283) & 511)])) + (0.000998745672f * fVec13[((IOTA - 284) & 511)])) + (0.00242570136f * fVec13[((IOTA - 418) & 511)])))))))))))))))))))))))))))))))) + (0.00326457759f * fVec13[((IOTA - 419) & 511)])) + (0.00265373383f * fVec13[((IOTA - 420) & 511)])) + (0.00137383863f * fVec13[((IOTA - 421) & 511)])) + (0.000710494351f * fVec13[((IOTA - 429) & 511)])) + (0.00214153575f * fVec13[((IOTA - 430) & 511)])) + (0.00249662111f * fVec13[((IOTA - 431) & 511)])) + (0.00232481817f * fVec13[((IOTA - 432) & 511)])) + (0.0021409844f * fVec13[((IOTA - 433) & 511)])) + (0.00158744119f * fVec13[((IOTA - 434) & 511)])) + (0.00150004774f * fVec13[((IOTA - 435) & 511)])) + (0.00184958801f * fVec13[((IOTA - 436) & 511)])) + (0.00231758691f * fVec13[((IOTA - 437) & 511)])) + (0.00324463425f * fVec13[((IOTA - 438) & 511)])) + (0.00412284583f * fVec13[((IOTA - 439) & 511)])) + (0.00453412812f * fVec13[((IOTA - 440) & 511)])) + (0.00452446472f * fVec13[((IOTA - 441) & 511)])) + (0.00364641566f * fVec13[((IOTA - 442) & 511)])) + (0.00239804015f * fVec13[((IOTA - 443) & 511)])) + (0.00168430293f * fVec13[((IOTA - 444) & 511)])) + (0.000716331415f * fVec13[((IOTA - 445) & 511)])) + (0.000624528155f * fVec13[((IOTA - 450) & 511)])) + (0.00128900725f * fVec13[((IOTA - 451) & 511)])) + (0.00242544198f * fVec13[((IOTA - 452) & 511)])) + (0.00307409652f * fVec13[((IOTA - 453) & 511)])) + (0.00285112252f * fVec13[((IOTA - 454) & 511)])) + (0.0027583139f * fVec13[((IOTA - 455) & 511)])) + (0.00200449582f * fVec13[((IOTA - 456) & 511)])) + (0.000764681492f * fVec13[((IOTA - 457) & 511)])) + (0.000188827515f * fVec13[((IOTA - 458) & 511)])) + (3.78759578e-05f * fVec13[((IOTA - 459) & 511)])) + (0.000557078049f * fVec13[((IOTA - 460) & 511)])) + (0.00145510305f * fVec13[((IOTA - 461) & 511)])) + (0.00207042182f * fVec13[((IOTA - 462) & 511)])) + (0.00289071677f * fVec13[((IOTA - 463) & 511)])) + (0.00349520473f * fVec13[((IOTA - 464) & 511)])) + (0.0029931888f * fVec13[((IOTA - 465) & 511)])) + (0.00186045142f * fVec13[((IOTA - 466) & 511)])) + (0.000534119084f * fVec13[((IOTA - 467) & 511)])) + (0.00015273504f * fVec13[((IOTA - 472) & 511)])) + (0.00115235662f * fVec13[((IOTA - 473) & 511)])) + (0.00206935126f * fVec13[((IOTA - 474) & 511)])) + (0.0029586209f * fVec13[((IOTA - 475) & 511)])) + (0.00314187072f * fVec13[((IOTA - 476) & 511)])) + (0.00292317709f * fVec13[((IOTA - 477) & 511)])) + (0.00259640161f * fVec13[((IOTA - 478) & 511)])) + (0.00140584493f * fVec13[((IOTA - 479) & 511)])) + (0.000279366039f * fVec13[((IOTA - 480) & 511)])) + (3.31089832e-05f * fVec13[((IOTA - 483) & 511)])) + (0.000777165871f * fVec13[((IOTA - 484) & 511)])) + (0.00145066017f * fVec13[((IOTA - 485) & 511)])) + (0.00224031135f * fVec13[((IOTA - 486) & 511)])) + (0.00224138144f * fVec13[((IOTA - 487) & 511)])) + (0.00161565328f * fVec13[((IOTA - 488) & 511)])) + (0.00129708182f * fVec13[((IOTA - 489) & 511)])) + (0.000704689883f * fVec13[((IOTA - 490) & 511)])) + (0.000189313665f * fVec13[((IOTA - 491) & 511)])) + (4.31938097e-05f * fVec13[((IOTA - 492) & 511)])) + (0.00106914667f * fVec13[((IOTA - 497) & 511)])) + (0.00251993677f * fVec13[((IOTA - 498) & 511)])) + (0.00355824409f * fVec13[((IOTA - 499) & 511)])) + (0.00425544335f * fVec13[((IOTA - 500) & 511)])) + (0.00409858953f * fVec13[((IOTA - 501) & 511)])) + (0.00333306519f * fVec13[((IOTA - 502) & 511)])) + (0.00250073941f * fVec13[((IOTA - 503) & 511)])) + (0.00159467245f * fVec13[((IOTA - 504) & 511)])) + (0.00139537081f * fVec13[((IOTA - 505) & 511)])) + (0.00198880071f * fVec13[((IOTA - 506) & 511)])) + (0.00286081806f * fVec13[((IOTA - 507) & 511)])) + (0.00391686382f * fVec13[((IOTA - 508) & 511)])) + (0.00452965312f * fVec13[((IOTA - 509) & 511)])) + (0.00413776236f * fVec13[((IOTA - 510) & 511)])) + (0.00364810182f * fVec13[((IOTA - 511) & 511)]))) : (iSlow39 ? ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((5.89569099e-05f * (fVec12[((IOTA - 340) & 511)] + fVec12[((IOTA - 353) & 511)])) + ((0.000381444581f * fVec12[((IOTA - 352) & 511)]) + ((0.00158584071f * fVec12[((IOTA - 351) & 511)]) + ((0.00225476967f * fVec12[((IOTA - 350) & 511)]) + ((0.00201606099f * fVec12[((IOTA - 349) & 511)]) + (((0.00530549837f * fVec12[((IOTA - 338) & 511)]) + ((0.00796168111f * fVec12[((IOTA - 337) & 511)]) + ((0.00935825892f * fVec12[((IOTA - 336) & 511)]) + ((0.00945202261f * fVec12[((IOTA - 335) & 511)]) + ((0.0078436099f * fVec12[((IOTA - 334) & 511)]) + ((0.00479051284f * fVec12[((IOTA - 333) & 511)]) + ((0.00162763149f * fVec12[((IOTA - 332) & 511)]) + ((0.000102918129f * fVec12[((IOTA - 327) & 511)]) + ((0.000344192144f * fVec12[((IOTA - 326) & 511)]) + ((8.10953788e-05f * fVec12[((IOTA - 325) & 511)]) + ((0.00024664076f * fVec12[((IOTA - 323) & 511)]) + ((0.000475128647f * fVec12[((IOTA - 322) & 511)]) + ((0.000515577849f * fVec12[((IOTA - 321) & 511)]) + ((0.000829146709f * fVec12[((IOTA - 313) & 511)]) + ((0.00541903218f * fVec12[((IOTA - 312) & 511)]) + ((0.00853357185f * fVec12[((IOTA - 311) & 511)]) + ((0.0105256792f * fVec12[((IOTA - 310) & 511)]) + ((0.0112596424f * fVec12[((IOTA - 309) & 511)]) + ((0.0105835311f * fVec12[((IOTA - 308) & 511)]) + ((0.00907578692f * fVec12[((IOTA - 307) & 511)]) + ((0.00702926097f * fVec12[((IOTA - 306) & 511)]) + ((0.00578425778f * fVec12[((IOTA - 305) & 511)]) + ((0.0054023792f * fVec12[((IOTA - 304) & 511)]) + ((0.00446759118f * fVec12[((IOTA - 303) & 511)]) + ((0.00329811918f * fVec12[((IOTA - 302) & 511)]) + ((0.00229924405f * fVec12[((IOTA - 301) & 511)]) + ((0.00140608894f * fVec12[((IOTA - 300) & 511)]) + ((0.00121437991f * fVec12[((IOTA - 299) & 511)]) + (((((((((((((((((((((((0.0118851233f * fVec12[((IOTA - 269) & 511)]) + ((0.0166898426f * fVec12[((IOTA - 268) & 511)]) + ((0.0222918242f * fVec12[((IOTA - 267) & 511)]) + ((0.0260823164f * fVec12[((IOTA - 266) & 511)]) + ((0.0268910602f * fVec12[((IOTA - 265) & 511)]) + ((0.024575796f * fVec12[((IOTA - 264) & 511)]) + ((0.0193807129f * fVec12[((IOTA - 263) & 511)]) + ((0.0123320371f * fVec12[((IOTA - 262) & 511)]) + ((0.00602639979f * fVec12[((IOTA - 261) & 511)]) + ((0.00165604474f * fVec12[((IOTA - 260) & 511)]) + ((0.00026862137f * fVec12[((IOTA - 259) & 511)]) + ((0.000573785044f * fVec12[((IOTA - 258) & 511)]) + ((0.00157743506f * fVec12[((IOTA - 257) & 511)]) + ((0.00235587265f * fVec12[((IOTA - 256) & 511)]) + ((0.00189183326f * fVec12[((IOTA - 255) & 511)]) + ((0.000682385638f * fVec12[((IOTA - 254) & 511)]) + ((0.0109786689f * fVec12[((IOTA - 273) & 511)]) + ((0.00946445391f * fVec12[((IOTA - 272) & 511)]) + (((0.00480890227f * fVec12[((IOTA - 250) & 511)]) + ((0.00921299867f * fVec12[((IOTA - 249) & 511)]) + ((0.0133837517f * fVec12[((IOTA - 248) & 511)]) + ((0.0169285517f * fVec12[((IOTA - 247) & 511)]) + ((0.0200814083f * fVec12[((IOTA - 246) & 511)]) + ((0.0221913513f * fVec12[((IOTA - 245) & 511)]) + ((0.0221021269f * fVec12[((IOTA - 244) & 511)]) + ((0.0195546243f * fVec12[((IOTA - 243) & 511)]) + ((0.013975177f * fVec12[((IOTA - 242) & 511)]) + ((0.005568319f * fVec12[((IOTA - 241) & 511)]) + ((((0.00688861636f * fVec12[((IOTA - 232) & 511)]) + ((0.00724685704f * fVec12[((IOTA - 231) & 511)]) + ((0.00597936055f * fVec12[((IOTA - 230) & 511)]) + ((0.00411479594f * fVec12[((IOTA - 229) & 511)]) + ((0.00323872827f * fVec12[((IOTA - 228) & 511)]) + ((0.00449549081f * fVec12[((IOTA - 227) & 511)]) + ((0.00669315876f * fVec12[((IOTA - 226) & 511)]) + ((0.00869323686f * fVec12[((IOTA - 225) & 511)]) + ((0.00914350525f * fVec12[((IOTA - 224) & 511)]) + ((0.00800797064f * fVec12[((IOTA - 223) & 511)]) + ((0.00572656374f * fVec12[((IOTA - 222) & 511)]) + ((0.00287965871f * fVec12[((IOTA - 221) & 511)]) + ((0.000748682767f * fVec12[((IOTA - 220) & 511)]) + ((0.00132609857f * fVec12[((IOTA - 219) & 511)]) + ((0.00400548475f * fVec12[((IOTA - 218) & 511)]) + ((0.00750008831f * fVec12[((IOTA - 217) & 511)]) + ((0.0106816348f * fVec12[((IOTA - 216) & 511)]) + ((0.0124298641f * fVec12[((IOTA - 215) & 511)]) + ((0.01299698f * fVec12[((IOTA - 214) & 511)]) + ((0.0134859998f * fVec12[((IOTA - 213) & 511)]) + ((0.0140601005f * fVec12[((IOTA - 212) & 511)]) + ((0.0136858374f * fVec12[((IOTA - 211) & 511)]) + ((0.0125837289f * fVec12[((IOTA - 210) & 511)]) + ((0.0103678685f * fVec12[((IOTA - 209) & 511)]) + ((0.00729946047f * fVec12[((IOTA - 208) & 511)]) + ((0.00467745261f * fVec12[((IOTA - 207) & 511)]) + ((0.00361275394f * fVec12[((IOTA - 206) & 511)]) + ((0.0040778988f * fVec12[((IOTA - 205) & 511)]) + ((0.00500546489f * fVec12[((IOTA - 204) & 511)]) + ((0.00474793278f * fVec12[((IOTA - 203) & 511)]) + ((0.00251526199f * fVec12[((IOTA - 202) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((fSlow43 * fTemp0) + (0.259647995f * fVec12[((IOTA - 1) & 511)])) + (0.301574945f * fVec12[((IOTA - 2) & 511)])) + (0.319780409f * fVec12[((IOTA - 3) & 511)])) + (0.216138214f * fVec12[((IOTA - 4) & 511)])) + (0.0257540271f * fVec12[((IOTA - 5) & 511)])) + (0.069441326f * fVec12[((IOTA - 10) & 511)])) + (0.151854336f * fVec12[((IOTA - 11) & 511)])) + (0.17618905f * fVec12[((IOTA - 12) & 511)])) + (0.149460763f * fVec12[((IOTA - 13) & 511)])) + (0.121939808f * fVec12[((IOTA - 14) & 511)])) + (0.10534969f * fVec12[((IOTA - 15) & 511)])) + (0.0837285668f * fVec12[((IOTA - 16) & 511)])) + (0.0517363474f * fVec12[((IOTA - 17) & 511)])) + (0.0248213708f * fVec12[((IOTA - 18) & 511)])) + (0.0332113765f * fVec12[((IOTA - 22) & 511)])) + (0.0737704411f * fVec12[((IOTA - 23) & 511)])) + (0.0786811188f * fVec12[((IOTA - 24) & 511)])) + (0.0647433102f * fVec12[((IOTA - 25) & 511)])) + (0.0267249234f * fVec12[((IOTA - 26) & 511)])) + (0.00579795148f * fVec12[((IOTA - 36) & 511)])) + (0.000625165179f * fVec12[((IOTA - 51) & 511)])) + (0.000763599761f * fVec12[((IOTA - 61) & 511)])) + (0.0129033355f * fVec12[((IOTA - 62) & 511)])) + (0.0188739356f * fVec12[((IOTA - 63) & 511)])) + (0.0151670631f * fVec12[((IOTA - 64) & 511)])) + (0.00118671684f * fVec12[((IOTA - 65) & 511)])) + (0.00948797353f * fVec12[((IOTA - 72) & 511)])) + (0.0154440906f * fVec12[((IOTA - 73) & 511)])) + (0.0103035448f * fVec12[((IOTA - 74) & 511)])) + (0.00306027848f * fVec12[((IOTA - 75) & 511)])) + (0.00430567609f * fVec12[((IOTA - 82) & 511)])) + (0.00150707364f * fVec12[((IOTA - 83) & 511)])) + (1.43642537e-05f * fVec12[((IOTA - 112) & 511)])) + (0.00114788581f * fVec12[((IOTA - 113) & 511)])) + (0.000741066411f * fVec12[((IOTA - 114) & 511)])) + (0.00562621048f * fVec12[((IOTA - 126) & 511)])) + (0.0154807512f * fVec12[((IOTA - 127) & 511)])) + (0.0229292214f * fVec12[((IOTA - 128) & 511)])) + (0.0261141621f * fVec12[((IOTA - 129) & 511)])) + (0.0228484813f * fVec12[((IOTA - 130) & 511)])) + (0.0165272169f * fVec12[((IOTA - 131) & 511)])) + (0.00875554793f * fVec12[((IOTA - 132) & 511)])) + (0.00245227991f * fVec12[((IOTA - 139) & 511)])) + (0.0103187375f * fVec12[((IOTA - 140) & 511)])) + (0.0156779848f * fVec12[((IOTA - 141) & 511)])) + (0.0150500964f * fVec12[((IOTA - 142) & 511)])) + (0.00634991378f * fVec12[((IOTA - 143) & 511)])) + (0.00215457426f * fVec12[((IOTA - 151) & 511)])) + (0.00881012529f * fVec12[((IOTA - 152) & 511)])) + (0.0106474217f * fVec12[((IOTA - 153) & 511)])) + (0.00725186896f * fVec12[((IOTA - 154) & 511)])) + (0.000621455722f * fVec12[((IOTA - 155) & 511)])) + (0.00097511895f * fVec12[((IOTA - 165) & 511)])) + (0.0119352806f * fVec12[((IOTA - 166) & 511)])) + (0.0197964907f * fVec12[((IOTA - 167) & 511)])) + (0.0230941363f * fVec12[((IOTA - 168) & 511)])) + (0.0199591927f * fVec12[((IOTA - 169) & 511)])) + (0.0117146848f * fVec12[((IOTA - 170) & 511)])) + (0.00119409617f * fVec12[((IOTA - 171) & 511)])) + (0.00319212303f * fVec12[((IOTA - 187) & 511)])) + (0.00761010963f * fVec12[((IOTA - 188) & 511)])) + (0.0120159416f * fVec12[((IOTA - 189) & 511)])) + (0.0158879254f * fVec12[((IOTA - 190) & 511)])) + (0.0201534294f * fVec12[((IOTA - 191) & 511)])) + (0.022407487f * fVec12[((IOTA - 192) & 511)])) + (0.0214298032f * fVec12[((IOTA - 193) & 511)])) + (0.0187743716f * fVec12[((IOTA - 194) & 511)])) + (0.0137481485f * fVec12[((IOTA - 195) & 511)])) + (0.00624147058f * fVec12[((IOTA - 196) & 511)])) + (0.00410781102f * fVec12[((IOTA - 233) & 511)]))))))))))))))))))))))))))))))))) + (0.00930230133f * fVec12[((IOTA - 270) & 511)])) + (0.0087242946f * fVec12[((IOTA - 271) & 511)])))))))))))) + (0.0117719062f * fVec12[((IOTA - 274) & 511)])))))))))))))))))))) + (0.0124276541f * fVec12[((IOTA - 275) & 511)])) + (0.0127395652f * fVec12[((IOTA - 276) & 511)])) + (0.011978887f * fVec12[((IOTA - 277) & 511)])) + (0.0110808779f * fVec12[((IOTA - 278) & 511)])) + (0.010100944f * fVec12[((IOTA - 279) & 511)])) + (0.00832146034f * fVec12[((IOTA - 280) & 511)])) + (0.00677117612f * fVec12[((IOTA - 281) & 511)])) + (0.00577451056f * fVec12[((IOTA - 282) & 511)])) + (0.00471052201f * fVec12[((IOTA - 283) & 511)])) + (0.0035543493f * fVec12[((IOTA - 284) & 511)])) + (0.00203887047f * fVec12[((IOTA - 285) & 511)])) + (0.000577376224f * fVec12[((IOTA - 286) & 511)])) + (0.000310412142f * fVec12[((IOTA - 291) & 511)])) + (0.00164779695f * fVec12[((IOTA - 292) & 511)])) + (0.00266439095f * fVec12[((IOTA - 293) & 511)])) + (0.00354349706f * fVec12[((IOTA - 294) & 511)])) + (0.00336942822f * fVec12[((IOTA - 295) & 511)])) + (0.00293332757f * fVec12[((IOTA - 296) & 511)])) + (0.00263550412f * fVec12[((IOTA - 297) & 511)])) + (0.00185213378f * fVec12[((IOTA - 298) & 511)])) + (0.00245373975f * fVec12[((IOTA - 339) & 511)])))))))))))))))))))))))))))))) + (0.000853100792f * fVec12[((IOTA - 348) & 511)]))))))) + (0.0009726719f * fVec12[((IOTA - 354) & 511)])) + (0.0031246026f * fVec12[((IOTA - 355) & 511)])) + (0.00631838292f * fVec12[((IOTA - 356) & 511)])) + (0.0095118871f * fVec12[((IOTA - 357) & 511)])) + (0.0116953086f * fVec12[((IOTA - 358) & 511)])) + (0.0123660928f * fVec12[((IOTA - 359) & 511)])) + (0.0109887719f * fVec12[((IOTA - 360) & 511)])) + (0.00804688036f * fVec12[((IOTA - 361) & 511)])) + (0.00447197119f * fVec12[((IOTA - 362) & 511)])) + (0.00125431595f * fVec12[((IOTA - 363) & 511)])) + (0.00018748641f * fVec12[((IOTA - 382) & 511)])) + (0.00240977854f * fVec12[((IOTA - 383) & 511)])) + (0.00296470057f * fVec12[((IOTA - 384) & 511)])) + (0.00194506813f * fVec12[((IOTA - 385) & 511)])) + (0.000483494718f * fVec12[((IOTA - 386) & 511)])) + (0.000438231044f * fVec12[((IOTA - 389) & 511)])) + (0.00183058716f * fVec12[((IOTA - 390) & 511)])) + (0.00373035204f * fVec12[((IOTA - 391) & 511)])) + (0.00519255688f * fVec12[((IOTA - 392) & 511)])) + (0.00595678808f * fVec12[((IOTA - 393) & 511)])) + (0.00563477399f * fVec12[((IOTA - 394) & 511)])) + (0.00432868302f * fVec12[((IOTA - 395) & 511)])) + (0.00296189869f * fVec12[((IOTA - 396) & 511)])) + (0.00146978162f * fVec12[((IOTA - 397) & 511)])) + (0.000220043119f * fVec12[((IOTA - 398) & 511)])) + (2.66768038e-05f * fVec12[((IOTA - 399) & 511)])) + (3.37800011e-05f * fVec12[((IOTA - 400) & 511)])) + (0.000116611831f * fVec12[((IOTA - 401) & 511)])) + (0.000279907603f * fVec12[((IOTA - 402) & 511)])) + (0.000228921883f * fVec12[((IOTA - 403) & 511)])) + (0.00025516469f * fVec12[((IOTA - 404) & 511)])) + (0.000359029975f * fVec12[((IOTA - 405) & 511)])) + (0.000710404012f * fVec12[((IOTA - 406) & 511)])) + (0.00210366771f * fVec12[((IOTA - 407) & 511)])) + (0.00408804044f * fVec12[((IOTA - 408) & 511)])) + (0.00563074881f * fVec12[((IOTA - 409) & 511)])) + (0.00640046503f * fVec12[((IOTA - 410) & 511)])) + (0.00604202691f * fVec12[((IOTA - 411) & 511)])) + (0.00428925967f * fVec12[((IOTA - 412) & 511)])) + (0.00204601325f * fVec12[((IOTA - 413) & 511)])) + (0.000757364556f * fVec12[((IOTA - 445) & 511)])) + (0.00253957091f * fVec12[((IOTA - 446) & 511)])) + (0.00311031705f * fVec12[((IOTA - 447) & 511)])) + (0.00284422142f * fVec12[((IOTA - 448) & 511)])) + (0.00234892732f * fVec12[((IOTA - 449) & 511)])) + (0.00139689399f * fVec12[((IOTA - 450) & 511)])) + (0.000356662087f * fVec12[((IOTA - 451) & 511)])) + (0.000311201438f * fVec12[((IOTA - 462) & 511)])) + (0.00012016343f * fVec12[((IOTA - 463) & 511)])) + (0.00165545242f * fVec12[((IOTA - 468) & 511)])) + (0.00424908707f * fVec12[((IOTA - 469) & 511)])) + (0.0059665353f * fVec12[((IOTA - 470) & 511)])) + (0.00570284668f * fVec12[((IOTA - 471) & 511)])) + (0.00351634715f * fVec12[((IOTA - 472) & 511)])) + (0.000438073184f * fVec12[((IOTA - 473) & 511)])) + (0.000100550707f * fVec12[((IOTA - 481) & 511)])) + (0.000436849892f * fVec12[((IOTA - 482) & 511)])) + (0.000882105436f * fVec12[((IOTA - 483) & 511)])) + (0.00167463114f * fVec12[((IOTA - 484) & 511)])) + (0.00222588331f * fVec12[((IOTA - 485) & 511)])) + (0.00245973794f * fVec12[((IOTA - 486) & 511)])) + (0.00231660763f * fVec12[((IOTA - 487) & 511)])) + (0.0016962965f * fVec12[((IOTA - 488) & 511)])) + (0.000483652577f * fVec12[((IOTA - 489) & 511)])) + (8.48444179e-05f * fVec12[((IOTA - 500) & 511)])) + (0.00107949693f * fVec12[((IOTA - 501) & 511)])) + (0.00167814363f * fVec12[((IOTA - 502) & 511)])) + (0.00158390682f * fVec12[((IOTA - 503) & 511)])) + (0.000847615302f * fVec12[((IOTA - 504) & 511)])) - (((((((((((((((0.00276916381f * fVec12[((IOTA - 492) & 511)]) + ((0.00217154343f * fVec12[((IOTA - 491) & 511)]) + ((0.00110704219f * fVec12[((IOTA - 490) & 511)]) + ((0.000469840597f * fVec12[((IOTA - 480) & 511)]) + ((0.00108182523f * fVec12[((IOTA - 479) & 511)]) + ((0.00233764108f * fVec12[((IOTA - 478) & 511)]) + ((0.00399147579f * fVec12[((IOTA - 477) & 511)]) + ((0.00478700036f * fVec12[((IOTA - 476) & 511)]) + ((0.00448767748f * fVec12[((IOTA - 475) & 511)]) + ((0.00260578888f * fVec12[((IOTA - 474) & 511)]) + ((0.000638582278f * fVec12[((IOTA - 467) & 511)]) + ((0.00171389664f * fVec12[((IOTA - 466) & 511)]) + ((0.00144653814f * fVec12[((IOTA - 465) & 511)]) + ((0.000596673228f * fVec12[((IOTA - 464) & 511)]) + ((0.000131647103f * fVec12[((IOTA - 461) & 511)]) + ((0.000975868665f * fVec12[((IOTA - 460) & 511)]) + ((0.00185623765f * fVec12[((IOTA - 459) & 511)]) + ((0.0027833702f * fVec12[((IOTA - 458) & 511)]) + ((0.00347645022f * fVec12[((IOTA - 457) & 511)]) + ((0.00347854197f * fVec12[((IOTA - 456) & 511)]) + ((0.00307728723f * fVec12[((IOTA - 455) & 511)]) + ((0.00256309053f * fVec12[((IOTA - 454) & 511)]) + ((0.0016452712f * fVec12[((IOTA - 453) & 511)]) + ((0.000605157577f * fVec12[((IOTA - 452) & 511)]) + ((0.00140995625f * fVec12[((IOTA - 444) & 511)]) + ((0.00358469598f * fVec12[((IOTA - 443) & 511)]) + ((0.00701765902f * fVec12[((IOTA - 441) & 511)]) + ((0.00746358512f * fVec12[((IOTA - 440) & 511)]) + ((0.00690913666f * fVec12[((IOTA - 439) & 511)]) + ((0.00523801753f * fVec12[((IOTA - 438) & 511)]) + ((0.00330210524f * fVec12[((IOTA - 437) & 511)]) + ((0.00200860249f * fVec12[((IOTA - 436) & 511)]) + ((0.00170363626f * fVec12[((IOTA - 435) & 511)]) + ((0.0026654168f * fVec12[((IOTA - 434) & 511)]) + ((0.00411317823f * fVec12[((IOTA - 433) & 511)]) + ((0.00515613286f * fVec12[((IOTA - 432) & 511)]) + ((0.00557688251f * fVec12[((IOTA - 431) & 511)]) + ((0.00525553897f * fVec12[((IOTA - 430) & 511)]) + ((0.00412860792f * fVec12[((IOTA - 429) & 511)]) + ((0.00290085003f * fVec12[((IOTA - 428) & 511)]) + ((0.00220883545f * fVec12[((IOTA - 427) & 511)]) + ((0.00197651982f * fVec12[((IOTA - 426) & 511)]) + ((0.00178733608f * fVec12[((IOTA - 425) & 511)]) + ((0.0018378878f * fVec12[((IOTA - 424) & 511)]) + ((0.00174175715f * fVec12[((IOTA - 423) & 511)]) + ((0.00168027449f * fVec12[((IOTA - 422) & 511)]) + ((0.00179005926f * fVec12[((IOTA - 421) & 511)]) + ((0.00192730967f * fVec12[((IOTA - 420) & 511)]) + ((0.00238183932f * fVec12[((IOTA - 419) & 511)]) + ((0.00302803796f * fVec12[((IOTA - 418) & 511)]) + ((0.00317831105f * fVec12[((IOTA - 417) & 511)]) + ((0.0028388151f * fVec12[((IOTA - 416) & 511)]) + ((0.00185260735f * fVec12[((IOTA - 415) & 511)]) + ((6.43632375e-05f * fVec12[((IOTA - 414) & 511)]) + ((0.000258400571f * fVec12[((IOTA - 388) & 511)]) + ((0.000299520325f * fVec12[((IOTA - 387) & 511)]) + ((0.00233957497f * fVec12[((IOTA - 381) & 511)]) + ((0.00384708215f * fVec12[((IOTA - 380) & 511)]) + ((0.00299737556f * fVec12[((IOTA - 368) & 511)]) + ((0.00236688275f * fVec12[((IOTA - 367) & 511)]) + ((0.00216664979f * fVec12[((IOTA - 366) & 511)]) + ((0.00200765533f * fVec12[((IOTA - 365) & 511)]) + ((0.00106000248f * fVec12[((IOTA - 364) & 511)]) + ((0.00561034633f * fVec12[((IOTA - 370) & 511)]) + ((0.00386835262f * fVec12[((IOTA - 379) & 511)]) + ((0.00316536753f * fVec12[((IOTA - 378) & 511)]) + ((0.00605055084f * fVec12[((IOTA - 371) & 511)]) + ((0.00095767621f * fVec12[((IOTA - 375) & 511)]) + ((0.00560754491f * fVec12[((IOTA - 372) & 511)]) + ((0.00192115363f * fVec12[((IOTA - 377) & 511)]) + ((0.00570418825f * fVec12[((IOTA - 442) & 511)]) + ((0.00207888521f * fVec12[((IOTA - 374) & 511)]) + ((0.00105763506f * fVec12[((IOTA - 376) & 511)]) + ((0.00410449645f * fVec12[((IOTA - 373) & 511)]) + ((0.000689212698f * fVec12[((IOTA - 347) & 511)]) + ((0.00196937704f * fVec12[((IOTA - 346) & 511)]) + (((0.00279864203f * fVec12[((IOTA - 345) & 511)]) + ((0.00299879629f * fVec12[((IOTA - 344) & 511)]) + ((0.00274966937f * fVec12[((IOTA - 343) & 511)]) + ((0.00250306819f * fVec12[((IOTA - 342) & 511)]) + ((0.00173986284f * fVec12[((IOTA - 341) & 511)]) + ((0.000982340425f * fVec12[((IOTA - 331) & 511)]) + ((0.00238894252f * fVec12[((IOTA - 330) & 511)]) + ((0.00196460215f * fVec12[((IOTA - 329) & 511)]) + ((0.000802272931f * fVec12[((IOTA - 328) & 511)]) + ((3.94647941e-06f * fVec12[((IOTA - 324) & 511)]) + ((9.36840661e-05f * fVec12[((IOTA - 320) & 511)]) + ((0.00154231349f * fVec12[((IOTA - 319) & 511)]) + ((0.00360166514f * fVec12[((IOTA - 318) & 511)]) + ((0.00629663933f * fVec12[((IOTA - 317) & 511)]) + (((((((((((((0.00351958303f * fVec12[((IOTA - 240) & 511)]) + ((0.0109680146f * fVec12[((IOTA - 239) & 511)]) + ((0.0154172163f * fVec12[((IOTA - 238) & 511)]) + ((0.0158163402f * fVec12[((IOTA - 237) & 511)]) + ((0.0124832168f * fVec12[((IOTA - 236) & 511)]) + ((0.00704859756f * fVec12[((IOTA - 235) & 511)]) + ((0.000935656484f * fVec12[((IOTA - 234) & 511)]) + ((0.00146236271f * fVec12[((IOTA - 201) & 511)]) + ((0.00591156399f * fVec12[((IOTA - 200) & 511)]) + ((0.00772391958f * fVec12[((IOTA - 199) & 511)]) + ((0.00527258683f * fVec12[((IOTA - 198) & 511)]) + ((0.000513565261f * fVec12[((IOTA - 197) & 511)]) + ((9.79457982e-05f * fVec12[((IOTA - 186) & 511)]) + ((0.00458704401f * fVec12[((IOTA - 185) & 511)]) + ((0.0101385526f * fVec12[((IOTA - 184) & 511)]) + ((0.0147223212f * fVec12[((IOTA - 183) & 511)]) + ((0.0181103759f * fVec12[((IOTA - 182) & 511)]) + ((0.0190016367f * fVec12[((IOTA - 181) & 511)]) + ((0.0163038205f * fVec12[((IOTA - 180) & 511)]) + ((0.0107983258f * fVec12[((IOTA - 179) & 511)]) + ((0.00565308426f * fVec12[((IOTA - 178) & 511)]) + ((0.00340301078f * fVec12[((IOTA - 177) & 511)]) + ((0.00520435628f * fVec12[((IOTA - 176) & 511)]) + ((0.00947597623f * fVec12[((IOTA - 175) & 511)]) + ((0.0132584982f * fVec12[((IOTA - 174) & 511)]) + ((0.0138021335f * fVec12[((IOTA - 173) & 511)]) + ((0.00863013603f * fVec12[((IOTA - 172) & 511)]) + ((0.0109153716f * fVec12[((IOTA - 164) & 511)]) + ((0.0219325162f * fVec12[((IOTA - 163) & 511)]) + ((0.0313860774f * fVec12[((IOTA - 162) & 511)]) + ((0.0372946039f * fVec12[((IOTA - 161) & 511)]) + ((0.0395345353f * fVec12[((IOTA - 160) & 511)]) + ((0.0370334424f * fVec12[((IOTA - 159) & 511)]) + ((0.0292460658f * fVec12[((IOTA - 158) & 511)]) + ((0.0184109621f * fVec12[((IOTA - 157) & 511)]) + ((0.0078249434f * fVec12[((IOTA - 156) & 511)]) + ((0.0089226719f * fVec12[((IOTA - 150) & 511)]) + ((0.021779757f * fVec12[((IOTA - 149) & 511)]) + ((0.0317910425f * fVec12[((IOTA - 148) & 511)]) + ((0.0355653167f * fVec12[((IOTA - 147) & 511)]) + ((0.0307753161f * fVec12[((IOTA - 146) & 511)]) + ((0.0215977952f * fVec12[((IOTA - 145) & 511)]) + ((0.00803062227f * fVec12[((IOTA - 144) & 511)]) + ((0.00593859563f * fVec12[((IOTA - 138) & 511)]) + ((0.0141354334f * fVec12[((IOTA - 137) & 511)]) + ((0.0176257361f * fVec12[((IOTA - 136) & 511)]) + ((0.0147690438f * fVec12[((IOTA - 135) & 511)]) + ((0.00974609703f * fVec12[((IOTA - 134) & 511)]) + ((0.0010736566f * fVec12[((IOTA - 133) & 511)]) + ((0.00625678198f * fVec12[((IOTA - 125) & 511)]) + ((0.0179913957f * fVec12[((IOTA - 124) & 511)]) + ((0.0242864955f * fVec12[((IOTA - 123) & 511)]) + ((0.0257028844f * fVec12[((IOTA - 122) & 511)]) + ((0.0218573399f * fVec12[((IOTA - 121) & 511)]) + ((0.0146773327f * fVec12[((IOTA - 120) & 511)]) + ((0.00777608901f * fVec12[((IOTA - 119) & 511)]) + ((((0.00224679848f * fVec12[((IOTA - 111) & 511)]) + ((0.00954057649f * fVec12[((IOTA - 110) & 511)]) + ((0.0212104712f * fVec12[((IOTA - 109) & 511)]) + ((0.0304593407f * fVec12[((IOTA - 108) & 511)]) + ((0.0341115184f * fVec12[((IOTA - 107) & 511)]) + ((0.0357836224f * fVec12[((IOTA - 106) & 511)]) + ((0.0327833295f * fVec12[((IOTA - 105) & 511)]) + ((0.0297684707f * fVec12[((IOTA - 104) & 511)]) + ((0.0314466916f * fVec12[((IOTA - 103) & 511)]) + ((0.0342974663f * fVec12[((IOTA - 102) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((0.00465468271f * fVec12[((IOTA - 37) & 511)]) + ((0.0116097936f * fVec12[((IOTA - 35) & 511)]) + ((0.01758359f * fVec12[((IOTA - 34) & 511)]) + ((0.0260258056f * fVec12[((IOTA - 33) & 511)]) + ((0.0450937375f * fVec12[((IOTA - 32) & 511)]) + ((0.057032451f * fVec12[((IOTA - 31) & 511)]) + ((0.0657503158f * fVec12[((IOTA - 30) & 511)]) + ((0.0589264184f * fVec12[((IOTA - 29) & 511)]) + ((0.045059368f * fVec12[((IOTA - 28) & 511)]) + ((0.0223169997f * fVec12[((IOTA - 27) & 511)]) + ((0.0129688038f * fVec12[((IOTA - 21) & 511)]) + ((0.0208352618f * fVec12[((IOTA - 20) & 511)]) + ((0.00477014994f * fVec12[((IOTA - 19) & 511)]) + ((0.0472962223f * fVec12[((IOTA - 9) & 511)]) + ((0.180423185f * fVec12[((IOTA - 8) & 511)]) + ((0.205275968f * fVec12[((IOTA - 7) & 511)]) + ((0.112471372f * fVec12[((IOTA - 6) & 511)]) + ((0.0508054644f * fVec12[((IOTA - 39) & 511)]) + ((0.0325204283f * fVec12[((IOTA - 38) & 511)]) + (0.0727625638f * fVec12[((IOTA - 40) & 511)])))))))))))))))))))) + (0.0806183293f * fVec12[((IOTA - 41) & 511)])) + (0.0756311342f * fVec12[((IOTA - 42) & 511)])) + (0.0718631744f * fVec12[((IOTA - 43) & 511)])) + (0.0708345473f * fVec12[((IOTA - 44) & 511)])) + (0.0653965324f * fVec12[((IOTA - 45) & 511)])) + (0.0605686083f * fVec12[((IOTA - 46) & 511)])) + (0.0552430227f * fVec12[((IOTA - 47) & 511)])) + (0.0349199474f * fVec12[((IOTA - 48) & 511)])) + (0.00753627531f * fVec12[((IOTA - 49) & 511)])) + (0.00181160588f * fVec12[((IOTA - 50) & 511)])) + (0.0052837152f * fVec12[((IOTA - 52) & 511)])) + (0.0304338485f * fVec12[((IOTA - 53) & 511)])) + (0.0494533591f * fVec12[((IOTA - 54) & 511)])) + (0.0550572351f * fVec12[((IOTA - 55) & 511)])) + (0.0620574504f * fVec12[((IOTA - 56) & 511)])) + (0.0560005084f * fVec12[((IOTA - 57) & 511)])) + (0.0430793762f * fVec12[((IOTA - 58) & 511)])) + (0.0324604437f * fVec12[((IOTA - 59) & 511)])) + (0.0188242514f * fVec12[((IOTA - 60) & 511)])) + (0.0157618038f * fVec12[((IOTA - 66) & 511)])) + (0.0255245529f * fVec12[((IOTA - 67) & 511)])) + (0.0301380381f * fVec12[((IOTA - 68) & 511)])) + (0.0258389898f * fVec12[((IOTA - 69) & 511)])) + (0.0151980408f * fVec12[((IOTA - 70) & 511)])) + (0.00402450562f * fVec12[((IOTA - 71) & 511)])) + (0.00435228134f * fVec12[((IOTA - 76) & 511)])) + (0.0157663804f * fVec12[((IOTA - 77) & 511)])) + (0.0171170235f * fVec12[((IOTA - 78) & 511)])) + (0.0131615382f * fVec12[((IOTA - 79) & 511)])) + (0.00956271496f * fVec12[((IOTA - 80) & 511)])) + (0.0019227718f * fVec12[((IOTA - 81) & 511)])) + (0.00173650868f * fVec12[((IOTA - 84) & 511)])) + (0.00964416564f * fVec12[((IOTA - 85) & 511)])) + (0.018386336f * fVec12[((IOTA - 86) & 511)])) + (0.0262419023f * fVec12[((IOTA - 87) & 511)])) + (0.0295721851f * fVec12[((IOTA - 88) & 511)])) + (0.0277528428f * fVec12[((IOTA - 89) & 511)])) + (0.0174717531f * fVec12[((IOTA - 90) & 511)])) + (0.0116975587f * fVec12[((IOTA - 91) & 511)])) + (0.00980829075f * fVec12[((IOTA - 92) & 511)])) + (0.0113470908f * fVec12[((IOTA - 93) & 511)])) + (0.015900474f * fVec12[((IOTA - 94) & 511)])) + (0.0192646142f * fVec12[((IOTA - 95) & 511)])) + (0.0222806558f * fVec12[((IOTA - 96) & 511)])) + (0.0294473246f * fVec12[((IOTA - 97) & 511)])) + (0.0323792323f * fVec12[((IOTA - 98) & 511)])) + (0.0354718715f * fVec12[((IOTA - 99) & 511)])) + (0.0381731577f * fVec12[((IOTA - 100) & 511)])) + (0.0363785625f * fVec12[((IOTA - 101) & 511)])) + (0.000818255357f * fVec12[((IOTA - 115) & 511)])))))))))))) + (0.00105952891f * fVec12[((IOTA - 116) & 511)])) + (0.00378950639f * fVec12[((IOTA - 118) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00140711479f * (fVec12[((IOTA - 117) & 511)] - fVec12[((IOTA - 251) & 511)]))) + (0.000169570558f * fVec12[((IOTA - 252) & 511)])) + (9.24607739e-05f * fVec12[((IOTA - 253) & 511)])) + (0.00037363125f * fVec12[((IOTA - 287) & 511)])) + (0.000998756848f * fVec12[((IOTA - 288) & 511)])) + (0.00116260536f * fVec12[((IOTA - 289) & 511)])) + (0.000788540114f * fVec12[((IOTA - 290) & 511)])) + (0.0038861502f * fVec12[((IOTA - 314) & 511)])) + (0.00704603223f * fVec12[((IOTA - 315) & 511)])) + (0.00801242981f * fVec12[((IOTA - 316) & 511)])) + (0.00428227521f * fVec12[((IOTA - 369) & 511)])))))))))))))))) + (0.00318758469f * fVec12[((IOTA - 493) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00304031046f * fVec12[((IOTA - 494) & 511)])) + (0.00296016224f * fVec12[((IOTA - 495) & 511)])) + (0.00317787705f * fVec12[((IOTA - 496) & 511)])) + (0.0030408632f * fVec12[((IOTA - 497) & 511)])) + (0.00235603051f * fVec12[((IOTA - 498) & 511)])) + (0.00119867409f * fVec12[((IOTA - 499) & 511)])) + (0.000322882086f * fVec12[((IOTA - 505) & 511)])) + (0.00135170948f * fVec12[((IOTA - 506) & 511)])) + (0.00202529551f * fVec12[((IOTA - 507) & 511)])) + (0.00206992729f * fVec12[((IOTA - 508) & 511)])) + (0.00196432555f * fVec12[((IOTA - 509) & 511)])) + (0.00255942065f * fVec12[((IOTA - 510) & 511)])) + (0.00327803288f * fVec12[((IOTA - 511) & 511)]))) : (((((((((((((((((((((((0.000248804223f * fVec11[((IOTA - 383) & 511)]) + ((9.17529687e-05f * fVec11[((IOTA - 380) & 511)]) + ((0.000641646329f * fVec11[((IOTA - 379) & 511)]) + ((0.00116709014f * fVec11[((IOTA - 378) & 511)]) + ((0.00122200372f * fVec11[((IOTA - 377) & 511)]) + ((0.00059064338f * fVec11[((IOTA - 376) & 511)]) + ((0.000737342983f * fVec11[((IOTA - 362) & 511)]) + ((0.00117724482f * fVec11[((IOTA - 361) & 511)]) + ((0.000775989611f * fVec11[((IOTA - 360) & 511)]) + ((0.000344040804f * fVec11[((IOTA - 359) & 511)]) + ((0.000251038931f * fVec11[((IOTA - 355) & 511)]) + ((0.00164869474f * fVec11[((IOTA - 354) & 511)]) + ((0.00343370438f * fVec11[((IOTA - 353) & 511)]) + ((0.00460473821f * fVec11[((IOTA - 352) & 511)]) + ((0.0051410594f * fVec11[((IOTA - 351) & 511)]) + ((0.00470963633f * fVec11[((IOTA - 350) & 511)]) + ((0.00309866806f * fVec11[((IOTA - 349) & 511)]) + ((0.00135730021f * fVec11[((IOTA - 348) & 511)]) + ((0.00022037793f * fVec11[((IOTA - 347) & 511)]) + ((0.000282455701f * fVec11[((IOTA - 346) & 511)]) + ((0.00179776037f * fVec11[((IOTA - 345) & 511)]) + ((0.00349992281f * fVec11[((IOTA - 344) & 511)]) + ((0.0047929436f * fVec11[((IOTA - 343) & 511)]) + ((0.00550366752f * fVec11[((IOTA - 342) & 511)]) + ((0.00511401333f * fVec11[((IOTA - 341) & 511)]) + ((0.00440213876f * fVec11[((IOTA - 340) & 511)]) + (((((((((((((((0.00179592008f * fVec11[((IOTA - 315) & 511)]) + ((0.00436668005f * fVec11[((IOTA - 314) & 511)]) + ((0.00607557921f * fVec11[((IOTA - 313) & 511)]) + ((0.00711680483f * fVec11[((IOTA - 312) & 511)]) + ((0.0075009712f * fVec11[((IOTA - 311) & 511)]) + ((0.00669836253f * fVec11[((IOTA - 310) & 511)]) + ((0.00563183241f * fVec11[((IOTA - 309) & 511)]) + ((0.00516656088f * fVec11[((IOTA - 308) & 511)]) + ((0.00534287002f * fVec11[((IOTA - 307) & 511)]) + ((0.00628254935f * fVec11[((IOTA - 306) & 511)]) + ((0.00698325038f * fVec11[((IOTA - 305) & 511)]) + ((0.00662672147f * fVec11[((IOTA - 304) & 511)]) + ((0.00585309789f * fVec11[((IOTA - 303) & 511)]) + ((0.00499922317f * fVec11[((IOTA - 302) & 511)]) + ((0.0044455179f * fVec11[((IOTA - 301) & 511)]) + ((0.00452313991f * fVec11[((IOTA - 300) & 511)]) + ((0.00492252177f * fVec11[((IOTA - 299) & 511)]) + ((0.00565319322f * fVec11[((IOTA - 298) & 511)]) + ((0.00646198029f * fVec11[((IOTA - 297) & 511)]) + ((0.0064935945f * fVec11[((IOTA - 296) & 511)]) + ((0.00573022384f * fVec11[((IOTA - 295) & 511)]) + ((0.00437818188f * fVec11[((IOTA - 294) & 511)]) + ((0.00260470714f * fVec11[((IOTA - 293) & 511)]) + ((0.00116160186f * fVec11[((IOTA - 292) & 511)]) + ((0.000598563347f * fVec11[((IOTA - 291) & 511)]) + (((0.000207528472f * fVec11[((IOTA - 320) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00408823323f * fVec11[((IOTA - 151) & 511)]) + ((0.00187137304f * fVec11[((IOTA - 150) & 511)]) + (((((((((((((((((((((((((((((((((((((((((0.229251936f * fVec11[((IOTA - 3) & 511)]) + ((0.102249801f * fVec11[((IOTA - 11) & 511)]) + ((0.26630044f * fVec11[((IOTA - 2) & 511)]) + ((0.0282903183f * fVec11[((IOTA - 13) & 511)]) + (((fSlow41 * fTemp0) + ((0.128427833f * fVec11[((IOTA - 4) & 511)]) + ((0.0507432483f * fVec11[((IOTA - 10) & 511)]) + ((0.223139688f * fVec11[((IOTA - 1) & 511)]) + (0.0982254818f * fVec11[((IOTA - 12) & 511)]))))) + (0.0288539827f * fVec11[((IOTA - 17) & 511)])))))) + (0.043173857f * fVec11[((IOTA - 18) & 511)])) + (0.0204231888f * fVec11[((IOTA - 19) & 511)])) + (0.0265800059f * fVec11[((IOTA - 24) & 511)])) + (0.0472559445f * fVec11[((IOTA - 25) & 511)])) + (0.0368280448f * fVec11[((IOTA - 26) & 511)])) + (6.27022237e-05f * fVec11[((IOTA - 27) & 511)])) + (0.00848261639f * fVec11[((IOTA - 35) & 511)])) + (0.014946864f * fVec11[((IOTA - 36) & 511)])) + (0.0184008777f * fVec11[((IOTA - 37) & 511)])) + (0.0166346002f * fVec11[((IOTA - 38) & 511)])) + (0.0136938049f * fVec11[((IOTA - 39) & 511)])) + (0.0105434768f * fVec11[((IOTA - 40) & 511)])) + (0.0117048807f * fVec11[((IOTA - 41) & 511)])) + (0.0146252681f * fVec11[((IOTA - 42) & 511)])) + (0.00125332223f * fVec11[((IOTA - 43) & 511)])) + (0.0143477423f * fVec11[((IOTA - 49) & 511)])) + (0.0425073318f * fVec11[((IOTA - 50) & 511)])) + (0.0411368199f * fVec11[((IOTA - 51) & 511)])) + (0.0192746669f * fVec11[((IOTA - 52) & 511)])) + (0.0105363131f * fVec11[((IOTA - 64) & 511)])) + (0.0179533511f * fVec11[((IOTA - 65) & 511)])) + (0.012748966f * fVec11[((IOTA - 66) & 511)])) + (0.0118664019f * fVec11[((IOTA - 74) & 511)])) + (0.0149869565f * fVec11[((IOTA - 75) & 511)])) + (0.00790045224f * fVec11[((IOTA - 76) & 511)])) + (0.00948496535f * fVec11[((IOTA - 97) & 511)])) + (0.0144017693f * fVec11[((IOTA - 98) & 511)])) + (0.0155555159f * fVec11[((IOTA - 99) & 511)])) + (0.0115294596f * fVec11[((IOTA - 100) & 511)])) + (0.00368612353f * fVec11[((IOTA - 101) & 511)])) + (0.00528913923f * fVec11[((IOTA - 109) & 511)])) + (0.007726443f * fVec11[((IOTA - 110) & 511)])) + (0.00457335403f * fVec11[((IOTA - 111) & 511)])) + (0.0019739382f * fVec11[((IOTA - 133) & 511)])) + (0.00455110613f * fVec11[((IOTA - 134) & 511)])) + (0.00474029733f * fVec11[((IOTA - 135) & 511)])) + (0.00391435623f * fVec11[((IOTA - 136) & 511)])) + (0.000701259822f * fVec11[((IOTA - 137) & 511)])) + (0.0054347543f * fVec11[((IOTA - 152) & 511)])))) + (0.00550238602f * fVec11[((IOTA - 153) & 511)])) + (0.00304838782f * fVec11[((IOTA - 154) & 511)])) + (0.00219507189f * fVec11[((IOTA - 173) & 511)])) + (0.00373176998f * fVec11[((IOTA - 174) & 511)])) + (0.00415895414f * fVec11[((IOTA - 175) & 511)])) + (0.00275788037f * fVec11[((IOTA - 176) & 511)])) + (0.000252879225f * fVec11[((IOTA - 177) & 511)])) + (0.00178412255f * fVec11[((IOTA - 181) & 511)])) + (0.00582260126f * fVec11[((IOTA - 182) & 511)])) + (0.00917858444f * fVec11[((IOTA - 183) & 511)])) + (0.00966298301f * fVec11[((IOTA - 184) & 511)])) + (0.00600265665f * fVec11[((IOTA - 185) & 511)])) + (0.000813420396f * fVec11[((IOTA - 186) & 511)])) + (0.00119630527f * fVec11[((IOTA - 190) & 511)])) + (0.00539893378f * fVec11[((IOTA - 191) & 511)])) + (0.00883996673f * fVec11[((IOTA - 192) & 511)])) + (0.0105244815f * fVec11[((IOTA - 193) & 511)])) + (0.0102109052f * fVec11[((IOTA - 194) & 511)])) + (0.008988671f * fVec11[((IOTA - 195) & 511)])) + (0.00697730202f * fVec11[((IOTA - 196) & 511)])) + (0.00486750901f * fVec11[((IOTA - 197) & 511)])) + (0.00361776911f * fVec11[((IOTA - 198) & 511)])) + (0.00240657711f * fVec11[((IOTA - 199) & 511)])) + (0.00125578698f * fVec11[((IOTA - 200) & 511)])) + (0.000519692432f * fVec11[((IOTA - 201) & 511)])) + (0.000442103483f * fVec11[((IOTA - 203) & 511)])) + (0.0017919438f * fVec11[((IOTA - 204) & 511)])) + (0.00262955111f * fVec11[((IOTA - 205) & 511)])) + (0.00268466212f * fVec11[((IOTA - 206) & 511)])) + (0.00233224127f * fVec11[((IOTA - 207) & 511)])) + (0.00211383495f * fVec11[((IOTA - 208) & 511)])) + (0.00275811041f * fVec11[((IOTA - 209) & 511)])) + (0.00388537114f * fVec11[((IOTA - 210) & 511)])) + (0.00480043609f * fVec11[((IOTA - 211) & 511)])) + (0.00557070784f * fVec11[((IOTA - 212) & 511)])) + (0.00570025295f * fVec11[((IOTA - 213) & 511)])) + (0.00482215872f * fVec11[((IOTA - 214) & 511)])) + (0.00350666f * fVec11[((IOTA - 215) & 511)])) + (0.00210535666f * fVec11[((IOTA - 216) & 511)])) + (0.00125950016f * fVec11[((IOTA - 217) & 511)])) + (0.00141480984f * fVec11[((IOTA - 218) & 511)])) + (0.00246842485f * fVec11[((IOTA - 219) & 511)])) + (0.00447798613f * fVec11[((IOTA - 220) & 511)])) + (0.00669921702f * fVec11[((IOTA - 221) & 511)])) + (0.00786068756f * fVec11[((IOTA - 222) & 511)])) + (0.00762213627f * fVec11[((IOTA - 223) & 511)])) + (0.00590505404f * fVec11[((IOTA - 224) & 511)])) + (0.00338464044f * fVec11[((IOTA - 225) & 511)])) + (0.00163545087f * fVec11[((IOTA - 226) & 511)])) + (0.00133317895f * fVec11[((IOTA - 227) & 511)])) + (0.00264243362f * fVec11[((IOTA - 228) & 511)])) + (0.00520823104f * fVec11[((IOTA - 229) & 511)])) + (0.00767774042f * fVec11[((IOTA - 230) & 511)])) + (0.00937474333f * fVec11[((IOTA - 231) & 511)])) + (0.0103720967f * fVec11[((IOTA - 232) & 511)])) + (0.0101294052f * fVec11[((IOTA - 233) & 511)])) + (0.00900434703f * fVec11[((IOTA - 234) & 511)])) + (0.0075989021f * fVec11[((IOTA - 235) & 511)])) + (0.0058478727f * fVec11[((IOTA - 236) & 511)])) + (0.00447966205f * fVec11[((IOTA - 237) & 511)])) + (0.0037627928f * fVec11[((IOTA - 238) & 511)])) + (0.00346098049f * fVec11[((IOTA - 239) & 511)])) + (0.00367849972f * fVec11[((IOTA - 240) & 511)])) + (0.00343935704f * fVec11[((IOTA - 241) & 511)])) + (0.00247700186f * fVec11[((IOTA - 242) & 511)])) + (0.00178172346f * fVec11[((IOTA - 243) & 511)])) + (0.00129676703f * fVec11[((IOTA - 244) & 511)])) + (0.00130705303f * fVec11[((IOTA - 245) & 511)])) + (0.00203660736f * fVec11[((IOTA - 246) & 511)])) + (0.00266547035f * fVec11[((IOTA - 247) & 511)])) + (0.00325118424f * fVec11[((IOTA - 248) & 511)])) + (0.00366952782f * fVec11[((IOTA - 249) & 511)])) + (0.00350159919f * fVec11[((IOTA - 250) & 511)])) + (0.00378241157f * fVec11[((IOTA - 251) & 511)])) + (0.00443878071f * fVec11[((IOTA - 252) & 511)])) + (0.00502590789f * fVec11[((IOTA - 253) & 511)])) + (0.00622963998f * fVec11[((IOTA - 254) & 511)])) + (0.0074590384f * fVec11[((IOTA - 255) & 511)])) + (0.00838869438f * fVec11[((IOTA - 256) & 511)])) + (0.00941309426f * fVec11[((IOTA - 257) & 511)])) + (0.00969742332f * fVec11[((IOTA - 258) & 511)])) + (0.00927819218f * fVec11[((IOTA - 259) & 511)])) + (0.00861995015f * fVec11[((IOTA - 260) & 511)])) + (0.00723655708f * fVec11[((IOTA - 261) & 511)])) + (0.00560748111f * fVec11[((IOTA - 262) & 511)])) + (0.00442326954f * fVec11[((IOTA - 263) & 511)])) + (0.00377136981f * fVec11[((IOTA - 264) & 511)])) + (0.00394850038f * fVec11[((IOTA - 265) & 511)])) + (0.00451709284f * fVec11[((IOTA - 266) & 511)])) + (0.00504056457f * fVec11[((IOTA - 267) & 511)])) + (0.00617978722f * fVec11[((IOTA - 268) & 511)])) + (0.00787080918f * fVec11[((IOTA - 269) & 511)])) + (0.00913228095f * fVec11[((IOTA - 270) & 511)])) + (0.00957924873f * fVec11[((IOTA - 271) & 511)])) + (0.00908509083f * fVec11[((IOTA - 272) & 511)])) + (0.00745381322f * fVec11[((IOTA - 273) & 511)])) + (0.00481131393f * fVec11[((IOTA - 274) & 511)])) + (0.00172299752f * fVec11[((IOTA - 275) & 511)])) + (0.000346045475f * fVec11[((IOTA - 279) & 511)])) + (0.0019010813f * fVec11[((IOTA - 280) & 511)])) + (0.00296324026f * fVec11[((IOTA - 281) & 511)])) + (0.00359013164f * fVec11[((IOTA - 282) & 511)])) + (0.00412359368f * fVec11[((IOTA - 283) & 511)])) + (0.00458091265f * fVec11[((IOTA - 284) & 511)])) + (0.00485633593f * fVec11[((IOTA - 285) & 511)])) + (0.00458896393f * fVec11[((IOTA - 286) & 511)])) + (0.00371040916f * fVec11[((IOTA - 287) & 511)])) + (0.00281706639f * fVec11[((IOTA - 288) & 511)])) + (0.00191291189f * fVec11[((IOTA - 289) & 511)])) + (0.000676316675f * fVec11[((IOTA - 321) & 511)]))) + (0.000353571028f * fVec11[((IOTA - 322) & 511)]))))))))))))))))))))))))))) + (0.00200873986f * fVec11[((IOTA - 328) & 511)])) + (0.00396736385f * fVec11[((IOTA - 329) & 511)])) + (0.00471029337f * fVec11[((IOTA - 330) & 511)])) + (0.00374553958f * fVec11[((IOTA - 331) & 511)])) + (0.00231071608f * fVec11[((IOTA - 332) & 511)])) + (0.00183588127f * fVec11[((IOTA - 333) & 511)])) + (0.00179115497f * fVec11[((IOTA - 334) & 511)])) + (0.0020005242f * fVec11[((IOTA - 335) & 511)])) + (0.00259530824f * fVec11[((IOTA - 336) & 511)])) + (0.00286905561f * fVec11[((IOTA - 337) & 511)])) + (0.0032308423f * fVec11[((IOTA - 338) & 511)])) + (0.00389256794f * fVec11[((IOTA - 339) & 511)])) + (0.00171543891f * fVec11[((IOTA - 384) & 511)])))))))))))))))))))))))))))) + (0.00270234235f * fVec11[((IOTA - 385) & 511)])) + (0.00277986564f * fVec11[((IOTA - 386) & 511)])) + (0.00181734655f * fVec11[((IOTA - 387) & 511)])) + (0.000179200899f * fVec11[((IOTA - 388) & 511)])) + (0.000169046223f * fVec11[((IOTA - 391) & 511)])) + (0.00103721628f * fVec11[((IOTA - 392) & 511)])) + (0.000987954903f * fVec11[((IOTA - 393) & 511)])) + (0.00106028607f * fVec11[((IOTA - 401) & 511)])) + (0.00213059504f * fVec11[((IOTA - 402) & 511)])) + (0.0020337482f * fVec11[((IOTA - 403) & 511)])) + (0.000821209047f * fVec11[((IOTA - 404) & 511)])) + (0.000198360067f * fVec11[((IOTA - 418) & 511)])) + (2.79662199e-05f * fVec11[((IOTA - 425) & 511)])) + (0.00147356885f * fVec11[((IOTA - 426) & 511)])) + (0.00165214529f * fVec11[((IOTA - 427) & 511)])) + (0.0010117148f * fVec11[((IOTA - 428) & 511)])) + (0.00140564144f * fVec11[((IOTA - 497) & 511)])) + (0.00212960923f * fVec11[((IOTA - 498) & 511)])) + (0.0018363744f * fVec11[((IOTA - 499) & 511)])) + (0.000256297179f * fVec11[((IOTA - 500) & 511)])) - (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00417338079f * fVec11[((IOTA - 435) & 511)]) + ((0.00504496833f * fVec11[((IOTA - 434) & 511)]) + ((0.00551865296f * fVec11[((IOTA - 433) & 511)]) + ((0.00502498774f * fVec11[((IOTA - 432) & 511)]) + ((0.00384997763f * fVec11[((IOTA - 431) & 511)]) + ((0.00192395365f * fVec11[((IOTA - 430) & 511)]) + ((3.09566967e-05f * fVec11[((IOTA - 429) & 511)]) + ((0.00160653191f * fVec11[((IOTA - 424) & 511)]) + ((0.00282400055f * fVec11[((IOTA - 423) & 511)]) + ((0.00316666113f * fVec11[((IOTA - 422) & 511)]) + ((0.00213503139f * fVec11[((IOTA - 421) & 511)]) + ((0.000897713471f * fVec11[((IOTA - 420) & 511)]) + ((0.000147816725f * fVec11[((IOTA - 419) & 511)]) + ((0.000408452004f * fVec11[((IOTA - 417) & 511)]) + ((0.00121825747f * fVec11[((IOTA - 416) & 511)]) + ((0.00166939851f * fVec11[((IOTA - 415) & 511)]) + ((0.00224568089f * fVec11[((IOTA - 414) & 511)]) + ((0.00205142843f * fVec11[((IOTA - 413) & 511)]) + ((0.00111056585f * fVec11[((IOTA - 412) & 511)]) + ((0.000712432899f * fVec11[((IOTA - 411) & 511)]) + ((0.00100116571f * fVec11[((IOTA - 410) & 511)]) + ((0.00217703031f * fVec11[((IOTA - 409) & 511)]) + ((0.00344924862f * fVec11[((IOTA - 408) & 511)]) + ((0.00336531689f * fVec11[((IOTA - 407) & 511)]) + ((0.00242599891f * fVec11[((IOTA - 406) & 511)]) + ((0.00103790639f * fVec11[((IOTA - 405) & 511)]) + ((0.00116712321f * fVec11[((IOTA - 400) & 511)]) + ((0.00341549842f * fVec11[((IOTA - 399) & 511)]) + ((0.00495919632f * fVec11[((IOTA - 398) & 511)]) + ((0.00546958903f * fVec11[((IOTA - 397) & 511)]) + ((0.00432198634f * fVec11[((IOTA - 396) & 511)]) + ((0.00221873308f * fVec11[((IOTA - 395) & 511)]) + ((0.000328496564f * fVec11[((IOTA - 394) & 511)]) + ((0.000496623106f * fVec11[((IOTA - 390) & 511)]) + ((0.000670270063f * fVec11[((IOTA - 389) & 511)]) + ((0.000381898601f * fVec11[((IOTA - 382) & 511)]) + ((0.00020000292f * fVec11[((IOTA - 381) & 511)]) + ((0.00105759129f * fVec11[((IOTA - 375) & 511)]) + ((0.00281815091f * fVec11[((IOTA - 374) & 511)]) + ((0.00376144517f * fVec11[((IOTA - 373) & 511)]) + ((0.00384133495f * fVec11[((IOTA - 372) & 511)]) + ((0.00292114308f * fVec11[((IOTA - 371) & 511)]) + ((0.00158319902f * fVec11[((IOTA - 370) & 511)]) + ((0.00076484913f * fVec11[((IOTA - 369) & 511)]) + ((0.000516241882f * fVec11[((IOTA - 368) & 511)]) + ((0.00117356423f * fVec11[((IOTA - 367) & 511)]) + ((0.00237854524f * fVec11[((IOTA - 366) & 511)]) + ((0.00270822505f * fVec11[((IOTA - 365) & 511)]) + ((0.00198195642f * fVec11[((IOTA - 364) & 511)]) + ((0.000683579594f * fVec11[((IOTA - 363) & 511)]) + ((0.000232800376f * fVec11[((IOTA - 358) & 511)]) + ((0.000634088181f * fVec11[((IOTA - 357) & 511)]) + ((0.000417423435f * fVec11[((IOTA - 356) & 511)]) + ((((((((0.000717066694f * fVec11[((IOTA - 316) & 511)]) + ((0.000942899846f * (fVec11[((IOTA - 77) & 511)] - fVec11[((IOTA - 290) & 511)])) + ((0.00256675063f * fVec11[((IOTA - 317) & 511)]) + ((((0.00105851144f * fVec11[((IOTA - 278) & 511)]) + ((0.00162874721f * fVec11[((IOTA - 277) & 511)]) + ((0.000735568348f * fVec11[((IOTA - 276) & 511)]) + ((4.66979109e-05f * fVec11[((IOTA - 202) & 511)]) + ((0.00291046267f * fVec11[((IOTA - 189) & 511)]) + ((0.00477362005f * fVec11[((IOTA - 188) & 511)]) + ((0.00321230758f * fVec11[((IOTA - 187) & 511)]) + ((0.00141563173f * fVec11[((IOTA - 180) & 511)]) + ((0.00223986385f * fVec11[((IOTA - 179) & 511)]) + ((0.00143827405f * fVec11[((IOTA - 178) & 511)]) + ((0.000185050536f * fVec11[((IOTA - 172) & 511)]) + ((0.00199349131f * fVec11[((IOTA - 171) & 511)]) + ((0.00244223326f * fVec11[((IOTA - 170) & 511)]) + ((0.00213453872f * fVec11[((IOTA - 169) & 511)]) + ((0.0011171056f * fVec11[((IOTA - 168) & 511)]) + ((0.000125568826f * fVec11[((IOTA - 167) & 511)]) + ((9.67481174e-05f * fVec11[((IOTA - 166) & 511)]) + ((0.000285084825f * fVec11[((IOTA - 165) & 511)]) + ((0.000622454565f * fVec11[((IOTA - 164) & 511)]) + ((0.000899323728f * fVec11[((IOTA - 163) & 511)]) + ((0.000330731273f * fVec11[((IOTA - 162) & 511)]) + ((0.000400367659f * fVec11[((IOTA - 161) & 511)]) + ((0.00116347522f * fVec11[((IOTA - 160) & 511)]) + ((0.00195303746f * fVec11[((IOTA - 159) & 511)]) + ((0.00386430603f * fVec11[((IOTA - 158) & 511)]) + ((0.00548233977f * fVec11[((IOTA - 157) & 511)]) + ((0.0042325668f * fVec11[((IOTA - 156) & 511)]) + ((0.000846217386f * fVec11[((IOTA - 155) & 511)]) + ((0.00104201445f * fVec11[((IOTA - 149) & 511)]) + ((0.00318384822f * fVec11[((IOTA - 148) & 511)]) + ((0.0037778765f * fVec11[((IOTA - 147) & 511)]) + ((0.00244979188f * fVec11[((IOTA - 146) & 511)]) + ((0.000353636686f * fVec11[((IOTA - 145) & 511)]) + ((0.000265663024f * fVec11[((IOTA - 144) & 511)]) + ((0.00179542741f * fVec11[((IOTA - 143) & 511)]) + ((0.0048473971f * fVec11[((IOTA - 142) & 511)]) + ((0.00900454354f * fVec11[((IOTA - 141) & 511)]) + ((0.0105822869f * fVec11[((IOTA - 140) & 511)]) + ((0.00901361369f * fVec11[((IOTA - 139) & 511)]) + ((0.00493165758f * fVec11[((IOTA - 138) & 511)]) + ((0.00108651072f * fVec11[((IOTA - 132) & 511)]) + ((0.0032568695f * fVec11[((IOTA - 131) & 511)]) + ((0.00453812536f * fVec11[((IOTA - 130) & 511)]) + ((0.00330110313f * fVec11[((IOTA - 129) & 511)]) + ((0.00163318356f * fVec11[((IOTA - 128) & 511)]) + ((0.00205911836f * fVec11[((IOTA - 127) & 511)]) + ((0.00393417245f * fVec11[((IOTA - 126) & 511)]) + ((0.00613000011f * fVec11[((IOTA - 125) & 511)]) + ((0.00688190153f * fVec11[((IOTA - 124) & 511)]) + ((0.00740580028f * fVec11[((IOTA - 123) & 511)]) + ((0.00778138964f * fVec11[((IOTA - 122) & 511)]) + ((0.00645001838f * fVec11[((IOTA - 121) & 511)]) + ((0.00593446614f * fVec11[((IOTA - 120) & 511)]) + ((0.00719843619f * fVec11[((IOTA - 119) & 511)]) + ((0.00906573422f * fVec11[((IOTA - 118) & 511)]) + ((0.0106578395f * fVec11[((IOTA - 117) & 511)]) + ((0.011486344f * fVec11[((IOTA - 116) & 511)]) + ((0.0120818503f * fVec11[((IOTA - 115) & 511)]) + ((0.0112268915f * fVec11[((IOTA - 114) & 511)]) + ((0.00745555479f * fVec11[((IOTA - 113) & 511)]) + ((0.00154024735f * fVec11[((IOTA - 112) & 511)]) + ((0.00234170584f * fVec11[((IOTA - 108) & 511)]) + ((0.0134862103f * fVec11[((IOTA - 107) & 511)]) + ((0.0225861222f * fVec11[((IOTA - 106) & 511)]) + ((0.0240391847f * fVec11[((IOTA - 105) & 511)]) + ((0.0198735595f * fVec11[((IOTA - 104) & 511)]) + ((0.0133193657f * fVec11[((IOTA - 103) & 511)]) + ((0.00491299154f * fVec11[((IOTA - 102) & 511)]) + ((0.000868958421f * fVec11[((IOTA - 96) & 511)]) + ((0.012877427f * fVec11[((IOTA - 95) & 511)]) + ((0.020820206f * fVec11[((IOTA - 94) & 511)]) + ((0.0254195537f * fVec11[((IOTA - 93) & 511)]) + ((0.0229608566f * fVec11[((IOTA - 92) & 511)]) + ((0.0136856884f * fVec11[((IOTA - 91) & 511)]) + ((0.00622740528f * fVec11[((IOTA - 90) & 511)]) + ((0.00168326637f * fVec11[((IOTA - 89) & 511)]) + ((0.00177748408f * fVec11[((IOTA - 88) & 511)]) + ((0.00940648839f * fVec11[((IOTA - 87) & 511)]) + ((0.0174995828f * fVec11[((IOTA - 86) & 511)]) + ((0.0207754467f * fVec11[((IOTA - 85) & 511)]) + ((0.0196428299f * fVec11[((IOTA - 84) & 511)]) + ((0.0125095276f * fVec11[((IOTA - 83) & 511)]) + ((0.00557014905f * fVec11[((IOTA - 82) & 511)]) + ((0.00309679471f * fVec11[((IOTA - 81) & 511)]) + ((0.00471482845f * fVec11[((IOTA - 80) & 511)]) + ((0.0107949432f * fVec11[((IOTA - 79) & 511)]) + (((((((((((((((((((((((((((((((((((((0.037409652f * fVec11[((IOTA - 14) & 511)]) + ((0.0399417654f * fVec11[((IOTA - 15) & 511)]) + ((((0.170917675f * fVec11[((IOTA - 6) & 511)]) + (((0.0350806974f * fVec11[((IOTA - 5) & 511)]) + (0.236069262f * fVec11[((IOTA - 7) & 511)])) + (0.200281486f * fVec11[((IOTA - 8) & 511)]))) + (0.0661760867f * fVec11[((IOTA - 9) & 511)])) + (0.00920204911f * fVec11[((IOTA - 16) & 511)])))) + (0.00657989224f * fVec11[((IOTA - 20) & 511)])) + (0.0277830474f * fVec11[((IOTA - 21) & 511)])) + (0.0323728658f * fVec11[((IOTA - 22) & 511)])) + (0.00691542123f * fVec11[((IOTA - 23) & 511)])) + (0.0258771684f * fVec11[((IOTA - 28) & 511)])) + (0.0355364047f * fVec11[((IOTA - 29) & 511)])) + (0.0396015681f * fVec11[((IOTA - 30) & 511)])) + (0.0455712974f * fVec11[((IOTA - 31) & 511)])) + (0.050046064f * fVec11[((IOTA - 32) & 511)])) + (0.0326207168f * fVec11[((IOTA - 33) & 511)])) + (0.00477641355f * fVec11[((IOTA - 34) & 511)])) + (0.0296512991f * fVec11[((IOTA - 44) & 511)])) + (0.0592258312f * fVec11[((IOTA - 45) & 511)])) + (0.0672751218f * fVec11[((IOTA - 46) & 511)])) + (0.0505191237f * fVec11[((IOTA - 47) & 511)])) + (0.0215152204f * fVec11[((IOTA - 48) & 511)])) + (0.0103578996f * fVec11[((IOTA - 53) & 511)])) + (0.0366828889f * fVec11[((IOTA - 54) & 511)])) + (0.0454903878f * fVec11[((IOTA - 55) & 511)])) + (0.0419808365f * fVec11[((IOTA - 56) & 511)])) + (0.0253606308f * fVec11[((IOTA - 57) & 511)])) + (0.00605326518f * fVec11[((IOTA - 58) & 511)])) + (0.00373140862f * fVec11[((IOTA - 59) & 511)])) + (0.00673493883f * fVec11[((IOTA - 60) & 511)])) + (0.0101961829f * fVec11[((IOTA - 61) & 511)])) + (0.0145660825f * fVec11[((IOTA - 62) & 511)])) + (0.00509610306f * fVec11[((IOTA - 63) & 511)])) + (0.00429888396f * fVec11[((IOTA - 67) & 511)])) + (0.021190241f * fVec11[((IOTA - 68) & 511)])) + (0.034178514f * fVec11[((IOTA - 69) & 511)])) + (0.0420709476f * fVec11[((IOTA - 70) & 511)])) + (0.0361052938f * fVec11[((IOTA - 71) & 511)])) + (0.0220224597f * fVec11[((IOTA - 72) & 511)])) + (0.00489879446f * fVec11[((IOTA - 73) & 511)])) + (0.0106097274f * fVec11[((IOTA - 78) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00275091361f * fVec11[((IOTA - 318) & 511)])) + (0.00118473731f * fVec11[((IOTA - 319) & 511)]))))) + (0.000884338282f * fVec11[((IOTA - 323) & 511)])) + (0.00197781576f * fVec11[((IOTA - 324) & 511)])) + (0.00246103061f * fVec11[((IOTA - 325) & 511)])) + (0.00227877358f * fVec11[((IOTA - 326) & 511)])) + (0.000536814332f * fVec11[((IOTA - 327) & 511)])) + (0.00369414221f * fVec11[((IOTA - 436) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.0035388656f * fVec11[((IOTA - 437) & 511)])) + (0.00425093714f * fVec11[((IOTA - 438) & 511)])) + (0.00579223596f * fVec11[((IOTA - 439) & 511)])) + (0.00728259748f * fVec11[((IOTA - 440) & 511)])) + (0.0085538961f * fVec11[((IOTA - 441) & 511)])) + (0.00909797288f * fVec11[((IOTA - 442) & 511)])) + (0.00844682939f * fVec11[((IOTA - 443) & 511)])) + (0.0072589363f * fVec11[((IOTA - 444) & 511)])) + (0.00566226337f * fVec11[((IOTA - 445) & 511)])) + (0.00413575303f * fVec11[((IOTA - 446) & 511)])) + (0.00366650475f * fVec11[((IOTA - 447) & 511)])) + (0.00369085604f * fVec11[((IOTA - 448) & 511)])) + (0.0035930234f * fVec11[((IOTA - 449) & 511)])) + (0.00321552809f * fVec11[((IOTA - 450) & 511)])) + (0.00236004312f * fVec11[((IOTA - 451) & 511)])) + (0.00170551473f * fVec11[((IOTA - 452) & 511)])) + (0.00161520764f * fVec11[((IOTA - 453) & 511)])) + (0.00184754748f * fVec11[((IOTA - 454) & 511)])) + (0.00273862295f * fVec11[((IOTA - 455) & 511)])) + (0.00385615602f * fVec11[((IOTA - 456) & 511)])) + (0.00442524161f * fVec11[((IOTA - 457) & 511)])) + (0.00460187905f * fVec11[((IOTA - 458) & 511)])) + (0.00408192351f * fVec11[((IOTA - 459) & 511)])) + (0.0025948151f * fVec11[((IOTA - 460) & 511)])) + (0.00124546792f * fVec11[((IOTA - 461) & 511)])) + (0.000451732427f * fVec11[((IOTA - 462) & 511)])) + (0.000265761744f * fVec11[((IOTA - 463) & 511)])) + (0.00105719687f * fVec11[((IOTA - 464) & 511)])) + (0.00218334002f * fVec11[((IOTA - 465) & 511)])) + (0.00323320832f * fVec11[((IOTA - 466) & 511)])) + (0.0041482076f * fVec11[((IOTA - 467) & 511)])) + (0.00416549388f * fVec11[((IOTA - 468) & 511)])) + (0.00317536993f * fVec11[((IOTA - 469) & 511)])) + (0.00183374528f * fVec11[((IOTA - 470) & 511)])) + (0.000634186435f * fVec11[((IOTA - 471) & 511)])) + (0.000352815259f * fVec11[((IOTA - 472) & 511)])) + (0.00105131464f * fVec11[((IOTA - 473) & 511)])) + (0.00183397532f * fVec11[((IOTA - 474) & 511)])) + (0.00251229666f * fVec11[((IOTA - 475) & 511)])) + (0.00247351872f * fVec11[((IOTA - 476) & 511)])) + (0.00165421562f * fVec11[((IOTA - 477) & 511)])) + (0.00135460543f * fVec11[((IOTA - 478) & 511)])) + (0.00168356206f * fVec11[((IOTA - 479) & 511)])) + (0.0023111105f * fVec11[((IOTA - 480) & 511)])) + (0.00317471242f * fVec11[((IOTA - 481) & 511)])) + (0.00333603611f * fVec11[((IOTA - 482) & 511)])) + (0.00293106772f * fVec11[((IOTA - 483) & 511)])) + (0.00252133422f * fVec11[((IOTA - 484) & 511)])) + (0.00182217732f * fVec11[((IOTA - 485) & 511)])) + (0.00147945108f * fVec11[((IOTA - 486) & 511)])) + (0.00132861082f * fVec11[((IOTA - 487) & 511)])) + (0.000741056632f * fVec11[((IOTA - 488) & 511)])) + (0.000622323249f * fVec11[((IOTA - 489) & 511)])) + (0.000981908292f * fVec11[((IOTA - 490) & 511)])) + (0.00154123316f * fVec11[((IOTA - 491) & 511)])) + (0.00257874513f * fVec11[((IOTA - 492) & 511)])) + (0.00340192625f * fVec11[((IOTA - 493) & 511)])) + (0.00357432431f * fVec11[((IOTA - 494) & 511)])) + (0.00267677521f * fVec11[((IOTA - 495) & 511)])) + (0.000514401589f * fVec11[((IOTA - 496) & 511)])) + (0.00209007505f * fVec11[((IOTA - 501) & 511)])) + (0.0042556366f * fVec11[((IOTA - 502) & 511)])) + (0.00576877175f * fVec11[((IOTA - 503) & 511)])) + (0.00579588395f * fVec11[((IOTA - 504) & 511)])) + (0.00477207545f * fVec11[((IOTA - 505) & 511)])) + (0.00408156216f * fVec11[((IOTA - 506) & 511)])) + (0.00359118311f * fVec11[((IOTA - 507) & 511)])) + (0.00349729415f * fVec11[((IOTA - 508) & 511)])) + (0.00434393855f * fVec11[((IOTA - 509) & 511)])) + (0.00518601574f * fVec11[((IOTA - 510) & 511)])) + (0.00569345057f * fVec11[((IOTA - 511) & 511)]))))) : (iSlow27 ? (iSlow33 ? (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0109605575f * fVec10[((IOTA - 235) & 511)]) + ((0.0125123821f * fVec10[((IOTA - 234) & 511)]) + ((0.0144284358f * fVec10[((IOTA - 233) & 511)]) + ((0.0150472457f * fVec10[((IOTA - 232) & 511)]) + ((0.0132938139f * fVec10[((IOTA - 231) & 511)]) + ((0.00988374371f * fVec10[((IOTA - 230) & 511)]) + ((0.00582307903f * fVec10[((IOTA - 229) & 511)]) + ((0.0028408058f * fVec10[((IOTA - 228) & 511)]) + ((0.00250764005f * fVec10[((IOTA - 227) & 511)]) + ((0.00423470465f * fVec10[((IOTA - 226) & 511)]) + ((0.00639395555f * fVec10[((IOTA - 225) & 511)]) + ((0.0074903816f * fVec10[((IOTA - 224) & 511)]) + ((0.00685813138f * fVec10[((IOTA - 223) & 511)]) + ((0.00494320877f * fVec10[((IOTA - 222) & 511)]) + ((0.00236082356f * fVec10[((IOTA - 221) & 511)]) + ((0.000999120064f * fVec10[((IOTA - 220) & 511)]) + ((0.00289463624f * fVec10[((IOTA - 219) & 511)]) + ((0.00730142649f * fVec10[((IOTA - 218) & 511)]) + ((((((((((((((((((((((((((((((((((((((((0.00171448151f * fVec10[((IOTA - 172) & 511)]) + ((0.00201733736f * fVec10[((IOTA - 171) & 511)]) + ((0.00227157492f * fVec10[((IOTA - 170) & 511)]) + ((0.00184069155f * fVec10[((IOTA - 169) & 511)]) + ((0.00133639993f * fVec10[((IOTA - 168) & 511)]) + ((6.46994449e-05f * fVec10[((IOTA - 167) & 511)]) + ((0.000883470289f * fVec10[((IOTA - 163) & 511)]) + ((0.00162146101f * fVec10[((IOTA - 162) & 511)]) + ((0.0034109964f * fVec10[((IOTA - 153) & 511)]) + ((0.0082624536f * fVec10[((IOTA - 152) & 511)]) + ((0.0117736366f * fVec10[((IOTA - 151) & 511)]) + ((0.01211798f * fVec10[((IOTA - 150) & 511)]) + ((0.00810051709f * fVec10[((IOTA - 149) & 511)]) + (((((((((((((((((((((((((((((0.0288574211f * fVec10[((IOTA - 37) & 511)]) + ((0.0210708342f * fVec10[((IOTA - 36) & 511)]) + ((0.00164004462f * fVec10[((IOTA - 35) & 511)]) + ((0.0282245185f * fVec10[((IOTA - 28) & 511)]) + ((0.040307425f * fVec10[((IOTA - 27) & 511)]) + ((0.028585868f * fVec10[((IOTA - 26) & 511)]) + ((0.00995735731f * fVec10[((IOTA - 25) & 511)]) + ((0.0178956278f * fVec10[((IOTA - 21) & 511)]) + ((0.0129741579f * fVec10[((IOTA - 20) & 511)]) + ((0.00368806906f * fVec10[((IOTA - 19) & 511)]) + ((0.00582232466f * fVec10[((IOTA - 15) & 511)]) + ((0.0355119221f * fVec10[((IOTA - 14) & 511)]) + ((0.062563248f * fVec10[((IOTA - 13) & 511)]) + ((0.0632545725f * fVec10[((IOTA - 12) & 511)]) + ((0.0359299481f * fVec10[((IOTA - 11) & 511)]) + ((0.0787522495f * fVec10[((IOTA - 5) & 511)]) + ((0.194845036f * fVec10[((IOTA - 4) & 511)]) + ((0.259378821f * fVec10[((IOTA - 3) & 511)]) + ((0.277840197f * fVec10[((IOTA - 2) & 511)]) + ((0.209975392f * fVec10[((IOTA - 1) & 511)]) + ((fSlow37 * fTemp0) + (((0.0203486495f * fVec10[((IOTA - 38) & 511)]) + ((0.00484586833f * fVec10[((IOTA - 39) & 511)]) + (0.00471413834f * fVec10[((IOTA - 40) & 511)]))) + (0.0125624407f * fVec10[((IOTA - 41) & 511)]))))))))))))))))))))))) + (0.0178562328f * fVec10[((IOTA - 42) & 511)])) + (0.00992128812f * fVec10[((IOTA - 43) & 511)])) + (0.00779022044f * fVec10[((IOTA - 51) & 511)])) + (0.00678510033f * fVec10[((IOTA - 52) & 511)])) + (0.000279095024f * fVec10[((IOTA - 68) & 511)])) + (0.00237141829f * fVec10[((IOTA - 69) & 511)])) + (0.000674011651f * fVec10[((IOTA - 75) & 511)])) + (0.00560864899f * fVec10[((IOTA - 76) & 511)])) + (0.00501740584f * fVec10[((IOTA - 89) & 511)])) + (0.00364689017f * fVec10[((IOTA - 90) & 511)])) + (6.18193299e-05f * fVec10[((IOTA - 98) & 511)])) + (0.00547513552f * fVec10[((IOTA - 99) & 511)])) + (0.0111686792f * fVec10[((IOTA - 100) & 511)])) + (0.0142653678f * fVec10[((IOTA - 101) & 511)])) + (0.0135630351f * fVec10[((IOTA - 102) & 511)])) + (0.00808375049f * fVec10[((IOTA - 103) & 511)])) + (0.00160891237f * fVec10[((IOTA - 110) & 511)])) + (0.00959607679f * fVec10[((IOTA - 111) & 511)])) + (0.00584793696f * fVec10[((IOTA - 112) & 511)])) + (0.0034788847f * fVec10[((IOTA - 127) & 511)])) + (0.0047338875f * fVec10[((IOTA - 128) & 511)])) + (5.78421168e-05f * fVec10[((IOTA - 129) & 511)])) + (0.00451657735f * fVec10[((IOTA - 134) & 511)])) + (0.00929493457f * fVec10[((IOTA - 135) & 511)])) + (0.00922156125f * fVec10[((IOTA - 136) & 511)])) + (0.00430883281f * fVec10[((IOTA - 137) & 511)])) + (0.00225957436f * fVec10[((IOTA - 173) & 511)]))))))))))))))) + (0.00273095071f * fVec10[((IOTA - 174) & 511)])) + (0.00258927699f * fVec10[((IOTA - 175) & 511)])) + (0.0011509764f * fVec10[((IOTA - 176) & 511)])) + (0.00446624402f * fVec10[((IOTA - 181) & 511)])) + (0.00872025266f * fVec10[((IOTA - 182) & 511)])) + (0.0104964506f * fVec10[((IOTA - 183) & 511)])) + (0.00997432973f * fVec10[((IOTA - 184) & 511)])) + (0.00768204546f * fVec10[((IOTA - 185) & 511)])) + (0.00481377589f * fVec10[((IOTA - 186) & 511)])) + (0.00231309608f * fVec10[((IOTA - 187) & 511)])) + (0.00111528393f * fVec10[((IOTA - 188) & 511)])) + (0.00157657964f * fVec10[((IOTA - 189) & 511)])) + (0.00287430407f * fVec10[((IOTA - 190) & 511)])) + (0.0038807271f * fVec10[((IOTA - 191) & 511)])) + (0.00458381372f * fVec10[((IOTA - 192) & 511)])) + (0.00620105769f * fVec10[((IOTA - 193) & 511)])) + (0.00876122527f * fVec10[((IOTA - 194) & 511)])) + (0.011152599f * fVec10[((IOTA - 195) & 511)])) + (0.0122339725f * fVec10[((IOTA - 196) & 511)])) + (0.011621369f * fVec10[((IOTA - 197) & 511)])) + (0.00994233973f * fVec10[((IOTA - 198) & 511)])) + (0.0076863314f * fVec10[((IOTA - 199) & 511)])) + (0.00495829526f * fVec10[((IOTA - 200) & 511)])) + (0.00217567431f * fVec10[((IOTA - 201) & 511)])) + (0.001751957f * fVec10[((IOTA - 205) & 511)])) + (0.00559335668f * fVec10[((IOTA - 206) & 511)])) + (0.00833390839f * fVec10[((IOTA - 207) & 511)])) + (0.00848974101f * fVec10[((IOTA - 208) & 511)])) + (0.00633193087f * fVec10[((IOTA - 209) & 511)])) + (0.00331845647f * fVec10[((IOTA - 210) & 511)])) + (0.000729076564f * fVec10[((IOTA - 211) & 511)])) + (0.000276249368f * fVec10[((IOTA - 212) & 511)])) + (0.00286172051f * fVec10[((IOTA - 213) & 511)])) + (0.00727437437f * fVec10[((IOTA - 214) & 511)])) + (0.0116447182f * fVec10[((IOTA - 215) & 511)])) + (0.0136559531f * fVec10[((IOTA - 216) & 511)])) + (0.0117475782f * fVec10[((IOTA - 217) & 511)])) + (0.0100592924f * fVec10[((IOTA - 236) & 511)])))))))))))))))))))) + (0.00990160741f * fVec10[((IOTA - 237) & 511)])) + (0.0101769995f * fVec10[((IOTA - 238) & 511)])) + (0.0100111533f * fVec10[((IOTA - 239) & 511)])) + (0.0089145219f * fVec10[((IOTA - 240) & 511)])) + (0.00671638967f * fVec10[((IOTA - 241) & 511)])) + (0.00404526992f * fVec10[((IOTA - 242) & 511)])) + (0.00233764574f * fVec10[((IOTA - 243) & 511)])) + (0.0021787947f * fVec10[((IOTA - 244) & 511)])) + (0.00314218737f * fVec10[((IOTA - 245) & 511)])) + (0.00426141405f * fVec10[((IOTA - 246) & 511)])) + (0.00441145385f * fVec10[((IOTA - 247) & 511)])) + (0.00376651715f * fVec10[((IOTA - 248) & 511)])) + (0.00316742249f * fVec10[((IOTA - 249) & 511)])) + (0.00271706423f * fVec10[((IOTA - 250) & 511)])) + (0.00284005143f * fVec10[((IOTA - 251) & 511)])) + (0.00343513442f * fVec10[((IOTA - 252) & 511)])) + (0.00437116669f * fVec10[((IOTA - 253) & 511)])) + (0.00663029542f * fVec10[((IOTA - 254) & 511)])) + (0.00990932155f * fVec10[((IOTA - 255) & 511)])) + (0.0126725705f * fVec10[((IOTA - 256) & 511)])) + (0.0142489448f * fVec10[((IOTA - 257) & 511)])) + (0.0140529945f * fVec10[((IOTA - 258) & 511)])) + (0.0122058578f * fVec10[((IOTA - 259) & 511)])) + (0.0102715967f * fVec10[((IOTA - 260) & 511)])) + (0.00936052576f * fVec10[((IOTA - 261) & 511)])) + (0.00973274373f * fVec10[((IOTA - 262) & 511)])) + (0.0111256484f * fVec10[((IOTA - 263) & 511)])) + (0.0120459776f * fVec10[((IOTA - 264) & 511)])) + (0.0109133106f * fVec10[((IOTA - 265) & 511)])) + (0.00751637109f * fVec10[((IOTA - 266) & 511)])) + (0.00353552634f * fVec10[((IOTA - 267) & 511)])) + (0.00216881698f * fVec10[((IOTA - 268) & 511)])) + (0.00500787422f * fVec10[((IOTA - 269) & 511)])) + (0.0104635693f * fVec10[((IOTA - 270) & 511)])) + (0.0154069494f * fVec10[((IOTA - 271) & 511)])) + (0.0172861107f * fVec10[((IOTA - 272) & 511)])) + (0.0155270901f * fVec10[((IOTA - 273) & 511)])) + (0.0114284707f * fVec10[((IOTA - 274) & 511)])) + (0.0066698282f * fVec10[((IOTA - 275) & 511)])) + (0.00295206672f * fVec10[((IOTA - 276) & 511)])) + (0.00146857603f * fVec10[((IOTA - 277) & 511)])) + (0.00183410849f * fVec10[((IOTA - 278) & 511)])) + (0.00275059696f * fVec10[((IOTA - 279) & 511)])) + (0.00332198804f * fVec10[((IOTA - 280) & 511)])) + (0.00307477918f * fVec10[((IOTA - 281) & 511)])) + (0.00234745163f * fVec10[((IOTA - 282) & 511)])) + (0.00205080165f * fVec10[((IOTA - 283) & 511)])) + (0.00244407216f * fVec10[((IOTA - 284) & 511)])) + (0.00332733663f * fVec10[((IOTA - 285) & 511)])) + (0.00407753373f * fVec10[((IOTA - 286) & 511)])) + (0.00419297768f * fVec10[((IOTA - 287) & 511)])) + (0.00445112353f * fVec10[((IOTA - 288) & 511)])) + (0.00527781481f * fVec10[((IOTA - 289) & 511)])) + (0.00609003659f * fVec10[((IOTA - 290) & 511)])) + (0.00648560468f * fVec10[((IOTA - 291) & 511)])) + (0.00617846241f * fVec10[((IOTA - 292) & 511)])) + (0.00552732032f * fVec10[((IOTA - 293) & 511)])) + (0.00502031995f * fVec10[((IOTA - 294) & 511)])) + (0.0045564184f * fVec10[((IOTA - 295) & 511)])) + (0.0044419691f * fVec10[((IOTA - 296) & 511)])) + (0.0046956921f * fVec10[((IOTA - 297) & 511)])) + (0.00492942566f * fVec10[((IOTA - 298) & 511)])) + (0.00560528878f * fVec10[((IOTA - 299) & 511)])) + (0.00657427032f * fVec10[((IOTA - 300) & 511)])) + (0.00714507839f * fVec10[((IOTA - 301) & 511)])) + (0.00755648687f * fVec10[((IOTA - 302) & 511)])) + (0.00807291642f * fVec10[((IOTA - 303) & 511)])) + (0.0086994404f * fVec10[((IOTA - 304) & 511)])) + (0.00960584823f * fVec10[((IOTA - 305) & 511)])) + (0.0101179229f * fVec10[((IOTA - 306) & 511)])) + (0.0099331513f * fVec10[((IOTA - 307) & 511)])) + (0.00931591913f * fVec10[((IOTA - 308) & 511)])) + (0.00793456845f * fVec10[((IOTA - 309) & 511)])) + (0.00637317775f * fVec10[((IOTA - 310) & 511)])) + (0.00536229741f * fVec10[((IOTA - 311) & 511)])) + (0.0050376351f * fVec10[((IOTA - 312) & 511)])) + (0.00607800204f * fVec10[((IOTA - 313) & 511)])) + (0.00788344629f * fVec10[((IOTA - 314) & 511)])) + (0.00891825929f * fVec10[((IOTA - 315) & 511)])) + (0.00871798955f * fVec10[((IOTA - 316) & 511)])) + (0.00672297273f * fVec10[((IOTA - 317) & 511)])) + (0.00361219188f * fVec10[((IOTA - 318) & 511)])) + (0.000952524133f * fVec10[((IOTA - 319) & 511)])) + (0.000192863867f * fVec10[((IOTA - 329) & 511)])) + (0.00233682292f * fVec10[((IOTA - 330) & 511)])) + (0.00405308697f * fVec10[((IOTA - 331) & 511)])) + (0.00471746409f * fVec10[((IOTA - 332) & 511)])) + (0.00524997385f * fVec10[((IOTA - 333) & 511)])) + (0.00569604617f * fVec10[((IOTA - 334) & 511)])) + (0.00543800322f * fVec10[((IOTA - 335) & 511)])) + (0.0046963091f * fVec10[((IOTA - 336) & 511)])) + (0.00370665221f * fVec10[((IOTA - 337) & 511)])) + (0.00283038244f * fVec10[((IOTA - 338) & 511)])) + (0.00275844848f * fVec10[((IOTA - 339) & 511)])) + (0.00385120604f * fVec10[((IOTA - 340) & 511)])) + (0.00600778265f * fVec10[((IOTA - 341) & 511)])) + (0.00819329731f * fVec10[((IOTA - 342) & 511)])) + (0.00879108906f * fVec10[((IOTA - 343) & 511)])) + (0.00732511887f * fVec10[((IOTA - 344) & 511)])) + (0.00434768014f * fVec10[((IOTA - 345) & 511)])) + (0.00105833309f * fVec10[((IOTA - 346) & 511)])) + (0.00263789576f * fVec10[((IOTA - 349) & 511)])) + (0.00642813975f * fVec10[((IOTA - 350) & 511)])) + (0.00917163864f * fVec10[((IOTA - 351) & 511)])) + (0.00970037747f * fVec10[((IOTA - 352) & 511)])) + (0.00800708495f * fVec10[((IOTA - 353) & 511)])) + (0.00427989475f * fVec10[((IOTA - 354) & 511)])) + (0.00142163737f * fVec10[((IOTA - 360) & 511)])) + (0.00338943023f * fVec10[((IOTA - 361) & 511)])) + (0.0038170903f * fVec10[((IOTA - 362) & 511)])) + (0.00257065939f * fVec10[((IOTA - 363) & 511)])) + (0.00118200621f * fVec10[((IOTA - 364) & 511)])) + (0.000570499338f * fVec10[((IOTA - 365) & 511)])) + (0.000535903964f * fVec10[((IOTA - 366) & 511)])) + (0.000620798208f * fVec10[((IOTA - 367) & 511)])) + (0.00144172926f * fVec10[((IOTA - 377) & 511)])) + (0.00322001847f * fVec10[((IOTA - 378) & 511)])) + (0.0029361234f * fVec10[((IOTA - 379) & 511)])) + (0.00147533044f * fVec10[((IOTA - 380) & 511)])) + (0.000114415307f * fVec10[((IOTA - 383) & 511)])) + (0.0022457568f * fVec10[((IOTA - 384) & 511)])) + (0.0041791941f * fVec10[((IOTA - 385) & 511)])) + (0.00506029883f * fVec10[((IOTA - 386) & 511)])) + (0.00437051523f * fVec10[((IOTA - 387) & 511)])) + (0.00225799717f * fVec10[((IOTA - 388) & 511)])) + (0.000217653345f * fVec10[((IOTA - 389) & 511)])) + (0.000518040732f * fVec10[((IOTA - 393) & 511)])) + (0.00117432605f * fVec10[((IOTA - 394) & 511)])) + (0.000787912868f * fVec10[((IOTA - 395) & 511)])) + (0.00114281615f * fVec10[((IOTA - 411) & 511)])) + (0.00145863276f * fVec10[((IOTA - 412) & 511)])) + (0.00108384294f * fVec10[((IOTA - 420) & 511)])) + (0.00121773314f * fVec10[((IOTA - 421) & 511)])) + (0.0003135195f * fVec10[((IOTA - 422) & 511)])) + (0.000662079547f * fVec10[((IOTA - 463) & 511)])) + (0.00111319218f * fVec10[((IOTA - 464) & 511)])) + (0.00011407258f * fVec10[((IOTA - 488) & 511)])) + (0.00142438011f * fVec10[((IOTA - 489) & 511)])) + (0.00124248816f * fVec10[((IOTA - 490) & 511)])) + (0.00153121818f * fVec10[((IOTA - 497) & 511)])) + (0.00470388634f * fVec10[((IOTA - 498) & 511)])) + (0.00544801494f * fVec10[((IOTA - 499) & 511)])) + (0.00376634579f * fVec10[((IOTA - 500) & 511)])) + (8.36597756e-05f * fVec10[((IOTA - 501) & 511)])) - ((((((((((((((((((((((((((0.00138837891f * fVec10[((IOTA - 478) & 511)]) + ((0.00292079709f * fVec10[((IOTA - 477) & 511)]) + ((0.00399421668f * fVec10[((IOTA - 476) & 511)]) + ((0.00329037523f * fVec10[((IOTA - 475) & 511)]) + ((0.00159842055f * fVec10[((IOTA - 474) & 511)]) + ((0.000477205031f * fVec10[((IOTA - 473) & 511)]) + ((0.000640856102f * fVec10[((IOTA - 472) & 511)]) + ((0.00272577303f * fVec10[((IOTA - 471) & 511)]) + ((0.00614798162f * fVec10[((IOTA - 470) & 511)]) + ((0.0088231815f * fVec10[((IOTA - 469) & 511)]) + ((0.00899201073f * fVec10[((IOTA - 468) & 511)]) + ((0.00640856195f * fVec10[((IOTA - 467) & 511)]) + ((0.00270592095f * fVec10[((IOTA - 466) & 511)]) + ((4.663039e-05f * fVec10[((IOTA - 465) & 511)]) + ((0.00139602507f * fVec10[((IOTA - 462) & 511)]) + ((0.0036982866f * fVec10[((IOTA - 461) & 511)]) + ((0.00563388411f * fVec10[((IOTA - 460) & 511)]) + ((0.00679545524f * fVec10[((IOTA - 459) & 511)]) + ((0.00606922479f * fVec10[((IOTA - 458) & 511)]) + ((0.0041855718f * fVec10[((IOTA - 457) & 511)]) + ((0.00261790678f * fVec10[((IOTA - 456) & 511)]) + ((0.00194818107f * fVec10[((IOTA - 455) & 511)]) + ((0.00227555213f * fVec10[((IOTA - 454) & 511)]) + ((0.00311040366f * fVec10[((IOTA - 453) & 511)]) + ((0.00432594214f * fVec10[((IOTA - 452) & 511)]) + ((0.00594990607f * fVec10[((IOTA - 451) & 511)]) + ((0.00731253577f * fVec10[((IOTA - 450) & 511)]) + ((0.00789887551f * fVec10[((IOTA - 449) & 511)]) + ((0.00789788179f * fVec10[((IOTA - 448) & 511)]) + ((0.00766174775f * fVec10[((IOTA - 447) & 511)]) + ((0.00803794339f * fVec10[((IOTA - 446) & 511)]) + ((0.0093448218f * fVec10[((IOTA - 445) & 511)]) + ((0.0107833287f * fVec10[((IOTA - 444) & 511)]) + ((0.0118451938f * fVec10[((IOTA - 443) & 511)]) + ((0.0121529177f * fVec10[((IOTA - 442) & 511)]) + ((0.0112359151f * fVec10[((IOTA - 441) & 511)]) + ((0.00939666387f * fVec10[((IOTA - 440) & 511)]) + ((0.00699154194f * fVec10[((IOTA - 439) & 511)]) + ((0.00494598644f * fVec10[((IOTA - 438) & 511)]) + ((0.00447172998f * fVec10[((IOTA - 437) & 511)]) + ((0.00544623192f * fVec10[((IOTA - 436) & 511)]) + ((0.00678434642f * fVec10[((IOTA - 435) & 511)]) + ((0.00741543062f * fVec10[((IOTA - 434) & 511)]) + ((0.00667966856f * fVec10[((IOTA - 433) & 511)]) + ((0.00478062034f * fVec10[((IOTA - 432) & 511)]) + ((0.00264036469f * fVec10[((IOTA - 431) & 511)]) + ((0.00102541782f * fVec10[((IOTA - 430) & 511)]) + ((0.000409213826f * fVec10[((IOTA - 429) & 511)]) + ((0.000571082346f * fVec10[((IOTA - 428) & 511)]) + ((0.00077892933f * fVec10[((IOTA - 427) & 511)]) + ((0.000992502552f * fVec10[((IOTA - 426) & 511)]) + ((0.0014949427f * fVec10[((IOTA - 425) & 511)]) + ((0.00154095562f * fVec10[((IOTA - 424) & 511)]) + ((0.000795044471f * fVec10[((IOTA - 423) & 511)]) + ((0.000211035833f * fVec10[((IOTA - 419) & 511)]) + ((0.00228347257f * fVec10[((IOTA - 418) & 511)]) + ((0.0045253206f * fVec10[((IOTA - 417) & 511)]) + ((0.00547619862f * fVec10[((IOTA - 416) & 511)]) + ((0.00463418104f * fVec10[((IOTA - 415) & 511)]) + ((0.00270396657f * fVec10[((IOTA - 414) & 511)]) + ((0.000175480265f * fVec10[((IOTA - 413) & 511)]) + ((0.000561584719f * fVec10[((IOTA - 410) & 511)]) + ((0.00273869932f * fVec10[((IOTA - 409) & 511)]) + ((0.00380965043f * fVec10[((IOTA - 408) & 511)]) + ((0.00314479321f * fVec10[((IOTA - 407) & 511)]) + ((0.00226060301f * fVec10[((IOTA - 406) & 511)]) + ((0.00164782768f * fVec10[((IOTA - 405) & 511)]) + ((0.000985130668f * fVec10[((IOTA - 404) & 511)]) + ((0.000858886633f * fVec10[((IOTA - 403) & 511)]) + ((0.00165718794f * fVec10[((IOTA - 402) & 511)]) + ((0.00338092679f * fVec10[((IOTA - 401) & 511)]) + ((0.00538948691f * fVec10[((IOTA - 400) & 511)]) + ((0.00634026248f * fVec10[((IOTA - 399) & 511)]) + ((0.00576626556f * fVec10[((IOTA - 398) & 511)]) + ((0.00377004873f * fVec10[((IOTA - 397) & 511)]) + ((0.00107455114f * fVec10[((IOTA - 396) & 511)]) + ((0.00063489005f * fVec10[((IOTA - 392) & 511)]) + ((0.00131473085f * fVec10[((IOTA - 391) & 511)]) + ((0.00095681008f * fVec10[((IOTA - 390) & 511)]) + ((0.00074961409f * fVec10[((IOTA - 382) & 511)]) + ((3.73725779e-05f * fVec10[((IOTA - 381) & 511)]) + ((0.0021968293f * fVec10[((IOTA - 376) & 511)]) + ((0.0065581901f * fVec10[((IOTA - 375) & 511)]) + ((0.00975876767f * fVec10[((IOTA - 374) & 511)]) + ((0.010509273f * fVec10[((IOTA - 373) & 511)]) + ((0.00908105262f * fVec10[((IOTA - 372) & 511)]) + ((0.00622759573f * fVec10[((IOTA - 371) & 511)]) + ((0.00333878864f * fVec10[((IOTA - 370) & 511)]) + ((0.00138532743f * fVec10[((IOTA - 369) & 511)]) + ((1.33034773e-05f * fVec10[((IOTA - 368) & 511)]) + ((0.00138162449f * fVec10[((IOTA - 359) & 511)]) + ((0.00415930804f * fVec10[((IOTA - 358) & 511)]) + ((0.00516405096f * fVec10[((IOTA - 357) & 511)]) + ((0.00363629591f * fVec10[((IOTA - 356) & 511)]) + ((0.000174691901f * fVec10[((IOTA - 355) & 511)]) + ((0.000161114149f * fVec10[((IOTA - 348) & 511)]) + ((0.000756745692f * fVec10[((IOTA - 347) & 511)]) + ((0.00121577876f * fVec10[((IOTA - 328) & 511)]) + ((0.00177918095f * fVec10[((IOTA - 327) & 511)]) + ((0.00171636743f * fVec10[((IOTA - 326) & 511)]) + ((0.00181501079f * fVec10[((IOTA - 325) & 511)]) + ((0.00237025227f * fVec10[((IOTA - 324) & 511)]) + ((0.00272944197f * fVec10[((IOTA - 323) & 511)]) + ((0.00291856844f * fVec10[((IOTA - 322) & 511)]) + ((0.00270225247f * fVec10[((IOTA - 321) & 511)]) + ((0.00125829456f * fVec10[((IOTA - 320) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0566496514f * fVec10[((IOTA - 6) & 511)]) + (0.165006533f * fVec10[((IOTA - 7) & 511)])) + (0.194481835f * fVec10[((IOTA - 8) & 511)])) + (0.125268206f * fVec10[((IOTA - 9) & 511)])) + (0.0278372485f * fVec10[((IOTA - 10) & 511)])) + (0.00707095023f * fVec10[((IOTA - 16) & 511)])) + (0.00664678728f * fVec10[((IOTA - 17) & 511)])) + (0.000504291616f * fVec10[((IOTA - 18) & 511)])) + (0.00188389281f * fVec10[((IOTA - 22) & 511)])) + (0.0179008394f * fVec10[((IOTA - 23) & 511)])) + (0.00851926208f * fVec10[((IOTA - 24) & 511)])) + (0.00728006614f * fVec10[((IOTA - 29) & 511)])) + (0.0481873713f * fVec10[((IOTA - 30) & 511)])) + (0.0763159916f * fVec10[((IOTA - 31) & 511)])) + (0.0897222012f * fVec10[((IOTA - 32) & 511)])) + (0.0759736374f * fVec10[((IOTA - 33) & 511)])) + (0.0355028361f * fVec10[((IOTA - 34) & 511)])) + (0.016181387f * fVec10[((IOTA - 44) & 511)])) + (0.0431900918f * fVec10[((IOTA - 45) & 511)])) + (0.0602499805f * fVec10[((IOTA - 46) & 511)])) + (0.0668022409f * fVec10[((IOTA - 47) & 511)])) + (0.051366657f * fVec10[((IOTA - 48) & 511)])) + (0.0233363062f * fVec10[((IOTA - 49) & 511)])) + (0.00232993113f * fVec10[((IOTA - 50) & 511)])) + (0.00188924186f * fVec10[((IOTA - 53) & 511)])) + (0.0111620277f * fVec10[((IOTA - 54) & 511)])) + (0.018290991f * fVec10[((IOTA - 55) & 511)])) + (0.0223847069f * fVec10[((IOTA - 56) & 511)])) + (0.0193522386f * fVec10[((IOTA - 57) & 511)])) + (0.0110355429f * fVec10[((IOTA - 58) & 511)])) + (0.00490528764f * fVec10[((IOTA - 59) & 511)])) + (0.00226879772f * fVec10[((IOTA - 60) & 511)])) + (0.00290499069f * fVec10[((IOTA - 61) & 511)])) + (0.0118826004f * fVec10[((IOTA - 62) & 511)])) + (0.0277209468f * fVec10[((IOTA - 63) & 511)])) + (0.0424129814f * fVec10[((IOTA - 64) & 511)])) + (0.0437783524f * fVec10[((IOTA - 65) & 511)])) + (0.0296425223f * fVec10[((IOTA - 66) & 511)])) + (0.0116682043f * fVec10[((IOTA - 67) & 511)])) + (0.00579468952f * fVec10[((IOTA - 70) & 511)])) + (0.0181956384f * fVec10[((IOTA - 71) & 511)])) + (0.0286899973f * fVec10[((IOTA - 72) & 511)])) + (0.0285235699f * fVec10[((IOTA - 73) & 511)])) + (0.0147673283f * fVec10[((IOTA - 74) & 511)])) + (0.00183736579f * fVec10[((IOTA - 77) & 511)])) + (0.0136031164f * fVec10[((IOTA - 78) & 511)])) + (0.0182648301f * fVec10[((IOTA - 79) & 511)])) + (0.0150811207f * fVec10[((IOTA - 80) & 511)])) + (0.00759032788f * fVec10[((IOTA - 81) & 511)])) + (0.00445900951f * fVec10[((IOTA - 82) & 511)])) + (0.00790994987f * fVec10[((IOTA - 83) & 511)])) + (0.0149094127f * fVec10[((IOTA - 84) & 511)])) + (0.0247807782f * fVec10[((IOTA - 85) & 511)])) + (0.0292446576f * fVec10[((IOTA - 86) & 511)])) + (0.0213653594f * fVec10[((IOTA - 87) & 511)])) + (0.00633316487f * fVec10[((IOTA - 88) & 511)])) + (0.00818037055f * fVec10[((IOTA - 91) & 511)])) + (0.0228124708f * fVec10[((IOTA - 92) & 511)])) + (0.0363339856f * fVec10[((IOTA - 93) & 511)])) + (0.0399484038f * fVec10[((IOTA - 94) & 511)])) + (0.0310777016f * fVec10[((IOTA - 95) & 511)])) + (0.0175078437f * fVec10[((IOTA - 96) & 511)])) + (0.00683882786f * fVec10[((IOTA - 97) & 511)])) + (0.00308629964f * fVec10[((IOTA - 104) & 511)])) + (0.0174386539f * fVec10[((IOTA - 105) & 511)])) + (0.0306263492f * fVec10[((IOTA - 106) & 511)])) + (0.03526612f * fVec10[((IOTA - 107) & 511)])) + (0.0283625238f * fVec10[((IOTA - 108) & 511)])) + (0.0143622626f * fVec10[((IOTA - 109) & 511)])) + (0.00202110922f * fVec10[((IOTA - 113) & 511)])) + (0.00842624251f * fVec10[((IOTA - 114) & 511)])) + (0.0130135193f * fVec10[((IOTA - 115) & 511)])) + (0.0156835765f * fVec10[((IOTA - 116) & 511)])) + (0.0158632398f * fVec10[((IOTA - 117) & 511)])) + (0.0130381025f * fVec10[((IOTA - 118) & 511)])) + (0.0105417427f * fVec10[((IOTA - 119) & 511)])) + (0.0115038678f * fVec10[((IOTA - 120) & 511)])) + (0.0144899469f * fVec10[((IOTA - 121) & 511)])) + (0.0178677198f * fVec10[((IOTA - 122) & 511)])) + (0.0187462531f * fVec10[((IOTA - 123) & 511)])) + (0.0156782605f * fVec10[((IOTA - 124) & 511)])) + (0.0100036105f * fVec10[((IOTA - 125) & 511)])) + (0.00298251351f * fVec10[((IOTA - 126) & 511)])) + (0.00654714974f * fVec10[((IOTA - 130) & 511)])) + (0.00984009635f * fVec10[((IOTA - 131) & 511)])) + (0.00758329919f * fVec10[((IOTA - 132) & 511)])) + (0.00199940568f * fVec10[((IOTA - 133) & 511)])) + (0.00145009533f * fVec10[((IOTA - 138) & 511)])) + (0.00517687388f * fVec10[((IOTA - 139) & 511)])) + (0.00619176589f * fVec10[((IOTA - 140) & 511)])) + (0.00602430897f * fVec10[((IOTA - 141) & 511)])) + (0.00794752873f * fVec10[((IOTA - 142) & 511)])) + (0.0121549405f * fVec10[((IOTA - 143) & 511)])) + (0.0151943024f * fVec10[((IOTA - 144) & 511)])) + (0.0150236227f * fVec10[((IOTA - 145) & 511)])) + (0.0126102362f * fVec10[((IOTA - 146) & 511)])) + (0.00793182477f * fVec10[((IOTA - 147) & 511)])) + (1.59093179e-05f * fVec10[((IOTA - 148) & 511)])) + (0.000210624188f * fVec10[((IOTA - 154) & 511)])) + (0.00275690574f * fVec10[((IOTA - 155) & 511)])) + (0.00577134034f * fVec10[((IOTA - 156) & 511)])) + (0.00824164227f * fVec10[((IOTA - 157) & 511)])) + (0.00844904315f * fVec10[((IOTA - 158) & 511)])) + (0.00633295951f * fVec10[((IOTA - 159) & 511)])) + (0.00315161608f * fVec10[((IOTA - 160) & 511)])) + (0.000105191953f * fVec10[((IOTA - 161) & 511)])) + (0.00131483329f * fVec10[((IOTA - 164) & 511)])) + (0.00257600797f * fVec10[((IOTA - 165) & 511)])) + (0.00187322963f * fVec10[((IOTA - 166) & 511)])) + (0.0021004146f * fVec10[((IOTA - 177) & 511)])) + (0.00497317594f * fVec10[((IOTA - 178) & 511)])) + (0.00478507765f * fVec10[((IOTA - 179) & 511)])) + (0.000975736417f * fVec10[((IOTA - 180) & 511)])) + (0.000421077479f * fVec10[((IOTA - 202) & 511)])) + (0.00200499408f * fVec10[((IOTA - 203) & 511)])) + (0.00125637418f * fVec10[((IOTA - 204) & 511)])) + (0.000507446006f * fVec10[((IOTA - 479) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000539641362f * fVec10[((IOTA - 480) & 511)])) + (0.00144083798f * fVec10[((IOTA - 481) & 511)])) + (0.00275556836f * fVec10[((IOTA - 482) & 511)])) + (0.00452072592f * fVec10[((IOTA - 483) & 511)])) + (0.00605180673f * fVec10[((IOTA - 484) & 511)])) + (0.0059926277f * fVec10[((IOTA - 485) & 511)])) + (0.00465170201f * fVec10[((IOTA - 486) & 511)])) + (0.00243416335f * fVec10[((IOTA - 487) & 511)])) + (0.000288009644f * fVec10[((IOTA - 491) & 511)])) + (0.00348402746f * fVec10[((IOTA - 492) & 511)])) + (0.0069566723f * fVec10[((IOTA - 493) & 511)])) + (0.00869717728f * fVec10[((IOTA - 494) & 511)])) + (0.00754702371f * fVec10[((IOTA - 495) & 511)])) + (0.00342385424f * fVec10[((IOTA - 496) & 511)])) + (0.00389742479f * fVec10[((IOTA - 502) & 511)])) + (0.00670480076f * fVec10[((IOTA - 503) & 511)])) + (0.00777540868f * fVec10[((IOTA - 504) & 511)])) + (0.00741666509f * fVec10[((IOTA - 505) & 511)])) + (0.00667593116f * fVec10[((IOTA - 506) & 511)])) + (0.00605057273f * fVec10[((IOTA - 507) & 511)])) + (0.00604680087f * fVec10[((IOTA - 508) & 511)])) + (0.0069148764f * fVec10[((IOTA - 509) & 511)])) + (0.00738830958f * fVec10[((IOTA - 510) & 511)])) + (0.00702322274f * fVec10[((IOTA - 511) & 511)]))) : ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00977604277f * fVec9[((IOTA - 267) & 511)]) + ((0.0101385303f * fVec9[((IOTA - 266) & 511)]) + ((0.0107048927f * fVec9[((IOTA - 265) & 511)]) + ((0.0122852121f * fVec9[((IOTA - 264) & 511)]) + ((0.0144602731f * fVec9[((IOTA - 263) & 511)]) + ((0.0156689435f * fVec9[((IOTA - 262) & 511)]) + ((0.0156409666f * fVec9[((IOTA - 261) & 511)]) + ((0.0151758548f * fVec9[((IOTA - 260) & 511)]) + ((0.0147484848f * fVec9[((IOTA - 259) & 511)]) + ((0.0137106609f * fVec9[((IOTA - 258) & 511)]) + ((0.0110795144f * fVec9[((IOTA - 257) & 511)]) + ((0.00714513008f * fVec9[((IOTA - 256) & 511)]) + ((0.00307853986f * fVec9[((IOTA - 255) & 511)]) + ((0.000282796565f * fVec9[((IOTA - 254) & 511)]) + ((0.000148986466f * fVec9[((IOTA - 253) & 511)]) + ((0.0025546304f * fVec9[((IOTA - 252) & 511)]) + ((0.00578924362f * fVec9[((IOTA - 251) & 511)]) + ((0.00800084136f * fVec9[((IOTA - 250) & 511)]) + ((0.00799586065f * fVec9[((IOTA - 249) & 511)]) + ((0.00590212829f * fVec9[((IOTA - 248) & 511)]) + ((0.00363143114f * fVec9[((IOTA - 247) & 511)]) + ((0.00301118335f * fVec9[((IOTA - 246) & 511)]) + ((0.00472644949f * fVec9[((IOTA - 245) & 511)]) + ((0.00817265827f * fVec9[((IOTA - 244) & 511)]) + ((0.0114393951f * fVec9[((IOTA - 243) & 511)]) + ((0.0130259991f * fVec9[((IOTA - 242) & 511)]) + ((0.0124418195f * fVec9[((IOTA - 241) & 511)]) + ((0.0102903917f * fVec9[((IOTA - 240) & 511)]) + ((0.00863335654f * fVec9[((IOTA - 239) & 511)]) + ((0.0091951061f * fVec9[((IOTA - 238) & 511)]) + ((0.0119253974f * fVec9[((IOTA - 237) & 511)]) + ((0.015477974f * fVec9[((IOTA - 236) & 511)]) + ((0.0176608227f * fVec9[((IOTA - 235) & 511)]) + ((0.0177074876f * fVec9[((IOTA - 234) & 511)]) + ((0.0165719558f * fVec9[((IOTA - 233) & 511)]) + ((0.0149250487f * fVec9[((IOTA - 232) & 511)]) + ((0.0128367655f * fVec9[((IOTA - 231) & 511)]) + ((0.010159824f * fVec9[((IOTA - 230) & 511)]) + ((0.00732527114f * fVec9[((IOTA - 229) & 511)]) + ((0.00491929241f * fVec9[((IOTA - 228) & 511)]) + ((0.0029936675f * fVec9[((IOTA - 227) & 511)]) + ((0.00139195472f * fVec9[((IOTA - 226) & 511)]) + ((0.000373284798f * fVec9[((IOTA - 225) & 511)]) + ((0.00119673833f * fVec9[((IOTA - 224) & 511)]) + ((0.00386983575f * fVec9[((IOTA - 223) & 511)]) + ((0.00650689891f * fVec9[((IOTA - 222) & 511)]) + ((0.00770704681f * fVec9[((IOTA - 221) & 511)]) + ((0.00788588449f * fVec9[((IOTA - 220) & 511)]) + ((0.00855483487f * fVec9[((IOTA - 219) & 511)]) + ((0.0102131069f * fVec9[((IOTA - 218) & 511)]) + (((((((((((0.0170013979f * fVec9[((IOTA - 206) & 511)]) + ((0.0128226262f * fVec9[((IOTA - 205) & 511)]) + ((0.00587184308f * fVec9[((IOTA - 204) & 511)]) + ((0.00249329116f * fVec9[((IOTA - 200) & 511)]) + ((0.00784791075f * fVec9[((IOTA - 199) & 511)]) + ((0.011804089f * fVec9[((IOTA - 198) & 511)]) + ((0.0137033407f * fVec9[((IOTA - 197) & 511)]) + ((0.0136148911f * fVec9[((IOTA - 196) & 511)]) + ((0.0112713557f * fVec9[((IOTA - 195) & 511)]) + ((0.00786061212f * fVec9[((IOTA - 194) & 511)]) + ((0.00473159738f * fVec9[((IOTA - 193) & 511)]) + ((0.00236894097f * fVec9[((IOTA - 192) & 511)]) + ((0.00118376827f * fVec9[((IOTA - 191) & 511)]) + ((0.00154906418f * fVec9[((IOTA - 190) & 511)]) + ((0.00391884055f * fVec9[((IOTA - 189) & 511)]) + ((0.00794722326f * fVec9[((IOTA - 188) & 511)]) + ((0.0115996804f * fVec9[((IOTA - 187) & 511)]) + ((0.0130455531f * fVec9[((IOTA - 186) & 511)]) + ((0.0120011112f * fVec9[((IOTA - 185) & 511)]) + ((0.00984075852f * fVec9[((IOTA - 184) & 511)]) + ((0.00733941095f * fVec9[((IOTA - 183) & 511)]) + ((0.00436218968f * fVec9[((IOTA - 182) & 511)]) + ((0.00177235994f * fVec9[((IOTA - 181) & 511)]) + ((0.00533001637f * fVec9[((IOTA - 174) & 511)]) + ((0.0112088118f * fVec9[((IOTA - 173) & 511)]) + ((0.014366609f * fVec9[((IOTA - 172) & 511)]) + ((0.0125107132f * fVec9[((IOTA - 171) & 511)]) + ((0.0062530837f * fVec9[((IOTA - 170) & 511)]) + ((0.000949006993f * fVec9[((IOTA - 166) & 511)]) + ((0.00338543812f * fVec9[((IOTA - 165) & 511)]) + ((0.00217038114f * fVec9[((IOTA - 164) & 511)]) + ((0.000205913559f * fVec9[((IOTA - 156) & 511)]) + ((0.000918420963f * fVec9[((IOTA - 155) & 511)]) + ((0.0010505598f * fVec9[((IOTA - 154) & 511)]) + ((0.0013272725f * fVec9[((IOTA - 153) & 511)]) + ((0.00174013572f * fVec9[((IOTA - 152) & 511)]) + ((0.00335966516f * fVec9[((IOTA - 151) & 511)]) + ((0.00512674358f * fVec9[((IOTA - 150) & 511)]) + ((0.00461700745f * fVec9[((IOTA - 149) & 511)]) + ((0.00202781288f * fVec9[((IOTA - 148) & 511)]) + (((((((((((((((((((((((((((((((((((0.249394968f * fVec9[((IOTA - 3) & 511)]) + ((0.270876288f * fVec9[((IOTA - 2) & 511)]) + ((0.204836994f * fVec9[((IOTA - 1) & 511)]) + ((fSlow35 * fTemp0) + ((0.0789315403f * fVec9[((IOTA - 5) & 511)]) + ((0.0208536517f * fVec9[((IOTA - 15) & 511)]) + (((0.076719448f * fVec9[((IOTA - 12) & 511)]) + ((0.0666427538f * fVec9[((IOTA - 11) & 511)]) + (((0.176175252f * fVec9[((IOTA - 4) & 511)]) + ((0.0528399684f * fVec9[((IOTA - 13) & 511)]) + ((0.00631398847f * fVec9[((IOTA - 10) & 511)]) + ((0.0311596207f * fVec9[((IOTA - 14) & 511)]) + (0.0173193943f * fVec9[((IOTA - 16) & 511)]))))) + (0.0211369507f * fVec9[((IOTA - 17) & 511)])))) + (0.0190446228f * fVec9[((IOTA - 18) & 511)])))))))) + (0.00592221832f * fVec9[((IOTA - 19) & 511)])) + (0.00870592706f * fVec9[((IOTA - 26) & 511)])) + (0.0204573348f * fVec9[((IOTA - 27) & 511)])) + (0.0360261984f * fVec9[((IOTA - 28) & 511)])) + (0.0342316404f * fVec9[((IOTA - 29) & 511)])) + (0.0111140124f * fVec9[((IOTA - 30) & 511)])) + (0.0323243029f * fVec9[((IOTA - 37) & 511)])) + (0.044565089f * fVec9[((IOTA - 38) & 511)])) + (0.0285362974f * fVec9[((IOTA - 39) & 511)])) + (0.0121605266f * fVec9[((IOTA - 45) & 511)])) + (0.010881424f * fVec9[((IOTA - 46) & 511)])) + (0.00868259557f * fVec9[((IOTA - 54) & 511)])) + (0.0356839336f * fVec9[((IOTA - 55) & 511)])) + (0.0470302328f * fVec9[((IOTA - 56) & 511)])) + (0.0392180905f * fVec9[((IOTA - 57) & 511)])) + (0.0177420191f * fVec9[((IOTA - 58) & 511)])) + (0.00250271754f * fVec9[((IOTA - 81) & 511)])) + (0.00446106819f * fVec9[((IOTA - 88) & 511)])) + (0.0140365455f * fVec9[((IOTA - 89) & 511)])) + (0.00718571106f * fVec9[((IOTA - 90) & 511)])) + (0.00392549299f * fVec9[((IOTA - 102) & 511)])) + (0.00996464025f * fVec9[((IOTA - 103) & 511)])) + (0.00721041393f * fVec9[((IOTA - 104) & 511)])) + (0.00628280081f * fVec9[((IOTA - 128) & 511)])) + (0.0158867575f * fVec9[((IOTA - 129) & 511)])) + (0.0183831248f * fVec9[((IOTA - 130) & 511)])) + (0.0136465468f * fVec9[((IOTA - 131) & 511)])) + (0.00317935739f * fVec9[((IOTA - 132) & 511)])) + (0.00422958285f * fVec9[((IOTA - 136) & 511)])) + (0.00866795331f * fVec9[((IOTA - 137) & 511)])) + (0.00784934778f * fVec9[((IOTA - 138) & 511)])) + (0.00245896121f * fVec9[((IOTA - 139) & 511)])) + (0.0154681457f * fVec9[((IOTA - 207) & 511)])))))))))))))))))))))))))))))))))))))))))) + (0.00862399675f * fVec9[((IOTA - 208) & 511)])) + (0.000709365122f * fVec9[((IOTA - 209) & 511)])) + (0.00189055968f * fVec9[((IOTA - 212) & 511)])) + (0.00819070917f * fVec9[((IOTA - 213) & 511)])) + (0.0126487352f * fVec9[((IOTA - 214) & 511)])) + (0.0144022424f * fVec9[((IOTA - 215) & 511)])) + (0.0138221085f * fVec9[((IOTA - 216) & 511)])) + (0.0120944409f * fVec9[((IOTA - 217) & 511)])) + (0.00955725927f * fVec9[((IOTA - 268) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00973646436f * fVec9[((IOTA - 269) & 511)])) + (0.0104860757f * fVec9[((IOTA - 270) & 511)])) + (0.0117785502f * fVec9[((IOTA - 271) & 511)])) + (0.0130107552f * fVec9[((IOTA - 272) & 511)])) + (0.0141167045f * fVec9[((IOTA - 273) & 511)])) + (0.0150617342f * fVec9[((IOTA - 274) & 511)])) + (0.0144260097f * fVec9[((IOTA - 275) & 511)])) + (0.0114615578f * fVec9[((IOTA - 276) & 511)])) + (0.00757059548f * fVec9[((IOTA - 277) & 511)])) + (0.00482853688f * fVec9[((IOTA - 278) & 511)])) + (0.00463201664f * fVec9[((IOTA - 279) & 511)])) + (0.0067563015f * fVec9[((IOTA - 280) & 511)])) + (0.00888359454f * fVec9[((IOTA - 281) & 511)])) + (0.00890321657f * fVec9[((IOTA - 282) & 511)])) + (0.00616851216f * fVec9[((IOTA - 283) & 511)])) + (0.00181604968f * fVec9[((IOTA - 284) & 511)])) + (0.00136618223f * fVec9[((IOTA - 288) & 511)])) + (0.0062573622f * fVec9[((IOTA - 289) & 511)])) + (0.00998282433f * fVec9[((IOTA - 290) & 511)])) + (0.0111745484f * fVec9[((IOTA - 291) & 511)])) + (0.00998553261f * fVec9[((IOTA - 292) & 511)])) + (0.00787669141f * fVec9[((IOTA - 293) & 511)])) + (0.00641958602f * fVec9[((IOTA - 294) & 511)])) + (0.00656937482f * fVec9[((IOTA - 295) & 511)])) + (0.00840925798f * fVec9[((IOTA - 296) & 511)])) + (0.0102137085f * fVec9[((IOTA - 297) & 511)])) + (0.00973653048f * fVec9[((IOTA - 298) & 511)])) + (0.00670582568f * fVec9[((IOTA - 299) & 511)])) + (0.00275422633f * fVec9[((IOTA - 300) & 511)])) + (0.000445221085f * fVec9[((IOTA - 303) & 511)])) + (0.00500299502f * fVec9[((IOTA - 304) & 511)])) + (0.0114781372f * fVec9[((IOTA - 305) & 511)])) + (0.0168980062f * fVec9[((IOTA - 306) & 511)])) + (0.0187094435f * fVec9[((IOTA - 307) & 511)])) + (0.0167198386f * fVec9[((IOTA - 308) & 511)])) + (0.0123542063f * fVec9[((IOTA - 309) & 511)])) + (0.00756411068f * fVec9[((IOTA - 310) & 511)])) + (0.00345653808f * fVec9[((IOTA - 311) & 511)])) + (0.00107449386f * fVec9[((IOTA - 312) & 511)])) + (0.0022120988f * fVec9[((IOTA - 313) & 511)])) + (0.00660283584f * fVec9[((IOTA - 314) & 511)])) + (0.0115043111f * fVec9[((IOTA - 315) & 511)])) + (0.0144164823f * fVec9[((IOTA - 316) & 511)])) + (0.0138328383f * fVec9[((IOTA - 317) & 511)])) + (0.0102677941f * fVec9[((IOTA - 318) & 511)])) + (0.00558202621f * fVec9[((IOTA - 319) & 511)])) + (0.00129040238f * fVec9[((IOTA - 320) & 511)])) + (0.00012475159f * fVec9[((IOTA - 324) & 511)])) + (5.53559512e-05f * fVec9[((IOTA - 325) & 511)])) + (0.0016835765f * fVec9[((IOTA - 331) & 511)])) + (0.00358279375f * fVec9[((IOTA - 332) & 511)])) + (0.00482084882f * fVec9[((IOTA - 333) & 511)])) + (0.00510200718f * fVec9[((IOTA - 334) & 511)])) + (0.0049191257f * fVec9[((IOTA - 335) & 511)])) + (0.00475887395f * fVec9[((IOTA - 336) & 511)])) + (0.00477431761f * fVec9[((IOTA - 337) & 511)])) + (0.00540338969f * fVec9[((IOTA - 338) & 511)])) + (0.00670191506f * fVec9[((IOTA - 339) & 511)])) + (0.00802754983f * fVec9[((IOTA - 340) & 511)])) + (0.00854497403f * fVec9[((IOTA - 341) & 511)])) + (0.00767151313f * fVec9[((IOTA - 342) & 511)])) + (0.00554739544f * fVec9[((IOTA - 343) & 511)])) + (0.00328793004f * fVec9[((IOTA - 344) & 511)])) + (0.00190526759f * fVec9[((IOTA - 345) & 511)])) + (0.00185539387f * fVec9[((IOTA - 346) & 511)])) + (0.00309441797f * fVec9[((IOTA - 347) & 511)])) + (0.00521599501f * fVec9[((IOTA - 348) & 511)])) + (0.007967012f * fVec9[((IOTA - 349) & 511)])) + (0.0105498563f * fVec9[((IOTA - 350) & 511)])) + (0.0117996102f * fVec9[((IOTA - 351) & 511)])) + (0.0110293739f * fVec9[((IOTA - 352) & 511)])) + (0.00827648491f * fVec9[((IOTA - 353) & 511)])) + (0.00419906341f * fVec9[((IOTA - 354) & 511)])) + (0.000739249401f * fVec9[((IOTA - 361) & 511)])) + (0.00335007161f * fVec9[((IOTA - 362) & 511)])) + (0.00439939462f * fVec9[((IOTA - 363) & 511)])) + (0.00450886972f * fVec9[((IOTA - 364) & 511)])) + (0.00468205754f * fVec9[((IOTA - 365) & 511)])) + (0.00505948765f * fVec9[((IOTA - 366) & 511)])) + (0.00481095398f * fVec9[((IOTA - 367) & 511)])) + (0.00317487819f * fVec9[((IOTA - 368) & 511)])) + (0.000501412433f * fVec9[((IOTA - 369) & 511)])) + (0.00120135117f * fVec9[((IOTA - 378) & 511)])) + (0.00128492014f * fVec9[((IOTA - 379) & 511)])) + (0.00100399507f * fVec9[((IOTA - 384) & 511)])) + (0.00505353743f * fVec9[((IOTA - 385) & 511)])) + (0.00799860153f * fVec9[((IOTA - 386) & 511)])) + (0.00815387256f * fVec9[((IOTA - 387) & 511)])) + (0.0056854845f * fVec9[((IOTA - 388) & 511)])) + (0.00229800772f * fVec9[((IOTA - 389) & 511)])) + (0.00109913014f * fVec9[((IOTA - 393) & 511)])) + (0.00273714494f * fVec9[((IOTA - 394) & 511)])) + (0.00330557954f * fVec9[((IOTA - 395) & 511)])) + (0.00248195929f * fVec9[((IOTA - 396) & 511)])) + (0.00035463227f * fVec9[((IOTA - 397) & 511)])) + (0.000215206295f * fVec9[((IOTA - 409) & 511)])) + (0.00342357857f * fVec9[((IOTA - 410) & 511)])) + (0.00390984863f * fVec9[((IOTA - 411) & 511)])) + (0.00142698688f * fVec9[((IOTA - 412) & 511)])) + (0.000544266775f * fVec9[((IOTA - 420) & 511)])) + (0.00146599673f * fVec9[((IOTA - 421) & 511)])) + (0.00240437407f * fVec9[((IOTA - 422) & 511)])) + (0.00309986668f * fVec9[((IOTA - 423) & 511)])) + (0.00294549856f * fVec9[((IOTA - 424) & 511)])) + (0.00207053358f * fVec9[((IOTA - 425) & 511)])) + (0.000596112572f * fVec9[((IOTA - 426) & 511)])) + (0.00118557364f * fVec9[((IOTA - 464) & 511)])) + (0.000650900416f * fVec9[((IOTA - 465) & 511)])) + (0.000156540889f * fVec9[((IOTA - 489) & 511)])) + (0.0010783379f * fVec9[((IOTA - 498) & 511)])) + (0.0016613137f * fVec9[((IOTA - 499) & 511)])) + (0.00146489358f * fVec9[((IOTA - 500) & 511)])) + (0.000550216995f * fVec9[((IOTA - 501) & 511)])) - (((((((((((((((((0.00255182246f * fVec9[((IOTA - 491) & 511)]) + ((0.000719593838f * fVec9[((IOTA - 490) & 511)]) + ((0.000209223013f * fVec9[((IOTA - 488) & 511)]) + ((0.0018420564f * fVec9[((IOTA - 487) & 511)]) + ((0.00367736025f * fVec9[((IOTA - 486) & 511)]) + ((0.00491832336f * fVec9[((IOTA - 485) & 511)]) + ((0.00527713401f * fVec9[((IOTA - 484) & 511)]) + ((0.00486052688f * fVec9[((IOTA - 483) & 511)]) + ((0.00450164918f * fVec9[((IOTA - 482) & 511)]) + ((0.00446247216f * fVec9[((IOTA - 481) & 511)]) + ((0.0040422217f * fVec9[((IOTA - 480) & 511)]) + ((0.00285591278f * fVec9[((IOTA - 479) & 511)]) + ((0.0017266646f * fVec9[((IOTA - 478) & 511)]) + ((0.00189761305f * fVec9[((IOTA - 477) & 511)]) + ((0.0030025593f * fVec9[((IOTA - 476) & 511)]) + ((0.00346419308f * fVec9[((IOTA - 475) & 511)]) + ((0.00308967149f * fVec9[((IOTA - 474) & 511)]) + ((0.00311367214f * fVec9[((IOTA - 473) & 511)]) + ((0.00415517297f * fVec9[((IOTA - 472) & 511)]) + ((0.00603627274f * fVec9[((IOTA - 471) & 511)]) + ((0.00812061131f * fVec9[((IOTA - 470) & 511)]) + ((0.00935375318f * fVec9[((IOTA - 469) & 511)]) + ((0.00875018537f * fVec9[((IOTA - 468) & 511)]) + ((0.00594591815f * fVec9[((IOTA - 467) & 511)]) + ((0.00210198853f * fVec9[((IOTA - 466) & 511)]) + ((0.000174826011f * fVec9[((IOTA - 463) & 511)]) + ((0.00258621946f * fVec9[((IOTA - 462) & 511)]) + ((0.00489786547f * fVec9[((IOTA - 461) & 511)]) + ((0.00598599808f * fVec9[((IOTA - 460) & 511)]) + ((0.00577540463f * fVec9[((IOTA - 459) & 511)]) + ((0.00503177615f * fVec9[((IOTA - 458) & 511)]) + ((0.00435984973f * fVec9[((IOTA - 457) & 511)]) + ((0.00431107916f * fVec9[((IOTA - 456) & 511)]) + ((0.00530039985f * fVec9[((IOTA - 455) & 511)]) + ((0.0070233536f * fVec9[((IOTA - 454) & 511)]) + ((0.00831408985f * fVec9[((IOTA - 453) & 511)]) + ((0.00872344337f * fVec9[((IOTA - 452) & 511)]) + ((0.0088856332f * fVec9[((IOTA - 451) & 511)]) + ((0.00897869654f * fVec9[((IOTA - 450) & 511)]) + ((0.00898568239f * fVec9[((IOTA - 449) & 511)]) + (((0.00986001268f * fVec9[((IOTA - 447) & 511)]) + ((0.0109141488f * fVec9[((IOTA - 446) & 511)]) + ((0.0120375808f * fVec9[((IOTA - 445) & 511)]) + ((0.0121562481f * fVec9[((IOTA - 444) & 511)]) + ((0.011188589f * fVec9[((IOTA - 443) & 511)]) + ((0.010298213f * fVec9[((IOTA - 442) & 511)]) + ((0.0101634674f * fVec9[((IOTA - 441) & 511)]) + ((0.0103416024f * fVec9[((IOTA - 440) & 511)]) + ((0.00986676477f * fVec9[((IOTA - 439) & 511)]) + ((0.00881343056f * fVec9[((IOTA - 438) & 511)]) + ((0.00814424455f * fVec9[((IOTA - 437) & 511)]) + ((0.00788033474f * fVec9[((IOTA - 436) & 511)]) + ((0.00728482381f * fVec9[((IOTA - 435) & 511)]) + ((0.00617359299f * fVec9[((IOTA - 434) & 511)]) + ((0.00540710008f * fVec9[((IOTA - 433) & 511)]) + ((0.00539988f * fVec9[((IOTA - 432) & 511)]) + ((0.00556805357f * fVec9[((IOTA - 431) & 511)]) + ((0.00525764609f * fVec9[((IOTA - 430) & 511)]) + ((0.00450786669f * fVec9[((IOTA - 429) & 511)]) + ((0.00337607833f * fVec9[((IOTA - 428) & 511)]) + ((0.00152272359f * fVec9[((IOTA - 427) & 511)]) + ((0.000709565822f * fVec9[((IOTA - 419) & 511)]) + ((0.00229907734f * fVec9[((IOTA - 418) & 511)]) + ((0.00408754917f * fVec9[((IOTA - 417) & 511)]) + ((0.00536227413f * fVec9[((IOTA - 416) & 511)]) + ((0.00546011608f * fVec9[((IOTA - 415) & 511)]) + ((0.00453965645f * fVec9[((IOTA - 414) & 511)]) + ((0.00217766874f * fVec9[((IOTA - 413) & 511)]) + ((0.00373779749f * fVec9[((IOTA - 408) & 511)]) + ((0.00641490612f * fVec9[((IOTA - 407) & 511)]) + ((0.00778466556f * fVec9[((IOTA - 406) & 511)]) + ((0.00800655782f * fVec9[((IOTA - 405) & 511)]) + ((0.00658916403f * fVec9[((IOTA - 404) & 511)]) + ((0.00480647478f * fVec9[((IOTA - 403) & 511)]) + ((0.00459872279f * fVec9[((IOTA - 402) & 511)]) + ((0.0059263967f * fVec9[((IOTA - 401) & 511)]) + ((0.00690502021f * fVec9[((IOTA - 400) & 511)]) + ((0.0057601952f * fVec9[((IOTA - 399) & 511)]) + ((0.00278401002f * fVec9[((IOTA - 398) & 511)]) + ((0.000889773481f * fVec9[((IOTA - 392) & 511)]) + ((0.00181193836f * fVec9[((IOTA - 391) & 511)]) + ((0.000562885776f * fVec9[((IOTA - 390) & 511)]) + ((0.00217262097f * fVec9[((IOTA - 383) & 511)]) + ((0.00319359731f * fVec9[((IOTA - 382) & 511)]) + ((0.0021489542f * fVec9[((IOTA - 381) & 511)]) + ((0.000260333531f * fVec9[((IOTA - 380) & 511)]) + ((0.00122872833f * fVec9[((IOTA - 377) & 511)]) + ((0.00549337687f * fVec9[((IOTA - 376) & 511)]) + ((0.0104112653f * fVec9[((IOTA - 375) & 511)]) + ((0.0137357982f * fVec9[((IOTA - 374) & 511)]) + ((0.0138337743f * fVec9[((IOTA - 373) & 511)]) + ((0.0112158991f * fVec9[((IOTA - 372) & 511)]) + ((0.00708302204f * fVec9[((IOTA - 371) & 511)]) + ((0.00288181892f * fVec9[((IOTA - 370) & 511)]) + ((0.00252093561f * fVec9[((IOTA - 360) & 511)]) + ((0.00508602895f * fVec9[((IOTA - 359) & 511)]) + ((0.00642232737f * fVec9[((IOTA - 358) & 511)]) + ((0.00622731121f * fVec9[((IOTA - 357) & 511)]) + ((0.00408103084f * fVec9[((IOTA - 356) & 511)]) + ((0.000238304492f * fVec9[((IOTA - 355) & 511)]) + ((((((((((((((((((((((((((((((((((((((0.0118577406f * fVec9[((IOTA - 145) & 511)]) + ((0.0192068126f * fVec9[((IOTA - 144) & 511)]) + ((0.0229371209f * fVec9[((IOTA - 143) & 511)]) + ((0.0206487067f * fVec9[((IOTA - 142) & 511)]) + ((0.014056134f * fVec9[((IOTA - 141) & 511)]) + ((0.00548000587f * fVec9[((IOTA - 140) & 511)]) + ((0.00194247253f * fVec9[((IOTA - 135) & 511)]) + ((0.00594454771f * fVec9[((IOTA - 134) & 511)]) + ((0.00498852087f * fVec9[((IOTA - 133) & 511)]) + ((0.00740883965f * fVec9[((IOTA - 127) & 511)]) + ((0.020542575f * fVec9[((IOTA - 126) & 511)]) + (((((((((((((((((((((((((((((((((0.00882442854f * fVec9[((IOTA - 91) & 511)]) + ((0.0159543157f * fVec9[((IOTA - 87) & 511)]) + ((0.0343823992f * fVec9[((IOTA - 86) & 511)]) + ((0.0432718769f * fVec9[((IOTA - 85) & 511)]) + ((0.0390145183f * fVec9[((IOTA - 84) & 511)]) + ((0.0241568908f * fVec9[((IOTA - 83) & 511)]) + ((0.00688760448f * fVec9[((IOTA - 82) & 511)]) + ((0.00141863013f * fVec9[((IOTA - 80) & 511)]) + ((0.012760317f * fVec9[((IOTA - 79) & 511)]) + ((0.0211819764f * fVec9[((IOTA - 78) & 511)]) + ((0.0221399087f * fVec9[((IOTA - 77) & 511)]) + ((0.0142348707f * fVec9[((IOTA - 76) & 511)]) + ((0.00502930256f * fVec9[((IOTA - 75) & 511)]) + ((0.00203092163f * fVec9[((IOTA - 74) & 511)]) + ((0.00238010567f * fVec9[((IOTA - 73) & 511)]) + ((0.00064642122f * fVec9[((IOTA - 72) & 511)]) + ((0.00120509509f * fVec9[((IOTA - 71) & 511)]) + ((0.0111625157f * fVec9[((IOTA - 70) & 511)]) + ((0.0252580941f * fVec9[((IOTA - 69) & 511)]) + ((0.035082005f * fVec9[((IOTA - 68) & 511)]) + ((0.0401712433f * fVec9[((IOTA - 67) & 511)]) + ((0.0451868065f * fVec9[((IOTA - 66) & 511)]) + ((0.0493159071f * fVec9[((IOTA - 65) & 511)]) + ((0.0485629179f * fVec9[((IOTA - 64) & 511)]) + ((0.0465702042f * fVec9[((IOTA - 63) & 511)]) + ((0.0424361229f * fVec9[((IOTA - 62) & 511)]) + ((0.0311907083f * fVec9[((IOTA - 61) & 511)]) + ((0.0177881159f * fVec9[((IOTA - 60) & 511)]) + ((0.00343581336f * fVec9[((IOTA - 59) & 511)]) + (((((((((((((((((((((((((((0.127168775f * fVec9[((IOTA - 7) & 511)]) + ((0.15575324f * fVec9[((IOTA - 8) & 511)]) + ((0.0270823333f * fVec9[((IOTA - 6) & 511)]) + (0.0869615972f * fVec9[((IOTA - 9) & 511)])))) + (0.00487924647f * fVec9[((IOTA - 20) & 511)])) + (0.0125083067f * fVec9[((IOTA - 21) & 511)])) + (0.0205602925f * fVec9[((IOTA - 22) & 511)])) + (0.0214584228f * fVec9[((IOTA - 23) & 511)])) + (0.0136750937f * fVec9[((IOTA - 24) & 511)])) + (0.000797379762f * fVec9[((IOTA - 25) & 511)])) + (0.0294647124f * fVec9[((IOTA - 31) & 511)])) + (0.0778102204f * fVec9[((IOTA - 32) & 511)])) + (0.107053973f * fVec9[((IOTA - 33) & 511)])) + (0.0965009779f * fVec9[((IOTA - 34) & 511)])) + (0.0564537495f * fVec9[((IOTA - 35) & 511)])) + (0.00699203229f * fVec9[((IOTA - 36) & 511)])) + (0.000824222341f * fVec9[((IOTA - 40) & 511)])) + (0.0288380124f * fVec9[((IOTA - 41) & 511)])) + (0.0378572568f * fVec9[((IOTA - 42) & 511)])) + (0.02688618f * fVec9[((IOTA - 43) & 511)])) + (0.00733590079f * fVec9[((IOTA - 44) & 511)])) + (0.01030403f * fVec9[((IOTA - 47) & 511)])) + (0.0349344537f * fVec9[((IOTA - 48) & 511)])) + (0.0603730232f * fVec9[((IOTA - 49) & 511)])) + (0.0786156207f * fVec9[((IOTA - 50) & 511)])) + (0.0815227106f * fVec9[((IOTA - 51) & 511)])) + (0.0631462708f * fVec9[((IOTA - 52) & 511)])) + (0.0278191753f * fVec9[((IOTA - 53) & 511)])) + (0.0256064087f * fVec9[((IOTA - 92) & 511)]))))))))))))))))))))))))))))))) + (0.0370893255f * fVec9[((IOTA - 93) & 511)])) + (0.0362871327f * fVec9[((IOTA - 94) & 511)])) + (0.0248561949f * fVec9[((IOTA - 95) & 511)])) + (0.0142190931f * fVec9[((IOTA - 96) & 511)])) + (0.0118271206f * fVec9[((IOTA - 97) & 511)])) + (0.0155552579f * fVec9[((IOTA - 98) & 511)])) + (0.0193129443f * fVec9[((IOTA - 99) & 511)])) + (0.0162846129f * fVec9[((IOTA - 100) & 511)])) + (0.00679089874f * fVec9[((IOTA - 101) & 511)])) + (0.00268011726f * fVec9[((IOTA - 105) & 511)])) + (0.0130359605f * fVec9[((IOTA - 106) & 511)])) + (0.0202429648f * fVec9[((IOTA - 107) & 511)])) + (0.0211426318f * fVec9[((IOTA - 108) & 511)])) + (0.0154449139f * fVec9[((IOTA - 109) & 511)])) + (0.00798312388f * fVec9[((IOTA - 110) & 511)])) + (0.00469529489f * fVec9[((IOTA - 111) & 511)])) + (0.00682074949f * fVec9[((IOTA - 112) & 511)])) + (0.0115543865f * fVec9[((IOTA - 113) & 511)])) + (0.0142111368f * fVec9[((IOTA - 114) & 511)])) + (0.01322887f * fVec9[((IOTA - 115) & 511)])) + (0.0116553372f * fVec9[((IOTA - 116) & 511)])) + (0.00985245779f * fVec9[((IOTA - 117) & 511)])) + (0.00836834311f * fVec9[((IOTA - 118) & 511)])) + (0.0092028603f * fVec9[((IOTA - 119) & 511)])) + (0.0126421843f * fVec9[((IOTA - 120) & 511)])) + (0.0174464863f * fVec9[((IOTA - 121) & 511)])) + (0.0234569199f * fVec9[((IOTA - 122) & 511)])) + (0.0300078429f * fVec9[((IOTA - 123) & 511)])) + (0.0337449387f * fVec9[((IOTA - 124) & 511)])) + (0.0303266738f * fVec9[((IOTA - 125) & 511)])) + (0.00593665894f * fVec9[((IOTA - 146) & 511)]))))))))))))) + (0.00166813284f * fVec9[((IOTA - 147) & 511)])) + (0.00219939649f * fVec9[((IOTA - 157) & 511)])) + (0.00655660545f * fVec9[((IOTA - 158) & 511)])) + (0.0104188193f * fVec9[((IOTA - 159) & 511)])) + (0.010945905f * fVec9[((IOTA - 160) & 511)])) + (0.00851107854f * fVec9[((IOTA - 161) & 511)])) + (0.00515031023f * fVec9[((IOTA - 162) & 511)])) + (0.00123431068f * fVec9[((IOTA - 163) & 511)])) + (0.00335144205f * fVec9[((IOTA - 167) & 511)])) + (0.00484033674f * fVec9[((IOTA - 168) & 511)])) + (0.00102395145f * fVec9[((IOTA - 169) & 511)])) + (0.000638766214f * fVec9[((IOTA - 175) & 511)])) + (0.00534803374f * fVec9[((IOTA - 176) & 511)])) + (0.00739386445f * fVec9[((IOTA - 177) & 511)])) + (0.00627029873f * fVec9[((IOTA - 178) & 511)])) + (0.00346479472f * fVec9[((IOTA - 179) & 511)])) + (0.000544634648f * fVec9[((IOTA - 180) & 511)])) + (0.00195082929f * fVec9[((IOTA - 201) & 511)])) + (0.00331818173f * fVec9[((IOTA - 202) & 511)])) + (0.000432551838f * fVec9[((IOTA - 203) & 511)])) + (0.00390974851f * fVec9[((IOTA - 210) & 511)])) + (0.00319346366f * fVec9[((IOTA - 211) & 511)])) + (0.00188069837f * fVec9[((IOTA - 285) & 511)])) + (0.00351871317f * fVec9[((IOTA - 286) & 511)])) + (0.00243699923f * fVec9[((IOTA - 287) & 511)])) + (0.000252879225f * fVec9[((IOTA - 301) & 511)])) + (0.00122886198f * fVec9[((IOTA - 302) & 511)])) + (0.00115949987f * fVec9[((IOTA - 321) & 511)])) + (0.00141608948f * fVec9[((IOTA - 322) & 511)])) + (0.00067834463f * fVec9[((IOTA - 323) & 511)])) + (0.000988451298f * fVec9[((IOTA - 326) & 511)])) + (0.00209423341f * fVec9[((IOTA - 327) & 511)])) + (0.00290351361f * fVec9[((IOTA - 328) & 511)])) + (0.0025997241f * fVec9[((IOTA - 329) & 511)])) + (0.000660794787f * fVec9[((IOTA - 330) & 511)])) + (0.00925440621f * fVec9[((IOTA - 448) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00477425056f * fVec9[((IOTA - 492) & 511)])))))))))))))))))))))))))))))))))))))))))) + (0.00614517974f * fVec9[((IOTA - 493) & 511)])) + (0.00619003922f * fVec9[((IOTA - 494) & 511)])) + (0.00498009706f * fVec9[((IOTA - 495) & 511)])) + (0.0026406059f * fVec9[((IOTA - 496) & 511)])) + (0.000343902037f * fVec9[((IOTA - 497) & 511)])) + (0.00136628281f * fVec9[((IOTA - 502) & 511)])) + (0.0041008871f * fVec9[((IOTA - 503) & 511)])) + (0.00690007303f * fVec9[((IOTA - 504) & 511)])) + (0.00906209741f * fVec9[((IOTA - 505) & 511)])) + (0.00996544212f * fVec9[((IOTA - 506) & 511)])) + (0.00951734744f * fVec9[((IOTA - 507) & 511)])) + (0.00835737865f * fVec9[((IOTA - 508) & 511)])) + (0.0072395294f * fVec9[((IOTA - 509) & 511)])) + (0.00641564187f * fVec9[((IOTA - 510) & 511)])) + (0.00611770246f * fVec9[((IOTA - 511) & 511)])))) : (iSlow28 ? (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0023502321f * fVec8[((IOTA - 314) & 511)]) + ((0.00320995506f * fVec8[((IOTA - 313) & 511)]) + ((0.00405244622f * fVec8[((IOTA - 312) & 511)]) + ((0.00510648033f * fVec8[((IOTA - 311) & 511)]) + ((0.00601275358f * fVec8[((IOTA - 310) & 511)]) + ((0.00671937363f * fVec8[((IOTA - 309) & 511)]) + ((0.00683221407f * fVec8[((IOTA - 308) & 511)]) + ((0.00649717869f * fVec8[((IOTA - 307) & 511)]) + ((0.00634371722f * fVec8[((IOTA - 306) & 511)]) + ((0.00591336703f * fVec8[((IOTA - 305) & 511)]) + ((0.00488474127f * fVec8[((IOTA - 304) & 511)]) + ((0.00375200575f * fVec8[((IOTA - 303) & 511)]) + ((0.00297170039f * fVec8[((IOTA - 302) & 511)]) + ((0.00305271475f * fVec8[((IOTA - 301) & 511)]) + ((0.00386103475f * fVec8[((IOTA - 300) & 511)]) + ((0.00470434036f * fVec8[((IOTA - 299) & 511)]) + ((0.0055079041f * fVec8[((IOTA - 298) & 511)]) + ((0.00600539148f * fVec8[((IOTA - 297) & 511)]) + ((0.00573013164f * fVec8[((IOTA - 296) & 511)]) + ((0.00503966864f * fVec8[((IOTA - 295) & 511)]) + ((0.00395257073f * fVec8[((IOTA - 294) & 511)]) + ((0.00232391106f * fVec8[((IOTA - 293) & 511)]) + ((0.000770369545f * fVec8[((IOTA - 292) & 511)]) + ((2.99038365e-05f * fVec8[((IOTA - 289) & 511)]) + ((0.0012629712f * fVec8[((IOTA - 288) & 511)]) + ((0.00255822437f * fVec8[((IOTA - 287) & 511)]) + ((0.00381663488f * fVec8[((IOTA - 286) & 511)]) + ((0.00452732667f * fVec8[((IOTA - 285) & 511)]) + ((0.00467567425f * fVec8[((IOTA - 284) & 511)]) + ((0.00441741804f * fVec8[((IOTA - 283) & 511)]) + ((0.00368180638f * fVec8[((IOTA - 282) & 511)]) + ((0.00270833028f * fVec8[((IOTA - 281) & 511)]) + ((0.00165602285f * fVec8[((IOTA - 280) & 511)]) + ((0.000660168007f * fVec8[((IOTA - 279) & 511)]) + ((8.14441592e-07f * fVec8[((IOTA - 278) & 511)]) + ((0.000933766831f * fVec8[((IOTA - 274) & 511)]) + ((0.00284644915f * fVec8[((IOTA - 273) & 511)]) + ((0.00516658137f * fVec8[((IOTA - 272) & 511)]) + ((0.00742283417f * fVec8[((IOTA - 271) & 511)]) + ((0.00899341237f * fVec8[((IOTA - 270) & 511)]) + ((0.00936796144f * fVec8[((IOTA - 269) & 511)]) + ((0.00821082667f * fVec8[((IOTA - 268) & 511)]) + ((0.00606643734f * fVec8[((IOTA - 267) & 511)]) + ((0.0038285898f * fVec8[((IOTA - 266) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0114452131f * fVec8[((IOTA - 26) & 511)]) + ((0.0398671627f * fVec8[((IOTA - 25) & 511)]) + ((0.0386343226f * fVec8[((IOTA - 24) & 511)]) + ((0.00883278437f * fVec8[((IOTA - 23) & 511)]) + ((0.0186359175f * fVec8[((IOTA - 19) & 511)]) + ((0.0479441695f * fVec8[((IOTA - 18) & 511)]) + ((0.0405940749f * fVec8[((IOTA - 17) & 511)]) + ((0.00173221622f * fVec8[((IOTA - 16) & 511)]) + ((0.00948653556f * fVec8[((IOTA - 13) & 511)]) + ((0.0961691737f * fVec8[((IOTA - 12) & 511)]) + ((0.120536096f * fVec8[((IOTA - 11) & 511)]) + ((0.0795125216f * fVec8[((IOTA - 10) & 511)]) + ((0.114523247f * fVec8[((IOTA - 4) & 511)]) + ((0.22000581f * fVec8[((IOTA - 3) & 511)]) + ((0.263969272f * fVec8[((IOTA - 2) & 511)]) + ((0.211600974f * fVec8[((IOTA - 1) & 511)]) + ((fSlow32 * fTemp0) + ((0.0118902549f * fVec8[((IOTA - 39) & 511)]) + ((0.0298810862f * fVec8[((IOTA - 37) & 511)]) + ((0.0129917515f * fVec8[((IOTA - 36) & 511)]) + ((0.0101296008f * fVec8[((IOTA - 42) & 511)]) + (((0.000662252773f * fVec8[((IOTA - 40) & 511)]) + ((0.0286498107f * fVec8[((IOTA - 38) & 511)]) + (0.0016520489f * fVec8[((IOTA - 41) & 511)]))) + (0.00714288326f * fVec8[((IOTA - 43) & 511)]))))))))))))))))))))))) + (0.019868236f * fVec8[((IOTA - 49) & 511)])) + (0.0459218733f * fVec8[((IOTA - 50) & 511)])) + (0.041677624f * fVec8[((IOTA - 51) & 511)])) + (0.0134938648f * fVec8[((IOTA - 52) & 511)])) + (0.00133939227f * fVec8[((IOTA - 62) & 511)])) + (0.0183364544f * fVec8[((IOTA - 63) & 511)])) + (0.0287533347f * fVec8[((IOTA - 64) & 511)])) + (0.0195029695f * fVec8[((IOTA - 65) & 511)])) + (0.00672054663f * fVec8[((IOTA - 73) & 511)])) + (0.0107408408f * fVec8[((IOTA - 74) & 511)])) + (0.00602405705f * fVec8[((IOTA - 75) & 511)])) + (0.00877639651f * fVec8[((IOTA - 96) & 511)])) + (0.0157787502f * fVec8[((IOTA - 97) & 511)])) + (0.0160789639f * fVec8[((IOTA - 98) & 511)])) + (0.0104993619f * fVec8[((IOTA - 99) & 511)])) + (0.00111214817f * fVec8[((IOTA - 100) & 511)])) + (0.00490490533f * fVec8[((IOTA - 108) & 511)])) + (0.00815225672f * fVec8[((IOTA - 109) & 511)])) + (0.00582616311f * fVec8[((IOTA - 110) & 511)])) + (0.000932561234f * fVec8[((IOTA - 111) & 511)])) + (0.00113788247f * fVec8[((IOTA - 129) & 511)])) + (0.00325647229f * fVec8[((IOTA - 130) & 511)])) + (0.00352541311f * fVec8[((IOTA - 131) & 511)])) + (0.00146109331f * fVec8[((IOTA - 132) & 511)])) + (0.000185939018f * fVec8[((IOTA - 136) & 511)])) + (8.40439461e-05f * fVec8[((IOTA - 137) & 511)])) + (0.00181186246f * fVec8[((IOTA - 144) & 511)])) + (0.00365382433f * fVec8[((IOTA - 145) & 511)])) + (0.00291427039f * fVec8[((IOTA - 146) & 511)])) + (0.000767373014f * fVec8[((IOTA - 147) & 511)])) + (0.000977319665f * fVec8[((IOTA - 153) & 511)])) + (0.00221361173f * fVec8[((IOTA - 154) & 511)])) + (0.00322213816f * fVec8[((IOTA - 155) & 511)])) + (0.00335647818f * fVec8[((IOTA - 156) & 511)])) + (0.00149822887f * fVec8[((IOTA - 157) & 511)])) + (0.00156833045f * fVec8[((IOTA - 163) & 511)])) + (0.00312666036f * fVec8[((IOTA - 164) & 511)])) + (0.00205975911f * fVec8[((IOTA - 165) & 511)])) + (0.00014903117f * fVec8[((IOTA - 171) & 511)])) + (0.00127310213f * fVec8[((IOTA - 172) & 511)])) + (0.00173931755f * fVec8[((IOTA - 173) & 511)])) + (0.00216637785f * fVec8[((IOTA - 174) & 511)])) + (0.0029230332f * fVec8[((IOTA - 175) & 511)])) + (0.00308424793f * fVec8[((IOTA - 176) & 511)])) + (0.00199047197f * fVec8[((IOTA - 177) & 511)])) + (0.000740042422f * fVec8[((IOTA - 178) & 511)])) + (0.000458039343f * fVec8[((IOTA - 181) & 511)])) + (0.00336559908f * fVec8[((IOTA - 182) & 511)])) + (0.00624338584f * fVec8[((IOTA - 183) & 511)])) + (0.00703189988f * fVec8[((IOTA - 184) & 511)])) + (0.00479623489f * fVec8[((IOTA - 185) & 511)])) + (0.00116576673f * fVec8[((IOTA - 186) & 511)])) + (0.00144470809f * fVec8[((IOTA - 190) & 511)])) + (0.00477636373f * fVec8[((IOTA - 191) & 511)])) + (0.00741602574f * fVec8[((IOTA - 192) & 511)])) + (0.00906712934f * fVec8[((IOTA - 193) & 511)])) + (0.00903628115f * fVec8[((IOTA - 194) & 511)])) + (0.00753463199f * fVec8[((IOTA - 195) & 511)])) + (0.00516755879f * fVec8[((IOTA - 196) & 511)])) + (0.0027318825f * fVec8[((IOTA - 197) & 511)])) + (0.00123296957f * fVec8[((IOTA - 198) & 511)])) + (0.000549575314f * fVec8[((IOTA - 199) & 511)])) + (0.000515599269f * fVec8[((IOTA - 200) & 511)])) + (0.00130541669f * fVec8[((IOTA - 201) & 511)])) + (0.00219826866f * fVec8[((IOTA - 202) & 511)])) + (0.00276435958f * fVec8[((IOTA - 203) & 511)])) + (0.00269650575f * fVec8[((IOTA - 204) & 511)])) + (0.0016793469f * fVec8[((IOTA - 205) & 511)])) + (0.000719976146f * fVec8[((IOTA - 206) & 511)])) + (0.000652740709f * fVec8[((IOTA - 207) & 511)])) + (0.00149578555f * fVec8[((IOTA - 208) & 511)])) + (0.00352762826f * fVec8[((IOTA - 209) & 511)])) + (0.00588186691f * fVec8[((IOTA - 210) & 511)])) + (0.00688237976f * fVec8[((IOTA - 211) & 511)])) + (0.00614660513f * fVec8[((IOTA - 212) & 511)])) + (0.00365017587f * fVec8[((IOTA - 213) & 511)])) + (0.000146718696f * fVec8[((IOTA - 214) & 511)])) + (0.00271989452f * fVec8[((IOTA - 218) & 511)])) + (0.00656607514f * fVec8[((IOTA - 219) & 511)])) + (0.00900592096f * fVec8[((IOTA - 220) & 511)])) + (0.00933737308f * fVec8[((IOTA - 221) & 511)])) + (0.00736087607f * fVec8[((IOTA - 222) & 511)])) + (0.00462130597f * fVec8[((IOTA - 223) & 511)])) + (0.00247655809f * fVec8[((IOTA - 224) & 511)])) + (0.00128023606f * fVec8[((IOTA - 225) & 511)])) + (0.00147747854f * fVec8[((IOTA - 226) & 511)])) + (0.0024002674f * fVec8[((IOTA - 227) & 511)])) + (0.00325709162f * fVec8[((IOTA - 228) & 511)])) + (0.00434868457f * fVec8[((IOTA - 229) & 511)])) + (0.00551002147f * fVec8[((IOTA - 230) & 511)])) + (0.00661076838f * fVec8[((IOTA - 231) & 511)])) + (0.00769392448f * fVec8[((IOTA - 232) & 511)])) + (0.00786481425f * fVec8[((IOTA - 233) & 511)])) + (0.00718141953f * fVec8[((IOTA - 234) & 511)])) + (0.00618585804f * fVec8[((IOTA - 235) & 511)])) + (0.00468059303f * fVec8[((IOTA - 236) & 511)])) + (0.00328728883f * fVec8[((IOTA - 237) & 511)])) + (0.00235563936f * fVec8[((IOTA - 238) & 511)])) + (0.00159510737f * fVec8[((IOTA - 239) & 511)])) + (0.00137818931f * fVec8[((IOTA - 240) & 511)])) + (0.00135134766f * fVec8[((IOTA - 241) & 511)])) + (0.00133978343f * fVec8[((IOTA - 242) & 511)])) + (0.00187144242f * fVec8[((IOTA - 243) & 511)])) + (0.00239176536f * fVec8[((IOTA - 244) & 511)])) + (0.00288961129f * fVec8[((IOTA - 245) & 511)])) + (0.00357525283f * fVec8[((IOTA - 246) & 511)])) + (0.00357307028f * fVec8[((IOTA - 247) & 511)])) + (0.0031093955f * fVec8[((IOTA - 248) & 511)])) + (0.0027697999f * fVec8[((IOTA - 249) & 511)])) + (0.00249541923f * fVec8[((IOTA - 250) & 511)])) + (0.00287280232f * fVec8[((IOTA - 251) & 511)])) + (0.0037817792f * fVec8[((IOTA - 252) & 511)])) + (0.00456664525f * fVec8[((IOTA - 253) & 511)])) + (0.00544607639f * fVec8[((IOTA - 254) & 511)])) + (0.00602822704f * fVec8[((IOTA - 255) & 511)])) + (0.00630443171f * fVec8[((IOTA - 256) & 511)])) + (0.00724823121f * fVec8[((IOTA - 257) & 511)])) + (0.00832526386f * fVec8[((IOTA - 258) & 511)])) + (0.00855973922f * fVec8[((IOTA - 259) & 511)])) + (0.00786465034f * fVec8[((IOTA - 260) & 511)])) + (0.00618403358f * fVec8[((IOTA - 261) & 511)])) + (0.00401589694f * fVec8[((IOTA - 262) & 511)])) + (0.00219797576f * fVec8[((IOTA - 263) & 511)])) + (0.00131557975f * fVec8[((IOTA - 264) & 511)])) + (0.00197372818f * fVec8[((IOTA - 265) & 511)])) + (0.000883535948f * fVec8[((IOTA - 315) & 511)])))))))))))))))))))))))))))))))))))))))))))))) + (0.000926046167f * fVec8[((IOTA - 322) & 511)])) + (0.00104015693f * fVec8[((IOTA - 323) & 511)])) + (0.000280895736f * fVec8[((IOTA - 324) & 511)])) + (0.000830373261f * fVec8[((IOTA - 328) & 511)])) + (0.00298062619f * fVec8[((IOTA - 329) & 511)])) + (0.00445673661f * fVec8[((IOTA - 330) & 511)])) + (0.00407003704f * fVec8[((IOTA - 331) & 511)])) + (0.00225902162f * fVec8[((IOTA - 332) & 511)])) + (0.000817277934f * fVec8[((IOTA - 333) & 511)])) + (0.000155611429f * fVec8[((IOTA - 334) & 511)])) + (0.00040950207f * fVec8[((IOTA - 335) & 511)])) + (0.00148115959f * fVec8[((IOTA - 336) & 511)])) + (0.00248046732f * fVec8[((IOTA - 337) & 511)])) + (0.00335980067f * fVec8[((IOTA - 338) & 511)])) + (0.00384367211f * fVec8[((IOTA - 339) & 511)])) + (0.00343527738f * fVec8[((IOTA - 340) & 511)])) + (0.00291231601f * fVec8[((IOTA - 341) & 511)])) + (0.00263835909f * fVec8[((IOTA - 342) & 511)])) + (0.00244362466f * fVec8[((IOTA - 343) & 511)])) + (0.00260985596f * fVec8[((IOTA - 344) & 511)])) + (0.00272357557f * fVec8[((IOTA - 345) & 511)])) + (0.00250848196f * fVec8[((IOTA - 346) & 511)])) + (0.00267982716f * fVec8[((IOTA - 347) & 511)])) + (0.00304672122f * fVec8[((IOTA - 348) & 511)])) + (0.00320624141f * fVec8[((IOTA - 349) & 511)])) + (0.00325034838f * fVec8[((IOTA - 350) & 511)])) + (0.00293925591f * fVec8[((IOTA - 351) & 511)])) + (0.00265344139f * fVec8[((IOTA - 352) & 511)])) + (0.00246512424f * fVec8[((IOTA - 353) & 511)])) + (0.00168302748f * fVec8[((IOTA - 354) & 511)])) + (0.000985886902f * fVec8[((IOTA - 355) & 511)])) + (0.000985007267f * fVec8[((IOTA - 356) & 511)])) + (0.00104054809f * fVec8[((IOTA - 357) & 511)])) + (0.000944972504f * fVec8[((IOTA - 358) & 511)])) + (0.00052696839f * fVec8[((IOTA - 359) & 511)])) + (0.000532669015f * fVec8[((IOTA - 370) & 511)])) + (0.000355850905f * fVec8[((IOTA - 371) & 511)])) + (0.00101735443f * fVec8[((IOTA - 384) & 511)])) + (0.00171358325f * fVec8[((IOTA - 385) & 511)])) + (0.00162901822f * fVec8[((IOTA - 386) & 511)])) + (0.000981684774f * fVec8[((IOTA - 387) & 511)])) + (0.000720399432f * fVec8[((IOTA - 392) & 511)])) + (0.000943669584f * fVec8[((IOTA - 393) & 511)])) + (3.61260027e-05f * fVec8[((IOTA - 394) & 511)])) + (0.000419144519f * fVec8[((IOTA - 400) & 511)])) + (0.00229355134f * fVec8[((IOTA - 401) & 511)])) + (0.00254047057f * fVec8[((IOTA - 402) & 511)])) + (0.00161201367f * fVec8[((IOTA - 403) & 511)])) + (0.000196428038f * fVec8[((IOTA - 404) & 511)])) + (0.000266660005f * fVec8[((IOTA - 416) & 511)])) + (0.00037044473f * fVec8[((IOTA - 417) & 511)])) + (0.0011222139f * fVec8[((IOTA - 425) & 511)])) + (0.00186710991f * fVec8[((IOTA - 426) & 511)])) + (0.00122378301f * fVec8[((IOTA - 427) & 511)])) + (6.72023743e-05f * fVec8[((IOTA - 472) & 511)])) + (0.000263956375f * fVec8[((IOTA - 495) & 511)])) + (0.000597135164f * fVec8[((IOTA - 496) & 511)])) + (0.000319855288f * fVec8[((IOTA - 497) & 511)])) - ((((((((((((((((((((((((((((((((((((0.00021561468f * fVec8[((IOTA - 473) & 511)]) + ((0.000239394605f * fVec8[((IOTA - 471) & 511)]) + ((0.000943506602f * fVec8[((IOTA - 470) & 511)]) + ((0.00145985512f * fVec8[((IOTA - 469) & 511)]) + ((0.00157409627f * fVec8[((IOTA - 468) & 511)]) + ((0.00129196281f * fVec8[((IOTA - 467) & 511)]) + ((0.00113498326f * fVec8[((IOTA - 466) & 511)]) + ((0.00152663421f * fVec8[((IOTA - 465) & 511)]) + ((0.0018568486f * fVec8[((IOTA - 464) & 511)]) + ((0.0018689991f * fVec8[((IOTA - 463) & 511)]) + ((0.00203897618f * fVec8[((IOTA - 462) & 511)]) + ((0.00211683102f * fVec8[((IOTA - 461) & 511)]) + ((0.00198662793f * fVec8[((IOTA - 460) & 511)]) + ((0.00199920218f * fVec8[((IOTA - 459) & 511)]) + ((0.00217768131f * fVec8[((IOTA - 458) & 511)]) + ((0.00283117127f * fVec8[((IOTA - 457) & 511)]) + ((0.00363382325f * fVec8[((IOTA - 456) & 511)]) + ((0.00380204106f * fVec8[((IOTA - 455) & 511)]) + ((0.00358610041f * fVec8[((IOTA - 454) & 511)]) + ((0.00297981175f * fVec8[((IOTA - 453) & 511)]) + ((0.00187326642f * fVec8[((IOTA - 452) & 511)]) + ((0.00128896628f * fVec8[((IOTA - 451) & 511)]) + ((0.00133994641f * fVec8[((IOTA - 450) & 511)]) + ((0.00166116981f * fVec8[((IOTA - 449) & 511)]) + ((0.00239345897f * fVec8[((IOTA - 448) & 511)]) + ((0.00291606225f * fVec8[((IOTA - 447) & 511)]) + ((0.00304310536f * fVec8[((IOTA - 446) & 511)]) + ((0.00330279442f * fVec8[((IOTA - 445) & 511)]) + ((0.0038876161f * fVec8[((IOTA - 444) & 511)]) + ((0.00526707573f * fVec8[((IOTA - 443) & 511)]) + ((0.00700968364f * fVec8[((IOTA - 442) & 511)]) + ((0.00773943216f * fVec8[((IOTA - 441) & 511)]) + ((0.00742351823f * fVec8[((IOTA - 440) & 511)]) + ((0.0064393254f * fVec8[((IOTA - 439) & 511)]) + ((0.00492910855f * fVec8[((IOTA - 438) & 511)]) + ((0.0036363313f * fVec8[((IOTA - 437) & 511)]) + ((0.00288527878f * fVec8[((IOTA - 436) & 511)]) + ((0.00270862365f * fVec8[((IOTA - 435) & 511)]) + ((0.00334602175f * fVec8[((IOTA - 434) & 511)]) + ((0.00407616096f * fVec8[((IOTA - 433) & 511)]) + ((0.0042449981f * fVec8[((IOTA - 432) & 511)]) + ((0.00383591931f * fVec8[((IOTA - 431) & 511)]) + ((0.00262624118f * fVec8[((IOTA - 430) & 511)]) + ((1.89263374e-05f * fVec8[((IOTA - 428) & 511)]) + ((0.000178413931f * fVec8[((IOTA - 424) & 511)]) + ((0.00144548947f * fVec8[((IOTA - 423) & 511)]) + ((0.00216465117f * fVec8[((IOTA - 422) & 511)]) + ((0.00210826378f * fVec8[((IOTA - 421) & 511)]) + ((0.0019006622f * fVec8[((IOTA - 420) & 511)]) + ((0.00120449858f * fVec8[((IOTA - 419) & 511)]) + ((6.85057603e-05f * fVec8[((IOTA - 418) & 511)]) + ((0.000259689055f * fVec8[((IOTA - 415) & 511)]) + ((0.00141897332f * fVec8[((IOTA - 414) & 511)]) + ((0.00225084508f * fVec8[((IOTA - 413) & 511)]) + ((0.00248861127f * fVec8[((IOTA - 412) & 511)]) + ((0.00234218594f * fVec8[((IOTA - 411) & 511)]) + ((0.00181603199f * fVec8[((IOTA - 410) & 511)]) + ((0.00170729635f * fVec8[((IOTA - 409) & 511)]) + ((0.00207777321f * fVec8[((IOTA - 408) & 511)]) + ((0.00218950631f * fVec8[((IOTA - 407) & 511)]) + ((0.00208178023f * fVec8[((IOTA - 406) & 511)]) + ((0.00132828439f * fVec8[((IOTA - 405) & 511)]) + ((0.00200956082f * fVec8[((IOTA - 399) & 511)]) + ((0.00400071684f * fVec8[((IOTA - 398) & 511)]) + ((0.00472320104f * fVec8[((IOTA - 397) & 511)]) + ((0.00357232103f * fVec8[((IOTA - 396) & 511)]) + ((0.00160152465f * fVec8[((IOTA - 395) & 511)]) + ((3.54419462e-05f * fVec8[((IOTA - 391) & 511)]) + ((0.000443901401f * fVec8[((IOTA - 390) & 511)]) + ((0.000540356617f * fVec8[((IOTA - 389) & 511)]) + ((3.33245844e-05f * fVec8[((IOTA - 388) & 511)]) + ((0.000192193314f * fVec8[((IOTA - 383) & 511)]) + ((0.000751866959f * fVec8[((IOTA - 382) & 511)]) + ((0.00065169856f * fVec8[((IOTA - 381) & 511)]) + ((0.000373311341f * fVec8[((IOTA - 380) & 511)]) + ((4.95142303e-05f * fVec8[((IOTA - 379) & 511)]) + ((0.000116391107f * fVec8[((IOTA - 378) & 511)]) + ((0.000242587179f * fVec8[((IOTA - 377) & 511)]) + ((0.000147402752f * fVec8[((IOTA - 376) & 511)]) + ((0.00036617741f * fVec8[((IOTA - 375) & 511)]) + ((0.000513091218f * fVec8[((IOTA - 374) & 511)]) + ((0.000282947905f * fVec8[((IOTA - 373) & 511)]) + ((4.64520417e-05f * fVec8[((IOTA - 372) & 511)]) + ((6.12088479e-05f * fVec8[((IOTA - 369) & 511)]) + ((0.00105950655f * fVec8[((IOTA - 368) & 511)]) + ((0.00237733452f * fVec8[((IOTA - 367) & 511)]) + ((0.00352528272f * fVec8[((IOTA - 366) & 511)]) + ((0.00366473664f * fVec8[((IOTA - 365) & 511)]) + ((0.0032999278f * fVec8[((IOTA - 364) & 511)]) + ((0.00272706104f * fVec8[((IOTA - 363) & 511)]) + ((0.00179805048f * fVec8[((IOTA - 362) & 511)]) + ((0.00100442208f * fVec8[((IOTA - 361) & 511)]) + ((0.000286791474f * fVec8[((IOTA - 360) & 511)]) + ((0.00117156515f * fVec8[((IOTA - 429) & 511)]) + ((0.0010327301f * fVec8[((IOTA - 327) & 511)]) + ((0.00143043976f * fVec8[((IOTA - 326) & 511)]) + ((0.000591434538f * fVec8[((IOTA - 325) & 511)]) + ((0.000454227906f * fVec8[((IOTA - 321) & 511)]) + ((0.00185521971f * fVec8[((IOTA - 320) & 511)]) + ((0.00287817745f * fVec8[((IOTA - 319) & 511)]) + ((0.00324790506f * fVec8[((IOTA - 318) & 511)]) + ((0.00237837667f * fVec8[((IOTA - 317) & 511)]) + ((0.000824705232f * fVec8[((IOTA - 316) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0215416532f * fVec8[((IOTA - 31) & 511)]) + ((0.0157210268f * fVec8[((IOTA - 30) & 511)]) + ((0.0212446656f * fVec8[((IOTA - 29) & 511)]) + ((0.0303674005f * fVec8[((IOTA - 28) & 511)]) + ((0.0219306983f * fVec8[((IOTA - 27) & 511)]) + ((0.0304287411f * fVec8[((IOTA - 22) & 511)]) + ((0.0439060554f * fVec8[((IOTA - 21) & 511)]) + ((0.0211560614f * fVec8[((IOTA - 20) & 511)]) + ((0.0479637459f * fVec8[((IOTA - 15) & 511)]) + ((0.0615332201f * fVec8[((IOTA - 14) & 511)]) + ((0.04424005f * fVec8[((IOTA - 9) & 511)]) + ((0.190027982f * fVec8[((IOTA - 8) & 511)]) + ((0.250041693f * fVec8[((IOTA - 7) & 511)]) + ((0.203269035f * fVec8[((IOTA - 6) & 511)]) + ((0.0580584295f * fVec8[((IOTA - 5) & 511)]) + (((0.0369077101f * fVec8[((IOTA - 33) & 511)]) + ((0.0330643617f * fVec8[((IOTA - 32) & 511)]) + (0.0257726107f * fVec8[((IOTA - 34) & 511)]))) + (0.00692290347f * fVec8[((IOTA - 35) & 511)]))))))))))))))))) + (0.0204722099f * fVec8[((IOTA - 44) & 511)])) + (0.0485761613f * fVec8[((IOTA - 45) & 511)])) + (0.0560382791f * fVec8[((IOTA - 46) & 511)])) + (0.046044454f * fVec8[((IOTA - 47) & 511)])) + (0.0186512917f * fVec8[((IOTA - 48) & 511)])) + (0.0197356548f * fVec8[((IOTA - 53) & 511)])) + (0.0413237587f * fVec8[((IOTA - 54) & 511)])) + (0.0446985774f * fVec8[((IOTA - 55) & 511)])) + (0.0337590948f * fVec8[((IOTA - 56) & 511)])) + (0.0177558996f * fVec8[((IOTA - 57) & 511)])) + (0.00770630315f * fVec8[((IOTA - 58) & 511)])) + (0.00792517513f * fVec8[((IOTA - 59) & 511)])) + (0.00956031773f * fVec8[((IOTA - 60) & 511)])) + (0.00750873471f * fVec8[((IOTA - 61) & 511)])) + (0.00389103638f * fVec8[((IOTA - 66) & 511)])) + (0.0267682374f * fVec8[((IOTA - 67) & 511)])) + (0.039022848f * fVec8[((IOTA - 68) & 511)])) + (0.0394011103f * fVec8[((IOTA - 69) & 511)])) + (0.0292690974f * fVec8[((IOTA - 70) & 511)])) + (0.0147579107f * fVec8[((IOTA - 71) & 511)])) + (0.00287179276f * fVec8[((IOTA - 72) & 511)])) + (0.000645965338f * fVec8[((IOTA - 76) & 511)])) + (0.00467749825f * fVec8[((IOTA - 77) & 511)])) + (0.00713861594f * fVec8[((IOTA - 78) & 511)])) + (0.00504074385f * fVec8[((IOTA - 79) & 511)])) + (0.000844087452f * fVec8[((IOTA - 80) & 511)])) + (0.000978720374f * fVec8[((IOTA - 81) & 511)])) + (0.00520918984f * fVec8[((IOTA - 82) & 511)])) + (0.0121657755f * fVec8[((IOTA - 83) & 511)])) + (0.0185273774f * fVec8[((IOTA - 84) & 511)])) + (0.0198348779f * fVec8[((IOTA - 85) & 511)])) + (0.0170455985f * fVec8[((IOTA - 86) & 511)])) + (0.0109943077f * fVec8[((IOTA - 87) & 511)])) + (0.00383741781f * fVec8[((IOTA - 88) & 511)])) + (0.00261611026f * fVec8[((IOTA - 89) & 511)])) + (0.00694652041f * fVec8[((IOTA - 90) & 511)])) + (0.0126294503f * fVec8[((IOTA - 91) & 511)])) + (0.0188362543f * fVec8[((IOTA - 92) & 511)])) + (0.0199509766f * fVec8[((IOTA - 93) & 511)])) + (0.0127902739f * fVec8[((IOTA - 94) & 511)])) + (0.00192313921f * fVec8[((IOTA - 95) & 511)])) + (0.00898591988f * fVec8[((IOTA - 101) & 511)])) + (0.0161400102f * fVec8[((IOTA - 102) & 511)])) + (0.019431239f * fVec8[((IOTA - 103) & 511)])) + (0.0195816066f * fVec8[((IOTA - 104) & 511)])) + (0.0164351407f * fVec8[((IOTA - 105) & 511)])) + (0.0103639141f * fVec8[((IOTA - 106) & 511)])) + (0.00252734311f * fVec8[((IOTA - 107) & 511)])) + (0.00384901464f * fVec8[((IOTA - 112) & 511)])) + (0.00716197211f * fVec8[((IOTA - 113) & 511)])) + (0.00904921349f * fVec8[((IOTA - 114) & 511)])) + (0.009892812f * fVec8[((IOTA - 115) & 511)])) + (0.00965677202f * fVec8[((IOTA - 116) & 511)])) + (0.00926883519f * fVec8[((IOTA - 117) & 511)])) + (0.00783846062f * fVec8[((IOTA - 118) & 511)])) + (0.00584557792f * fVec8[((IOTA - 119) & 511)])) + (0.00512488559f * fVec8[((IOTA - 120) & 511)])) + (0.00468225405f * fVec8[((IOTA - 121) & 511)])) + (0.00443038298f * fVec8[((IOTA - 122) & 511)])) + (0.00531952176f * fVec8[((IOTA - 123) & 511)])) + (0.00645655766f * fVec8[((IOTA - 124) & 511)])) + (0.0072723045f * fVec8[((IOTA - 125) & 511)])) + (0.00661370018f * fVec8[((IOTA - 126) & 511)])) + (0.00439445302f * fVec8[((IOTA - 127) & 511)])) + (0.00167094218f * fVec8[((IOTA - 128) & 511)])) + (0.00107957283f * fVec8[((IOTA - 133) & 511)])) + (0.00192489801f * fVec8[((IOTA - 134) & 511)])) + (0.00111250672f * fVec8[((IOTA - 135) & 511)])) + (0.002339873f * fVec8[((IOTA - 138) & 511)])) + (0.0055322703f * fVec8[((IOTA - 139) & 511)])) + (0.00783686433f * fVec8[((IOTA - 140) & 511)])) + (0.00807635672f * fVec8[((IOTA - 141) & 511)])) + (0.00563048432f * fVec8[((IOTA - 142) & 511)])) + (0.00174814556f * fVec8[((IOTA - 143) & 511)])) + (0.00142480433f * fVec8[((IOTA - 148) & 511)])) + (0.00286286697f * fVec8[((IOTA - 149) & 511)])) + (0.00253389077f * fVec8[((IOTA - 150) & 511)])) + (0.00142708467f * fVec8[((IOTA - 151) & 511)])) + (0.000408003572f * fVec8[((IOTA - 152) & 511)])) + (0.00139662717f * fVec8[((IOTA - 158) & 511)])) + (0.00420789514f * fVec8[((IOTA - 159) & 511)])) + (0.00557947159f * fVec8[((IOTA - 160) & 511)])) + (0.00423470419f * fVec8[((IOTA - 161) & 511)])) + (0.00133688422f * fVec8[((IOTA - 162) & 511)])) + (0.000473284163f * fVec8[((IOTA - 166) & 511)])) + (0.00289508374f * fVec8[((IOTA - 167) & 511)])) + (0.00428786688f * fVec8[((IOTA - 168) & 511)])) + (0.00369734457f * fVec8[((IOTA - 169) & 511)])) + (0.00173638575f * fVec8[((IOTA - 170) & 511)])) + (0.000349303242f * fVec8[((IOTA - 179) & 511)])) + (0.000882135238f * fVec8[((IOTA - 180) & 511)])) + (0.00190861057f * fVec8[((IOTA - 187) & 511)])) + (0.0031912569f * fVec8[((IOTA - 188) & 511)])) + (0.00183961634f * fVec8[((IOTA - 189) & 511)])) + (0.00239492487f * fVec8[((IOTA - 215) & 511)])) + (0.00293844147f * fVec8[((IOTA - 216) & 511)])) + (0.00110810902f * fVec8[((IOTA - 217) & 511)])) + (0.00045641046f * fVec8[((IOTA - 275) & 511)])) + (0.000973443035f * fVec8[((IOTA - 276) & 511)])) + (0.000586092006f * fVec8[((IOTA - 277) & 511)])) + (0.000742224976f * fVec8[((IOTA - 290) & 511)])) + (0.000374158379f * fVec8[((IOTA - 291) & 511)])) + (0.000798612367f * fVec8[((IOTA - 474) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00189786078f * fVec8[((IOTA - 475) & 511)])) + (0.00305730803f * fVec8[((IOTA - 476) & 511)])) + (0.00350967934f * fVec8[((IOTA - 477) & 511)])) + (0.00351616181f * fVec8[((IOTA - 478) & 511)])) + (0.00291508483f * fVec8[((IOTA - 479) & 511)])) + (0.00181111321f * fVec8[((IOTA - 480) & 511)])) + (0.00127710868f * fVec8[((IOTA - 481) & 511)])) + (0.00131030288f * fVec8[((IOTA - 482) & 511)])) + (0.00148024736f * fVec8[((IOTA - 483) & 511)])) + (0.00175752724f * fVec8[((IOTA - 484) & 511)])) + (0.00178065524f * fVec8[((IOTA - 485) & 511)])) + (0.00172325782f * fVec8[((IOTA - 486) & 511)])) + (0.00141255604f * fVec8[((IOTA - 487) & 511)])) + (0.000645150896f * fVec8[((IOTA - 488) & 511)])) + (0.00045214314f * fVec8[((IOTA - 489) & 511)])) + (0.000802847091f * fVec8[((IOTA - 490) & 511)])) + (0.00108367763f * fVec8[((IOTA - 491) & 511)])) + (0.00135421427f * fVec8[((IOTA - 492) & 511)])) + (0.00106110284f * fVec8[((IOTA - 493) & 511)])) + (0.000267930795f * fVec8[((IOTA - 494) & 511)])) + (0.000834607985f * fVec8[((IOTA - 498) & 511)])) + (0.00208689459f * fVec8[((IOTA - 499) & 511)])) + (0.00322969584f * fVec8[((IOTA - 500) & 511)])) + (0.00396289723f * fVec8[((IOTA - 501) & 511)])) + (0.00386562804f * fVec8[((IOTA - 502) & 511)])) + (0.00354951853f * fVec8[((IOTA - 503) & 511)])) + (0.00309955794f * fVec8[((IOTA - 504) & 511)])) + (0.00245492859f * fVec8[((IOTA - 505) & 511)])) + (0.00244896719f * fVec8[((IOTA - 506) & 511)])) + (0.00306131458f * fVec8[((IOTA - 507) & 511)])) + (0.00390058104f * fVec8[((IOTA - 508) & 511)])) + (0.00471391715f * fVec8[((IOTA - 509) & 511)])) + (0.00477965409f * fVec8[((IOTA - 510) & 511)])) + (0.00421463791f * fVec8[((IOTA - 511) & 511)]))) : (((((0.00320567982f * (fVec7[((IOTA - 336) & 511)] + fVec7[((IOTA - 496) & 511)])) + ((0.00199221121f * fVec7[((IOTA - 495) & 511)]) + ((0.00027802866f * fVec7[((IOTA - 494) & 511)]) + ((0.000249522272f * fVec7[((IOTA - 451) & 511)]) + ((0.000130963512f * fVec7[((IOTA - 428) & 511)]) + ((0.00140985381f * fVec7[((IOTA - 427) & 511)]) + ((0.00228792243f * fVec7[((IOTA - 426) & 511)]) + ((0.00232099136f * fVec7[((IOTA - 425) & 511)]) + ((0.00167562719f * fVec7[((IOTA - 424) & 511)]) + ((9.86699015e-05f * fVec7[((IOTA - 423) & 511)]) + ((0.00108429417f * fVec7[((IOTA - 403) & 511)]) + ((0.00264670001f * fVec7[((IOTA - 402) & 511)]) + ((0.00302799046f * fVec7[((IOTA - 401) & 511)]) + ((0.00160844577f * fVec7[((IOTA - 400) & 511)]) + ((0.00010868907f * fVec7[((IOTA - 390) & 511)]) + ((0.000264819246f * fVec7[((IOTA - 389) & 511)]) + ((0.000608359464f * fVec7[((IOTA - 388) & 511)]) + ((0.00107934419f * fVec7[((IOTA - 387) & 511)]) + ((0.0011889278f * fVec7[((IOTA - 386) & 511)]) + ((0.00145162968f * fVec7[((IOTA - 385) & 511)]) + ((0.00123186642f * fVec7[((IOTA - 384) & 511)]) + ((1.73244625e-05f * fVec7[((IOTA - 383) & 511)]) + ((0.00101356441f * fVec7[((IOTA - 379) & 511)]) + ((0.00271200249f * fVec7[((IOTA - 378) & 511)]) + ((0.00348030915f * fVec7[((IOTA - 377) & 511)]) + ((0.00270413049f * fVec7[((IOTA - 376) & 511)]) + ((0.000291596167f * fVec7[((IOTA - 375) & 511)]) + ((0.0010108212f * fVec7[((IOTA - 362) & 511)]) + ((0.00148440013f * fVec7[((IOTA - 361) & 511)]) + ((0.00137681467f * fVec7[((IOTA - 360) & 511)]) + ((0.00135528576f * fVec7[((IOTA - 359) & 511)]) + ((0.000835457817f * fVec7[((IOTA - 358) & 511)]) + ((0.000763982534f * fVec7[((IOTA - 353) & 511)]) + ((0.002792513f * fVec7[((IOTA - 352) & 511)]) + ((0.00490921689f * fVec7[((IOTA - 351) & 511)]) + ((0.00649362896f * fVec7[((IOTA - 350) & 511)]) + ((0.00652872538f * fVec7[((IOTA - 349) & 511)]) + ((0.0053825872f * fVec7[((IOTA - 348) & 511)]) + ((0.00297118584f * fVec7[((IOTA - 347) & 511)]) + ((0.000199277885f * fVec7[((IOTA - 346) & 511)]) + ((0.00158515759f * fVec7[((IOTA - 343) & 511)]) + ((0.0039550215f * fVec7[((IOTA - 342) & 511)]) + ((0.00512754871f * fVec7[((IOTA - 341) & 511)]) + ((0.00533547392f * fVec7[((IOTA - 340) & 511)]) + ((0.00526489317f * fVec7[((IOTA - 339) & 511)]) + ((0.00454217941f * fVec7[((IOTA - 338) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.000337993726f * fVec7[((IOTA - 217) & 511)]) + ((0.000285155606f * fVec7[((IOTA - 216) & 511)]) + ((0.00172554329f * fVec7[((IOTA - 215) & 511)]) + ((0.00390045345f * fVec7[((IOTA - 214) & 511)]) + ((0.00638046721f * fVec7[((IOTA - 213) & 511)]) + ((0.00792790391f * fVec7[((IOTA - 212) & 511)]) + ((0.00827857107f * fVec7[((IOTA - 211) & 511)]) + ((0.00764590921f * fVec7[((IOTA - 210) & 511)]) + ((0.00554572511f * fVec7[((IOTA - 209) & 511)]) + ((0.00309615582f * fVec7[((IOTA - 208) & 511)]) + ((0.00140427751f * fVec7[((IOTA - 207) & 511)]) + ((0.000165284611f * fVec7[((IOTA - 206) & 511)]) + ((2.98484229e-05f * fVec7[((IOTA - 205) & 511)]) + ((0.000478141475f * fVec7[((IOTA - 204) & 511)]) + ((9.95956361e-06f * fVec7[((IOTA - 203) & 511)]) + ((0.000950825866f * fVec7[((IOTA - 198) & 511)]) + ((0.0043717362f * fVec7[((IOTA - 197) & 511)]) + ((0.00745000131f * fVec7[((IOTA - 196) & 511)]) + ((0.0087078996f * fVec7[((IOTA - 195) & 511)]) + ((0.00842450373f * fVec7[((IOTA - 194) & 511)]) + ((0.00739930943f * fVec7[((IOTA - 193) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((0.0166519955f * fVec7[((IOTA - 97) & 511)]) + ((0.000612623524f * fVec7[((IOTA - 96) & 511)]) + ((0.00467153266f * fVec7[((IOTA - 90) & 511)]) + ((0.00221570162f * fVec7[((IOTA - 89) & 511)]) + ((0.00682637468f * fVec7[((IOTA - 80) & 511)]) + ((0.00851589721f * fVec7[((IOTA - 79) & 511)]) + (((((((((((((((((((((((((0.00871275924f * fVec7[((IOTA - 14) & 511)]) + ((0.0714100003f * fVec7[((IOTA - 13) & 511)]) + ((0.116993204f * fVec7[((IOTA - 12) & 511)]) + ((0.0818852186f * fVec7[((IOTA - 11) & 511)]) + ((0.000886954367f * fVec7[((IOTA - 10) & 511)]) + ((0.00197285879f * fVec7[((IOTA - 5) & 511)]) + ((0.160117865f * fVec7[((IOTA - 4) & 511)]) + ((0.228670225f * fVec7[((IOTA - 3) & 511)]) + ((0.233944625f * fVec7[((IOTA - 2) & 511)]) + ((0.186619684f * fVec7[((IOTA - 1) & 511)]) + ((fSlow30 * fTemp0) + ((0.0388264246f * fVec7[((IOTA - 18) & 511)]) + ((0.0311233848f * fVec7[((IOTA - 24) & 511)]) + (((0.0200772583f * fVec7[((IOTA - 17) & 511)]) + (0.0204540156f * fVec7[((IOTA - 19) & 511)])) + (0.0482785664f * fVec7[((IOTA - 25) & 511)]))))))))))))))) + (0.0399446823f * fVec7[((IOTA - 26) & 511)])) + (0.0124845756f * fVec7[((IOTA - 27) & 511)])) + (0.0234568696f * fVec7[((IOTA - 36) & 511)])) + (0.0474105179f * fVec7[((IOTA - 37) & 511)])) + (0.0502588823f * fVec7[((IOTA - 38) & 511)])) + (0.0345809124f * fVec7[((IOTA - 39) & 511)])) + (0.00752031337f * fVec7[((IOTA - 40) & 511)])) + (0.0139419008f * fVec7[((IOTA - 49) & 511)])) + (0.0279704835f * fVec7[((IOTA - 50) & 511)])) + (0.0187237319f * fVec7[((IOTA - 51) & 511)])) + (0.00108319102f * fVec7[((IOTA - 52) & 511)])) + (0.000107019208f * fVec7[((IOTA - 58) & 511)])) + (0.0113651548f * fVec7[((IOTA - 63) & 511)])) + (0.0198891331f * fVec7[((IOTA - 64) & 511)])) + (0.0105318744f * fVec7[((IOTA - 65) & 511)])) + (0.00248550065f * fVec7[((IOTA - 72) & 511)])) + (0.00923947617f * fVec7[((IOTA - 73) & 511)])) + (0.0108039686f * fVec7[((IOTA - 74) & 511)])) + (0.00750465877f * fVec7[((IOTA - 75) & 511)])) + (0.0057684402f * fVec7[((IOTA - 76) & 511)])) + (0.00768306339f * fVec7[((IOTA - 77) & 511)])) + (0.00732872868f * fVec7[((IOTA - 78) & 511)])) + (0.0248861946f * fVec7[((IOTA - 98) & 511)])))))))) + (0.0249415692f * fVec7[((IOTA - 99) & 511)])) + (0.0158897415f * fVec7[((IOTA - 100) & 511)])) + (0.00103005394f * fVec7[((IOTA - 101) & 511)])) + (0.000155503862f * fVec7[((IOTA - 109) & 511)])) + (0.00573438732f * fVec7[((IOTA - 110) & 511)])) + (0.00771541661f * fVec7[((IOTA - 111) & 511)])) + (0.00487584993f * fVec7[((IOTA - 112) & 511)])) + (0.00359919574f * fVec7[((IOTA - 130) & 511)])) + (0.00780171156f * fVec7[((IOTA - 131) & 511)])) + (0.00949245691f * fVec7[((IOTA - 132) & 511)])) + (0.00841973163f * fVec7[((IOTA - 133) & 511)])) + (0.00538026169f * fVec7[((IOTA - 134) & 511)])) + (0.00239535887f * fVec7[((IOTA - 135) & 511)])) + (0.0009091096f * fVec7[((IOTA - 136) & 511)])) + (0.000131798442f * fVec7[((IOTA - 147) & 511)])) + (0.0028772871f * fVec7[((IOTA - 148) & 511)])) + (0.00533341663f * fVec7[((IOTA - 149) & 511)])) + (0.00630335603f * fVec7[((IOTA - 150) & 511)])) + (0.00533723319f * fVec7[((IOTA - 151) & 511)])) + (0.0022788276f * fVec7[((IOTA - 152) & 511)])) + (0.00146460067f * fVec7[((IOTA - 157) & 511)])) + (0.00269596046f * fVec7[((IOTA - 158) & 511)])) + (0.000977573451f * fVec7[((IOTA - 159) & 511)])) + (0.000630455092f * fVec7[((IOTA - 166) & 511)])) + (0.000400762074f * fVec7[((IOTA - 167) & 511)])) + (0.000111879315f * fVec7[((IOTA - 170) & 511)])) + (0.00170595245f * fVec7[((IOTA - 171) & 511)])) + (0.00257033436f * fVec7[((IOTA - 172) & 511)])) + (0.00245714281f * fVec7[((IOTA - 173) & 511)])) + (0.000997820403f * fVec7[((IOTA - 174) & 511)])) + (0.000466690864f * fVec7[((IOTA - 179) & 511)])) + (0.00203514984f * fVec7[((IOTA - 180) & 511)])) + (0.00393483415f * fVec7[((IOTA - 181) & 511)])) + (0.00509349583f * fVec7[((IOTA - 182) & 511)])) + (0.00481460243f * fVec7[((IOTA - 183) & 511)])) + (0.00372052798f * fVec7[((IOTA - 184) & 511)])) + (0.00229615252f * fVec7[((IOTA - 185) & 511)])) + (0.00149507541f * fVec7[((IOTA - 186) & 511)])) + (0.00140105747f * fVec7[((IOTA - 187) & 511)])) + (0.00121120224f * fVec7[((IOTA - 188) & 511)])) + (0.0016118451f * fVec7[((IOTA - 189) & 511)])) + (0.0028242101f * fVec7[((IOTA - 190) & 511)])) + (0.00393030187f * fVec7[((IOTA - 191) & 511)])) + (0.0055367793f * fVec7[((IOTA - 192) & 511)])) + (0.00205453206f * fVec7[((IOTA - 218) & 511)]))))))))))))))))))))))) + (0.0041940473f * fVec7[((IOTA - 219) & 511)])) + (0.00625084573f * fVec7[((IOTA - 220) & 511)])) + (0.00766555965f * fVec7[((IOTA - 221) & 511)])) + (0.00730794528f * fVec7[((IOTA - 222) & 511)])) + (0.00563136395f * fVec7[((IOTA - 223) & 511)])) + (0.00369512243f * fVec7[((IOTA - 224) & 511)])) + (0.00244324747f * fVec7[((IOTA - 225) & 511)])) + (0.00278115226f * fVec7[((IOTA - 226) & 511)])) + (0.00391774811f * fVec7[((IOTA - 227) & 511)])) + (0.00491154287f * fVec7[((IOTA - 228) & 511)])) + (0.00588246668f * fVec7[((IOTA - 229) & 511)])) + (0.00634456566f * fVec7[((IOTA - 230) & 511)])) + (0.00659453496f * fVec7[((IOTA - 231) & 511)])) + (0.00724625075f * fVec7[((IOTA - 232) & 511)])) + (0.00744907651f * fVec7[((IOTA - 233) & 511)])) + (0.00711886538f * fVec7[((IOTA - 234) & 511)])) + (0.00642340584f * fVec7[((IOTA - 235) & 511)])) + (0.00504337065f * fVec7[((IOTA - 236) & 511)])) + (0.00359591562f * fVec7[((IOTA - 237) & 511)])) + (0.00249086786f * fVec7[((IOTA - 238) & 511)])) + (0.00185871311f * fVec7[((IOTA - 239) & 511)])) + (0.0023322925f * fVec7[((IOTA - 240) & 511)])) + (0.00314046629f * fVec7[((IOTA - 241) & 511)])) + (0.00345362118f * fVec7[((IOTA - 242) & 511)])) + (0.00340054417f * fVec7[((IOTA - 243) & 511)])) + (0.00231490843f * fVec7[((IOTA - 244) & 511)])) + (0.00075622974f * fVec7[((IOTA - 245) & 511)])) + (0.00036429381f * fVec7[((IOTA - 248) & 511)])) + (0.00279406365f * fVec7[((IOTA - 249) & 511)])) + (0.0053878054f * fVec7[((IOTA - 250) & 511)])) + (0.00769558735f * fVec7[((IOTA - 251) & 511)])) + (0.00887864083f * fVec7[((IOTA - 252) & 511)])) + (0.00858561322f * fVec7[((IOTA - 253) & 511)])) + (0.00784640945f * fVec7[((IOTA - 254) & 511)])) + (0.00655198377f * fVec7[((IOTA - 255) & 511)])) + (0.00510843517f * fVec7[((IOTA - 256) & 511)])) + (0.00476185326f * fVec7[((IOTA - 257) & 511)])) + (0.00534719275f * fVec7[((IOTA - 258) & 511)])) + (0.00678942958f * fVec7[((IOTA - 259) & 511)])) + (0.00867110305f * fVec7[((IOTA - 260) & 511)])) + (0.00927767344f * fVec7[((IOTA - 261) & 511)])) + (0.00781900622f * fVec7[((IOTA - 262) & 511)])) + (0.00466076843f * fVec7[((IOTA - 263) & 511)])) + (0.00115204183f * fVec7[((IOTA - 264) & 511)])) + (0.00253276294f * fVec7[((IOTA - 267) & 511)])) + (0.00647403812f * fVec7[((IOTA - 268) & 511)])) + (0.0098703485f * fVec7[((IOTA - 269) & 511)])) + (0.010774985f * fVec7[((IOTA - 270) & 511)])) + (0.00915816054f * fVec7[((IOTA - 271) & 511)])) + (0.00599878887f * fVec7[((IOTA - 272) & 511)])) + (0.00275705848f * fVec7[((IOTA - 273) & 511)])) + (0.000871717464f * fVec7[((IOTA - 274) & 511)])) + (0.000558442902f * fVec7[((IOTA - 275) & 511)])) + (0.00145195751f * fVec7[((IOTA - 276) & 511)])) + (0.00273275655f * fVec7[((IOTA - 277) & 511)])) + (0.00317818671f * fVec7[((IOTA - 278) & 511)])) + (0.00278016785f * fVec7[((IOTA - 279) & 511)])) + (0.00235283747f * fVec7[((IOTA - 280) & 511)])) + (0.0022445363f * fVec7[((IOTA - 281) & 511)])) + (0.00255757198f * fVec7[((IOTA - 282) & 511)])) + (0.00309227966f * fVec7[((IOTA - 283) & 511)])) + (0.00357140508f * fVec7[((IOTA - 284) & 511)])) + (0.00397666963f * fVec7[((IOTA - 285) & 511)])) + (0.00395940477f * fVec7[((IOTA - 286) & 511)])) + (0.00335838087f * fVec7[((IOTA - 287) & 511)])) + (0.00297527108f * fVec7[((IOTA - 288) & 511)])) + (0.00312752509f * fVec7[((IOTA - 289) & 511)])) + (0.00351704564f * fVec7[((IOTA - 290) & 511)])) + (0.00406016177f * fVec7[((IOTA - 291) & 511)])) + (0.00429328345f * fVec7[((IOTA - 292) & 511)])) + (0.0040370822f * fVec7[((IOTA - 293) & 511)])) + (0.00385235576f * fVec7[((IOTA - 294) & 511)])) + (0.00408413587f * fVec7[((IOTA - 295) & 511)])) + (0.00488106813f * fVec7[((IOTA - 296) & 511)])) + (0.00587408757f * fVec7[((IOTA - 297) & 511)])) + (0.00611084746f * fVec7[((IOTA - 298) & 511)])) + (0.0057050162f * fVec7[((IOTA - 299) & 511)])) + (0.00504304282f * fVec7[((IOTA - 300) & 511)])) + (0.004257889f * fVec7[((IOTA - 301) & 511)])) + (0.00411693659f * fVec7[((IOTA - 302) & 511)])) + (0.00472818827f * fVec7[((IOTA - 303) & 511)])) + (0.00555827841f * fVec7[((IOTA - 304) & 511)])) + (0.00643646671f * fVec7[((IOTA - 305) & 511)])) + (0.00661615329f * fVec7[((IOTA - 306) & 511)])) + (0.00588831119f * fVec7[((IOTA - 307) & 511)])) + (0.00468474254f * fVec7[((IOTA - 308) & 511)])) + (0.00314663863f * fVec7[((IOTA - 309) & 511)])) + (0.00228675967f * fVec7[((IOTA - 310) & 511)])) + (0.00253980001f * fVec7[((IOTA - 311) & 511)])) + (0.00303693628f * fVec7[((IOTA - 312) & 511)])) + (0.00350162946f * fVec7[((IOTA - 313) & 511)])) + (0.0034517427f * fVec7[((IOTA - 314) & 511)])) + (0.00268015638f * fVec7[((IOTA - 315) & 511)])) + (0.00197751075f * fVec7[((IOTA - 316) & 511)])) + (0.0010503307f * fVec7[((IOTA - 317) & 511)])) + (5.18248416e-05f * fVec7[((IOTA - 318) & 511)])) + (6.78375363e-05f * fVec7[((IOTA - 325) & 511)])) + (0.000869898126f * fVec7[((IOTA - 326) & 511)])) + (0.00196117023f * fVec7[((IOTA - 327) & 511)])) + (0.00295517361f * fVec7[((IOTA - 328) & 511)])) + (0.0030506826f * fVec7[((IOTA - 329) & 511)])) + (0.00268212426f * fVec7[((IOTA - 330) & 511)])) + (0.00193749415f * fVec7[((IOTA - 331) & 511)])) + (0.00137463817f * fVec7[((IOTA - 332) & 511)])) + (0.00168102421f * fVec7[((IOTA - 333) & 511)])) + (0.00204120344f * fVec7[((IOTA - 334) & 511)])) + (0.00240314147f * fVec7[((IOTA - 335) & 511)])) + (0.00381063949f * fVec7[((IOTA - 337) & 511)])))))))))))))))))))))))))))))))))))))))))))))))) + (0.00279698567f * fVec7[((IOTA - 497) & 511)])) + (0.000820727553f * fVec7[((IOTA - 498) & 511)])) - ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.121651046f * fVec7[((IOTA - 9) & 511)]) + ((0.237631217f * fVec7[((IOTA - 8) & 511)]) + ((0.241632015f * fVec7[((IOTA - 7) & 511)]) + ((0.149871171f * fVec7[((IOTA - 6) & 511)]) + ((0.00631325599f * fVec7[((IOTA - 16) & 511)]) + ((0.0349581167f * fVec7[((IOTA - 22) & 511)]) + ((((0.010341065f * fVec7[((IOTA - 15) & 511)]) + (0.00651825918f * fVec7[((IOTA - 20) & 511)])) + (0.0306729153f * fVec7[((IOTA - 21) & 511)])) + (0.0036865049f * fVec7[((IOTA - 23) & 511)])))))))) + (0.0103044473f * fVec7[((IOTA - 28) & 511)])) + (0.0241262391f * fVec7[((IOTA - 29) & 511)])) + (0.0399960317f * fVec7[((IOTA - 30) & 511)])) + (0.0532934926f * fVec7[((IOTA - 31) & 511)])) + (0.0603033714f * fVec7[((IOTA - 32) & 511)])) + (0.0522966571f * fVec7[((IOTA - 33) & 511)])) + (0.0330486521f * fVec7[((IOTA - 34) & 511)])) + (0.00889808219f * fVec7[((IOTA - 35) & 511)])) + (0.0143299298f * fVec7[((IOTA - 41) & 511)])) + (0.0227156095f * fVec7[((IOTA - 42) & 511)])) + (0.0298464317f * fVec7[((IOTA - 43) & 511)])) + (0.0423983075f * fVec7[((IOTA - 44) & 511)])) + (0.0501130372f * fVec7[((IOTA - 45) & 511)])) + (0.0426729359f * fVec7[((IOTA - 46) & 511)])) + (0.0303801857f * fVec7[((IOTA - 47) & 511)])) + (0.0125346407f * fVec7[((IOTA - 48) & 511)])) + (0.0194204152f * fVec7[((IOTA - 53) & 511)])) + (0.0316396356f * fVec7[((IOTA - 54) & 511)])) + (0.0267883539f * fVec7[((IOTA - 55) & 511)])) + (0.0167895481f * fVec7[((IOTA - 56) & 511)])) + (0.00509916153f * fVec7[((IOTA - 57) & 511)])) + (0.00809614081f * fVec7[((IOTA - 59) & 511)])) + (0.0101766745f * fVec7[((IOTA - 60) & 511)])) + (0.00767241791f * fVec7[((IOTA - 61) & 511)])) + (0.00320475502f * fVec7[((IOTA - 62) & 511)])) + (0.00980110932f * fVec7[((IOTA - 66) & 511)])) + (0.0343561098f * fVec7[((IOTA - 67) & 511)])) + (0.050023105f * fVec7[((IOTA - 68) & 511)])) + (0.0496005155f * fVec7[((IOTA - 69) & 511)])) + (0.0356219113f * fVec7[((IOTA - 70) & 511)])) + (0.0138984546f * fVec7[((IOTA - 71) & 511)])) + (0.000506141223f * fVec7[((IOTA - 81) & 511)])) + (0.00996332243f * fVec7[((IOTA - 82) & 511)])) + (0.0203874316f * fVec7[((IOTA - 83) & 511)])) + (0.0270621181f * fVec7[((IOTA - 84) & 511)])) + (0.0284020491f * fVec7[((IOTA - 85) & 511)])) + (0.0257853456f * fVec7[((IOTA - 86) & 511)])) + (0.0163136423f * fVec7[((IOTA - 87) & 511)])) + (0.00529381726f * fVec7[((IOTA - 88) & 511)])) + (0.000957177486f * fVec7[((IOTA - 91) & 511)])) + (0.0130853606f * fVec7[((IOTA - 92) & 511)])) + (0.0237111039f * fVec7[((IOTA - 93) & 511)])) + (0.0253086053f * fVec7[((IOTA - 94) & 511)])) + (0.0160425026f * fVec7[((IOTA - 95) & 511)])) + (0.0111789079f * fVec7[((IOTA - 102) & 511)])) + (0.0187261775f * fVec7[((IOTA - 103) & 511)])) + (0.0237083603f * fVec7[((IOTA - 104) & 511)])) + (0.0254539419f * fVec7[((IOTA - 105) & 511)])) + (0.0230065789f * fVec7[((IOTA - 106) & 511)])) + (0.0167079344f * fVec7[((IOTA - 107) & 511)])) + (0.00798700377f * fVec7[((IOTA - 108) & 511)])) + (0.00189816346f * fVec7[((IOTA - 113) & 511)])) + (0.00839179195f * fVec7[((IOTA - 114) & 511)])) + (0.0112584941f * fVec7[((IOTA - 115) & 511)])) + (0.00966946036f * fVec7[((IOTA - 116) & 511)])) + (0.00699547585f * fVec7[((IOTA - 117) & 511)])) + (0.00612933468f * fVec7[((IOTA - 118) & 511)])) + (0.00627493905f * fVec7[((IOTA - 119) & 511)])) + (0.00714510586f * fVec7[((IOTA - 120) & 511)])) + (0.0100342017f * fVec7[((IOTA - 121) & 511)])) + (0.0120859304f * fVec7[((IOTA - 122) & 511)])) + (0.0112786219f * fVec7[((IOTA - 123) & 511)])) + (0.00981416926f * fVec7[((IOTA - 124) & 511)])) + (0.00871064235f * fVec7[((IOTA - 125) & 511)])) + (0.00769985141f * fVec7[((IOTA - 126) & 511)])) + (0.00663365703f * fVec7[((IOTA - 127) & 511)])) + (0.00431203935f * fVec7[((IOTA - 128) & 511)])) + (0.000784438103f * fVec7[((IOTA - 129) & 511)])) + (0.000342198182f * fVec7[((IOTA - 137) & 511)])) + (0.0016804873f * fVec7[((IOTA - 138) & 511)])) + (0.00308401976f * fVec7[((IOTA - 139) & 511)])) + (0.00490056956f * fVec7[((IOTA - 140) & 511)])) + (0.00614227587f * fVec7[((IOTA - 141) & 511)])) + (0.00697111432f * fVec7[((IOTA - 142) & 511)])) + (0.00707151368f * fVec7[((IOTA - 143) & 511)])) + (0.00580496807f * fVec7[((IOTA - 144) & 511)])) + (0.00410843827f * fVec7[((IOTA - 145) & 511)])) + (0.00222396152f * fVec7[((IOTA - 146) & 511)])) + (0.0017261398f * fVec7[((IOTA - 153) & 511)])) + (0.00453514233f * fVec7[((IOTA - 154) & 511)])) + (0.00450350484f * fVec7[((IOTA - 155) & 511)])) + (0.00178008154f * fVec7[((IOTA - 156) & 511)])) + (0.00260376092f * fVec7[((IOTA - 160) & 511)])) + (0.00566813024f * fVec7[((IOTA - 161) & 511)])) + (0.00688142003f * fVec7[((IOTA - 162) & 511)])) + (0.00601208815f * fVec7[((IOTA - 163) & 511)])) + (0.00332358247f * fVec7[((IOTA - 164) & 511)])) + (0.000668026507f * fVec7[((IOTA - 165) & 511)])) + (0.000948351342f * fVec7[((IOTA - 168) & 511)])) + (0.00137296831f * fVec7[((IOTA - 169) & 511)])) + (0.000550212804f * fVec7[((IOTA - 175) & 511)])) + (0.0015001446f * fVec7[((IOTA - 176) & 511)])) + (0.00184532488f * fVec7[((IOTA - 177) & 511)])) + (0.00098938169f * fVec7[((IOTA - 178) & 511)])) + (0.00185113959f * fVec7[((IOTA - 199) & 511)])) + (0.0030002892f * fVec7[((IOTA - 200) & 511)])) + (0.00217371713f * fVec7[((IOTA - 201) & 511)])) + (0.000952675007f * fVec7[((IOTA - 202) & 511)])) + (0.000238041859f * fVec7[((IOTA - 246) & 511)])) + (0.000643008389f * fVec7[((IOTA - 247) & 511)])) + (0.000615277328f * fVec7[((IOTA - 265) & 511)])) + (2.57631764e-05f * fVec7[((IOTA - 266) & 511)])) + (0.000352575444f * fVec7[((IOTA - 319) & 511)])) + (0.000706044957f * fVec7[((IOTA - 320) & 511)])) + (0.000789686106f * fVec7[((IOTA - 321) & 511)])) + (0.000610864256f * fVec7[((IOTA - 322) & 511)])) + (0.00098347757f * fVec7[((IOTA - 323) & 511)])) + (0.000869361684f * fVec7[((IOTA - 324) & 511)])) + (0.000299289357f * fVec7[((IOTA - 344) & 511)])) + (0.000897629652f * fVec7[((IOTA - 345) & 511)])) + (0.00124346605f * fVec7[((IOTA - 354) & 511)])) + (0.00191089604f * fVec7[((IOTA - 355) & 511)])) + (0.00112589123f * fVec7[((IOTA - 356) & 511)])) + (0.000114592724f * fVec7[((IOTA - 357) & 511)])) + (5.69550321e-06f * fVec7[((IOTA - 363) & 511)])) + (0.000634719152f * fVec7[((IOTA - 364) & 511)])) + (0.00108283293f * fVec7[((IOTA - 365) & 511)])) + (0.00119590526f * fVec7[((IOTA - 366) & 511)])) + (0.00103753852f * fVec7[((IOTA - 367) & 511)])) + (0.00170201669f * fVec7[((IOTA - 368) & 511)])) + (0.0026277951f * fVec7[((IOTA - 369) & 511)])) + (0.00325729558f * fVec7[((IOTA - 370) & 511)])) + (0.00407211902f * fVec7[((IOTA - 371) & 511)])) + (0.00438417075f * fVec7[((IOTA - 372) & 511)])) + (0.00368724996f * fVec7[((IOTA - 373) & 511)])) + (0.00217720587f * fVec7[((IOTA - 374) & 511)])) + (0.00075915223f * fVec7[((IOTA - 380) & 511)])) + (0.00146549521f * fVec7[((IOTA - 381) & 511)])) + (0.00106413662f * fVec7[((IOTA - 382) & 511)])) + (0.000191405881f * fVec7[((IOTA - 391) & 511)])) + (0.000224027317f * fVec7[((IOTA - 392) & 511)])) + (0.000776983332f * fVec7[((IOTA - 393) & 511)])) + (0.0022180872f * fVec7[((IOTA - 394) & 511)])) + (0.00350139057f * fVec7[((IOTA - 395) & 511)])) + (0.00437442027f * fVec7[((IOTA - 396) & 511)])) + (0.00420677988f * fVec7[((IOTA - 397) & 511)])) + (0.00263450434f * fVec7[((IOTA - 398) & 511)])) + (0.000558532309f * fVec7[((IOTA - 399) & 511)])) + (0.000821114983f * fVec7[((IOTA - 404) & 511)])) + (0.00232796883f * fVec7[((IOTA - 405) & 511)])) + (0.00249945559f * fVec7[((IOTA - 406) & 511)])) + (0.0019468274f * fVec7[((IOTA - 407) & 511)])) + (0.00133527722f * fVec7[((IOTA - 408) & 511)])) + (0.0006383867f * fVec7[((IOTA - 409) & 511)])) + (0.00077504525f * fVec7[((IOTA - 410) & 511)])) + (0.00178857986f * fVec7[((IOTA - 411) & 511)])) + (0.0029145903f * fVec7[((IOTA - 412) & 511)])) + (0.0039784885f * fVec7[((IOTA - 413) & 511)])) + (0.00417129556f * fVec7[((IOTA - 414) & 511)])) + (0.00339085329f * fVec7[((IOTA - 415) & 511)])) + (0.00258074095f * fVec7[((IOTA - 416) & 511)])) + (0.00161232194f * fVec7[((IOTA - 417) & 511)])) + (0.00120341964f * fVec7[((IOTA - 418) & 511)])) + (0.00212186249f * fVec7[((IOTA - 419) & 511)])) + (0.00299164141f * fVec7[((IOTA - 420) & 511)])) + (0.00290263304f * fVec7[((IOTA - 421) & 511)])) + (0.00183065422f * fVec7[((IOTA - 422) & 511)])) + (0.00151901972f * fVec7[((IOTA - 429) & 511)])) + (0.00375613105f * fVec7[((IOTA - 430) & 511)])) + (0.00544347707f * fVec7[((IOTA - 431) & 511)])) + (0.00609614654f * fVec7[((IOTA - 432) & 511)])) + (0.00622293539f * fVec7[((IOTA - 433) & 511)])) + (0.00577968173f * fVec7[((IOTA - 434) & 511)])) + (0.00516422559f * fVec7[((IOTA - 435) & 511)])) + (0.00497123972f * fVec7[((IOTA - 436) & 511)])) + (0.00552559737f * fVec7[((IOTA - 437) & 511)])) + (0.00712184748f * fVec7[((IOTA - 438) & 511)])) + (0.0087405201f * fVec7[((IOTA - 439) & 511)])) + (0.00904753339f * fVec7[((IOTA - 440) & 511)])) + (0.00823041424f * fVec7[((IOTA - 441) & 511)])) + (0.00659572752f * fVec7[((IOTA - 442) & 511)])) + (0.00449229311f * fVec7[((IOTA - 443) & 511)])) + (0.00330139743f * fVec7[((IOTA - 444) & 511)])) + (0.00322416704f * fVec7[((IOTA - 445) & 511)])) + (0.00354125816f * fVec7[((IOTA - 446) & 511)])) + (0.00370627455f * fVec7[((IOTA - 447) & 511)])) + (0.00294536306f * fVec7[((IOTA - 448) & 511)])) + (0.00149585074f * fVec7[((IOTA - 449) & 511)])) + (0.000331255142f * fVec7[((IOTA - 450) & 511)])) + (0.000186217017f * fVec7[((IOTA - 452) & 511)])) + (0.00159678655f * fVec7[((IOTA - 453) & 511)])) + (0.0030553937f * fVec7[((IOTA - 454) & 511)])) + (0.00434764288f * fVec7[((IOTA - 455) & 511)])) + (0.00522517506f * fVec7[((IOTA - 456) & 511)])) + (0.00518491957f * fVec7[((IOTA - 457) & 511)])) + (0.00494309096f * fVec7[((IOTA - 458) & 511)])) + (0.00462683477f * fVec7[((IOTA - 459) & 511)])) + (0.00378022483f * fVec7[((IOTA - 460) & 511)])) + (0.00285113649f * fVec7[((IOTA - 461) & 511)])) + (0.00181595329f * fVec7[((IOTA - 462) & 511)])) + (0.00109312031f * fVec7[((IOTA - 463) & 511)])) + (0.00153058954f * fVec7[((IOTA - 464) & 511)])) + (0.00257626828f * fVec7[((IOTA - 465) & 511)])) + (0.00365740154f * fVec7[((IOTA - 466) & 511)])) + (0.00448826747f * fVec7[((IOTA - 467) & 511)])) + (0.00426862342f * fVec7[((IOTA - 468) & 511)])) + (0.00329161668f * fVec7[((IOTA - 469) & 511)])) + (0.00227984134f * fVec7[((IOTA - 470) & 511)])) + (0.00129359076f * fVec7[((IOTA - 471) & 511)])) + (0.000711203553f * fVec7[((IOTA - 472) & 511)])) + (0.000421009026f * fVec7[((IOTA - 473) & 511)])) + (0.000246987678f * fVec7[((IOTA - 474) & 511)])) + (0.000578182749f * fVec7[((IOTA - 475) & 511)])) + (0.00102486555f * fVec7[((IOTA - 476) & 511)])) + (0.00138787739f * fVec7[((IOTA - 477) & 511)])) + (0.00220484752f * fVec7[((IOTA - 478) & 511)])) + (0.0033052736f * fVec7[((IOTA - 479) & 511)])) + (0.00428275764f * fVec7[((IOTA - 480) & 511)])) + (0.00476253917f * fVec7[((IOTA - 481) & 511)])) + (0.00443572737f * fVec7[((IOTA - 482) & 511)])) + (0.00385089451f * fVec7[((IOTA - 483) & 511)])) + (0.00322962413f * fVec7[((IOTA - 484) & 511)])) + (0.00245347526f * fVec7[((IOTA - 485) & 511)])) + (0.0019968031f * fVec7[((IOTA - 486) & 511)])) + (0.00152704073f * fVec7[((IOTA - 487) & 511)])) + (0.00107931439f * fVec7[((IOTA - 488) & 511)])) + (0.0014922726f * fVec7[((IOTA - 489) & 511)])) + (0.00207913248f * fVec7[((IOTA - 490) & 511)])) + (0.00243454054f * fVec7[((IOTA - 491) & 511)])) + (0.00259228097f * fVec7[((IOTA - 492) & 511)])) + (0.00155912573f * fVec7[((IOTA - 493) & 511)])) + (0.00144852838f * fVec7[((IOTA - 499) & 511)])) + (0.0038029463f * fVec7[((IOTA - 500) & 511)])) + (0.00558272982f * fVec7[((IOTA - 501) & 511)])) + (0.00574795483f * fVec7[((IOTA - 502) & 511)])) + (0.00493763387f * fVec7[((IOTA - 503) & 511)])) + (0.00406949501f * fVec7[((IOTA - 504) & 511)])) + (0.0038159769f * fVec7[((IOTA - 505) & 511)])) + (0.0045903367f * fVec7[((IOTA - 506) & 511)])) + (0.00560059119f * fVec7[((IOTA - 507) & 511)])) + (0.00622326322f * fVec7[((IOTA - 508) & 511)])) + (0.00622329302f * fVec7[((IOTA - 509) & 511)])) + (0.00528090587f * fVec7[((IOTA - 510) & 511)])) + (0.0040102154f * fVec7[((IOTA - 511) & 511)])))))) : (iSlow4 ? (iSlow15 ? (iSlow21 ? ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00349776121f * fVec6[((IOTA - 317) & 511)]) + ((0.00739633199f * fVec6[((IOTA - 316) & 511)]) + ((0.00984383468f * fVec6[((IOTA - 315) & 511)]) + ((0.010277207f * fVec6[((IOTA - 314) & 511)]) + ((0.00885873288f * fVec6[((IOTA - 313) & 511)]) + ((0.00649768021f * fVec6[((IOTA - 312) & 511)]) + ((0.00379969506f * fVec6[((IOTA - 311) & 511)]) + ((0.00149924122f * fVec6[((IOTA - 310) & 511)]) + ((0.00122306449f * fVec6[((IOTA - 309) & 511)]) + ((0.00304219127f * fVec6[((IOTA - 308) & 511)]) + ((0.00570477219f * fVec6[((IOTA - 307) & 511)]) + ((0.0082386937f * fVec6[((IOTA - 306) & 511)]) + ((0.00986047462f * fVec6[((IOTA - 305) & 511)]) + ((0.010757098f * fVec6[((IOTA - 304) & 511)]) + ((0.0113442931f * fVec6[((IOTA - 303) & 511)]) + ((0.0107025867f * fVec6[((IOTA - 302) & 511)]) + ((0.00870003924f * fVec6[((IOTA - 301) & 511)]) + ((0.00636080932f * fVec6[((IOTA - 300) & 511)]) + ((0.00485963235f * fVec6[((IOTA - 299) & 511)]) + ((0.00493840175f * fVec6[((IOTA - 298) & 511)]) + ((0.00583171519f * fVec6[((IOTA - 297) & 511)]) + ((0.00644145207f * fVec6[((IOTA - 296) & 511)]) + ((0.00658494141f * fVec6[((IOTA - 295) & 511)]) + ((0.0059407996f * fVec6[((IOTA - 294) & 511)]) + ((0.00464533456f * fVec6[((IOTA - 293) & 511)]) + ((0.00372332986f * fVec6[((IOTA - 292) & 511)]) + ((0.00391680328f * fVec6[((IOTA - 291) & 511)]) + ((0.00506521948f * fVec6[((IOTA - 290) & 511)]) + ((0.00632577995f * fVec6[((IOTA - 289) & 511)]) + ((0.00715409173f * fVec6[((IOTA - 288) & 511)]) + ((0.007570168f * fVec6[((IOTA - 287) & 511)]) + ((0.00714550633f * fVec6[((IOTA - 286) & 511)]) + ((0.00558123272f * fVec6[((IOTA - 285) & 511)]) + ((0.0038416246f * fVec6[((IOTA - 284) & 511)]) + ((0.00311237527f * fVec6[((IOTA - 283) & 511)]) + ((0.00347746816f * fVec6[((IOTA - 282) & 511)]) + ((0.00391143374f * fVec6[((IOTA - 281) & 511)]) + ((0.00363222836f * fVec6[((IOTA - 280) & 511)]) + ((0.00256417366f * fVec6[((IOTA - 279) & 511)]) + ((((((((((((((((((0.0122558083f * fVec6[((IOTA - 261) & 511)]) + ((0.0128729446f * fVec6[((IOTA - 260) & 511)]) + ((0.0106349625f * fVec6[((IOTA - 259) & 511)]) + ((0.00733723165f * fVec6[((IOTA - 258) & 511)]) + ((0.00552962488f * fVec6[((IOTA - 257) & 511)]) + ((0.00689780246f * fVec6[((IOTA - 256) & 511)]) + ((0.0104929097f * fVec6[((IOTA - 255) & 511)]) + ((0.0134973554f * fVec6[((IOTA - 254) & 511)]) + ((0.0141553907f * fVec6[((IOTA - 253) & 511)]) + ((0.0122430697f * fVec6[((IOTA - 252) & 511)]) + ((0.0083286399f * fVec6[((IOTA - 251) & 511)]) + ((0.0040919818f * fVec6[((IOTA - 250) & 511)]) + ((0.00102128601f * fVec6[((IOTA - 249) & 511)]) + ((0.00198075548f * fVec6[((IOTA - 244) & 511)]) + ((0.00529334787f * fVec6[((IOTA - 243) & 511)]) + ((0.00896385312f * fVec6[((IOTA - 242) & 511)]) + ((0.0111910943f * fVec6[((IOTA - 241) & 511)]) + ((0.0101368083f * fVec6[((IOTA - 240) & 511)]) + ((0.00669917744f * fVec6[((IOTA - 239) & 511)]) + ((0.00374299893f * fVec6[((IOTA - 238) & 511)]) + ((0.00309729576f * fVec6[((IOTA - 237) & 511)]) + ((0.00491002249f * fVec6[((IOTA - 236) & 511)]) + ((0.00778178079f * fVec6[((IOTA - 235) & 511)]) + ((0.0102241319f * fVec6[((IOTA - 234) & 511)]) + ((0.0117528141f * fVec6[((IOTA - 233) & 511)]) + ((0.012030771f * fVec6[((IOTA - 232) & 511)]) + ((0.0108875055f * fVec6[((IOTA - 231) & 511)]) + ((0.00963746756f * fVec6[((IOTA - 230) & 511)]) + ((0.00909591559f * fVec6[((IOTA - 229) & 511)]) + ((0.0089691598f * fVec6[((IOTA - 228) & 511)]) + ((0.00872164406f * fVec6[((IOTA - 227) & 511)]) + ((0.00814187899f * fVec6[((IOTA - 226) & 511)]) + ((0.00758571597f * fVec6[((IOTA - 225) & 511)]) + ((0.00705936877f * fVec6[((IOTA - 224) & 511)]) + ((0.00619224971f * fVec6[((IOTA - 223) & 511)]) + ((0.00484945439f * fVec6[((IOTA - 222) & 511)]) + ((0.00293176435f * fVec6[((IOTA - 221) & 511)]) + ((0.000739552081f * fVec6[((IOTA - 220) & 511)]) + ((0.00203770166f * fVec6[((IOTA - 217) & 511)]) + ((0.00627217442f * fVec6[((IOTA - 216) & 511)]) + ((0.0108234417f * fVec6[((IOTA - 215) & 511)]) + ((0.0139271058f * fVec6[((IOTA - 214) & 511)]) + ((0.0144693758f * fVec6[((IOTA - 213) & 511)]) + ((0.0126702301f * fVec6[((IOTA - 212) & 511)]) + ((0.00921186805f * fVec6[((IOTA - 211) & 511)]) + ((0.00501664029f * fVec6[((IOTA - 210) & 511)]) + ((0.00187554257f * fVec6[((IOTA - 209) & 511)]) + ((0.00149355922f * fVec6[((IOTA - 208) & 511)]) + ((0.00357265957f * fVec6[((IOTA - 207) & 511)]) + ((0.00562356785f * fVec6[((IOTA - 206) & 511)]) + ((0.00522378879f * fVec6[((IOTA - 205) & 511)]) + ((0.00218896521f * fVec6[((IOTA - 204) & 511)]) + ((0.00480318582f * fVec6[((IOTA - 198) & 511)]) + ((0.00992416497f * fVec6[((IOTA - 197) & 511)]) + ((0.0131026339f * fVec6[((IOTA - 196) & 511)]) + ((0.0134124048f * fVec6[((IOTA - 195) & 511)]) + ((0.011300304f * fVec6[((IOTA - 194) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00359723018f * fVec6[((IOTA - 54) & 511)]) + ((0.0114442613f * fVec6[((IOTA - 53) & 511)]) + ((0.0153822014f * fVec6[((IOTA - 52) & 511)]) + ((0.0119174719f * fVec6[((IOTA - 51) & 511)]) + ((0.00808973983f * fVec6[((IOTA - 42) & 511)]) + ((0.0106556937f * fVec6[((IOTA - 41) & 511)]) + ((0.0151243201f * fVec6[((IOTA - 40) & 511)]) + ((0.0159543492f * fVec6[((IOTA - 39) & 511)]) + ((0.0178508405f * fVec6[((IOTA - 38) & 511)]) + ((0.0157746114f * fVec6[((IOTA - 37) & 511)]) + ((0.00385907665f * fVec6[((IOTA - 36) & 511)]) + ((0.00465888437f * fVec6[((IOTA - 28) & 511)]) + ((0.0412707999f * fVec6[((IOTA - 27) & 511)]) + ((0.0562865958f * fVec6[((IOTA - 26) & 511)]) + ((0.0481109992f * fVec6[((IOTA - 25) & 511)]) + ((0.0250989068f * fVec6[((IOTA - 24) & 511)]) + ((0.00311911898f * fVec6[((IOTA - 19) & 511)]) + ((0.0285696313f * fVec6[((IOTA - 18) & 511)]) + ((0.0325679183f * fVec6[((IOTA - 17) & 511)]) + ((0.0242023151f * fVec6[((IOTA - 16) & 511)]) + ((0.0236350689f * fVec6[((IOTA - 15) & 511)]) + ((0.0440732166f * fVec6[((IOTA - 14) & 511)]) + ((0.0681192726f * fVec6[((IOTA - 13) & 511)]) + ((0.0538650379f * fVec6[((IOTA - 12) & 511)]) + ((0.0072424775f * fVec6[((IOTA - 11) & 511)]) + ((0.0745768026f * fVec6[((IOTA - 5) & 511)]) + ((0.198292792f * fVec6[((IOTA - 4) & 511)]) + ((0.251756459f * fVec6[((IOTA - 3) & 511)]) + ((0.252992362f * fVec6[((IOTA - 2) & 511)]) + ((0.192090496f * fVec6[((IOTA - 1) & 511)]) + ((fSlow25 * fTemp0) + ((0.0145149883f * fVec6[((IOTA - 64) & 511)]) + (0.0282502435f * fVec6[((IOTA - 65) & 511)]))))))))))))))))))))))))))))))))) + (0.0185996965f * fVec6[((IOTA - 66) & 511)])) + (0.00615672069f * fVec6[((IOTA - 73) & 511)])) + (0.00839848071f * fVec6[((IOTA - 74) & 511)])) + (0.00126533723f * fVec6[((IOTA - 75) & 511)])) + (0.00923291128f * fVec6[((IOTA - 79) & 511)])) + (0.0180156846f * fVec6[((IOTA - 80) & 511)])) + (0.0141792428f * fVec6[((IOTA - 81) & 511)])) + (0.00876922347f * fVec6[((IOTA - 98) & 511)])) + (0.0204155147f * fVec6[((IOTA - 99) & 511)])) + (0.023536725f * fVec6[((IOTA - 100) & 511)])) + (0.0164468214f * fVec6[((IOTA - 101) & 511)])) + (0.00496250391f * fVec6[((IOTA - 102) & 511)])) + (0.00254041515f * fVec6[((IOTA - 112) & 511)])) + (0.0027170293f * fVec6[((IOTA - 113) & 511)])) + (8.82605091e-05f * fVec6[((IOTA - 114) & 511)])) + (0.00123767555f * fVec6[((IOTA - 129) & 511)])) + (0.00762577169f * fVec6[((IOTA - 130) & 511)])) + (0.0112663042f * fVec6[((IOTA - 131) & 511)])) + (0.0109282807f * fVec6[((IOTA - 132) & 511)])) + (0.00784971658f * fVec6[((IOTA - 133) & 511)])) + (0.00454674009f * fVec6[((IOTA - 134) & 511)])) + (0.00360928103f * fVec6[((IOTA - 135) & 511)])) + (0.00429116888f * fVec6[((IOTA - 136) & 511)])) + (0.00504982797f * fVec6[((IOTA - 137) & 511)])) + (0.00435673213f * fVec6[((IOTA - 138) & 511)])) + (0.000414202921f * fVec6[((IOTA - 139) & 511)])) + (0.0050106463f * fVec6[((IOTA - 146) & 511)])) + (0.0082273297f * fVec6[((IOTA - 147) & 511)])) + (0.00770307379f * fVec6[((IOTA - 148) & 511)])) + (0.00482491497f * fVec6[((IOTA - 149) & 511)])) + (0.000228690449f * fVec6[((IOTA - 150) & 511)])) + (0.000132250134f * fVec6[((IOTA - 155) & 511)])) + (0.00191897014f * fVec6[((IOTA - 168) & 511)])) + (0.00492663169f * fVec6[((IOTA - 169) & 511)])) + (0.00672811875f * fVec6[((IOTA - 170) & 511)])) + (0.00583842723f * fVec6[((IOTA - 171) & 511)])) + (0.00220498163f * fVec6[((IOTA - 172) & 511)])) + (3.82764265e-05f * fVec6[((IOTA - 178) & 511)])) + (0.00196527038f * fVec6[((IOTA - 179) & 511)])) + (0.0034713177f * fVec6[((IOTA - 180) & 511)])) + (0.00475342013f * fVec6[((IOTA - 181) & 511)])) + (0.00583127793f * fVec6[((IOTA - 182) & 511)])) + (0.00702664955f * fVec6[((IOTA - 183) & 511)])) + (0.00759576866f * fVec6[((IOTA - 184) & 511)])) + (0.00655059889f * fVec6[((IOTA - 185) & 511)])) + (0.004319767f * fVec6[((IOTA - 186) & 511)])) + (0.00200573215f * fVec6[((IOTA - 187) & 511)])) + (0.000683948398f * fVec6[((IOTA - 188) & 511)])) + (0.000569306314f * fVec6[((IOTA - 189) & 511)])) + (0.00158584723f * fVec6[((IOTA - 190) & 511)])) + (0.00359379593f * fVec6[((IOTA - 191) & 511)])) + (0.00597554818f * fVec6[((IOTA - 192) & 511)])) + (0.00849816762f * fVec6[((IOTA - 193) & 511)])) + (0.00877965149f * fVec6[((IOTA - 262) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00407053344f * fVec6[((IOTA - 263) & 511)])) + (0.000469088554f * fVec6[((IOTA - 264) & 511)])) + (0.00260541588f * fVec6[((IOTA - 266) & 511)])) + (0.00669446308f * fVec6[((IOTA - 267) & 511)])) + (0.0106770173f * fVec6[((IOTA - 268) & 511)])) + (0.013589425f * fVec6[((IOTA - 269) & 511)])) + (0.0149077121f * fVec6[((IOTA - 270) & 511)])) + (0.0144224511f * fVec6[((IOTA - 271) & 511)])) + (0.0121633951f * fVec6[((IOTA - 272) & 511)])) + (0.00908645615f * fVec6[((IOTA - 273) & 511)])) + (0.00653208513f * fVec6[((IOTA - 274) & 511)])) + (0.00473415712f * fVec6[((IOTA - 275) & 511)])) + (0.00324983895f * fVec6[((IOTA - 276) & 511)])) + (0.0020964588f * fVec6[((IOTA - 277) & 511)])) + (0.00178088155f * fVec6[((IOTA - 278) & 511)])) + (0.000132968184f * fVec6[((IOTA - 318) & 511)]))))))))))))))))))))))))))))))))))))))))) + (0.00159433903f * fVec6[((IOTA - 326) & 511)])) + (0.00296342187f * fVec6[((IOTA - 327) & 511)])) + (0.00355501985f * fVec6[((IOTA - 328) & 511)])) + (0.00332823396f * fVec6[((IOTA - 329) & 511)])) + (0.00308408914f * fVec6[((IOTA - 330) & 511)])) + (0.00292882975f * fVec6[((IOTA - 331) & 511)])) + (0.00281050382f * fVec6[((IOTA - 332) & 511)])) + (0.00290769339f * fVec6[((IOTA - 333) & 511)])) + (0.00288377842f * fVec6[((IOTA - 334) & 511)])) + (0.0029294542f * fVec6[((IOTA - 335) & 511)])) + (0.00347799901f * fVec6[((IOTA - 336) & 511)])) + (0.00415105093f * fVec6[((IOTA - 337) & 511)])) + (0.0048615369f * fVec6[((IOTA - 338) & 511)])) + (0.00555363344f * fVec6[((IOTA - 339) & 511)])) + (0.00595775247f * fVec6[((IOTA - 340) & 511)])) + (0.00611856906f * fVec6[((IOTA - 341) & 511)])) + (0.00551307807f * fVec6[((IOTA - 342) & 511)])) + (0.00386166805f * fVec6[((IOTA - 343) & 511)])) + (0.00237934804f * fVec6[((IOTA - 344) & 511)])) + (0.00183673529f * fVec6[((IOTA - 345) & 511)])) + (0.0023962697f * fVec6[((IOTA - 346) & 511)])) + (0.00435410952f * fVec6[((IOTA - 347) & 511)])) + (0.0071016727f * fVec6[((IOTA - 348) & 511)])) + (0.00970996171f * fVec6[((IOTA - 349) & 511)])) + (0.0110627469f * fVec6[((IOTA - 350) & 511)])) + (0.00966322422f * fVec6[((IOTA - 351) & 511)])) + (0.00558925606f * fVec6[((IOTA - 352) & 511)])) + (0.000271743629f * fVec6[((IOTA - 353) & 511)])) + (0.00193292554f * fVec6[((IOTA - 358) & 511)])) + (0.00426294561f * fVec6[((IOTA - 359) & 511)])) + (0.00509434845f * fVec6[((IOTA - 360) & 511)])) + (0.00498620048f * fVec6[((IOTA - 361) & 511)])) + (0.00389064057f * fVec6[((IOTA - 362) & 511)])) + (0.00219377317f * fVec6[((IOTA - 363) & 511)])) + (0.000839551445f * fVec6[((IOTA - 364) & 511)])) + (0.00272099441f * fVec6[((IOTA - 375) & 511)])) + (0.00511667086f * fVec6[((IOTA - 376) & 511)])) + (0.00485941395f * fVec6[((IOTA - 377) & 511)])) + (0.00275293319f * fVec6[((IOTA - 378) & 511)])) + (0.000376644544f * fVec6[((IOTA - 379) & 511)])) + (0.000599215738f * fVec6[((IOTA - 384) & 511)])) + (0.00194697501f * fVec6[((IOTA - 385) & 511)])) + (0.00236367527f * fVec6[((IOTA - 386) & 511)])) + (0.00136480574f * fVec6[((IOTA - 387) & 511)])) + (0.00118425721f * fVec6[((IOTA - 391) & 511)])) + (0.00320737902f * fVec6[((IOTA - 392) & 511)])) + (0.00366707053f * fVec6[((IOTA - 393) & 511)])) + (0.00195087772f * fVec6[((IOTA - 394) & 511)])) + (0.000578423031f * fVec6[((IOTA - 401) & 511)])) + (0.00249530142f * fVec6[((IOTA - 402) & 511)])) + (0.00223229965f * fVec6[((IOTA - 403) & 511)])) + (0.000295658596f * fVec6[((IOTA - 404) & 511)])) + (0.000193286221f * fVec6[((IOTA - 418) & 511)])) + (0.000984289683f * fVec6[((IOTA - 426) & 511)])) + (0.0011511324f * fVec6[((IOTA - 427) & 511)])) + (0.00067133503f * fVec6[((IOTA - 428) & 511)])) + (0.000800432172f * fVec6[((IOTA - 475) & 511)])) + (0.00132178375f * fVec6[((IOTA - 476) & 511)])) + (0.000603867695f * fVec6[((IOTA - 477) & 511)])) + (0.00140529871f * fVec6[((IOTA - 494) & 511)])) + (0.00251097418f * fVec6[((IOTA - 495) & 511)])) + (0.00281087821f * fVec6[((IOTA - 496) & 511)])) + (0.00248396816f * fVec6[((IOTA - 497) & 511)])) + (0.00187541777f * fVec6[((IOTA - 498) & 511)])) + (0.000881730579f * fVec6[((IOTA - 499) & 511)])) - ((((((((((((((((((((((((((((0.00232408801f * fVec6[((IOTA - 478) & 511)]) + ((0.000195065979f * fVec6[((IOTA - 474) & 511)]) + ((0.00121391704f * fVec6[((IOTA - 473) & 511)]) + ((0.00181975123f * fVec6[((IOTA - 472) & 511)]) + ((0.0017744815f * fVec6[((IOTA - 471) & 511)]) + ((0.00164778857f * fVec6[((IOTA - 470) & 511)]) + ((0.00267076073f * fVec6[((IOTA - 469) & 511)]) + ((0.00496184826f * fVec6[((IOTA - 468) & 511)]) + ((0.00759764202f * fVec6[((IOTA - 467) & 511)]) + ((0.00947087444f * fVec6[((IOTA - 466) & 511)]) + ((0.00921411626f * fVec6[((IOTA - 465) & 511)]) + ((0.00673295837f * fVec6[((IOTA - 464) & 511)]) + ((0.00373397581f * fVec6[((IOTA - 463) & 511)]) + ((0.00206024293f * fVec6[((IOTA - 462) & 511)]) + ((0.0022430704f * fVec6[((IOTA - 461) & 511)]) + ((0.00388317881f * fVec6[((IOTA - 460) & 511)]) + ((0.0060169464f * fVec6[((IOTA - 459) & 511)]) + ((0.00760988053f * fVec6[((IOTA - 458) & 511)]) + ((0.00796651281f * fVec6[((IOTA - 457) & 511)]) + ((0.00667132903f * fVec6[((IOTA - 456) & 511)]) + ((0.00461942144f * fVec6[((IOTA - 455) & 511)]) + ((0.00303207571f * fVec6[((IOTA - 454) & 511)]) + ((0.00185777806f * fVec6[((IOTA - 453) & 511)]) + ((0.00106443278f * fVec6[((IOTA - 452) & 511)]) + ((0.00134972623f * fVec6[((IOTA - 451) & 511)]) + ((0.00249121152f * fVec6[((IOTA - 450) & 511)]) + ((0.0037835543f * fVec6[((IOTA - 449) & 511)]) + ((0.00486765616f * fVec6[((IOTA - 448) & 511)]) + ((0.00541785546f * fVec6[((IOTA - 447) & 511)]) + ((0.00578394765f * fVec6[((IOTA - 446) & 511)]) + ((0.00644129608f * fVec6[((IOTA - 445) & 511)]) + ((0.0072496268f * fVec6[((IOTA - 444) & 511)]) + ((0.0087267952f * fVec6[((IOTA - 443) & 511)]) + ((0.0107201021f * fVec6[((IOTA - 442) & 511)]) + ((0.0121804737f * fVec6[((IOTA - 441) & 511)]) + ((0.0124322977f * fVec6[((IOTA - 440) & 511)]) + ((0.0111903455f * fVec6[((IOTA - 439) & 511)]) + ((0.0092924796f * fVec6[((IOTA - 438) & 511)]) + ((0.00828383863f * fVec6[((IOTA - 437) & 511)]) + ((0.00843135547f * fVec6[((IOTA - 436) & 511)]) + ((0.00908380188f * fVec6[((IOTA - 435) & 511)]) + ((0.00930066034f * fVec6[((IOTA - 434) & 511)]) + ((0.00841874257f * fVec6[((IOTA - 433) & 511)]) + ((0.00673423801f * fVec6[((IOTA - 432) & 511)]) + ((0.00464773877f * fVec6[((IOTA - 431) & 511)]) + ((0.00230835285f * fVec6[((IOTA - 430) & 511)]) + ((3.05939466e-06f * fVec6[((IOTA - 425) & 511)]) + ((0.00144313788f * fVec6[((IOTA - 424) & 511)]) + ((0.00267662993f * fVec6[((IOTA - 423) & 511)]) + ((0.00302320952f * fVec6[((IOTA - 422) & 511)]) + ((0.00235942937f * fVec6[((IOTA - 421) & 511)]) + ((0.00144335674f * fVec6[((IOTA - 420) & 511)]) + ((0.000484854914f * fVec6[((IOTA - 419) & 511)]) + ((0.000296001788f * fVec6[((IOTA - 417) & 511)]) + ((0.00161903445f * fVec6[((IOTA - 416) & 511)]) + ((0.00348499231f * fVec6[((IOTA - 415) & 511)]) + ((0.00597511092f * fVec6[((IOTA - 414) & 511)]) + ((0.00737987878f * fVec6[((IOTA - 413) & 511)]) + ((0.00697163912f * fVec6[((IOTA - 412) & 511)]) + ((0.00562491035f * fVec6[((IOTA - 411) & 511)]) + ((0.0033996664f * fVec6[((IOTA - 410) & 511)]) + ((0.00141194882f * fVec6[((IOTA - 409) & 511)]) + ((0.000511267688f * fVec6[((IOTA - 408) & 511)]) + ((0.000279486179f * fVec6[((IOTA - 407) & 511)]) + ((0.000891658477f * fVec6[((IOTA - 406) & 511)]) + ((0.00122584309f * fVec6[((IOTA - 405) & 511)]) + ((0.00278381025f * fVec6[((IOTA - 400) & 511)]) + ((0.00603152625f * fVec6[((IOTA - 399) & 511)]) + ((0.00795814581f * fVec6[((IOTA - 398) & 511)]) + ((0.00778727559f * fVec6[((IOTA - 397) & 511)]) + ((0.00518882181f * fVec6[((IOTA - 396) & 511)]) + ((0.00133102527f * fVec6[((IOTA - 395) & 511)]) + ((0.000589974225f * fVec6[((IOTA - 390) & 511)]) + ((0.00121822534f * fVec6[((IOTA - 389) & 511)]) + ((0.000379735138f * fVec6[((IOTA - 388) & 511)]) + ((0.00099833915f * fVec6[((IOTA - 383) & 511)]) + ((0.00198740559f * fVec6[((IOTA - 382) & 511)]) + ((0.00219898717f * fVec6[((IOTA - 381) & 511)]) + ((0.00144210784f * fVec6[((IOTA - 380) & 511)]) + ((0.00503740227f * fVec6[((IOTA - 373) & 511)]) + ((0.00813766383f * fVec6[((IOTA - 372) & 511)]) + ((0.00942529179f * fVec6[((IOTA - 371) & 511)]) + ((0.0087690372f * fVec6[((IOTA - 370) & 511)]) + ((0.0067991768f * fVec6[((IOTA - 369) & 511)]) + ((0.00408842275f * fVec6[((IOTA - 368) & 511)]) + ((0.00181241473f * fVec6[((IOTA - 367) & 511)]) + ((0.000687850639f * fVec6[((IOTA - 366) & 511)]) + ((3.43113206e-05f * fVec6[((IOTA - 365) & 511)]) + ((0.00145028764f * fVec6[((IOTA - 357) & 511)]) + ((0.00457355846f * fVec6[((IOTA - 356) & 511)]) + ((0.00606599404f * fVec6[((IOTA - 355) & 511)]) + (((0.00436906423f * fVec6[((IOTA - 354) & 511)]) + ((0.00112462603f * fVec6[((IOTA - 374) & 511)]) + ((9.00086015e-05f * fVec6[((IOTA - 325) & 511)]) + ((0.00162740145f * fVec6[((IOTA - 324) & 511)]) + ((0.00215896266f * fVec6[((IOTA - 323) & 511)]) + ((0.00191481784f * fVec6[((IOTA - 322) & 511)]) + ((0.0017645536f * fVec6[((IOTA - 321) & 511)]) + ((0.00160180079f * fVec6[((IOTA - 320) & 511)]) + ((0.00125846872f * fVec6[((IOTA - 319) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0650879815f * fVec6[((IOTA - 6) & 511)]) + (0.17157723f * fVec6[((IOTA - 7) & 511)])) + (0.200366527f * fVec6[((IOTA - 8) & 511)])) + (0.138788238f * fVec6[((IOTA - 9) & 511)])) + (0.0551313125f * fVec6[((IOTA - 10) & 511)])) + (0.0149352485f * fVec6[((IOTA - 20) & 511)])) + (0.0199410859f * fVec6[((IOTA - 21) & 511)])) + (0.0233959202f * fVec6[((IOTA - 22) & 511)])) + (0.00632290775f * fVec6[((IOTA - 23) & 511)])) + (0.0335313864f * fVec6[((IOTA - 29) & 511)])) + (0.0575697944f * fVec6[((IOTA - 30) & 511)])) + (0.0669819117f * fVec6[((IOTA - 31) & 511)])) + (0.0721962079f * fVec6[((IOTA - 32) & 511)])) + (0.062200889f * fVec6[((IOTA - 33) & 511)])) + (0.0348662212f * fVec6[((IOTA - 34) & 511)])) + (0.0116010197f * fVec6[((IOTA - 35) & 511)])) + (0.00241128681f * fVec6[((IOTA - 43) & 511)])) + (0.0275884941f * fVec6[((IOTA - 44) & 511)])) + (0.0527660139f * fVec6[((IOTA - 45) & 511)])) + (0.0685384423f * fVec6[((IOTA - 46) & 511)])) + (0.0708376467f * fVec6[((IOTA - 47) & 511)])) + (0.0511710197f * fVec6[((IOTA - 48) & 511)])) + (0.0265881568f * fVec6[((IOTA - 49) & 511)])) + (0.00491289468f * fVec6[((IOTA - 50) & 511)])) + (0.00488532707f * fVec6[((IOTA - 55) & 511)])) + (0.00419522822f * fVec6[((IOTA - 56) & 511)])) + (0.0012410786f * fVec6[((IOTA - 57) & 511)])) + (0.00880403444f * fVec6[((IOTA - 58) & 511)])) + (0.0273921788f * fVec6[((IOTA - 59) & 511)])) + (0.044720605f * fVec6[((IOTA - 60) & 511)])) + (0.0476465635f * fVec6[((IOTA - 61) & 511)])) + (0.0375843719f * fVec6[((IOTA - 62) & 511)])) + (0.0141203608f * fVec6[((IOTA - 63) & 511)])) + (0.00984936021f * fVec6[((IOTA - 67) & 511)])) + (0.0414099172f * fVec6[((IOTA - 68) & 511)])) + (0.057888303f * fVec6[((IOTA - 69) & 511)])) + (0.0532095954f * fVec6[((IOTA - 70) & 511)])) + (0.0314781964f * fVec6[((IOTA - 71) & 511)])) + (0.00732062245f * fVec6[((IOTA - 72) & 511)])) + (0.0105301552f * fVec6[((IOTA - 76) & 511)])) + (0.0134361321f * fVec6[((IOTA - 77) & 511)])) + (0.00447955355f * fVec6[((IOTA - 78) & 511)])) + (0.00135031948f * fVec6[((IOTA - 82) & 511)])) + (0.0172489714f * fVec6[((IOTA - 83) & 511)])) + (0.0285956375f * fVec6[((IOTA - 84) & 511)])) + (0.034230914f * fVec6[((IOTA - 85) & 511)])) + (0.0303975306f * fVec6[((IOTA - 86) & 511)])) + (0.0191983189f * fVec6[((IOTA - 87) & 511)])) + (0.0071666115f * fVec6[((IOTA - 88) & 511)])) + (0.00115703326f * fVec6[((IOTA - 89) & 511)])) + (0.00283316988f * fVec6[((IOTA - 90) & 511)])) + (0.00599777699f * fVec6[((IOTA - 91) & 511)])) + (0.0123570878f * fVec6[((IOTA - 92) & 511)])) + (0.0225117542f * fVec6[((IOTA - 93) & 511)])) + (0.0286856461f * fVec6[((IOTA - 94) & 511)])) + (0.0279676989f * fVec6[((IOTA - 95) & 511)])) + (0.0195987839f * fVec6[((IOTA - 96) & 511)])) + (0.00553352758f * fVec6[((IOTA - 97) & 511)])) + (0.00761693623f * fVec6[((IOTA - 103) & 511)])) + (0.0161890015f * fVec6[((IOTA - 104) & 511)])) + (0.0212119501f * fVec6[((IOTA - 105) & 511)])) + (0.0251208544f * fVec6[((IOTA - 106) & 511)])) + (0.0258133262f * fVec6[((IOTA - 107) & 511)])) + (0.0247517973f * fVec6[((IOTA - 108) & 511)])) + (0.0193875153f * fVec6[((IOTA - 109) & 511)])) + (0.00908152293f * fVec6[((IOTA - 110) & 511)])) + (0.00106508844f * fVec6[((IOTA - 111) & 511)])) + (0.0054850732f * fVec6[((IOTA - 115) & 511)])) + (0.0123460051f * fVec6[((IOTA - 116) & 511)])) + (0.0160042085f * fVec6[((IOTA - 117) & 511)])) + (0.0145967547f * fVec6[((IOTA - 118) & 511)])) + (0.011956716f * fVec6[((IOTA - 119) & 511)])) + (0.0112720188f * fVec6[((IOTA - 120) & 511)])) + (0.0125521226f * fVec6[((IOTA - 121) & 511)])) + (0.014871465f * fVec6[((IOTA - 122) & 511)])) + (0.0160007421f * fVec6[((IOTA - 123) & 511)])) + (0.016272923f * fVec6[((IOTA - 124) & 511)])) + (0.0161432959f * fVec6[((IOTA - 125) & 511)])) + (0.0144610088f * fVec6[((IOTA - 126) & 511)])) + (0.011201147f * fVec6[((IOTA - 127) & 511)])) + (0.00584929204f * fVec6[((IOTA - 128) & 511)])) + (0.00558856921f * fVec6[((IOTA - 140) & 511)])) + (0.0122783184f * fVec6[((IOTA - 141) & 511)])) + (0.0175418518f * fVec6[((IOTA - 142) & 511)])) + (0.0173074156f * fVec6[((IOTA - 143) & 511)])) + (0.0109592509f * fVec6[((IOTA - 144) & 511)])) + (0.00216192845f * fVec6[((IOTA - 145) & 511)])) + (0.00383060332f * fVec6[((IOTA - 151) & 511)])) + (0.0051850751f * fVec6[((IOTA - 152) & 511)])) + (0.00360687729f * fVec6[((IOTA - 153) & 511)])) + (0.000791503116f * fVec6[((IOTA - 154) & 511)])) + (0.000912295189f * fVec6[((IOTA - 156) & 511)])) + (0.00187822757f * fVec6[((IOTA - 157) & 511)])) + (0.00188415917f * fVec6[((IOTA - 158) & 511)])) + (0.0012960583f * fVec6[((IOTA - 159) & 511)])) + (0.000947386958f * fVec6[((IOTA - 160) & 511)])) + (0.00137838675f * fVec6[((IOTA - 161) & 511)])) + (0.00301774591f * fVec6[((IOTA - 162) & 511)])) + (0.00531979185f * fVec6[((IOTA - 163) & 511)])) + (0.00646714633f * fVec6[((IOTA - 164) & 511)])) + (0.00576868048f * fVec6[((IOTA - 165) & 511)])) + (0.00362383015f * fVec6[((IOTA - 166) & 511)])) + (0.000923846848f * fVec6[((IOTA - 167) & 511)])) + (0.00231572054f * fVec6[((IOTA - 173) & 511)])) + (0.00488086231f * fVec6[((IOTA - 174) & 511)])) + (0.0043379995f * fVec6[((IOTA - 175) & 511)])) + (0.00289227022f * fVec6[((IOTA - 176) & 511)])) + (0.00176383555f * fVec6[((IOTA - 177) & 511)])) + (0.000546733849f * fVec6[((IOTA - 199) & 511)])) + (0.00438320683f * fVec6[((IOTA - 200) & 511)])) + (0.00553895999f * fVec6[((IOTA - 201) & 511)])) + (0.00445579458f * fVec6[((IOTA - 202) & 511)])) + (0.00162890041f * fVec6[((IOTA - 203) & 511)])) + (0.000406210311f * fVec6[((IOTA - 218) & 511)])) + (0.000658940524f * fVec6[((IOTA - 219) & 511)])) + (0.000106618274f * fVec6[((IOTA - 245) & 511)])) + (0.000927437097f * fVec6[((IOTA - 246) & 511)])) + (0.00118647423f * fVec6[((IOTA - 247) & 511)])) + (0.000741862226f * fVec6[((IOTA - 248) & 511)])) + (2.83480622e-05f * fVec6[((IOTA - 265) & 511)])) + (0.000396313611f * fVec6[((IOTA - 429) & 511)]))))))))))) + (0.00653080503f * fVec6[((IOTA - 479) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00925854314f * fVec6[((IOTA - 480) & 511)])) + (0.00950221904f * fVec6[((IOTA - 481) & 511)])) + (0.00821081363f * fVec6[((IOTA - 482) & 511)])) + (0.00595531706f * fVec6[((IOTA - 483) & 511)])) + (0.00351571338f * fVec6[((IOTA - 484) & 511)])) + (0.00175484363f * fVec6[((IOTA - 485) & 511)])) + (0.00136290118f * fVec6[((IOTA - 486) & 511)])) + (0.00251943478f * fVec6[((IOTA - 487) & 511)])) + (0.00420343922f * fVec6[((IOTA - 488) & 511)])) + (0.00524202129f * fVec6[((IOTA - 489) & 511)])) + (0.00528850872f * fVec6[((IOTA - 490) & 511)])) + (0.00433216151f * fVec6[((IOTA - 491) & 511)])) + (0.00264000846f * fVec6[((IOTA - 492) & 511)])) + (0.000511673279f * fVec6[((IOTA - 493) & 511)])) + (0.000856067054f * fVec6[((IOTA - 500) & 511)])) + (0.0030237711f * fVec6[((IOTA - 501) & 511)])) + (0.00510892831f * fVec6[((IOTA - 502) & 511)])) + (0.00744812703f * fVec6[((IOTA - 503) & 511)])) + (0.00992260408f * fVec6[((IOTA - 504) & 511)])) + (0.0114598721f * fVec6[((IOTA - 505) & 511)])) + (0.0114375185f * fVec6[((IOTA - 506) & 511)])) + (0.00985563546f * fVec6[((IOTA - 507) & 511)])) + (0.00739642559f * fVec6[((IOTA - 508) & 511)])) + (0.00541960401f * fVec6[((IOTA - 509) & 511)])) + (0.00456553511f * fVec6[((IOTA - 510) & 511)])) + (0.00459594373f * fVec6[((IOTA - 511) & 511)]))) : ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00374100916f * fVec5[((IOTA - 284) & 511)]) + ((0.007299372f * fVec5[((IOTA - 283) & 511)]) + ((0.00979614817f * fVec5[((IOTA - 282) & 511)]) + ((0.0102606546f * fVec5[((IOTA - 281) & 511)]) + ((0.00893353391f * fVec5[((IOTA - 280) & 511)]) + ((0.00707313325f * fVec5[((IOTA - 279) & 511)]) + ((0.00630379934f * fVec5[((IOTA - 278) & 511)]) + ((0.00673770439f * fVec5[((IOTA - 277) & 511)]) + ((0.00841375813f * fVec5[((IOTA - 276) & 511)]) + ((0.0116024017f * fVec5[((IOTA - 275) & 511)]) + ((0.0151289767f * fVec5[((IOTA - 274) & 511)]) + ((0.0172965135f * fVec5[((IOTA - 273) & 511)]) + ((0.0175200589f * fVec5[((IOTA - 272) & 511)]) + ((0.0157292653f * fVec5[((IOTA - 271) & 511)]) + ((0.0130050322f * fVec5[((IOTA - 270) & 511)]) + ((0.0113919768f * fVec5[((IOTA - 269) & 511)]) + ((0.0114656575f * fVec5[((IOTA - 268) & 511)]) + ((0.0127344625f * fVec5[((IOTA - 267) & 511)]) + ((0.0142115755f * fVec5[((IOTA - 266) & 511)]) + ((0.0144091696f * fVec5[((IOTA - 265) & 511)]) + ((0.0133446306f * fVec5[((IOTA - 264) & 511)]) + ((0.0115568526f * fVec5[((IOTA - 263) & 511)]) + ((0.00912237074f * fVec5[((IOTA - 262) & 511)]) + ((0.0071229809f * fVec5[((IOTA - 261) & 511)]) + ((0.00641972525f * fVec5[((IOTA - 260) & 511)]) + ((0.00776022207f * fVec5[((IOTA - 259) & 511)]) + ((0.0118283518f * fVec5[((IOTA - 258) & 511)]) + ((0.0160460249f * fVec5[((IOTA - 257) & 511)]) + ((0.0176508687f * fVec5[((IOTA - 256) & 511)]) + ((0.016052248f * fVec5[((IOTA - 255) & 511)]) + ((0.0113356505f * fVec5[((IOTA - 254) & 511)]) + ((0.00565420836f * fVec5[((IOTA - 253) & 511)]) + ((0.00177478697f * fVec5[((IOTA - 252) & 511)]) + ((0.000350761693f * fVec5[((IOTA - 251) & 511)]) + ((0.0015179785f * fVec5[((IOTA - 250) & 511)]) + ((0.00512230815f * fVec5[((IOTA - 249) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00104856445f * fVec5[((IOTA - 77) & 511)]) + ((0.0125371888f * fVec5[((IOTA - 76) & 511)]) + ((0.0106091388f * fVec5[((IOTA - 75) & 511)]) + (((((((((((((0.00605151383f * fVec5[((IOTA - 19) & 511)]) + ((0.0316457972f * fVec5[((IOTA - 18) & 511)]) + ((0.0428507626f * fVec5[((IOTA - 17) & 511)]) + ((0.0427167453f * fVec5[((IOTA - 16) & 511)]) + ((0.0526188761f * fVec5[((IOTA - 15) & 511)]) + ((0.0481564552f * fVec5[((IOTA - 14) & 511)]) + ((0.0267843381f * fVec5[((IOTA - 13) & 511)]) + ((0.0144708212f * fVec5[((IOTA - 12) & 511)]) + ((0.0204317495f * fVec5[((IOTA - 6) & 511)]) + ((0.112947837f * fVec5[((IOTA - 5) & 511)]) + ((0.189276502f * fVec5[((IOTA - 4) & 511)]) + ((0.238861442f * fVec5[((IOTA - 3) & 511)]) + ((0.259932399f * fVec5[((IOTA - 2) & 511)]) + ((0.20827499f * fVec5[((IOTA - 1) & 511)]) + ((fSlow23 * fTemp0) + ((0.0445962027f * fVec5[((IOTA - 27) & 511)]) + ((0.0386992022f * fVec5[((IOTA - 26) & 511)]) + (((0.000536840409f * fVec5[((IOTA - 24) & 511)]) + (0.0234365929f * fVec5[((IOTA - 25) & 511)])) + (0.0295902397f * fVec5[((IOTA - 28) & 511)]))))))))))))))))))) + (0.01729507f * fVec5[((IOTA - 42) & 511)])) + (0.026530128f * fVec5[((IOTA - 43) & 511)])) + (0.0132105164f * fVec5[((IOTA - 44) & 511)])) + (0.0267633907f * fVec5[((IOTA - 52) & 511)])) + (0.0578998066f * fVec5[((IOTA - 53) & 511)])) + (0.0623464137f * fVec5[((IOTA - 54) & 511)])) + (0.0373377278f * fVec5[((IOTA - 55) & 511)])) + (0.0088997893f * fVec5[((IOTA - 56) & 511)])) + (0.0132362433f * fVec5[((IOTA - 66) & 511)])) + (0.0136433635f * fVec5[((IOTA - 67) & 511)])) + (0.0115278233f * fVec5[((IOTA - 101) & 511)]))))) + (0.0204693452f * fVec5[((IOTA - 102) & 511)])) + (0.0207448211f * fVec5[((IOTA - 103) & 511)])) + (0.0111427391f * fVec5[((IOTA - 104) & 511)])) + (0.00903168879f * fVec5[((IOTA - 127) & 511)])) + (0.013747165f * fVec5[((IOTA - 128) & 511)])) + (0.0134105813f * fVec5[((IOTA - 129) & 511)])) + (0.0105452407f * fVec5[((IOTA - 130) & 511)])) + (0.00626418414f * fVec5[((IOTA - 131) & 511)])) + (0.000412638299f * fVec5[((IOTA - 132) & 511)])) + (0.00136182783f * fVec5[((IOTA - 136) & 511)])) + (0.00410184311f * fVec5[((IOTA - 137) & 511)])) + (0.00482511474f * fVec5[((IOTA - 138) & 511)])) + (0.005521602f * fVec5[((IOTA - 139) & 511)])) + (0.00539948512f * fVec5[((IOTA - 140) & 511)])) + (0.00137164351f * fVec5[((IOTA - 141) & 511)])) + (0.00416955771f * fVec5[((IOTA - 153) & 511)])) + (0.0074463808f * fVec5[((IOTA - 154) & 511)])) + (0.0067726681f * fVec5[((IOTA - 155) & 511)])) + (0.0016182512f * fVec5[((IOTA - 156) & 511)])) + (0.00178995915f * fVec5[((IOTA - 162) & 511)])) + (0.000329462811f * fVec5[((IOTA - 163) & 511)])) + (0.00381924491f * fVec5[((IOTA - 169) & 511)])) + (0.00786129665f * fVec5[((IOTA - 170) & 511)])) + (0.00820381474f * fVec5[((IOTA - 171) & 511)])) + (0.00538296532f * fVec5[((IOTA - 172) & 511)])) + (0.00277289422f * fVec5[((IOTA - 173) & 511)])) + (0.00187698426f * fVec5[((IOTA - 174) & 511)])) + (0.00130139478f * fVec5[((IOTA - 175) & 511)])) + (0.00308869174f * fVec5[((IOTA - 181) & 511)])) + (0.00697193062f * fVec5[((IOTA - 182) & 511)])) + (0.00877914764f * fVec5[((IOTA - 183) & 511)])) + (0.00979566667f * fVec5[((IOTA - 184) & 511)])) + (0.00993366167f * fVec5[((IOTA - 185) & 511)])) + (0.0081712883f * fVec5[((IOTA - 186) & 511)])) + (0.00529058371f * fVec5[((IOTA - 187) & 511)])) + (0.00484230788f * fVec5[((IOTA - 188) & 511)])) + (0.00763958041f * fVec5[((IOTA - 189) & 511)])) + (0.0112879202f * fVec5[((IOTA - 190) & 511)])) + (0.0133068766f * fVec5[((IOTA - 191) & 511)])) + (0.0116480477f * fVec5[((IOTA - 192) & 511)])) + (0.00717767235f * fVec5[((IOTA - 193) & 511)])) + (0.00333869969f * fVec5[((IOTA - 194) & 511)])) + (0.00236721663f * fVec5[((IOTA - 195) & 511)])) + (0.00337732071f * fVec5[((IOTA - 196) & 511)])) + (0.00443342282f * fVec5[((IOTA - 197) & 511)])) + (0.00485177059f * fVec5[((IOTA - 198) & 511)])) + (0.00483303796f * fVec5[((IOTA - 199) & 511)])) + (0.00452214759f * fVec5[((IOTA - 200) & 511)])) + (0.00401882781f * fVec5[((IOTA - 201) & 511)])) + (0.00327935722f * fVec5[((IOTA - 202) & 511)])) + (0.00312429713f * fVec5[((IOTA - 203) & 511)])) + (0.00535977399f * fVec5[((IOTA - 204) & 511)])) + (0.00896265917f * fVec5[((IOTA - 205) & 511)])) + (0.0107645197f * fVec5[((IOTA - 206) & 511)])) + (0.00916006137f * fVec5[((IOTA - 207) & 511)])) + (0.00554299727f * fVec5[((IOTA - 208) & 511)])) + (0.00298501924f * fVec5[((IOTA - 209) & 511)])) + (0.0022820523f * fVec5[((IOTA - 210) & 511)])) + (0.0033815545f * fVec5[((IOTA - 211) & 511)])) + (0.00638691057f * fVec5[((IOTA - 212) & 511)])) + (0.0110987611f * fVec5[((IOTA - 213) & 511)])) + (0.016675856f * fVec5[((IOTA - 214) & 511)])) + (0.0214022063f * fVec5[((IOTA - 215) & 511)])) + (0.0225627199f * fVec5[((IOTA - 216) & 511)])) + (0.0183503386f * fVec5[((IOTA - 217) & 511)])) + (0.00990206562f * fVec5[((IOTA - 218) & 511)])) + (0.00131252548f * fVec5[((IOTA - 219) & 511)])) + (0.000535364728f * fVec5[((IOTA - 223) & 511)])) + (0.00318152271f * fVec5[((IOTA - 224) & 511)])) + (0.00561584439f * fVec5[((IOTA - 225) & 511)])) + (0.00744227506f * fVec5[((IOTA - 226) & 511)])) + (0.00920936372f * fVec5[((IOTA - 227) & 511)])) + (0.0127355214f * fVec5[((IOTA - 228) & 511)])) + (0.0180380382f * fVec5[((IOTA - 229) & 511)])) + (0.0220255591f * fVec5[((IOTA - 230) & 511)])) + (0.0229535773f * fVec5[((IOTA - 231) & 511)])) + (0.0205736272f * fVec5[((IOTA - 232) & 511)])) + (0.0152300512f * fVec5[((IOTA - 233) & 511)])) + (0.00958203338f * fVec5[((IOTA - 234) & 511)])) + (0.00679521821f * fVec5[((IOTA - 235) & 511)])) + (0.00826225895f * fVec5[((IOTA - 236) & 511)])) + (0.0121269245f * fVec5[((IOTA - 237) & 511)])) + (0.0149349757f * fVec5[((IOTA - 238) & 511)])) + (0.0157100186f * fVec5[((IOTA - 239) & 511)])) + (0.0147368358f * fVec5[((IOTA - 240) & 511)])) + (0.0115211513f * fVec5[((IOTA - 241) & 511)])) + (0.00699576363f * fVec5[((IOTA - 242) & 511)])) + (0.0033973367f * fVec5[((IOTA - 243) & 511)])) + (0.00278598163f * fVec5[((IOTA - 244) & 511)])) + (0.00605671015f * fVec5[((IOTA - 245) & 511)])) + (0.0101060113f * fVec5[((IOTA - 246) & 511)])) + (0.0111276302f * fVec5[((IOTA - 247) & 511)])) + (0.00899040606f * fVec5[((IOTA - 248) & 511)])) + (0.00125898933f * fVec5[((IOTA - 285) & 511)])))))))))))))))))))))))))))))))))))))) + (0.000878524035f * fVec5[((IOTA - 286) & 511)])) + (0.00198100973f * fVec5[((IOTA - 287) & 511)])) + (0.0040411856f * fVec5[((IOTA - 288) & 511)])) + (0.00680099241f * fVec5[((IOTA - 289) & 511)])) + (0.0100149121f * fVec5[((IOTA - 290) & 511)])) + (0.0131869409f * fVec5[((IOTA - 291) & 511)])) + (0.0154437805f * fVec5[((IOTA - 292) & 511)])) + (0.015655553f * fVec5[((IOTA - 293) & 511)])) + (0.0126949437f * fVec5[((IOTA - 294) & 511)])) + (0.00746190641f * fVec5[((IOTA - 295) & 511)])) + (0.00240298221f * fVec5[((IOTA - 296) & 511)])) + (0.00194306253f * fVec5[((IOTA - 299) & 511)])) + (0.00877135247f * fVec5[((IOTA - 300) & 511)])) + (0.0148548791f * fVec5[((IOTA - 301) & 511)])) + (0.0181422234f * fVec5[((IOTA - 302) & 511)])) + (0.0181070995f * fVec5[((IOTA - 303) & 511)])) + (0.0157362577f * fVec5[((IOTA - 304) & 511)])) + (0.0126944948f * fVec5[((IOTA - 305) & 511)])) + (0.00951759145f * fVec5[((IOTA - 306) & 511)])) + (0.00718549918f * fVec5[((IOTA - 307) & 511)])) + (0.00604307745f * fVec5[((IOTA - 308) & 511)])) + (0.00550405588f * fVec5[((IOTA - 309) & 511)])) + (0.00624298118f * fVec5[((IOTA - 310) & 511)])) + (0.00847794488f * fVec5[((IOTA - 311) & 511)])) + (0.0111354571f * fVec5[((IOTA - 312) & 511)])) + (0.013176579f * fVec5[((IOTA - 313) & 511)])) + (0.0137872612f * fVec5[((IOTA - 314) & 511)])) + (0.0127258338f * fVec5[((IOTA - 315) & 511)])) + (0.0104994997f * fVec5[((IOTA - 316) & 511)])) + (0.0072356672f * fVec5[((IOTA - 317) & 511)])) + (0.00371133815f * fVec5[((IOTA - 318) & 511)])) + (0.00149247749f * fVec5[((IOTA - 319) & 511)])) + (0.000457000453f * fVec5[((IOTA - 320) & 511)])) + (0.000201764051f * fVec5[((IOTA - 321) & 511)])) + (0.000366736203f * fVec5[((IOTA - 322) & 511)])) + (1.2927223e-05f * fVec5[((IOTA - 323) & 511)])) + (0.000967569649f * fVec5[((IOTA - 325) & 511)])) + (0.00294643035f * fVec5[((IOTA - 326) & 511)])) + (0.00431246078f * fVec5[((IOTA - 327) & 511)])) + (0.00438848278f * fVec5[((IOTA - 328) & 511)])) + (0.00326861162f * fVec5[((IOTA - 329) & 511)])) + (0.00115008792f * fVec5[((IOTA - 330) & 511)])) + (4.02564183e-05f * fVec5[((IOTA - 333) & 511)])) + (0.00343092112f * fVec5[((IOTA - 334) & 511)])) + (0.00665735174f * fVec5[((IOTA - 335) & 511)])) + (0.00768487342f * fVec5[((IOTA - 336) & 511)])) + (0.00612971745f * fVec5[((IOTA - 337) & 511)])) + (0.00366139412f * fVec5[((IOTA - 338) & 511)])) + (0.00174944615f * fVec5[((IOTA - 339) & 511)])) + (0.00220266171f * fVec5[((IOTA - 340) & 511)])) + (0.0056450665f * fVec5[((IOTA - 341) & 511)])) + (0.00992779154f * fVec5[((IOTA - 342) & 511)])) + (0.0122439731f * fVec5[((IOTA - 343) & 511)])) + (0.011338409f * fVec5[((IOTA - 344) & 511)])) + (0.00869395025f * fVec5[((IOTA - 345) & 511)])) + (0.00711387116f * fVec5[((IOTA - 346) & 511)])) + (0.00724095991f * fVec5[((IOTA - 347) & 511)])) + (0.00832525827f * fVec5[((IOTA - 348) & 511)])) + (0.00986838527f * fVec5[((IOTA - 349) & 511)])) + (0.0108502293f * fVec5[((IOTA - 350) & 511)])) + (0.0102816327f * fVec5[((IOTA - 351) & 511)])) + (0.00819807313f * fVec5[((IOTA - 352) & 511)])) + (0.00452978211f * fVec5[((IOTA - 353) & 511)])) + (0.000487730373f * fVec5[((IOTA - 358) & 511)])) + (0.00449215574f * fVec5[((IOTA - 359) & 511)])) + (0.00678405585f * fVec5[((IOTA - 360) & 511)])) + (0.00668923603f * fVec5[((IOTA - 361) & 511)])) + (0.00442505069f * fVec5[((IOTA - 362) & 511)])) + (0.00175801059f * fVec5[((IOTA - 363) & 511)])) + (0.000439711381f * fVec5[((IOTA - 364) & 511)])) + (0.000189735088f * fVec5[((IOTA - 365) & 511)])) + (0.0019429666f * fVec5[((IOTA - 376) & 511)])) + (0.00336304633f * fVec5[((IOTA - 377) & 511)])) + (0.00221376028f * fVec5[((IOTA - 378) & 511)])) + (0.00141360005f * fVec5[((IOTA - 383) & 511)])) + (0.00506668631f * fVec5[((IOTA - 384) & 511)])) + (0.00548570789f * fVec5[((IOTA - 385) & 511)])) + (0.00358768133f * fVec5[((IOTA - 386) & 511)])) + (0.000567056704f * fVec5[((IOTA - 387) & 511)])) + (0.00270367181f * fVec5[((IOTA - 391) & 511)])) + (0.00647364696f * fVec5[((IOTA - 392) & 511)])) + (0.00797314942f * fVec5[((IOTA - 393) & 511)])) + (0.00695746392f * fVec5[((IOTA - 394) & 511)])) + (0.00383217214f * fVec5[((IOTA - 395) & 511)])) + (0.00353613356f * fVec5[((IOTA - 418) & 511)])) + (0.00524230814f * fVec5[((IOTA - 419) & 511)])) + (0.00399204344f * fVec5[((IOTA - 420) & 511)])) + (0.00131874857f * fVec5[((IOTA - 421) & 511)])) + (0.0016183476f * fVec5[((IOTA - 486) & 511)])) + (0.00252173143f * fVec5[((IOTA - 487) & 511)])) + (0.000960673206f * fVec5[((IOTA - 488) & 511)])) + (0.000397915021f * fVec5[((IOTA - 496) & 511)])) + (0.00123175606f * fVec5[((IOTA - 497) & 511)])) + (0.00201606983f * fVec5[((IOTA - 498) & 511)])) + (0.00271637458f * fVec5[((IOTA - 499) & 511)])) + (0.00286687957f * fVec5[((IOTA - 500) & 511)])) + (0.00186254969f * fVec5[((IOTA - 501) & 511)])) - ((((((((((((((((((((((((((((((((((((((((((((((((((0.00406174688f * fVec5[((IOTA - 453) & 511)]) + ((0.0070424038f * fVec5[((IOTA - 452) & 511)]) + ((0.00934617221f * fVec5[((IOTA - 451) & 511)]) + ((0.0101479683f * fVec5[((IOTA - 450) & 511)]) + ((0.00916698948f * fVec5[((IOTA - 449) & 511)]) + ((0.00770883495f * fVec5[((IOTA - 448) & 511)]) + ((0.00693058316f * fVec5[((IOTA - 447) & 511)]) + ((0.00738312537f * fVec5[((IOTA - 446) & 511)]) + ((0.009670984f * fVec5[((IOTA - 445) & 511)]) + ((0.0127663799f * fVec5[((IOTA - 444) & 511)]) + ((0.01483698f * fVec5[((IOTA - 443) & 511)]) + ((0.0151916556f * fVec5[((IOTA - 442) & 511)]) + ((0.014173436f * fVec5[((IOTA - 441) & 511)]) + ((0.0126320729f * fVec5[((IOTA - 440) & 511)]) + ((0.0116428509f * fVec5[((IOTA - 439) & 511)]) + ((0.0115171736f * fVec5[((IOTA - 438) & 511)]) + ((0.0115813911f * fVec5[((IOTA - 437) & 511)]) + ((0.0115291066f * fVec5[((IOTA - 436) & 511)]) + ((0.0116287051f * fVec5[((IOTA - 435) & 511)]) + ((0.0114706941f * fVec5[((IOTA - 434) & 511)]) + ((0.0109494105f * fVec5[((IOTA - 433) & 511)]) + ((0.0105048567f * fVec5[((IOTA - 432) & 511)]) + ((0.00949610025f * fVec5[((IOTA - 431) & 511)]) + ((0.00708230725f * fVec5[((IOTA - 430) & 511)]) + ((0.00422963779f * fVec5[((IOTA - 429) & 511)]) + ((0.00203162711f * fVec5[((IOTA - 428) & 511)]) + ((0.00102036865f * fVec5[((IOTA - 427) & 511)]) + ((0.00127226906f * fVec5[((IOTA - 426) & 511)]) + ((0.00222755363f * fVec5[((IOTA - 425) & 511)]) + ((0.00304894848f * fVec5[((IOTA - 424) & 511)]) + ((0.00273119379f * fVec5[((IOTA - 423) & 511)]) + ((0.00114229321f * fVec5[((IOTA - 422) & 511)]) + ((0.000703928992f * fVec5[((IOTA - 417) & 511)]) + ((0.00502495421f * fVec5[((IOTA - 416) & 511)]) + ((0.00755711086f * fVec5[((IOTA - 415) & 511)]) + ((0.00865507312f * fVec5[((IOTA - 414) & 511)]) + ((0.00883800909f * fVec5[((IOTA - 413) & 511)]) + ((0.00783329364f * fVec5[((IOTA - 412) & 511)]) + ((0.00590675045f * fVec5[((IOTA - 411) & 511)]) + ((0.00409658253f * fVec5[((IOTA - 410) & 511)]) + ((0.0032353159f * fVec5[((IOTA - 409) & 511)]) + ((0.00290270941f * fVec5[((IOTA - 408) & 511)]) + ((0.000516471453f * fVec5[((IOTA - 406) & 511)]) + ((8.36886466e-05f * fVec5[((IOTA - 405) & 511)]) + ((0.000780785456f * fVec5[((IOTA - 404) & 511)]) + ((0.0019987803f * fVec5[((IOTA - 403) & 511)]) + ((0.0039300709f * fVec5[((IOTA - 402) & 511)]) + ((0.00674780877f * fVec5[((IOTA - 401) & 511)]) + ((0.00984054245f * fVec5[((IOTA - 400) & 511)]) + ((0.0113186492f * fVec5[((IOTA - 399) & 511)]) + ((0.00960577093f * fVec5[((IOTA - 398) & 511)]) + ((0.00552019058f * fVec5[((IOTA - 397) & 511)]) + ((0.000692638103f * fVec5[((IOTA - 396) & 511)]) + ((0.0010148515f * fVec5[((IOTA - 390) & 511)]) + ((0.00271255709f * fVec5[((IOTA - 389) & 511)]) + ((0.00203335937f * fVec5[((IOTA - 388) & 511)]) + ((0.0037248102f * fVec5[((IOTA - 382) & 511)]) + ((0.00688808132f * fVec5[((IOTA - 381) & 511)]) + ((0.00603399985f * fVec5[((IOTA - 380) & 511)]) + ((0.00181642268f * fVec5[((IOTA - 379) & 511)]) + ((0.0016357014f * fVec5[((IOTA - 375) & 511)]) + ((0.00607762439f * fVec5[((IOTA - 374) & 511)]) + ((0.00919669308f * fVec5[((IOTA - 373) & 511)]) + ((0.01023403f * fVec5[((IOTA - 372) & 511)]) + ((0.00866389461f * fVec5[((IOTA - 371) & 511)]) + ((0.00556615693f * fVec5[((IOTA - 370) & 511)]) + ((0.00356602948f * fVec5[((IOTA - 369) & 511)]) + ((0.00268266164f * fVec5[((IOTA - 368) & 511)]) + ((0.00148311118f * fVec5[((IOTA - 367) & 511)]) + ((0.000291772187f * fVec5[((IOTA - 366) & 511)]) + ((0.00365347136f * fVec5[((IOTA - 357) & 511)]) + ((0.00561568374f * fVec5[((IOTA - 356) & 511)]) + ((0.00428824266f * fVec5[((IOTA - 355) & 511)]) + ((0.000312205404f * fVec5[((IOTA - 354) & 511)]) + ((0.00182800274f * fVec5[((IOTA - 332) & 511)]) + ((0.00117985532f * fVec5[((IOTA - 331) & 511)]) + ((0.000208596699f * fVec5[((IOTA - 324) & 511)]) + (((0.00192423351f * fVec5[((IOTA - 298) & 511)]) + ((0.00115826726f * fVec5[((IOTA - 297) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0746757761f * fVec5[((IOTA - 7) & 511)]) + (0.115776613f * fVec5[((IOTA - 8) & 511)])) + (0.0840260237f * fVec5[((IOTA - 9) & 511)])) + (0.0378716141f * fVec5[((IOTA - 10) & 511)])) + (0.00411611749f * fVec5[((IOTA - 11) & 511)])) + (0.0104050655f * fVec5[((IOTA - 20) & 511)])) + (0.0182505473f * fVec5[((IOTA - 21) & 511)])) + (0.021040218f * fVec5[((IOTA - 22) & 511)])) + (0.017291991f * fVec5[((IOTA - 23) & 511)])) + (0.00646950863f * fVec5[((IOTA - 29) & 511)])) + (0.0436159931f * fVec5[((IOTA - 30) & 511)])) + (0.0677918345f * fVec5[((IOTA - 31) & 511)])) + (0.0774198622f * fVec5[((IOTA - 32) & 511)])) + (0.0702439249f * fVec5[((IOTA - 33) & 511)])) + (0.0397782698f * fVec5[((IOTA - 34) & 511)])) + (0.0121080317f * fVec5[((IOTA - 35) & 511)])) + (0.0053683063f * fVec5[((IOTA - 36) & 511)])) + (0.0107712243f * fVec5[((IOTA - 37) & 511)])) + (0.0264606494f * fVec5[((IOTA - 38) & 511)])) + (0.0363447517f * fVec5[((IOTA - 39) & 511)])) + (0.0254494864f * fVec5[((IOTA - 40) & 511)])) + (0.00587149756f * fVec5[((IOTA - 41) & 511)])) + (0.0118725859f * fVec5[((IOTA - 45) & 511)])) + (0.0549601093f * fVec5[((IOTA - 46) & 511)])) + (0.0942602456f * fVec5[((IOTA - 47) & 511)])) + (0.10390114f * fVec5[((IOTA - 48) & 511)])) + (0.0922031179f * fVec5[((IOTA - 49) & 511)])) + (0.0616588742f * fVec5[((IOTA - 50) & 511)])) + (0.0158752482f * fVec5[((IOTA - 51) & 511)])) + (0.0231054947f * fVec5[((IOTA - 57) & 511)])) + (0.0514168888f * fVec5[((IOTA - 58) & 511)])) + (0.0618152805f * fVec5[((IOTA - 59) & 511)])) + (0.0638877079f * fVec5[((IOTA - 60) & 511)])) + (0.0598275363f * fVec5[((IOTA - 61) & 511)])) + (0.0517009608f * fVec5[((IOTA - 62) & 511)])) + (0.0384659693f * fVec5[((IOTA - 63) & 511)])) + (0.0198147818f * fVec5[((IOTA - 64) & 511)])) + (0.00174139487f * fVec5[((IOTA - 65) & 511)])) + (0.003607505f * fVec5[((IOTA - 68) & 511)])) + (0.0251940582f * fVec5[((IOTA - 69) & 511)])) + (0.0454174988f * fVec5[((IOTA - 70) & 511)])) + (0.0565295108f * fVec5[((IOTA - 71) & 511)])) + (0.0529997274f * fVec5[((IOTA - 72) & 511)])) + (0.0368860811f * fVec5[((IOTA - 73) & 511)])) + (0.0111837331f * fVec5[((IOTA - 74) & 511)])) + (0.00887650065f * fVec5[((IOTA - 78) & 511)])) + (0.0124651445f * fVec5[((IOTA - 79) & 511)])) + (0.01071156f * fVec5[((IOTA - 80) & 511)])) + (0.0105632367f * fVec5[((IOTA - 81) & 511)])) + (0.0124920886f * fVec5[((IOTA - 82) & 511)])) + (0.0143120727f * fVec5[((IOTA - 83) & 511)])) + (0.0138931153f * fVec5[((IOTA - 84) & 511)])) + (0.0126347989f * fVec5[((IOTA - 85) & 511)])) + (0.011139499f * fVec5[((IOTA - 86) & 511)])) + (0.00880256295f * fVec5[((IOTA - 87) & 511)])) + (0.00740387896f * fVec5[((IOTA - 88) & 511)])) + (0.0102840383f * fVec5[((IOTA - 89) & 511)])) + (0.0158137567f * fVec5[((IOTA - 90) & 511)])) + (0.0192007311f * fVec5[((IOTA - 91) & 511)])) + (0.0215629768f * fVec5[((IOTA - 92) & 511)])) + (0.0235941224f * fVec5[((IOTA - 93) & 511)])) + (0.0213886052f * fVec5[((IOTA - 94) & 511)])) + (0.0203040186f * fVec5[((IOTA - 95) & 511)])) + (0.024816256f * fVec5[((IOTA - 96) & 511)])) + (0.0303607285f * fVec5[((IOTA - 97) & 511)])) + (0.0303597655f * fVec5[((IOTA - 98) & 511)])) + (0.0209631696f * fVec5[((IOTA - 99) & 511)])) + (0.00422854722f * fVec5[((IOTA - 100) & 511)])) + (0.00435656635f * fVec5[((IOTA - 105) & 511)])) + (0.0202744119f * fVec5[((IOTA - 106) & 511)])) + (0.0313818343f * fVec5[((IOTA - 107) & 511)])) + (0.0344023295f * fVec5[((IOTA - 108) & 511)])) + (0.0298822038f * fVec5[((IOTA - 109) & 511)])) + (0.0213396568f * fVec5[((IOTA - 110) & 511)])) + (0.0141962431f * fVec5[((IOTA - 111) & 511)])) + (0.00938860979f * fVec5[((IOTA - 112) & 511)])) + (0.00629658205f * fVec5[((IOTA - 113) & 511)])) + (0.0045827413f * fVec5[((IOTA - 114) & 511)])) + (0.00346729625f * fVec5[((IOTA - 115) & 511)])) + (0.00644179434f * fVec5[((IOTA - 116) & 511)])) + (0.0109412316f * fVec5[((IOTA - 117) & 511)])) + (0.016291799f * fVec5[((IOTA - 118) & 511)])) + (0.0238175057f * fVec5[((IOTA - 119) & 511)])) + (0.0320918262f * fVec5[((IOTA - 120) & 511)])) + (0.0382766835f * fVec5[((IOTA - 121) & 511)])) + (0.0400860161f * fVec5[((IOTA - 122) & 511)])) + (0.0362337008f * fVec5[((IOTA - 123) & 511)])) + (0.0272065345f * fVec5[((IOTA - 124) & 511)])) + (0.0137271807f * fVec5[((IOTA - 125) & 511)])) + (0.000501010101f * fVec5[((IOTA - 126) & 511)])) + (0.00347679108f * fVec5[((IOTA - 133) & 511)])) + (0.00371582899f * fVec5[((IOTA - 134) & 511)])) + (0.00190906134f * fVec5[((IOTA - 135) & 511)])) + (0.00434094481f * fVec5[((IOTA - 142) & 511)])) + (0.00773975719f * fVec5[((IOTA - 143) & 511)])) + (0.00757176988f * fVec5[((IOTA - 144) & 511)])) + (0.00640862668f * fVec5[((IOTA - 145) & 511)])) + (0.00691101607f * fVec5[((IOTA - 146) & 511)])) + (0.00882594753f * fVec5[((IOTA - 147) & 511)])) + (0.0105120409f * fVec5[((IOTA - 148) & 511)])) + (0.0112636369f * fVec5[((IOTA - 149) & 511)])) + (0.00961988419f * fVec5[((IOTA - 150) & 511)])) + (0.00573055167f * fVec5[((IOTA - 151) & 511)])) + (0.000673648436f * fVec5[((IOTA - 152) & 511)])) + (0.00532333413f * fVec5[((IOTA - 157) & 511)])) + (0.00989847258f * fVec5[((IOTA - 158) & 511)])) + (0.00986998901f * fVec5[((IOTA - 159) & 511)])) + (0.00572468154f * fVec5[((IOTA - 160) & 511)])) + (0.000610007904f * fVec5[((IOTA - 161) & 511)])) + (0.00268445769f * fVec5[((IOTA - 164) & 511)])) + (0.00485090446f * fVec5[((IOTA - 165) & 511)])) + (0.00583403185f * fVec5[((IOTA - 166) & 511)])) + (0.00497985398f * fVec5[((IOTA - 167) & 511)])) + (0.00152384862f * fVec5[((IOTA - 168) & 511)])) + (0.000768660568f * fVec5[((IOTA - 176) & 511)])) + (0.00440939702f * fVec5[((IOTA - 177) & 511)])) + (0.00709084002f * fVec5[((IOTA - 178) & 511)])) + (0.00648862682f * fVec5[((IOTA - 179) & 511)])) + (0.00235098554f * fVec5[((IOTA - 180) & 511)])) + (0.00315258931f * fVec5[((IOTA - 220) & 511)])) + (0.00332663907f * fVec5[((IOTA - 221) & 511)])) + (0.00164285442f * fVec5[((IOTA - 222) & 511)])) + (0.0019387966f * fVec5[((IOTA - 407) & 511)])))) + (0.00179913314f * fVec5[((IOTA - 454) & 511)]))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00174161931f * fVec5[((IOTA - 455) & 511)])) + (0.00453834655f * fVec5[((IOTA - 456) & 511)])) + (0.00925969239f * fVec5[((IOTA - 457) & 511)])) + (0.0130208461f * fVec5[((IOTA - 458) & 511)])) + (0.0136346389f * fVec5[((IOTA - 459) & 511)])) + (0.0112354094f * fVec5[((IOTA - 460) & 511)])) + (0.00714787282f * fVec5[((IOTA - 461) & 511)])) + (0.00337587716f * fVec5[((IOTA - 462) & 511)])) + (0.00222431356f * fVec5[((IOTA - 463) & 511)])) + (0.0045819073f * fVec5[((IOTA - 464) & 511)])) + (0.00900480896f * fVec5[((IOTA - 465) & 511)])) + (0.0126806051f * fVec5[((IOTA - 466) & 511)])) + (0.0132132117f * fVec5[((IOTA - 467) & 511)])) + (0.0103119779f * fVec5[((IOTA - 468) & 511)])) + (0.00620096037f * fVec5[((IOTA - 469) & 511)])) + (0.00303717609f * fVec5[((IOTA - 470) & 511)])) + (0.00157061685f * fVec5[((IOTA - 471) & 511)])) + (0.00161504373f * fVec5[((IOTA - 472) & 511)])) + (0.00230206829f * fVec5[((IOTA - 473) & 511)])) + (0.00260635046f * fVec5[((IOTA - 474) & 511)])) + (0.00172327133f * fVec5[((IOTA - 475) & 511)])) + (7.93263316e-05f * fVec5[((IOTA - 476) & 511)])) + (0.000112365466f * fVec5[((IOTA - 477) & 511)])) + (0.00315451389f * fVec5[((IOTA - 478) & 511)])) + (0.0077424515f * fVec5[((IOTA - 479) & 511)])) + (0.0119600603f * fVec5[((IOTA - 480) & 511)])) + (0.0149724735f * fVec5[((IOTA - 481) & 511)])) + (0.0158297624f * fVec5[((IOTA - 482) & 511)])) + (0.0135390498f * fVec5[((IOTA - 483) & 511)])) + (0.00862909108f * fVec5[((IOTA - 484) & 511)])) + (0.00266299816f * fVec5[((IOTA - 485) & 511)])) + (0.00205289433f * fVec5[((IOTA - 489) & 511)])) + (0.00537003856f * fVec5[((IOTA - 490) & 511)])) + (0.00748455245f * fVec5[((IOTA - 491) & 511)])) + (0.00751371076f * fVec5[((IOTA - 492) & 511)])) + (0.0055285627f * fVec5[((IOTA - 493) & 511)])) + (0.00293693552f * fVec5[((IOTA - 494) & 511)])) + (0.000919518527f * fVec5[((IOTA - 495) & 511)])) + (0.00160824321f * fVec5[((IOTA - 502) & 511)])) + (0.00743361423f * fVec5[((IOTA - 503) & 511)])) + (0.0131314471f * fVec5[((IOTA - 504) & 511)])) + (0.0173486397f * fVec5[((IOTA - 505) & 511)])) + (0.0195908193f * fVec5[((IOTA - 506) & 511)])) + (0.0184697621f * fVec5[((IOTA - 507) & 511)])) + (0.0140947513f * fVec5[((IOTA - 508) & 511)])) + (0.00890219398f * fVec5[((IOTA - 509) & 511)])) + (0.00531412847f * fVec5[((IOTA - 510) & 511)])) + (0.00457879575f * fVec5[((IOTA - 511) & 511)])))) : (iSlow16 ? ((((((((((((((0.000254721381f * (fVec4[((IOTA - 170) & 511)] - fVec4[((IOTA - 390) & 511)])) + ((0.000456425827f * fVec4[((IOTA - 387) & 511)]) + ((0.00115764933f * fVec4[((IOTA - 386) & 511)]) + ((0.00165713765f * fVec4[((IOTA - 385) & 511)]) + ((0.00146491546f * fVec4[((IOTA - 384) & 511)]) + ((0.000616453122f * fVec4[((IOTA - 383) & 511)]) + ((5.85927628e-05f * fVec4[((IOTA - 382) & 511)]) + ((0.000104616396f * fVec4[((IOTA - 380) & 511)]) + ((0.000783380121f * fVec4[((IOTA - 379) & 511)]) + ((0.00125772972f * fVec4[((IOTA - 378) & 511)]) + ((0.00116899004f * fVec4[((IOTA - 377) & 511)]) + ((0.000491392333f * fVec4[((IOTA - 376) & 511)]) + ((0.000634566881f * fVec4[((IOTA - 369) & 511)]) + ((0.000880498905f * fVec4[((IOTA - 368) & 511)]) + ((0.000146734063f * fVec4[((IOTA - 367) & 511)]) + ((0.000633810647f * fVec4[((IOTA - 356) & 511)]) + ((0.0012947442f * fVec4[((IOTA - 355) & 511)]) + ((0.0020349985f * fVec4[((IOTA - 354) & 511)]) + ((0.00290362164f * fVec4[((IOTA - 353) & 511)]) + ((0.00341898669f * fVec4[((IOTA - 352) & 511)]) + ((0.00384312309f * fVec4[((IOTA - 351) & 511)]) + ((0.00359593052f * fVec4[((IOTA - 350) & 511)]) + ((0.00251936587f * fVec4[((IOTA - 349) & 511)]) + ((0.00139841577f * fVec4[((IOTA - 348) & 511)]) + ((0.000414591748f * fVec4[((IOTA - 347) & 511)]) + ((0.000258879736f * fVec4[((IOTA - 346) & 511)]) + ((0.00138568925f * fVec4[((IOTA - 345) & 511)]) + ((0.00278883008f * fVec4[((IOTA - 344) & 511)]) + ((0.00389327342f * fVec4[((IOTA - 343) & 511)]) + ((0.0042673857f * fVec4[((IOTA - 342) & 511)]) + ((0.00366284f * fVec4[((IOTA - 341) & 511)]) + ((0.00305249775f * fVec4[((IOTA - 340) & 511)]) + ((0.00290399976f * fVec4[((IOTA - 338) & 511)]) + ((0.00340229087f * fVec4[((IOTA - 337) & 511)]) + ((0.00390864629f * fVec4[((IOTA - 336) & 511)]) + ((0.00373841217f * fVec4[((IOTA - 335) & 511)]) + ((0.00307458034f * fVec4[((IOTA - 334) & 511)]) + ((0.00188123947f * fVec4[((IOTA - 333) & 511)]) + ((0.000854699407f * fVec4[((IOTA - 332) & 511)]) + ((0.000872970093f * fVec4[((IOTA - 331) & 511)]) + ((0.00145294471f * fVec4[((IOTA - 330) & 511)]) + ((0.00188936712f * fVec4[((IOTA - 329) & 511)]) + ((0.00167112425f * fVec4[((IOTA - 328) & 511)]) + ((0.000701696612f * fVec4[((IOTA - 327) & 511)]) + ((0.000246405136f * fVec4[((IOTA - 326) & 511)]) + ((0.000519586261f * fVec4[((IOTA - 325) & 511)]) + ((0.000588101801f * fVec4[((IOTA - 324) & 511)]) + ((0.000719022471f * fVec4[((IOTA - 323) & 511)]) + ((0.000888532028f * fVec4[((IOTA - 322) & 511)]) + ((0.000895052683f * fVec4[((IOTA - 321) & 511)]) + ((0.00104005449f * fVec4[((IOTA - 320) & 511)]) + ((0.000623667147f * fVec4[((IOTA - 319) & 511)]) + ((0.000735119451f * fVec4[((IOTA - 313) & 511)]) + ((0.00258652726f * fVec4[((IOTA - 312) & 511)]) + ((0.00423522247f * fVec4[((IOTA - 311) & 511)]) + ((0.00499702385f * fVec4[((IOTA - 310) & 511)]) + ((0.00525489543f * fVec4[((IOTA - 309) & 511)]) + ((0.00481125945f * fVec4[((IOTA - 308) & 511)]) + ((0.00405815244f * fVec4[((IOTA - 307) & 511)]) + ((0.00400444213f * fVec4[((IOTA - 306) & 511)]) + ((0.00444839336f * fVec4[((IOTA - 305) & 511)]) + ((0.00493890373f * fVec4[((IOTA - 304) & 511)]) + ((0.00514634093f * fVec4[((IOTA - 303) & 511)]) + ((0.00489952648f * fVec4[((IOTA - 302) & 511)]) + ((0.00477011828f * fVec4[((IOTA - 301) & 511)]) + ((0.00288796518f * fVec4[((IOTA - 339) & 511)]) + ((0.00458120368f * fVec4[((IOTA - 300) & 511)]) + ((0.0039537563f * fVec4[((IOTA - 299) & 511)]) + ((0.00342755485f * fVec4[((IOTA - 298) & 511)]) + ((0.00323044974f * fVec4[((IOTA - 297) & 511)]) + ((0.00330513995f * fVec4[((IOTA - 296) & 511)]) + ((0.00388183864f * fVec4[((IOTA - 295) & 511)]) + ((0.00455779815f * fVec4[((IOTA - 294) & 511)]) + ((0.00483787805f * fVec4[((IOTA - 293) & 511)]) + ((0.00492227077f * fVec4[((IOTA - 292) & 511)]) + ((0.00473187538f * fVec4[((IOTA - 291) & 511)]) + ((0.00420198822f * fVec4[((IOTA - 290) & 511)]) + ((0.00339643145f * fVec4[((IOTA - 289) & 511)]) + ((0.00214988459f * fVec4[((IOTA - 288) & 511)]) + ((0.0010506073f * fVec4[((IOTA - 287) & 511)]) + ((0.000791633502f * fVec4[((IOTA - 286) & 511)]) + ((0.00135075394f * fVec4[((IOTA - 285) & 511)]) + ((0.00256529497f * fVec4[((IOTA - 284) & 511)]) + ((0.00376244774f * fVec4[((IOTA - 283) & 511)]) + ((0.00433549192f * fVec4[((IOTA - 282) & 511)]) + ((0.00336697744f * fVec4[((IOTA - 280) & 511)]) + ((0.00176849542f * fVec4[((IOTA - 279) & 511)]) + ((0.000559278298f * fVec4[((IOTA - 278) & 511)]) + ((0.00018759165f * fVec4[((IOTA - 277) & 511)]) + ((0.000681567006f * fVec4[((IOTA - 276) & 511)]) + ((0.00207667518f * fVec4[((IOTA - 275) & 511)]) + ((0.00355775096f * fVec4[((IOTA - 274) & 511)]) + ((0.00433624769f * fVec4[((IOTA - 273) & 511)]) + ((0.0042383098f * fVec4[((IOTA - 272) & 511)]) + ((0.00366712408f * fVec4[((IOTA - 271) & 511)]) + ((0.00337034836f * fVec4[((IOTA - 270) & 511)]) + ((0.00350674987f * fVec4[((IOTA - 269) & 511)]) + ((0.00378604233f * fVec4[((IOTA - 268) & 511)]) + ((0.00414563203f * fVec4[((IOTA - 267) & 511)]) + ((0.00426127436f * fVec4[((IOTA - 266) & 511)]) + ((0.00383874448f * fVec4[((IOTA - 265) & 511)]) + ((0.00335736945f * fVec4[((IOTA - 264) & 511)]) + ((0.00333005749f * fVec4[((IOTA - 263) & 511)]) + ((0.00410222309f * fVec4[((IOTA - 262) & 511)]) + ((0.00579439057f * fVec4[((IOTA - 261) & 511)]) + ((0.00722040143f * fVec4[((IOTA - 260) & 511)]) + ((0.0076774573f * fVec4[((IOTA - 259) & 511)]) + ((0.00746523123f * fVec4[((IOTA - 258) & 511)]) + ((0.00656082248f * fVec4[((IOTA - 257) & 511)]) + ((0.00572817447f * fVec4[((IOTA - 256) & 511)]) + ((0.00543788774f * fVec4[((IOTA - 255) & 511)]) + ((0.00490497658f * fVec4[((IOTA - 254) & 511)]) + ((0.00433023134f * fVec4[((IOTA - 253) & 511)]) + ((0.00407188712f * fVec4[((IOTA - 252) & 511)]) + ((0.00394657394f * fVec4[((IOTA - 251) & 511)]) + ((0.00429828838f * fVec4[((IOTA - 250) & 511)]) + ((0.00449321978f * fVec4[((IOTA - 249) & 511)]) + ((0.00371957384f * fVec4[((IOTA - 248) & 511)]) + ((0.00272412598f * fVec4[((IOTA - 247) & 511)]) + ((0.00189922703f * fVec4[((IOTA - 246) & 511)]) + ((0.00122257415f * fVec4[((IOTA - 245) & 511)]) + ((0.00106853154f * fVec4[((IOTA - 244) & 511)]) + ((0.0012533511f * fVec4[((IOTA - 243) & 511)]) + ((0.00180752622f * fVec4[((IOTA - 242) & 511)]) + ((0.00271769939f * fVec4[((IOTA - 241) & 511)]) + ((0.00274775224f * fVec4[((IOTA - 240) & 511)]) + ((0.00204826053f * fVec4[((IOTA - 239) & 511)]) + ((0.00177860772f * fVec4[((IOTA - 238) & 511)]) + ((0.00427545002f * fVec4[((IOTA - 281) & 511)]) + ((0.00202932814f * fVec4[((IOTA - 237) & 511)]) + ((0.00322575634f * fVec4[((IOTA - 236) & 511)]) + ((0.00501494808f * fVec4[((IOTA - 235) & 511)]) + ((0.00620331196f * fVec4[((IOTA - 234) & 511)]) + ((0.00673697935f * fVec4[((IOTA - 233) & 511)]) + ((0.00609217444f * fVec4[((IOTA - 232) & 511)]) + ((0.00442303484f * fVec4[((IOTA - 231) & 511)]) + ((0.00343741477f * fVec4[((IOTA - 230) & 511)]) + ((0.00308100646f * fVec4[((IOTA - 229) & 511)]) + ((0.0030372194f * fVec4[((IOTA - 228) & 511)]) + ((0.00338052306f * fVec4[((IOTA - 227) & 511)]) + ((0.00338688632f * fVec4[((IOTA - 226) & 511)]) + ((0.00351758627f * fVec4[((IOTA - 225) & 511)]) + ((0.00422807178f * fVec4[((IOTA - 224) & 511)]) + ((0.00457361201f * fVec4[((IOTA - 223) & 511)]) + ((0.00480933767f * fVec4[((IOTA - 222) & 511)]) + ((0.00541038672f * fVec4[((IOTA - 221) & 511)]) + ((0.00590956025f * fVec4[((IOTA - 220) & 511)]) + ((0.00574912271f * fVec4[((IOTA - 218) & 511)]) + ((0.00383612979f * fVec4[((IOTA - 217) & 511)]) + ((0.00180532085f * fVec4[((IOTA - 216) & 511)]) + ((0.00055121351f * fVec4[((IOTA - 215) & 511)]) + ((0.000546141993f * fVec4[((IOTA - 214) & 511)]) + ((0.00182756083f * fVec4[((IOTA - 213) & 511)]) + ((0.00360519206f * fVec4[((IOTA - 212) & 511)]) + ((0.00560777541f * fVec4[((IOTA - 211) & 511)]) + ((0.00697248476f * fVec4[((IOTA - 210) & 511)]) + ((0.00615476817f * fVec4[((IOTA - 209) & 511)]) + ((0.00362862926f * fVec4[((IOTA - 208) & 511)]) + ((0.00103299785f * fVec4[((IOTA - 207) & 511)]) + ((7.26110302e-05f * fVec4[((IOTA - 203) & 511)]) + ((0.000759533141f * fVec4[((IOTA - 202) & 511)]) + ((0.00117418775f * fVec4[((IOTA - 201) & 511)]) + ((0.00134429615f * fVec4[((IOTA - 200) & 511)]) + ((0.00146693131f * fVec4[((IOTA - 199) & 511)]) + ((0.00111704413f * fVec4[((IOTA - 198) & 511)]) + ((0.000960639212f * fVec4[((IOTA - 197) & 511)]) + ((0.00192307355f * fVec4[((IOTA - 196) & 511)]) + ((0.00356572075f * fVec4[((IOTA - 195) & 511)]) + ((0.00548479334f * fVec4[((IOTA - 194) & 511)]) + ((0.00715783937f * fVec4[((IOTA - 193) & 511)]) + ((0.00725675421f * fVec4[((IOTA - 192) & 511)]) + ((0.0058756643f * fVec4[((IOTA - 191) & 511)]) + ((0.00390133774f * fVec4[((IOTA - 190) & 511)]) + ((0.00150032295f * fVec4[((IOTA - 189) & 511)]) + ((0.000859739725f * fVec4[((IOTA - 186) & 511)]) + ((0.00329975318f * fVec4[((IOTA - 185) & 511)]) + ((0.00543193379f * fVec4[((IOTA - 184) & 511)]) + ((0.00491351355f * fVec4[((IOTA - 183) & 511)]) + ((0.0021635564f * fVec4[((IOTA - 182) & 511)]) + ((0.00627664756f * fVec4[((IOTA - 219) & 511)]) + ((0.00167874759f * fVec4[((IOTA - 178) & 511)]) + ((0.00255426951f * fVec4[((IOTA - 177) & 511)]) + ((0.00276589673f * fVec4[((IOTA - 176) & 511)]) + ((0.00199250318f * fVec4[((IOTA - 175) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0435650982f * fVec4[((IOTA - 13) & 511)]) + ((0.115089245f * fVec4[((IOTA - 12) & 511)]) + ((0.116537564f * fVec4[((IOTA - 11) & 511)]) + ((0.0502434187f * fVec4[((IOTA - 10) & 511)]) + ((0.118146189f * fVec4[((IOTA - 4) & 511)]) + ((0.21648027f * fVec4[((IOTA - 3) & 511)]) + ((0.246502891f * fVec4[((IOTA - 2) & 511)]) + ((0.197712898f * fVec4[((IOTA - 1) & 511)]) + ((fSlow20 * fTemp0) + ((0.0341515578f * fVec4[((IOTA - 24) & 511)]) + (((0.00120931212f * fVec4[((IOTA - 16) & 511)]) + ((0.038688127f * fVec4[((IOTA - 18) & 511)]) + ((0.0261173155f * fVec4[((IOTA - 17) & 511)]) + (0.0159032606f * fVec4[((IOTA - 19) & 511)])))) + (0.0457480252f * fVec4[((IOTA - 25) & 511)])))))))))))) + (0.0307200979f * fVec4[((IOTA - 26) & 511)])) + (0.00982797146f * fVec4[((IOTA - 27) & 511)])) + (0.0108782956f * fVec4[((IOTA - 35) & 511)])) + (0.0390565656f * fVec4[((IOTA - 36) & 511)])) + (0.0525852107f * fVec4[((IOTA - 37) & 511)])) + (0.0419361219f * fVec4[((IOTA - 38) & 511)])) + (0.0158895273f * fVec4[((IOTA - 39) & 511)])) + (0.0164253991f * fVec4[((IOTA - 49) & 511)])) + (0.0238030255f * fVec4[((IOTA - 50) & 511)])) + (0.0153365806f * fVec4[((IOTA - 51) & 511)])) + (0.000592260156f * fVec4[((IOTA - 52) & 511)])) + (0.00468043378f * fVec4[((IOTA - 60) & 511)])) + (0.0162035972f * fVec4[((IOTA - 61) & 511)])) + (0.0224271007f * fVec4[((IOTA - 62) & 511)])) + (0.0227029603f * fVec4[((IOTA - 63) & 511)])) + (0.00943530537f * fVec4[((IOTA - 64) & 511)])) + (0.00117258122f * fVec4[((IOTA - 71) & 511)])) + (0.00345256692f * fVec4[((IOTA - 72) & 511)])) + (0.00197665766f * fVec4[((IOTA - 73) & 511)])) + (0.000886106398f * fVec4[((IOTA - 74) & 511)])) + (0.00337787718f * fVec4[((IOTA - 75) & 511)])) + (0.0070479936f * fVec4[((IOTA - 76) & 511)])) + (0.00846329425f * fVec4[((IOTA - 77) & 511)])) + (0.0047016656f * fVec4[((IOTA - 78) & 511)])) + (0.00101734186f * fVec4[((IOTA - 79) & 511)])) + (0.000819826964f * fVec4[((IOTA - 80) & 511)])) + (0.000185417943f * fVec4[((IOTA - 95) & 511)])) + (0.00779750943f * fVec4[((IOTA - 96) & 511)])) + (0.0142917372f * fVec4[((IOTA - 97) & 511)])) + (0.0145748425f * fVec4[((IOTA - 98) & 511)])) + (0.00988325663f * fVec4[((IOTA - 99) & 511)])) + (0.00372634688f * fVec4[((IOTA - 100) & 511)])) + (0.00432049716f * fVec4[((IOTA - 109) & 511)])) + (0.00648833765f * fVec4[((IOTA - 110) & 511)])) + (0.00521614868f * fVec4[((IOTA - 111) & 511)])) + (0.00209633214f * fVec4[((IOTA - 112) & 511)])) + (0.000430877786f * fVec4[((IOTA - 128) & 511)])) + (0.00207809266f * fVec4[((IOTA - 129) & 511)])) + (0.00242523942f * fVec4[((IOTA - 130) & 511)])) + (0.00287986919f * fVec4[((IOTA - 131) & 511)])) + (0.00298152491f * fVec4[((IOTA - 132) & 511)])) + (0.00256088516f * fVec4[((IOTA - 133) & 511)])) + (0.00251599541f * fVec4[((IOTA - 134) & 511)])) + (0.00240170769f * fVec4[((IOTA - 135) & 511)])) + (0.00157057168f * fVec4[((IOTA - 136) & 511)])) + (0.000575942453f * fVec4[((IOTA - 142) & 511)])) + (0.000906897243f * fVec4[((IOTA - 143) & 511)])) + (0.00055184355f * fVec4[((IOTA - 149) & 511)])) + (0.00428417604f * fVec4[((IOTA - 150) & 511)])) + (0.00626874063f * fVec4[((IOTA - 151) & 511)])) + (0.00644086488f * fVec4[((IOTA - 152) & 511)])) + (0.00526119582f * fVec4[((IOTA - 153) & 511)])) + (0.00341300108f * fVec4[((IOTA - 154) & 511)])) + (0.00148397405f * fVec4[((IOTA - 155) & 511)])) + (0.00107694278f * fVec4[((IOTA - 168) & 511)])) + (0.00117573142f * fVec4[((IOTA - 169) & 511)])) + (0.000976578798f * fVec4[((IOTA - 174) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000713509507f * fVec4[((IOTA - 399) & 511)])) + (0.00175142195f * fVec4[((IOTA - 400) & 511)])) + (0.0019586389f * fVec4[((IOTA - 401) & 511)])) + (0.00135295885f * fVec4[((IOTA - 402) & 511)])) + (0.000808801502f * fVec4[((IOTA - 403) & 511)])) + (0.000334672164f * fVec4[((IOTA - 404) & 511)])) + (0.000845028553f * fVec4[((IOTA - 423) & 511)])) + (0.00233599544f * fVec4[((IOTA - 424) & 511)])) + (0.00293865148f * fVec4[((IOTA - 425) & 511)])) + (0.00239433628f * fVec4[((IOTA - 426) & 511)])) + (0.000470034312f * fVec4[((IOTA - 427) & 511)])) - ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.000640173908f * fVec4[((IOTA - 414) & 511)]) + ((0.000559498556f * fVec4[((IOTA - 413) & 511)]) + ((0.00116331968f * fVec4[((IOTA - 412) & 511)]) + ((0.00220384682f * fVec4[((IOTA - 411) & 511)]) + ((0.00276879501f * fVec4[((IOTA - 410) & 511)]) + ((0.00300763967f * fVec4[((IOTA - 409) & 511)]) + ((0.00293751713f * fVec4[((IOTA - 408) & 511)]) + ((0.00217080163f * fVec4[((IOTA - 407) & 511)]) + ((0.00129020773f * fVec4[((IOTA - 406) & 511)]) + ((0.00047687022f * fVec4[((IOTA - 405) & 511)]) + ((0.000917261466f * fVec4[((IOTA - 398) & 511)]) + ((0.00254970184f * fVec4[((IOTA - 397) & 511)]) + ((0.00324380631f * fVec4[((IOTA - 396) & 511)]) + ((0.00321120257f * fVec4[((IOTA - 395) & 511)]) + ((0.00259556808f * fVec4[((IOTA - 394) & 511)]) + ((0.00147751626f * fVec4[((IOTA - 393) & 511)]) + ((0.000738931354f * fVec4[((IOTA - 392) & 511)]) + ((0.000385326799f * fVec4[((IOTA - 391) & 511)]) + ((0.00379835954f * fVec4[((IOTA - 419) & 511)]) + ((0.00397505146f * fVec4[((IOTA - 418) & 511)]) + ((0.0036417339f * fVec4[((IOTA - 417) & 511)]) + ((0.00255360827f * fVec4[((IOTA - 416) & 511)]) + (((0.000456646085f * fVec4[((IOTA - 389) & 511)]) + ((0.000266975258f * fVec4[((IOTA - 388) & 511)]) + ((0.000103419647f * fVec4[((IOTA - 381) & 511)]) + ((0.00110708969f * fVec4[((IOTA - 375) & 511)]) + ((0.00269734953f * fVec4[((IOTA - 374) & 511)]) + ((0.00332769519f * fVec4[((IOTA - 373) & 511)]) + ((0.00304455915f * fVec4[((IOTA - 372) & 511)]) + ((0.00177892251f * fVec4[((IOTA - 371) & 511)]) + ((0.000257556327f * fVec4[((IOTA - 370) & 511)]) + ((0.00107886409f * fVec4[((IOTA - 366) & 511)]) + ((0.00150800962f * fVec4[((IOTA - 365) & 511)]) + ((0.00141199306f * fVec4[((IOTA - 364) & 511)]) + ((0.00112006813f * fVec4[((IOTA - 363) & 511)]) + ((0.00066795852f * fVec4[((IOTA - 362) & 511)]) + ((0.000778623391f * fVec4[((IOTA - 361) & 511)]) + ((0.00113881147f * fVec4[((IOTA - 360) & 511)]) + ((0.00122062117f * fVec4[((IOTA - 359) & 511)]) + ((0.00117214024f * fVec4[((IOTA - 358) & 511)]) + ((0.000455007888f * fVec4[((IOTA - 357) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0180286057f * fVec4[((IOTA - 15) & 511)]) + ((0.0188781396f * fVec4[((IOTA - 14) & 511)]) + ((0.0867297798f * fVec4[((IOTA - 9) & 511)]) + ((0.221392944f * fVec4[((IOTA - 8) & 511)]) + ((0.255269319f * fVec4[((IOTA - 7) & 511)]) + ((0.197356135f * fVec4[((IOTA - 6) & 511)]) + ((0.0544479303f * fVec4[((IOTA - 5) & 511)]) + ((0.035418015f * fVec4[((IOTA - 21) & 511)]) + (((0.0154297929f * fVec4[((IOTA - 20) & 511)]) + (0.0323360339f * fVec4[((IOTA - 22) & 511)])) + (0.000321724918f * fVec4[((IOTA - 23) & 511)])))))))))) + (0.00403273059f * fVec4[((IOTA - 28) & 511)])) + (0.0209805518f * fVec4[((IOTA - 29) & 511)])) + (0.0441775508f * fVec4[((IOTA - 30) & 511)])) + (0.0625073388f * fVec4[((IOTA - 31) & 511)])) + (0.0646149218f * fVec4[((IOTA - 32) & 511)])) + (0.0459156781f * fVec4[((IOTA - 33) & 511)])) + (0.0185069889f * fVec4[((IOTA - 34) & 511)])) + (0.00490692956f * fVec4[((IOTA - 40) & 511)])) + (0.012636805f * fVec4[((IOTA - 41) & 511)])) + (0.0143091585f * fVec4[((IOTA - 42) & 511)])) + (0.0201357752f * fVec4[((IOTA - 43) & 511)])) + (0.0361773893f * fVec4[((IOTA - 44) & 511)])) + (0.048254475f * fVec4[((IOTA - 45) & 511)])) + (0.0423437841f * fVec4[((IOTA - 46) & 511)])) + (0.0256250091f * fVec4[((IOTA - 47) & 511)])) + (0.0045153969f * fVec4[((IOTA - 48) & 511)])) + (0.0133452434f * fVec4[((IOTA - 53) & 511)])) + (0.0187487304f * fVec4[((IOTA - 54) & 511)])) + (0.0201588012f * fVec4[((IOTA - 55) & 511)])) + (0.0227092598f * fVec4[((IOTA - 56) & 511)])) + (0.0221041162f * fVec4[((IOTA - 57) & 511)])) + (0.0165519081f * fVec4[((IOTA - 58) & 511)])) + (0.00849844981f * fVec4[((IOTA - 59) & 511)])) + (0.0157377534f * fVec4[((IOTA - 65) & 511)])) + (0.0370867141f * fVec4[((IOTA - 66) & 511)])) + (0.0454482585f * fVec4[((IOTA - 67) & 511)])) + (0.0403465219f * fVec4[((IOTA - 68) & 511)])) + (0.0250129364f * fVec4[((IOTA - 69) & 511)])) + (0.00827419013f * fVec4[((IOTA - 70) & 511)])) + (0.000865063164f * fVec4[((IOTA - 81) & 511)])) + (0.00445614289f * fVec4[((IOTA - 82) & 511)])) + (0.00891631749f * fVec4[((IOTA - 83) & 511)])) + (0.016088143f * fVec4[((IOTA - 84) & 511)])) + (0.0220034048f * fVec4[((IOTA - 85) & 511)])) + (0.0243813302f * fVec4[((IOTA - 86) & 511)])) + (0.0222569611f * fVec4[((IOTA - 87) & 511)])) + (0.0150337564f * fVec4[((IOTA - 88) & 511)])) + (0.00854264665f * fVec4[((IOTA - 89) & 511)])) + (0.0047492329f * fVec4[((IOTA - 90) & 511)])) + (0.00374972122f * fVec4[((IOTA - 91) & 511)])) + (0.00670163427f * fVec4[((IOTA - 92) & 511)])) + (0.00861784071f * fVec4[((IOTA - 93) & 511)])) + (0.00568832504f * fVec4[((IOTA - 94) & 511)])) + (0.00357901445f * fVec4[((IOTA - 101) & 511)])) + (0.0103718452f * fVec4[((IOTA - 102) & 511)])) + (0.0153919915f * fVec4[((IOTA - 103) & 511)])) + (0.0198396929f * fVec4[((IOTA - 104) & 511)])) + (0.0212251917f * fVec4[((IOTA - 105) & 511)])) + (0.0183359664f * fVec4[((IOTA - 106) & 511)])) + (0.0117797432f * fVec4[((IOTA - 107) & 511)])) + (0.0028554243f * fVec4[((IOTA - 108) & 511)])) + (0.00235313224f * fVec4[((IOTA - 113) & 511)])) + (0.00546293147f * fVec4[((IOTA - 114) & 511)])) + (0.00618223706f * fVec4[((IOTA - 115) & 511)])) + (0.00645488314f * fVec4[((IOTA - 116) & 511)])) + (0.00786602497f * fVec4[((IOTA - 117) & 511)])) + (0.00941801071f * fVec4[((IOTA - 118) & 511)])) + (0.0102790734f * fVec4[((IOTA - 119) & 511)])) + (0.0105280615f * fVec4[((IOTA - 120) & 511)])) + (0.00994008593f * fVec4[((IOTA - 121) & 511)])) + (0.00825418718f * fVec4[((IOTA - 122) & 511)])) + (0.0064409906f * fVec4[((IOTA - 123) & 511)])) + (0.00575094996f * fVec4[((IOTA - 124) & 511)])) + (0.00558770914f * fVec4[((IOTA - 125) & 511)])) + (0.00442322344f * fVec4[((IOTA - 126) & 511)])) + (0.00214856165f * fVec4[((IOTA - 127) & 511)])) + (0.000416261144f * fVec4[((IOTA - 137) & 511)])) + (0.00338020828f * fVec4[((IOTA - 138) & 511)])) + (0.00459818309f * fVec4[((IOTA - 139) & 511)])) + (0.00369471917f * fVec4[((IOTA - 140) & 511)])) + (0.00175895076f * fVec4[((IOTA - 141) & 511)])) + (0.00160730211f * fVec4[((IOTA - 144) & 511)])) + (0.00506267324f * fVec4[((IOTA - 145) & 511)])) + (0.00717185764f * fVec4[((IOTA - 146) & 511)])) + (0.00669108145f * fVec4[((IOTA - 147) & 511)])) + (0.00365710631f * fVec4[((IOTA - 148) & 511)])) + (0.000334136654f * fVec4[((IOTA - 156) & 511)])) + (0.00209746603f * fVec4[((IOTA - 157) & 511)])) + (0.00359331584f * fVec4[((IOTA - 158) & 511)])) + (0.00487145875f * fVec4[((IOTA - 159) & 511)])) + (0.00554738706f * fVec4[((IOTA - 160) & 511)])) + (0.0051119416f * fVec4[((IOTA - 161) & 511)])) + (0.00414150534f * fVec4[((IOTA - 162) & 511)])) + (0.0031409855f * fVec4[((IOTA - 163) & 511)])) + (0.00228244299f * fVec4[((IOTA - 164) & 511)])) + (0.00190622034f * fVec4[((IOTA - 165) & 511)])) + (0.00136420503f * fVec4[((IOTA - 166) & 511)])) + (7.38082454e-05f * fVec4[((IOTA - 167) & 511)])) + (0.0010108524f * fVec4[((IOTA - 171) & 511)])) + (0.00119387638f * fVec4[((IOTA - 172) & 511)])) + (2.4035573e-05f * fVec4[((IOTA - 173) & 511)])) + (0.000264864881f * fVec4[((IOTA - 179) & 511)])) + (0.00197681505f * fVec4[((IOTA - 180) & 511)])) + (0.000928790774f * fVec4[((IOTA - 181) & 511)])) + (0.000336215831f * fVec4[((IOTA - 187) & 511)])) + (0.000236229971f * fVec4[((IOTA - 188) & 511)])) + (0.000668745954f * fVec4[((IOTA - 204) & 511)])) + (0.00125839142f * fVec4[((IOTA - 205) & 511)])) + (0.000785711221f * fVec4[((IOTA - 206) & 511)])) + (0.000564003363f * fVec4[((IOTA - 314) & 511)])) + (0.00141107943f * fVec4[((IOTA - 315) & 511)])) + (0.00139104435f * fVec4[((IOTA - 316) & 511)])) + (0.000861471985f * fVec4[((IOTA - 317) & 511)])) + (0.000276016537f * fVec4[((IOTA - 318) & 511)])) + (0.00123656075f * fVec4[((IOTA - 415) & 511)]))))))))))))))))))))) + (0.00287476601f * fVec4[((IOTA - 420) & 511)])))))))))))))))))))))))) + (0.0016887337f * fVec4[((IOTA - 421) & 511)])) + (0.000658917241f * fVec4[((IOTA - 422) & 511)])) + (0.00167323509f * fVec4[((IOTA - 428) & 511)])) + (0.00321126543f * fVec4[((IOTA - 429) & 511)])) + (0.00462892838f * fVec4[((IOTA - 430) & 511)])) + (0.00539838476f * fVec4[((IOTA - 431) & 511)])) + (0.00513663888f * fVec4[((IOTA - 432) & 511)])) + (0.00458098343f * fVec4[((IOTA - 433) & 511)])) + (0.00407103635f * fVec4[((IOTA - 434) & 511)])) + (0.00413407106f * fVec4[((IOTA - 435) & 511)])) + (0.00488897366f * fVec4[((IOTA - 436) & 511)])) + (0.00550227705f * fVec4[((IOTA - 437) & 511)])) + (0.00603584992f * fVec4[((IOTA - 438) & 511)])) + (0.00651769713f * fVec4[((IOTA - 439) & 511)])) + (0.00642555486f * fVec4[((IOTA - 440) & 511)])) + (0.00595580414f * fVec4[((IOTA - 441) & 511)])) + (0.00508340122f * fVec4[((IOTA - 442) & 511)])) + (0.00376084121f * fVec4[((IOTA - 443) & 511)])) + (0.00280851824f * fVec4[((IOTA - 444) & 511)])) + (0.00226596789f * fVec4[((IOTA - 445) & 511)])) + (0.00189091032f * fVec4[((IOTA - 446) & 511)])) + (0.00189053267f * fVec4[((IOTA - 447) & 511)])) + (0.00176959811f * fVec4[((IOTA - 448) & 511)])) + (0.00135821989f * fVec4[((IOTA - 449) & 511)])) + (0.00119409664f * fVec4[((IOTA - 450) & 511)])) + (0.00111127924f * fVec4[((IOTA - 451) & 511)])) + (0.00142267207f * fVec4[((IOTA - 452) & 511)])) + (0.00240350328f * fVec4[((IOTA - 453) & 511)])) + (0.00321955048f * fVec4[((IOTA - 454) & 511)])) + (0.00387229351f * fVec4[((IOTA - 455) & 511)])) + (0.00444905506f * fVec4[((IOTA - 456) & 511)])) + (0.00429406716f * fVec4[((IOTA - 457) & 511)])) + (0.00385433761f * fVec4[((IOTA - 458) & 511)])) + (0.0033063055f * fVec4[((IOTA - 459) & 511)])) + (0.00234213844f * fVec4[((IOTA - 460) & 511)])) + (0.00174301071f * fVec4[((IOTA - 461) & 511)])) + (0.00165855512f * fVec4[((IOTA - 462) & 511)])) + (0.00152965123f * fVec4[((IOTA - 463) & 511)])) + (0.00161927287f * fVec4[((IOTA - 464) & 511)])) + (0.00171362003f * fVec4[((IOTA - 465) & 511)])) + (0.00162358861f * fVec4[((IOTA - 466) & 511)])) + (0.00187427783f * fVec4[((IOTA - 467) & 511)])) + (0.00194477802f * fVec4[((IOTA - 468) & 511)])) + (0.00157302851f * fVec4[((IOTA - 469) & 511)])) + (0.00149814971f * fVec4[((IOTA - 470) & 511)])) + (0.00149940979f * fVec4[((IOTA - 471) & 511)])) + (0.00151682971f * fVec4[((IOTA - 472) & 511)])) + (0.00194947189f * fVec4[((IOTA - 473) & 511)])) + (0.00234428048f * fVec4[((IOTA - 474) & 511)])) + (0.00254053483f * fVec4[((IOTA - 475) & 511)])) + (0.00243752496f * fVec4[((IOTA - 476) & 511)])) + (0.00191466277f * fVec4[((IOTA - 477) & 511)])) + (0.00175778521f * fVec4[((IOTA - 478) & 511)])) + (0.00217508571f * fVec4[((IOTA - 479) & 511)])) + (0.00278508151f * fVec4[((IOTA - 480) & 511)])) + (0.00339296646f * fVec4[((IOTA - 481) & 511)])) + (0.00332249748f * fVec4[((IOTA - 482) & 511)])) + (0.00265356246f * fVec4[((IOTA - 483) & 511)])) + (0.00201275852f * fVec4[((IOTA - 484) & 511)])) + (0.00116527313f * fVec4[((IOTA - 485) & 511)])) + (0.000727055129f * fVec4[((IOTA - 486) & 511)])) + (0.00101274252f * fVec4[((IOTA - 487) & 511)])) + (0.00120654004f * fVec4[((IOTA - 488) & 511)])) + (0.00138937496f * fVec4[((IOTA - 489) & 511)])) + (0.00144147826f * fVec4[((IOTA - 490) & 511)])) + (0.000847989693f * fVec4[((IOTA - 491) & 511)])) + (0.0002917354f * fVec4[((IOTA - 492) & 511)])) + (0.000108774751f * fVec4[((IOTA - 493) & 511)])) + (0.000177826267f * fVec4[((IOTA - 494) & 511)])) + (0.00053155655f * fVec4[((IOTA - 495) & 511)])) + (0.000736033078f * fVec4[((IOTA - 496) & 511)])) + (0.00114372605f * fVec4[((IOTA - 497) & 511)])) + (0.0019413759f * fVec4[((IOTA - 498) & 511)])) + (0.00241147308f * fVec4[((IOTA - 499) & 511)])) + (0.002703398f * fVec4[((IOTA - 500) & 511)])) + (0.00291266246f * fVec4[((IOTA - 501) & 511)])) + (0.00271565188f * fVec4[((IOTA - 502) & 511)])) + (0.00253436062f * fVec4[((IOTA - 503) & 511)])) + (0.00252383901f * fVec4[((IOTA - 504) & 511)])) + (0.00305501791f * fVec4[((IOTA - 505) & 511)])) + (0.00447409879f * fVec4[((IOTA - 506) & 511)])) + (0.0056120595f * fVec4[((IOTA - 507) & 511)])) + (0.00576594472f * fVec4[((IOTA - 508) & 511)])) + (0.00515557127f * fVec4[((IOTA - 509) & 511)])) + (0.00363830011f * fVec4[((IOTA - 510) & 511)])) + (0.0019927551f * fVec4[((IOTA - 511) & 511)]))) : (((((((((((((((((((((0.000286384486f * fVec3[((IOTA - 390) & 511)]) + ((0.0001025768f * fVec3[((IOTA - 389) & 511)]) + ((0.000228354242f * fVec3[((IOTA - 388) & 511)]) + ((0.0010328046f * fVec3[((IOTA - 387) & 511)]) + ((0.00163171859f * fVec3[((IOTA - 386) & 511)]) + ((0.00178525969f * fVec3[((IOTA - 385) & 511)]) + ((0.00111706834f * fVec3[((IOTA - 384) & 511)]) + ((0.00057541905f * fVec3[((IOTA - 380) & 511)]) + ((0.00163001101f * fVec3[((IOTA - 379) & 511)]) + ((0.00254984573f * fVec3[((IOTA - 378) & 511)]) + ((0.00280917296f * fVec3[((IOTA - 377) & 511)]) + ((0.00194324693f * fVec3[((IOTA - 376) & 511)]) + ((0.00144281704f * fVec3[((IOTA - 362) & 511)]) + ((0.0024825111f * fVec3[((IOTA - 361) & 511)]) + ((0.00235340698f * fVec3[((IOTA - 360) & 511)]) + ((0.00154948654f * fVec3[((IOTA - 359) & 511)]) + ((0.00149631361f * fVec3[((IOTA - 353) & 511)]) + ((0.00399543019f * fVec3[((IOTA - 352) & 511)]) + ((0.00649328064f * fVec3[((IOTA - 351) & 511)]) + ((0.0076282206f * fVec3[((IOTA - 350) & 511)]) + ((0.00647243578f * fVec3[((IOTA - 349) & 511)]) + ((0.00415412383f * fVec3[((IOTA - 348) & 511)]) + ((0.00135652209f * fVec3[((IOTA - 347) & 511)]) + ((0.000374210998f * fVec3[((IOTA - 344) & 511)]) + ((0.00244891737f * fVec3[((IOTA - 343) & 511)]) + ((0.00479452219f * fVec3[((IOTA - 342) & 511)]) + ((0.00578981731f * fVec3[((IOTA - 341) & 511)]) + ((0.00567611121f * fVec3[((IOTA - 340) & 511)]) + ((0.00518769398f * fVec3[((IOTA - 339) & 511)]) + ((0.00420314539f * fVec3[((IOTA - 338) & 511)]) + ((0.00346694188f * fVec3[((IOTA - 337) & 511)]) + ((0.00295373425f * fVec3[((IOTA - 336) & 511)]) + ((0.00181346573f * fVec3[((IOTA - 334) & 511)]) + ((0.00178255141f * fVec3[((IOTA - 333) & 511)]) + ((0.002063666f * fVec3[((IOTA - 332) & 511)]) + ((0.0031653652f * fVec3[((IOTA - 331) & 511)]) + ((0.00380452676f * fVec3[((IOTA - 330) & 511)]) + ((0.00325401593f * fVec3[((IOTA - 329) & 511)]) + ((0.00210040947f * fVec3[((IOTA - 328) & 511)]) + ((0.000522952992f * fVec3[((IOTA - 327) & 511)]) + ((0.000266570132f * fVec3[((IOTA - 317) & 511)]) + ((0.00169181032f * fVec3[((IOTA - 316) & 511)]) + ((0.00274251541f * fVec3[((IOTA - 315) & 511)]) + ((0.00327612692f * fVec3[((IOTA - 314) & 511)]) + ((0.00304800831f * fVec3[((IOTA - 313) & 511)]) + ((0.00290986523f * fVec3[((IOTA - 312) & 511)]) + ((0.00343367225f * fVec3[((IOTA - 311) & 511)]) + ((0.00419027917f * fVec3[((IOTA - 310) & 511)]) + ((0.00520350458f * fVec3[((IOTA - 309) & 511)]) + ((0.0061712414f * fVec3[((IOTA - 308) & 511)]) + ((0.00660009729f * fVec3[((IOTA - 307) & 511)]) + ((0.00671857269f * fVec3[((IOTA - 306) & 511)]) + ((0.00636667898f * fVec3[((IOTA - 305) & 511)]) + ((0.00560441939f * fVec3[((IOTA - 304) & 511)]) + (((0.0050276164f * fVec3[((IOTA - 303) & 511)]) + ((0.00475094793f * fVec3[((IOTA - 302) & 511)]) + ((0.00502214022f * fVec3[((IOTA - 301) & 511)]) + ((0.00564537384f * fVec3[((IOTA - 300) & 511)]) + ((0.00582815101f * fVec3[((IOTA - 299) & 511)]) + ((0.00567502202f * fVec3[((IOTA - 298) & 511)]) + ((0.00535139302f * fVec3[((IOTA - 297) & 511)]) + ((((((((((((((((0.00370689621f * fVec3[((IOTA - 282) & 511)]) + ((0.0036545773f * fVec3[((IOTA - 281) & 511)]) + ((0.00348920049f * fVec3[((IOTA - 280) & 511)]) + ((0.00272102281f * fVec3[((IOTA - 279) & 511)]) + ((0.0015098867f * fVec3[((IOTA - 278) & 511)]) + ((8.47922638e-06f * fVec3[((IOTA - 277) & 511)]) + ((0.00200280873f * fVec3[((IOTA - 274) & 511)]) + ((0.00543662813f * fVec3[((IOTA - 273) & 511)]) + ((0.00894272886f * fVec3[((IOTA - 272) & 511)]) + ((0.0110934256f * fVec3[((IOTA - 271) & 511)]) + ((0.0109359976f * fVec3[((IOTA - 270) & 511)]) + ((0.00834826007f * fVec3[((IOTA - 269) & 511)]) + ((0.00429615332f * fVec3[((IOTA - 268) & 511)]) + ((0.00119176321f * fVec3[((IOTA - 267) & 511)]) + ((0.000508614816f * fVec3[((IOTA - 266) & 511)]) + ((0.00159647642f * fVec3[((IOTA - 265) & 511)]) + ((0.00381280016f * fVec3[((IOTA - 264) & 511)]) + ((0.00639426662f * fVec3[((IOTA - 263) & 511)]) + ((0.00820555352f * fVec3[((IOTA - 262) & 511)]) + ((0.00882345811f * fVec3[((IOTA - 261) & 511)]) + ((0.0080765672f * fVec3[((IOTA - 260) & 511)]) + ((0.00671380339f * fVec3[((IOTA - 259) & 511)]) + ((0.00617056433f * fVec3[((IOTA - 258) & 511)]) + ((0.00645391643f * fVec3[((IOTA - 257) & 511)]) + ((0.00708624767f * fVec3[((IOTA - 256) & 511)]) + ((0.00793229975f * fVec3[((IOTA - 255) & 511)]) + ((0.00801297184f * fVec3[((IOTA - 254) & 511)]) + ((0.00754186651f * fVec3[((IOTA - 253) & 511)]) + ((0.00714445487f * fVec3[((IOTA - 252) & 511)]) + ((0.00586495409f * fVec3[((IOTA - 251) & 511)]) + ((0.00393919554f * fVec3[((IOTA - 250) & 511)]) + ((0.0023273211f * fVec3[((IOTA - 249) & 511)]) + ((0.00110776443f * fVec3[((IOTA - 248) & 511)]) + ((0.00093046343f * fVec3[((IOTA - 247) & 511)]) + ((0.00157465972f * fVec3[((IOTA - 246) & 511)]) + ((0.00217501633f * fVec3[((IOTA - 245) & 511)]) + ((0.00290636159f * fVec3[((IOTA - 244) & 511)]) + ((0.00317528704f * fVec3[((IOTA - 243) & 511)]) + ((0.00257566618f * fVec3[((IOTA - 242) & 511)]) + ((0.00206499081f * fVec3[((IOTA - 241) & 511)]) + ((0.00170765026f * fVec3[((IOTA - 240) & 511)]) + ((0.00181849999f * fVec3[((IOTA - 239) & 511)]) + ((0.0029624491f * fVec3[((IOTA - 238) & 511)]) + ((0.00440682657f * fVec3[((IOTA - 237) & 511)]) + ((0.00595690217f * fVec3[((IOTA - 236) & 511)]) + ((0.00721832551f * fVec3[((IOTA - 235) & 511)]) + ((0.00769941183f * fVec3[((IOTA - 234) & 511)]) + ((0.00805357285f * fVec3[((IOTA - 233) & 511)]) + ((0.00839728117f * fVec3[((IOTA - 232) & 511)]) + ((0.00830618665f * fVec3[((IOTA - 231) & 511)]) + ((0.00773444818f * fVec3[((IOTA - 230) & 511)]) + ((0.00615543127f * fVec3[((IOTA - 229) & 511)]) + ((0.00392738916f * fVec3[((IOTA - 228) & 511)]) + ((0.00235069823f * fVec3[((IOTA - 227) & 511)]) + ((0.00207135035f * fVec3[((IOTA - 226) & 511)]) + ((0.0033581825f * fVec3[((IOTA - 225) & 511)]) + ((0.00581996609f * fVec3[((IOTA - 224) & 511)]) + ((0.00794937648f * fVec3[((IOTA - 223) & 511)]) + ((0.00889835879f * fVec3[((IOTA - 222) & 511)]) + ((0.00811148528f * fVec3[((IOTA - 221) & 511)]) + ((0.00518339546f * fVec3[((IOTA - 220) & 511)]) + ((0.00175331486f * fVec3[((IOTA - 219) & 511)]) + ((0.000866543967f * fVec3[((IOTA - 216) & 511)]) + ((0.00365180988f * fVec3[((IOTA - 215) & 511)]) + ((0.00599152595f * fVec3[((IOTA - 214) & 511)]) + ((0.00756913004f * fVec3[((IOTA - 213) & 511)]) + ((0.0077193738f * fVec3[((IOTA - 212) & 511)]) + ((0.00689010322f * fVec3[((IOTA - 211) & 511)]) + ((0.00564714009f * fVec3[((IOTA - 210) & 511)]) + ((0.00389361894f * fVec3[((IOTA - 209) & 511)]) + ((0.00273112161f * fVec3[((IOTA - 208) & 511)]) + ((0.00251507433f * fVec3[((IOTA - 207) & 511)]) + ((0.00221293792f * fVec3[((IOTA - 206) & 511)]) + ((0.00169357657f * fVec3[((IOTA - 205) & 511)]) + ((0.000465834979f * fVec3[((IOTA - 204) & 511)]) + ((0.00137495296f * fVec3[((IOTA - 199) & 511)]) + ((0.00480724126f * fVec3[((IOTA - 198) & 511)]) + ((0.0070197084f * fVec3[((IOTA - 197) & 511)]) + ((0.0078112334f * fVec3[((IOTA - 196) & 511)]) + ((0.00721676508f * fVec3[((IOTA - 195) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0162933674f * fVec3[((IOTA - 5) & 511)]) + ((0.169673622f * fVec3[((IOTA - 4) & 511)]) + ((0.232662946f * fVec3[((IOTA - 3) & 511)]) + ((0.236797556f * fVec3[((IOTA - 2) & 511)]) + ((0.189583063f * fVec3[((IOTA - 1) & 511)]) + ((fSlow18 * fTemp0) + ((0.0738352612f * fVec3[((IOTA - 11) & 511)]) + ((0.00781120406f * fVec3[((IOTA - 14) & 511)]) + (((0.113354377f * fVec3[((IOTA - 12) & 511)]) + (((0.0718108416f * fVec3[((IOTA - 13) & 511)]) + (0.0151138818f * fVec3[((IOTA - 17) & 511)])) + (0.0326552764f * fVec3[((IOTA - 18) & 511)]))) + (0.0199659634f * fVec3[((IOTA - 19) & 511)])))))))))) + (0.00279813213f * fVec3[((IOTA - 20) & 511)])) + (0.0263934694f * fVec3[((IOTA - 24) & 511)])) + (0.0434649363f * fVec3[((IOTA - 25) & 511)])) + (0.0340976231f * fVec3[((IOTA - 26) & 511)])) + (0.00462734932f * fVec3[((IOTA - 27) & 511)])) + (0.00933996309f * fVec3[((IOTA - 36) & 511)])) + (0.0386612602f * fVec3[((IOTA - 37) & 511)])) + (0.0496201329f * fVec3[((IOTA - 38) & 511)])) + (0.0422110222f * fVec3[((IOTA - 39) & 511)])) + (0.0214747302f * fVec3[((IOTA - 40) & 511)])) + (0.0123415412f * fVec3[((IOTA - 49) & 511)])) + (0.0296999812f * fVec3[((IOTA - 50) & 511)])) + (0.0229296796f * fVec3[((IOTA - 51) & 511)])) + (0.00536249252f * fVec3[((IOTA - 52) & 511)])) + (0.00161078526f * fVec3[((IOTA - 61) & 511)])) + (0.00103186211f * fVec3[((IOTA - 62) & 511)])) + (0.00445231516f * fVec3[((IOTA - 63) & 511)])) + (0.00559906103f * fVec3[((IOTA - 64) & 511)])) + (0.0106680151f * fVec3[((IOTA - 73) & 511)])) + (0.0286122672f * fVec3[((IOTA - 74) & 511)])) + (0.0329760797f * fVec3[((IOTA - 75) & 511)])) + (0.0234268997f * fVec3[((IOTA - 76) & 511)])) + (0.00500079477f * fVec3[((IOTA - 77) & 511)])) + (0.0101473574f * fVec3[((IOTA - 96) & 511)])) + (0.0216058083f * fVec3[((IOTA - 97) & 511)])) + (0.0229340065f * fVec3[((IOTA - 98) & 511)])) + (0.0187315382f * fVec3[((IOTA - 99) & 511)])) + (0.00979416817f * fVec3[((IOTA - 100) & 511)])) + (0.00120548345f * fVec3[((IOTA - 109) & 511)])) + (0.00720021874f * fVec3[((IOTA - 110) & 511)])) + (0.0073271147f * fVec3[((IOTA - 111) & 511)])) + (0.00282975286f * fVec3[((IOTA - 112) & 511)])) + (0.00133499969f * fVec3[((IOTA - 130) & 511)])) + (0.0065517826f * fVec3[((IOTA - 131) & 511)])) + (0.00895853899f * fVec3[((IOTA - 132) & 511)])) + (0.00780325476f * fVec3[((IOTA - 133) & 511)])) + (0.00496799592f * fVec3[((IOTA - 134) & 511)])) + (0.00196208991f * fVec3[((IOTA - 135) & 511)])) + (0.000491037965f * fVec3[((IOTA - 136) & 511)])) + (0.00325554656f * fVec3[((IOTA - 148) & 511)])) + (0.00627997192f * fVec3[((IOTA - 149) & 511)])) + (0.00765233347f * fVec3[((IOTA - 150) & 511)])) + (0.00645300373f * fVec3[((IOTA - 151) & 511)])) + (0.00357493619f * fVec3[((IOTA - 152) & 511)])) + (9.70121473e-05f * fVec3[((IOTA - 153) & 511)])) + (0.00159836048f * fVec3[((IOTA - 158) & 511)])) + (0.000370353926f * fVec3[((IOTA - 159) & 511)])) + (0.000245371833f * fVec3[((IOTA - 165) & 511)])) + (0.00120212696f * fVec3[((IOTA - 166) & 511)])) + (0.000317976344f * fVec3[((IOTA - 167) & 511)])) + (0.00217737164f * fVec3[((IOTA - 171) & 511)])) + (0.00330115296f * fVec3[((IOTA - 172) & 511)])) + (0.00332885794f * fVec3[((IOTA - 173) & 511)])) + (0.00239815889f * fVec3[((IOTA - 174) & 511)])) + (0.000900844112f * fVec3[((IOTA - 175) & 511)])) + (0.00097453827f * fVec3[((IOTA - 180) & 511)])) + (0.00529453997f * fVec3[((IOTA - 181) & 511)])) + (0.00849408749f * fVec3[((IOTA - 182) & 511)])) + (0.00915530138f * fVec3[((IOTA - 183) & 511)])) + (0.00681358296f * fVec3[((IOTA - 184) & 511)])) + (0.00246631773f * fVec3[((IOTA - 185) & 511)])) + (0.00224008365f * fVec3[((IOTA - 189) & 511)])) + (0.00536531908f * fVec3[((IOTA - 190) & 511)])) + (0.00649413466f * fVec3[((IOTA - 191) & 511)])) + (0.00625041174f * fVec3[((IOTA - 192) & 511)])) + (0.00584764173f * fVec3[((IOTA - 193) & 511)])) + (0.00615784526f * fVec3[((IOTA - 194) & 511)])) + (0.00384972058f * fVec3[((IOTA - 283) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00395011855f * fVec3[((IOTA - 284) & 511)])) + (0.00410215836f * fVec3[((IOTA - 285) & 511)])) + (0.00379404519f * fVec3[((IOTA - 286) & 511)])) + (0.00293194689f * fVec3[((IOTA - 287) & 511)])) + (0.0025622407f * fVec3[((IOTA - 288) & 511)])) + (0.00284038158f * fVec3[((IOTA - 289) & 511)])) + (0.00320334546f * fVec3[((IOTA - 290) & 511)])) + (0.00359301362f * fVec3[((IOTA - 291) & 511)])) + (0.00387571799f * fVec3[((IOTA - 292) & 511)])) + (0.00410380727f * fVec3[((IOTA - 293) & 511)])) + (0.00438447995f * fVec3[((IOTA - 294) & 511)])) + (0.00453074928f * fVec3[((IOTA - 295) & 511)])) + (0.00481062708f * fVec3[((IOTA - 296) & 511)])) + (0.00216061901f * fVec3[((IOTA - 335) & 511)]))))))))) + (0.000104255043f * fVec3[((IOTA - 391) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (1.00117177e-06f * fVec3[((IOTA - 392) & 511)])) + (0.00071815541f * fVec3[((IOTA - 400) & 511)])) + (0.00312317442f * fVec3[((IOTA - 401) & 511)])) + (0.00330392038f * fVec3[((IOTA - 402) & 511)])) + (0.00177407172f * fVec3[((IOTA - 403) & 511)])) + (0.000139026437f * fVec3[((IOTA - 410) & 511)])) + (1.38082542e-05f * fVec3[((IOTA - 424) & 511)])) + (0.00159998005f * fVec3[((IOTA - 425) & 511)])) + (0.0023292643f * fVec3[((IOTA - 426) & 511)])) + (0.00156470807f * fVec3[((IOTA - 427) & 511)])) + (0.000296983868f * fVec3[((IOTA - 428) & 511)])) + (0.000160283409f * fVec3[((IOTA - 451) & 511)])) + (0.000652675517f * fVec3[((IOTA - 452) & 511)])) + (0.000994529575f * fVec3[((IOTA - 495) & 511)])) + (0.00336018438f * fVec3[((IOTA - 496) & 511)])) + (0.00402419548f * fVec3[((IOTA - 497) & 511)])) + (0.00252640946f * fVec3[((IOTA - 498) & 511)])) + (0.000286090188f * fVec3[((IOTA - 499) & 511)])) - ((((((((((((((((((((((((((((((((((((0.00419540191f * fVec3[((IOTA - 468) & 511)]) + ((0.00464916602f * fVec3[((IOTA - 467) & 511)]) + ((0.00395432906f * fVec3[((IOTA - 466) & 511)]) + ((0.00330047542f * fVec3[((IOTA - 465) & 511)]) + ((0.00257548969f * fVec3[((IOTA - 464) & 511)]) + ((0.00178605504f * fVec3[((IOTA - 463) & 511)]) + ((0.00177221699f * fVec3[((IOTA - 462) & 511)]) + ((0.00218252419f * fVec3[((IOTA - 461) & 511)]) + ((0.00296504004f * fVec3[((IOTA - 460) & 511)]) + ((0.00416501751f * fVec3[((IOTA - 459) & 511)]) + ((0.00484996196f * fVec3[((IOTA - 458) & 511)]) + ((0.00504905032f * fVec3[((IOTA - 457) & 511)]) + ((0.00500097126f * fVec3[((IOTA - 456) & 511)]) + ((0.00401818939f * fVec3[((IOTA - 455) & 511)]) + ((0.00232867524f * fVec3[((IOTA - 454) & 511)]) + ((0.000533935148f * fVec3[((IOTA - 453) & 511)]) + ((0.00154827908f * fVec3[((IOTA - 450) & 511)]) + ((0.00315455999f * fVec3[((IOTA - 449) & 511)]) + ((0.00419098558f * fVec3[((IOTA - 448) & 511)]) + ((0.00415597903f * fVec3[((IOTA - 447) & 511)]) + ((0.00344300549f * fVec3[((IOTA - 446) & 511)]) + ((0.00337540591f * fVec3[((IOTA - 445) & 511)]) + ((0.00435889466f * fVec3[((IOTA - 444) & 511)]) + ((0.00635154592f * fVec3[((IOTA - 443) & 511)]) + ((0.00867951475f * fVec3[((IOTA - 442) & 511)]) + ((0.00996431522f * fVec3[((IOTA - 441) & 511)]) + ((0.0099929329f * fVec3[((IOTA - 440) & 511)]) + ((0.00881424174f * fVec3[((IOTA - 439) & 511)]) + ((0.00647482043f * fVec3[((IOTA - 438) & 511)]) + ((0.00451087579f * fVec3[((IOTA - 437) & 511)]) + ((0.00398886483f * fVec3[((IOTA - 436) & 511)]) + ((0.00442617014f * fVec3[((IOTA - 435) & 511)]) + ((0.00541881565f * fVec3[((IOTA - 434) & 511)]) + ((0.00599185005f * fVec3[((IOTA - 433) & 511)]) + ((0.00558910938f * fVec3[((IOTA - 432) & 511)]) + ((0.0046917689f * fVec3[((IOTA - 431) & 511)]) + ((0.00309635233f * (fVec3[((IOTA - 82) & 511)] + fVec3[((IOTA - 430) & 511)])) + ((0.00273789326f * fVec3[((IOTA - 469) & 511)]) + ((0.000520568341f * fVec3[((IOTA - 471) & 511)]) + ((0.00137742609f * fVec3[((IOTA - 470) & 511)]) + (((0.00117068272f * fVec3[((IOTA - 429) & 511)]) + ((0.00155222462f * fVec3[((IOTA - 423) & 511)]) + ((0.00252902973f * fVec3[((IOTA - 422) & 511)]) + ((0.00248365942f * fVec3[((IOTA - 421) & 511)]) + ((0.00211981218f * fVec3[((IOTA - 420) & 511)]) + ((0.00164043345f * fVec3[((IOTA - 419) & 511)]) + ((0.00120586623f * fVec3[((IOTA - 418) & 511)]) + ((0.00181611534f * fVec3[((IOTA - 417) & 511)]) + ((0.00294136861f * fVec3[((IOTA - 416) & 511)]) + ((0.00369064417f * fVec3[((IOTA - 415) & 511)]) + ((0.00405416777f * fVec3[((IOTA - 414) & 511)]) + ((0.00320732035f * fVec3[((IOTA - 413) & 511)]) + ((0.00146422163f * fVec3[((IOTA - 412) & 511)]) + ((0.000210718252f * fVec3[((IOTA - 411) & 511)]) + ((0.000743887853f * fVec3[((IOTA - 409) & 511)]) + ((0.00230962643f * fVec3[((IOTA - 408) & 511)]) + ((0.00308316248f * fVec3[((IOTA - 407) & 511)]) + ((0.00307951169f * fVec3[((IOTA - 406) & 511)]) + ((0.0022956999f * fVec3[((IOTA - 405) & 511)]) + ((0.00038536964f * fVec3[((IOTA - 404) & 511)]) + ((0.0023146607f * fVec3[((IOTA - 399) & 511)]) + ((0.00453507714f * fVec3[((IOTA - 398) & 511)]) + ((0.00526651088f * fVec3[((IOTA - 397) & 511)]) + ((0.00424960535f * fVec3[((IOTA - 396) & 511)]) + ((0.00265518995f * fVec3[((IOTA - 395) & 511)]) + ((0.00141204987f * fVec3[((IOTA - 394) & 511)]) + ((0.000415489078f * fVec3[((IOTA - 393) & 511)]) + ((0.00020329887f * fVec3[((IOTA - 383) & 511)]) + ((0.000720657874f * fVec3[((IOTA - 382) & 511)]) + ((0.000249935314f * fVec3[((IOTA - 381) & 511)]) + ((0.000402710866f * fVec3[((IOTA - 375) & 511)]) + ((0.00303420005f * fVec3[((IOTA - 374) & 511)]) + ((0.00466412259f * fVec3[((IOTA - 373) & 511)]) + ((0.00515854638f * fVec3[((IOTA - 372) & 511)]) + ((0.00446526986f * fVec3[((IOTA - 371) & 511)]) + ((0.00328949373f * fVec3[((IOTA - 370) & 511)]) + ((0.00232561352f * fVec3[((IOTA - 369) & 511)]) + ((0.00122930203f * fVec3[((IOTA - 368) & 511)]) + ((0.00056272978f * fVec3[((IOTA - 367) & 511)]) + ((0.00081993686f * fVec3[((IOTA - 366) & 511)]) + ((0.00100769009f * fVec3[((IOTA - 365) & 511)]) + ((0.00084390305f * fVec3[((IOTA - 364) & 511)]) + ((0.000134138856f * fVec3[((IOTA - 363) & 511)]) + ((2.27293931e-05f * fVec3[((IOTA - 358) & 511)]) + ((0.00155449146f * fVec3[((IOTA - 357) & 511)]) + ((0.00231872406f * fVec3[((IOTA - 356) & 511)]) + ((0.00238128891f * fVec3[((IOTA - 355) & 511)]) + ((0.000973478425f * fVec3[((IOTA - 354) & 511)]) + ((0.000727400184f * fVec3[((IOTA - 346) & 511)]) + ((0.000814814121f * fVec3[((IOTA - 345) & 511)]) + ((0.000402357895f * fVec3[((IOTA - 326) & 511)]) + ((0.000496749766f * fVec3[((IOTA - 325) & 511)]) + ((0.000720215961f * fVec3[((IOTA - 324) & 511)]) + ((0.000465040095f * fVec3[((IOTA - 323) & 511)]) + ((7.78748654e-05f * fVec3[((IOTA - 322) & 511)]) + ((0.000381954014f * fVec3[((IOTA - 321) & 511)]) + ((0.000571209006f * fVec3[((IOTA - 320) & 511)]) + ((0.000750777312f * fVec3[((IOTA - 319) & 511)]) + ((0.000792879611f * fVec3[((IOTA - 318) & 511)]) + ((0.00101958495f * fVec3[((IOTA - 276) & 511)]) + ((0.000381071121f * fVec3[((IOTA - 275) & 511)]) + ((0.0005904641f * fVec3[((IOTA - 218) & 511)]) + ((0.00101902569f * fVec3[((IOTA - 217) & 511)]) + ((0.00166507671f * fVec3[((IOTA - 203) & 511)]) + ((0.0031910683f * fVec3[((IOTA - 202) & 511)]) + ((0.00335467886f * fVec3[((IOTA - 201) & 511)]) + ((0.00184732396f * fVec3[((IOTA - 200) & 511)]) + ((0.0011648233f * fVec3[((IOTA - 188) & 511)]) + ((0.00248672161f * fVec3[((IOTA - 187) & 511)]) + ((0.00117851421f * fVec3[((IOTA - 186) & 511)]) + ((0.00254007056f * fVec3[((IOTA - 179) & 511)]) + ((0.00426406134f * fVec3[((IOTA - 178) & 511)]) + ((0.00367024075f * fVec3[((IOTA - 177) & 511)]) + ((0.0012923968f * fVec3[((IOTA - 176) & 511)]) + ((0.000343443826f * fVec3[((IOTA - 170) & 511)]) + ((0.00245189108f * fVec3[((IOTA - 169) & 511)]) + ((0.00180501584f * fVec3[((IOTA - 168) & 511)]) + ((0.00240769843f * fVec3[((IOTA - 164) & 511)]) + ((0.00544855231f * fVec3[((IOTA - 163) & 511)]) + ((0.0066062212f * fVec3[((IOTA - 162) & 511)]) + ((0.00555183552f * fVec3[((IOTA - 161) & 511)]) + ((0.00288536958f * fVec3[((IOTA - 160) & 511)]) + ((0.000241338275f * fVec3[((IOTA - 157) & 511)]) + ((0.00305625238f * fVec3[((IOTA - 156) & 511)]) + ((0.00438786577f * fVec3[((IOTA - 155) & 511)]) + ((0.003103978f * fVec3[((IOTA - 154) & 511)]) + ((8.01123679e-05f * fVec3[((IOTA - 147) & 511)]) + ((0.00272208266f * fVec3[((IOTA - 146) & 511)]) + ((0.00515518989f * fVec3[((IOTA - 145) & 511)]) + ((0.00865092687f * fVec3[((IOTA - 144) & 511)]) + ((0.0106910095f * fVec3[((IOTA - 143) & 511)]) + ((0.00912279729f * fVec3[((IOTA - 142) & 511)]) + ((0.00589398388f * fVec3[((IOTA - 141) & 511)]) + ((0.00261685625f * fVec3[((IOTA - 140) & 511)]) + ((0.00106248213f * fVec3[((IOTA - 139) & 511)]) + ((0.000842283946f * fVec3[((IOTA - 138) & 511)]) + ((0.000159989111f * fVec3[((IOTA - 137) & 511)]) + ((0.00361326989f * fVec3[((IOTA - 129) & 511)]) + ((0.00673400052f * fVec3[((IOTA - 128) & 511)]) + ((0.00765686762f * fVec3[((IOTA - 127) & 511)]) + ((0.00695558311f * fVec3[((IOTA - 126) & 511)]) + ((0.00608644774f * fVec3[((IOTA - 125) & 511)]) + ((0.00688533392f * fVec3[((IOTA - 124) & 511)]) + ((0.0103671439f * fVec3[((IOTA - 123) & 511)]) + ((0.0134077333f * fVec3[((IOTA - 122) & 511)]) + ((0.0121730138f * fVec3[((IOTA - 121) & 511)]) + ((0.00874711387f * fVec3[((IOTA - 120) & 511)]) + ((0.006043904f * fVec3[((IOTA - 119) & 511)]) + ((0.00538104121f * fVec3[((IOTA - 118) & 511)]) + ((0.00715508359f * fVec3[((IOTA - 117) & 511)]) + ((0.00954385102f * fVec3[((IOTA - 116) & 511)]) + ((0.0105005177f * fVec3[((IOTA - 115) & 511)]) + ((0.00841418095f * fVec3[((IOTA - 114) & 511)]) + ((0.00325186644f * fVec3[((IOTA - 113) & 511)]) + ((0.00829708949f * fVec3[((IOTA - 108) & 511)]) + ((0.0184458904f * fVec3[((IOTA - 107) & 511)]) + ((0.0246290565f * fVec3[((IOTA - 106) & 511)]) + ((0.0249124076f * fVec3[((IOTA - 105) & 511)]) + ((0.0215745997f * fVec3[((IOTA - 104) & 511)]) + ((0.0158231743f * fVec3[((IOTA - 103) & 511)]) + ((0.00888678804f * fVec3[((IOTA - 102) & 511)]) + ((0.00080350833f * fVec3[((IOTA - 101) & 511)]) + ((0.00738373213f * fVec3[((IOTA - 95) & 511)]) + ((0.0219253749f * fVec3[((IOTA - 94) & 511)]) + ((0.0291459076f * fVec3[((IOTA - 93) & 511)]) + ((0.0240720082f * fVec3[((IOTA - 92) & 511)]) + ((0.0119425105f * fVec3[((IOTA - 91) & 511)]) + ((0.00354811409f * fVec3[((IOTA - 90) & 511)]) + ((0.00129354512f * fVec3[((IOTA - 89) & 511)]) + ((0.00631303526f * fVec3[((IOTA - 88) & 511)]) + ((0.0170318969f * fVec3[((IOTA - 87) & 511)]) + ((0.0217289645f * fVec3[((IOTA - 86) & 511)]) + ((0.0178366415f * fVec3[((IOTA - 85) & 511)]) + ((0.0104254689f * fVec3[((IOTA - 84) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((0.127300173f * fVec3[((IOTA - 9) & 511)]) + ((0.238582134f * fVec3[((IOTA - 8) & 511)]) + ((0.23635824f * fVec3[((IOTA - 7) & 511)]) + ((0.138396159f * fVec3[((IOTA - 6) & 511)]) + ((0.0124834524f * fVec3[((IOTA - 15) & 511)]) + ((0.00692561083f * fVec3[((IOTA - 10) & 511)]) + (0.00919651985f * fVec3[((IOTA - 16) & 511)]))))))) + (0.0196890887f * fVec3[((IOTA - 21) & 511)])) + (0.0321968906f * fVec3[((IOTA - 22) & 511)])) + (0.00670052459f * fVec3[((IOTA - 23) & 511)])) + (0.013298355f * fVec3[((IOTA - 28) & 511)])) + (0.0177277643f * fVec3[((IOTA - 29) & 511)])) + (0.0267868787f * fVec3[((IOTA - 30) & 511)])) + (0.040306285f * fVec3[((IOTA - 31) & 511)])) + (0.0542834029f * fVec3[((IOTA - 32) & 511)])) + (0.0561236888f * fVec3[((IOTA - 33) & 511)])) + (0.0414414294f * fVec3[((IOTA - 34) & 511)])) + (0.0207355842f * fVec3[((IOTA - 35) & 511)])) + (0.00336186262f * fVec3[((IOTA - 41) & 511)])) + (0.0154391006f * fVec3[((IOTA - 42) & 511)])) + (0.0261058789f * fVec3[((IOTA - 43) & 511)])) + (0.0444178954f * fVec3[((IOTA - 44) & 511)])) + (0.0547580682f * fVec3[((IOTA - 45) & 511)])) + (0.0492932349f * fVec3[((IOTA - 46) & 511)])) + (0.0366106369f * fVec3[((IOTA - 47) & 511)])) + (0.0161756277f * fVec3[((IOTA - 48) & 511)])) + (0.0151877813f * fVec3[((IOTA - 53) & 511)])) + (0.0314927213f * fVec3[((IOTA - 54) & 511)])) + (0.0319983028f * fVec3[((IOTA - 55) & 511)])) + (0.0236102659f * fVec3[((IOTA - 56) & 511)])) + (0.0113910865f * fVec3[((IOTA - 57) & 511)])) + (0.003209705f * fVec3[((IOTA - 58) & 511)])) + (0.00534435594f * fVec3[((IOTA - 59) & 511)])) + (0.00336775091f * fVec3[((IOTA - 60) & 511)])) + (0.00342875533f * fVec3[((IOTA - 65) & 511)])) + (0.0148803461f * fVec3[((IOTA - 66) & 511)])) + (0.0258671008f * fVec3[((IOTA - 67) & 511)])) + (0.0351546593f * fVec3[((IOTA - 68) & 511)])) + (0.0416772924f * fVec3[((IOTA - 69) & 511)])) + (0.0414701365f * fVec3[((IOTA - 70) & 511)])) + (0.0286085866f * fVec3[((IOTA - 71) & 511)])) + (0.00986948237f * fVec3[((IOTA - 72) & 511)])) + (0.0156009449f * fVec3[((IOTA - 78) & 511)])) + (0.0231597107f * fVec3[((IOTA - 79) & 511)])) + (0.0175806414f * fVec3[((IOTA - 80) & 511)])) + (0.00976201706f * fVec3[((IOTA - 81) & 511)])) + (0.00303817447f * fVec3[((IOTA - 83) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.000731993001f * fVec3[((IOTA - 472) & 511)])))))))))))))))))))))))))))))))))))))))))) + (0.00147022773f * fVec3[((IOTA - 473) & 511)])) + (0.00169130974f * fVec3[((IOTA - 474) & 511)])) + (0.00169086829f * fVec3[((IOTA - 475) & 511)])) + (0.00144066801f * fVec3[((IOTA - 476) & 511)])) + (0.00108909793f * fVec3[((IOTA - 477) & 511)])) + (0.00150826713f * fVec3[((IOTA - 478) & 511)])) + (0.00241647242f * fVec3[((IOTA - 479) & 511)])) + (0.00336945895f * fVec3[((IOTA - 480) & 511)])) + (0.00413369108f * fVec3[((IOTA - 481) & 511)])) + (0.00417879643f * fVec3[((IOTA - 482) & 511)])) + (0.00398056209f * fVec3[((IOTA - 483) & 511)])) + (0.00361815747f * fVec3[((IOTA - 484) & 511)])) + (0.00265145069f * fVec3[((IOTA - 485) & 511)])) + (0.00204829685f * fVec3[((IOTA - 486) & 511)])) + (0.00166013045f * fVec3[((IOTA - 487) & 511)])) + (0.00128147379f * fVec3[((IOTA - 488) & 511)])) + (0.00183931598f * fVec3[((IOTA - 489) & 511)])) + (0.00250335643f * fVec3[((IOTA - 490) & 511)])) + (0.00285504386f * fVec3[((IOTA - 491) & 511)])) + (0.00338977389f * fVec3[((IOTA - 492) & 511)])) + (0.00304974522f * fVec3[((IOTA - 493) & 511)])) + (0.0013614092f * fVec3[((IOTA - 494) & 511)])) + (0.00223752204f * fVec3[((IOTA - 500) & 511)])) + (0.00457370561f * fVec3[((IOTA - 501) & 511)])) + (0.00579034723f * fVec3[((IOTA - 502) & 511)])) + (0.00603613118f * fVec3[((IOTA - 503) & 511)])) + (0.0055532488f * fVec3[((IOTA - 504) & 511)])) + (0.00493655168f * fVec3[((IOTA - 505) & 511)])) + (0.0048690699f * fVec3[((IOTA - 506) & 511)])) + (0.00503827445f * fVec3[((IOTA - 507) & 511)])) + (0.00550384494f * fVec3[((IOTA - 508) & 511)])) + (0.00595060131f * fVec3[((IOTA - 509) & 511)])) + (0.00539281825f * fVec3[((IOTA - 510) & 511)])) + (0.00437564729f * fVec3[((IOTA - 511) & 511)]))))) : (iSlow5 ? (iSlow10 ? ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00231825886f * fVec2[((IOTA - 24) & 511)]) + ((0.000552930404f * fVec2[((IOTA - 21) & 511)]) + ((0.0062910486f * fVec2[((IOTA - 20) & 511)]) + ((0.0114113996f * fVec2[((IOTA - 19) & 511)]) + ((0.0186470114f * fVec2[((IOTA - 18) & 511)]) + ((0.0137477256f * fVec2[((IOTA - 17) & 511)]) + ((0.0140868044f * fVec2[((IOTA - 16) & 511)]) + ((0.0267587081f * fVec2[((IOTA - 15) & 511)]) + ((0.0525451489f * fVec2[((IOTA - 14) & 511)]) + ((0.0686993524f * fVec2[((IOTA - 13) & 511)]) + ((0.0428468958f * fVec2[((IOTA - 12) & 511)]) + ((0.0958107635f * fVec2[((IOTA - 5) & 511)]) + ((0.203860566f * fVec2[((IOTA - 4) & 511)]) + ((0.248298213f * fVec2[((IOTA - 3) & 511)]) + ((0.251988828f * fVec2[((IOTA - 2) & 511)]) + ((0.194228575f * fVec2[((IOTA - 1) & 511)]) + ((fSlow14 * fTemp0) + ((0.053193111f * fVec2[((IOTA - 26) & 511)]) + (((0.0311796945f * fVec2[((IOTA - 25) & 511)]) + (0.050579153f * fVec2[((IOTA - 27) & 511)])) + (0.0236315615f * fVec2[((IOTA - 28) & 511)])))))))))))))))))))) + (0.000338860787f * fVec2[((IOTA - 36) & 511)])) + (0.0177404489f * fVec2[((IOTA - 37) & 511)])) + (0.0276339874f * fVec2[((IOTA - 38) & 511)])) + (0.0306455158f * fVec2[((IOTA - 39) & 511)])) + (0.0254557263f * fVec2[((IOTA - 40) & 511)])) + (0.0107271168f * fVec2[((IOTA - 41) & 511)])) + (0.00388522167f * fVec2[((IOTA - 52) & 511)])) + (0.00574654527f * fVec2[((IOTA - 53) & 511)])) + (0.000208503567f * fVec2[((IOTA - 54) & 511)])) + (0.00477328105f * fVec2[((IOTA - 57) & 511)])) + (0.00625852123f * fVec2[((IOTA - 58) & 511)])) + (0.00800124276f * fVec2[((IOTA - 65) & 511)])) + (0.0265894178f * fVec2[((IOTA - 66) & 511)])) + (0.0185823925f * fVec2[((IOTA - 67) & 511)])) + (0.0151773654f * fVec2[((IOTA - 74) & 511)])) + (0.026910523f * fVec2[((IOTA - 75) & 511)])) + (0.0194807444f * fVec2[((IOTA - 76) & 511)])) + (0.00661557354f * fVec2[((IOTA - 77) & 511)])) + (0.00104083773f * fVec2[((IOTA - 87) & 511)])) + (0.0114935879f * fVec2[((IOTA - 88) & 511)])) + (0.00717282668f * fVec2[((IOTA - 89) & 511)])) + (0.000557719264f * fVec2[((IOTA - 97) & 511)])) + (0.00512725487f * fVec2[((IOTA - 98) & 511)])) + (0.0108389407f * fVec2[((IOTA - 99) & 511)])) + (0.0153540568f * fVec2[((IOTA - 100) & 511)])) + (0.0150667857f * fVec2[((IOTA - 101) & 511)])) + (0.0111312186f * fVec2[((IOTA - 102) & 511)])) + (0.00187634351f * fVec2[((IOTA - 103) & 511)])) + (0.00175839383f * fVec2[((IOTA - 111) & 511)])) + (0.000762491021f * fVec2[((IOTA - 112) & 511)])) + (0.00222618133f * fVec2[((IOTA - 131) & 511)])) + (0.00624440331f * fVec2[((IOTA - 132) & 511)])) + (0.00844502356f * fVec2[((IOTA - 133) & 511)])) + (0.00998334587f * fVec2[((IOTA - 134) & 511)])) + (0.0104141599f * fVec2[((IOTA - 135) & 511)])) + (0.00980796106f * fVec2[((IOTA - 136) & 511)])) + (0.00735996664f * fVec2[((IOTA - 137) & 511)])) + (0.00339852693f * fVec2[((IOTA - 138) & 511)])) + (0.00469494844f * fVec2[((IOTA - 147) & 511)])) + (0.0100820782f * fVec2[((IOTA - 148) & 511)])) + (0.0121056642f * fVec2[((IOTA - 149) & 511)])) + (0.0100372061f * fVec2[((IOTA - 150) & 511)])) + (0.00439191097f * fVec2[((IOTA - 151) & 511)])) + (0.000672372989f * fVec2[((IOTA - 165) & 511)])) + (0.00307630282f * fVec2[((IOTA - 170) & 511)])) + (0.0070218211f * fVec2[((IOTA - 171) & 511)])) + (0.00760385767f * fVec2[((IOTA - 172) & 511)])) + (0.00468313182f * fVec2[((IOTA - 173) & 511)])) + (0.00104304543f * fVec2[((IOTA - 174) & 511)])) + (0.000464024954f * fVec2[((IOTA - 180) & 511)])) + (0.00387956202f * fVec2[((IOTA - 181) & 511)])) + (0.00682084309f * fVec2[((IOTA - 182) & 511)])) + (0.00923018344f * fVec2[((IOTA - 183) & 511)])) + (0.0104798051f * fVec2[((IOTA - 184) & 511)])) + (0.00949117914f * fVec2[((IOTA - 185) & 511)])) + (0.00617969129f * fVec2[((IOTA - 186) & 511)])) + (0.00267602643f * fVec2[((IOTA - 187) & 511)])) + (0.000772224274f * fVec2[((IOTA - 188) & 511)])) + (0.000281705055f * fVec2[((IOTA - 189) & 511)])) + (0.000876553822f * fVec2[((IOTA - 190) & 511)])) + (0.00241117598f * fVec2[((IOTA - 191) & 511)])) + (0.00478307623f * fVec2[((IOTA - 192) & 511)])) + (0.00777709763f * fVec2[((IOTA - 193) & 511)])) + (0.0109196054f * fVec2[((IOTA - 194) & 511)])) + (0.0137419421f * fVec2[((IOTA - 195) & 511)])) + (0.0144057944f * fVec2[((IOTA - 196) & 511)])) + (0.0119122434f * fVec2[((IOTA - 197) & 511)])) + (0.00764820166f * fVec2[((IOTA - 198) & 511)])) + (0.00280327396f * fVec2[((IOTA - 199) & 511)])) + (0.000468254089f * fVec2[((IOTA - 204) & 511)])) + (0.00507837068f * fVec2[((IOTA - 205) & 511)])) + (0.00743164448f * fVec2[((IOTA - 206) & 511)])) + (0.0064249197f * fVec2[((IOTA - 207) & 511)])) + (0.00324721029f * fVec2[((IOTA - 208) & 511)])) + (0.000992357731f * fVec2[((IOTA - 209) & 511)])) + (0.00161733944f * fVec2[((IOTA - 210) & 511)])) + (0.00470906636f * fVec2[((IOTA - 211) & 511)])) + (0.00939092226f * fVec2[((IOTA - 212) & 511)])) + (0.0136991534f * fVec2[((IOTA - 213) & 511)])) + (0.0153970635f * fVec2[((IOTA - 214) & 511)])) + (0.0137032568f * fVec2[((IOTA - 215) & 511)])) + (0.00899717584f * fVec2[((IOTA - 216) & 511)])) + (0.0034070788f * fVec2[((IOTA - 217) & 511)])) + (0.0012600692f * fVec2[((IOTA - 220) & 511)])) + (0.00399844442f * fVec2[((IOTA - 221) & 511)])) + (0.00544792367f * fVec2[((IOTA - 222) & 511)])) + (0.00595647935f * fVec2[((IOTA - 223) & 511)])) + (0.00588368205f * fVec2[((IOTA - 224) & 511)])) + (0.00579331489f * fVec2[((IOTA - 225) & 511)])) + (0.00661635119f * fVec2[((IOTA - 226) & 511)])) + (0.00790599361f * fVec2[((IOTA - 227) & 511)])) + (0.00896607991f * fVec2[((IOTA - 228) & 511)])) + (0.00959435757f * fVec2[((IOTA - 229) & 511)])) + (0.0100881103f * fVec2[((IOTA - 230) & 511)])) + (0.0115579274f * fVec2[((IOTA - 231) & 511)])) + (0.0135290539f * fVec2[((IOTA - 232) & 511)])) + (0.0143913347f * fVec2[((IOTA - 233) & 511)])) + (0.0135938898f * fVec2[((IOTA - 234) & 511)])) + (0.0113034323f * fVec2[((IOTA - 235) & 511)])) + (0.00797518343f * fVec2[((IOTA - 236) & 511)])) + (0.00472103851f * fVec2[((IOTA - 237) & 511)])) + (0.00308544561f * fVec2[((IOTA - 238) & 511)])) + (0.00411997037f * fVec2[((IOTA - 239) & 511)])) + (0.00698080426f * fVec2[((IOTA - 240) & 511)])) + (0.00879392866f * fVec2[((IOTA - 241) & 511)])) + (0.00831339136f * fVec2[((IOTA - 242) & 511)])) + (0.00666937092f * fVec2[((IOTA - 243) & 511)])) + (0.00492587266f * fVec2[((IOTA - 244) & 511)])) + (0.00382007379f * fVec2[((IOTA - 245) & 511)])) + (0.00287613366f * fVec2[((IOTA - 246) & 511)])) + (0.00128721679f * fVec2[((IOTA - 247) & 511)])) + (0.000674798153f * fVec2[((IOTA - 250) & 511)])) + (0.00367687363f * fVec2[((IOTA - 251) & 511)])) + (0.00753037632f * fVec2[((IOTA - 252) & 511)])) + (0.0111012412f * fVec2[((IOTA - 253) & 511)])) + (0.0136126727f * fVec2[((IOTA - 254) & 511)])) + (0.0137239993f * fVec2[((IOTA - 255) & 511)])) + (0.0116029549f * fVec2[((IOTA - 256) & 511)])) + (0.00939959846f * fVec2[((IOTA - 257) & 511)])) + (0.00878687017f * fVec2[((IOTA - 258) & 511)])) + (0.0100281872f * fVec2[((IOTA - 259) & 511)])) + (0.0120158568f * fVec2[((IOTA - 260) & 511)])) + (0.012824838f * fVec2[((IOTA - 261) & 511)])) + (0.011661604f * fVec2[((IOTA - 262) & 511)])) + (0.00876864698f * fVec2[((IOTA - 263) & 511)])) + (0.00485329283f * fVec2[((IOTA - 264) & 511)])) + (0.00172782596f * fVec2[((IOTA - 265) & 511)])) + (0.00103241019f * fVec2[((IOTA - 266) & 511)])) + (0.00281325588f * fVec2[((IOTA - 267) & 511)])) + (0.00661149994f * fVec2[((IOTA - 268) & 511)])) + (0.0113897882f * fVec2[((IOTA - 269) & 511)])) + (0.0152221452f * fVec2[((IOTA - 270) & 511)])) + (0.0167789701f * fVec2[((IOTA - 271) & 511)])) + (0.0155451149f * fVec2[((IOTA - 272) & 511)])) + (0.0120046008f * fVec2[((IOTA - 273) & 511)])) + (0.00820738263f * fVec2[((IOTA - 274) & 511)])) + (0.00541971903f * fVec2[((IOTA - 275) & 511)])) + (0.00312891882f * fVec2[((IOTA - 276) & 511)])) + (0.00128531968f * fVec2[((IOTA - 277) & 511)])) + (0.000430036336f * fVec2[((IOTA - 278) & 511)])) + (0.00104970019f * fVec2[((IOTA - 279) & 511)])) + (0.00293981982f * fVec2[((IOTA - 280) & 511)])) + (0.00450186897f * fVec2[((IOTA - 281) & 511)])) + (0.00477794558f * fVec2[((IOTA - 282) & 511)])) + (0.00423347345f * fVec2[((IOTA - 283) & 511)])) + (0.00360158831f * fVec2[((IOTA - 284) & 511)])) + (0.00402186019f * fVec2[((IOTA - 285) & 511)])) + (0.00538535742f * fVec2[((IOTA - 286) & 511)])) + (0.00663180603f * fVec2[((IOTA - 287) & 511)])) + (0.00783577748f * fVec2[((IOTA - 288) & 511)])) + (0.0085216146f * fVec2[((IOTA - 289) & 511)])) + (0.00776559161f * fVec2[((IOTA - 290) & 511)])) + (0.00574949943f * fVec2[((IOTA - 291) & 511)])) + (0.0033631702f * fVec2[((IOTA - 292) & 511)])) + (0.00229767291f * fVec2[((IOTA - 293) & 511)])) + (0.00329289166f * fVec2[((IOTA - 294) & 511)])) + (0.00516273594f * fVec2[((IOTA - 295) & 511)])) + (0.0070530423f * fVec2[((IOTA - 296) & 511)])) + (0.00804546196f * fVec2[((IOTA - 297) & 511)])) + (0.00759487087f * fVec2[((IOTA - 298) & 511)])) + (0.00666103698f * fVec2[((IOTA - 299) & 511)])) + (0.00586919067f * fVec2[((IOTA - 300) & 511)])) + (0.00575963734f * fVec2[((IOTA - 301) & 511)])) + (0.00685364986f * fVec2[((IOTA - 302) & 511)])) + (0.00853862427f * fVec2[((IOTA - 303) & 511)])) + (0.0104509778f * fVec2[((IOTA - 304) & 511)])) + (0.0124224778f * fVec2[((IOTA - 305) & 511)])) + (0.0130255986f * fVec2[((IOTA - 306) & 511)])) + (0.0113396905f * fVec2[((IOTA - 307) & 511)])) + (0.00768393185f * fVec2[((IOTA - 308) & 511)])) + (0.00361318747f * fVec2[((IOTA - 309) & 511)])) + (0.00148353027f * fVec2[((IOTA - 310) & 511)])) + (0.00202405313f * fVec2[((IOTA - 311) & 511)])) + (0.00413219165f * fVec2[((IOTA - 312) & 511)])) + (0.00677006226f * fVec2[((IOTA - 313) & 511)])) + (0.00893911906f * fVec2[((IOTA - 314) & 511)])) + (0.00966712367f * fVec2[((IOTA - 315) & 511)])) + (0.00860899687f * fVec2[((IOTA - 316) & 511)])) + (0.00572029967f * fVec2[((IOTA - 317) & 511)])) + (0.00233116373f * fVec2[((IOTA - 318) & 511)])) + (8.31838697e-05f * fVec2[((IOTA - 319) & 511)])) + (0.000254153274f * fVec2[((IOTA - 327) & 511)])) + (0.00107149873f * fVec2[((IOTA - 328) & 511)])) + (0.00224490184f * fVec2[((IOTA - 329) & 511)])) + (0.00380017189f * fVec2[((IOTA - 330) & 511)])) + (0.00484564295f * fVec2[((IOTA - 331) & 511)])) + (0.00491399365f * fVec2[((IOTA - 332) & 511)])) + (0.00472501898f * fVec2[((IOTA - 333) & 511)])) + (0.00405174447f * fVec2[((IOTA - 334) & 511)])) + (0.00312643079f * fVec2[((IOTA - 335) & 511)])) + (0.00307882205f * fVec2[((IOTA - 336) & 511)])) + (0.00363554619f * fVec2[((IOTA - 337) & 511)])) + (0.00474109594f * fVec2[((IOTA - 338) & 511)])) + (0.00615960266f * fVec2[((IOTA - 339) & 511)])) + (0.00699949358f * fVec2[((IOTA - 340) & 511)])) + (0.00742104044f * fVec2[((IOTA - 341) & 511)])) + (0.00683856802f * fVec2[((IOTA - 342) & 511)])) + (0.0044381828f * fVec2[((IOTA - 343) & 511)])) + (0.00171989622f * fVec2[((IOTA - 344) & 511)])) + (0.000152840279f * fVec2[((IOTA - 345) & 511)])) + (0.000317341648f * fVec2[((IOTA - 346) & 511)])) + (0.00238424586f * fVec2[((IOTA - 347) & 511)])) + (0.00562197203f * fVec2[((IOTA - 348) & 511)])) + (0.00916618668f * fVec2[((IOTA - 349) & 511)])) + (0.011815222f * fVec2[((IOTA - 350) & 511)])) + (0.0119215101f * fVec2[((IOTA - 351) & 511)])) + (0.0089185331f * fVec2[((IOTA - 352) & 511)])) + (0.00370025821f * fVec2[((IOTA - 353) & 511)])) + (0.0016550906f * fVec2[((IOTA - 359) & 511)])) + (0.00395979127f * fVec2[((IOTA - 360) & 511)])) + (0.00527241407f * fVec2[((IOTA - 361) & 511)])) + (0.00486694416f * fVec2[((IOTA - 362) & 511)])) + (0.00322634447f * fVec2[((IOTA - 363) & 511)])) + (0.00204889942f * fVec2[((IOTA - 364) & 511)])) + (0.00177664775f * fVec2[((IOTA - 365) & 511)])) + (0.0018063141f * fVec2[((IOTA - 366) & 511)])) + (0.00115371868f * fVec2[((IOTA - 367) & 511)])) + (0.00367684243f * fVec2[((IOTA - 376) & 511)])) + (0.0049412651f * fVec2[((IOTA - 377) & 511)])) + (0.00408812752f * fVec2[((IOTA - 378) & 511)])) + (0.00229117367f * fVec2[((IOTA - 379) & 511)])) + (0.00076364167f * fVec2[((IOTA - 380) & 511)])) + (0.000421142671f * fVec2[((IOTA - 384) & 511)])) + (0.00161248818f * fVec2[((IOTA - 385) & 511)])) + (0.00261467276f * fVec2[((IOTA - 386) & 511)])) + (0.00240284204f * fVec2[((IOTA - 387) & 511)])) + (0.000706019346f * fVec2[((IOTA - 388) & 511)])) + (0.00131088123f * fVec2[((IOTA - 392) & 511)])) + (0.00303746341f * fVec2[((IOTA - 393) & 511)])) + (0.00301967608f * fVec2[((IOTA - 394) & 511)])) + (0.00107802916f * fVec2[((IOTA - 395) & 511)])) + (0.000726045575f * fVec2[((IOTA - 402) & 511)])) + (0.00199830486f * fVec2[((IOTA - 403) & 511)])) + (0.0011722832f * fVec2[((IOTA - 404) & 511)])) + (0.000227690209f * fVec2[((IOTA - 418) & 511)])) + (0.00089885015f * fVec2[((IOTA - 419) & 511)])) + (0.000330558047f * fVec2[((IOTA - 420) & 511)])) + (0.000573485158f * fVec2[((IOTA - 426) & 511)])) + (0.00136813056f * fVec2[((IOTA - 427) & 511)])) + (0.00114243058f * fVec2[((IOTA - 428) & 511)])) + (6.18202612e-05f * fVec2[((IOTA - 429) & 511)])) + (4.86974604e-05f * fVec2[((IOTA - 463) & 511)])) + (0.000348065514f * fVec2[((IOTA - 472) & 511)])) + (0.00046934234f * fVec2[((IOTA - 473) & 511)])) + (0.00168220699f * fVec2[((IOTA - 487) & 511)])) + (0.000863368623f * fVec2[((IOTA - 488) & 511)])) + (0.00214069663f * fVec2[((IOTA - 495) & 511)])) + (0.00506220059f * fVec2[((IOTA - 496) & 511)])) + (0.00560356257f * fVec2[((IOTA - 497) & 511)])) + (0.00417619338f * fVec2[((IOTA - 498) & 511)])) + (0.0018985155f * fVec2[((IOTA - 499) & 511)])) - ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00466577988f * fVec2[((IOTA - 357) & 511)]) + ((0.00644192984f * fVec2[((IOTA - 356) & 511)]) + ((0.00575960614f * fVec2[((IOTA - 355) & 511)]) + ((0.00198487099f * fVec2[((IOTA - 354) & 511)]) + ((0.000168606173f * fVec2[((IOTA - 326) & 511)]) + ((0.000833609141f * fVec2[((IOTA - 325) & 511)]) + ((0.00198773202f * fVec2[((IOTA - 324) & 511)]) + ((0.00247744285f * fVec2[((IOTA - 323) & 511)]) + ((0.00219035801f * fVec2[((IOTA - 322) & 511)]) + ((0.0017713611f * fVec2[((IOTA - 321) & 511)]) + ((0.00110393297f * fVec2[((IOTA - 320) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0338563137f * fVec2[((IOTA - 6) & 511)]) + (0.145590752f * fVec2[((IOTA - 7) & 511)])) + (0.191964462f * fVec2[((IOTA - 8) & 511)])) + (0.148331523f * fVec2[((IOTA - 9) & 511)])) + (0.0742889866f * fVec2[((IOTA - 10) & 511)])) + (0.0113348402f * fVec2[((IOTA - 11) & 511)])) + (0.0197037086f * fVec2[((IOTA - 22) & 511)])) + (0.0209964905f * fVec2[((IOTA - 23) & 511)])) + (0.0166538991f * fVec2[((IOTA - 29) & 511)])) + (0.0514837876f * fVec2[((IOTA - 30) & 511)])) + (0.0680667832f * fVec2[((IOTA - 31) & 511)])) + (0.0785749182f * fVec2[((IOTA - 32) & 511)])) + (0.0730925426f * fVec2[((IOTA - 33) & 511)])) + (0.0471555628f * fVec2[((IOTA - 34) & 511)])) + (0.0202273447f * fVec2[((IOTA - 35) & 511)])) + (3.17809172e-05f * fVec2[((IOTA - 42) & 511)])) + (0.0116307558f * fVec2[((IOTA - 43) & 511)])) + (0.0311349779f * fVec2[((IOTA - 44) & 511)])) + (0.0472340174f * fVec2[((IOTA - 45) & 511)])) + (0.055726774f * fVec2[((IOTA - 46) & 511)])) + (0.0566821285f * fVec2[((IOTA - 47) & 511)])) + (0.0444025397f * fVec2[((IOTA - 48) & 511)])) + (0.0297624953f * fVec2[((IOTA - 49) & 511)])) + (0.0170829408f * fVec2[((IOTA - 50) & 511)])) + (0.00473161135f * fVec2[((IOTA - 51) & 511)])) + (0.00613786606f * fVec2[((IOTA - 55) & 511)])) + (0.00444107503f * fVec2[((IOTA - 56) & 511)])) + (0.00859201699f * fVec2[((IOTA - 59) & 511)])) + (0.0277259722f * fVec2[((IOTA - 60) & 511)])) + (0.0430775099f * fVec2[((IOTA - 61) & 511)])) + (0.0530212708f * fVec2[((IOTA - 62) & 511)])) + (0.0457822382f * fVec2[((IOTA - 63) & 511)])) + (0.0204295348f * fVec2[((IOTA - 64) & 511)])) + (0.00987864286f * fVec2[((IOTA - 68) & 511)])) + (0.0398599654f * fVec2[((IOTA - 69) & 511)])) + (0.0609105639f * fVec2[((IOTA - 70) & 511)])) + (0.0596754961f * fVec2[((IOTA - 71) & 511)])) + (0.0394212827f * fVec2[((IOTA - 72) & 511)])) + (0.0121687911f * fVec2[((IOTA - 73) & 511)])) + (0.0019447566f * fVec2[((IOTA - 78) & 511)])) + (0.00255453167f * fVec2[((IOTA - 79) & 511)])) + (0.00171796838f * fVec2[((IOTA - 80) & 511)])) + (0.00830751378f * fVec2[((IOTA - 81) & 511)])) + (0.0212031603f * fVec2[((IOTA - 82) & 511)])) + (0.0315622762f * fVec2[((IOTA - 83) & 511)])) + (0.0351037867f * fVec2[((IOTA - 84) & 511)])) + (0.0304121673f * fVec2[((IOTA - 85) & 511)])) + (0.016347535f * fVec2[((IOTA - 86) & 511)])) + (0.00937988423f * fVec2[((IOTA - 90) & 511)])) + (0.0244315565f * fVec2[((IOTA - 91) & 511)])) + (0.0329083279f * fVec2[((IOTA - 92) & 511)])) + (0.034952037f * fVec2[((IOTA - 93) & 511)])) + (0.0284606926f * fVec2[((IOTA - 94) & 511)])) + (0.0181957353f * fVec2[((IOTA - 95) & 511)])) + (0.0073864921f * fVec2[((IOTA - 96) & 511)])) + (0.0109621147f * fVec2[((IOTA - 104) & 511)])) + (0.0240216702f * fVec2[((IOTA - 105) & 511)])) + (0.03384462f * fVec2[((IOTA - 106) & 511)])) + (0.0339194685f * fVec2[((IOTA - 107) & 511)])) + (0.0258245319f * fVec2[((IOTA - 108) & 511)])) + (0.0143269952f * fVec2[((IOTA - 109) & 511)])) + (0.00355286011f * fVec2[((IOTA - 110) & 511)])) + (0.00171280606f * fVec2[((IOTA - 113) & 511)])) + (0.00198539998f * fVec2[((IOTA - 114) & 511)])) + (0.00245175697f * fVec2[((IOTA - 115) & 511)])) + (0.00446722703f * fVec2[((IOTA - 116) & 511)])) + (0.008363612f * fVec2[((IOTA - 117) & 511)])) + (0.0141349416f * fVec2[((IOTA - 118) & 511)])) + (0.0198552106f * fVec2[((IOTA - 119) & 511)])) + (0.0236036684f * fVec2[((IOTA - 120) & 511)])) + (0.0238104314f * fVec2[((IOTA - 121) & 511)])) + (0.0185588524f * fVec2[((IOTA - 122) & 511)])) + (0.0109160598f * fVec2[((IOTA - 123) & 511)])) + (0.00620030845f * fVec2[((IOTA - 124) & 511)])) + (0.00514743663f * fVec2[((IOTA - 125) & 511)])) + (0.00655748509f * fVec2[((IOTA - 126) & 511)])) + (0.00988582708f * fVec2[((IOTA - 127) & 511)])) + (0.011952389f * fVec2[((IOTA - 128) & 511)])) + (0.0096560223f * fVec2[((IOTA - 129) & 511)])) + (0.00402192259f * fVec2[((IOTA - 130) & 511)])) + (0.00142727606f * fVec2[((IOTA - 139) & 511)])) + (0.00724332267f * fVec2[((IOTA - 140) & 511)])) + (0.0133081432f * fVec2[((IOTA - 141) & 511)])) + (0.0182074271f * fVec2[((IOTA - 142) & 511)])) + (0.0196950324f * fVec2[((IOTA - 143) & 511)])) + (0.0161440056f * fVec2[((IOTA - 144) & 511)])) + (0.00951005425f * fVec2[((IOTA - 145) & 511)])) + (0.00229823263f * fVec2[((IOTA - 146) & 511)])) + (0.00169700896f * fVec2[((IOTA - 152) & 511)])) + (0.00477875397f * fVec2[((IOTA - 153) & 511)])) + (0.00481666066f * fVec2[((IOTA - 154) & 511)])) + (0.00333403237f * fVec2[((IOTA - 155) & 511)])) + (0.00167418411f * fVec2[((IOTA - 156) & 511)])) + (0.000564622693f * fVec2[((IOTA - 157) & 511)])) + (0.000652221963f * fVec2[((IOTA - 158) & 511)])) + (0.00256292755f * fVec2[((IOTA - 159) & 511)])) + (0.00508169783f * fVec2[((IOTA - 160) & 511)])) + (0.00610359758f * fVec2[((IOTA - 161) & 511)])) + (0.00551089458f * fVec2[((IOTA - 162) & 511)])) + (0.00380474329f * fVec2[((IOTA - 163) & 511)])) + (0.00107933534f * fVec2[((IOTA - 164) & 511)])) + (4.25404869e-05f * fVec2[((IOTA - 166) & 511)])) + (0.00258817803f * fVec2[((IOTA - 167) & 511)])) + (0.00428860774f * fVec2[((IOTA - 168) & 511)])) + (0.00199021958f * fVec2[((IOTA - 169) & 511)])) + (0.00146403257f * fVec2[((IOTA - 175) & 511)])) + (0.00360053126f * fVec2[((IOTA - 176) & 511)])) + (0.00522953179f * fVec2[((IOTA - 177) & 511)])) + (0.00498564029f * fVec2[((IOTA - 178) & 511)])) + (0.00282765366f * fVec2[((IOTA - 179) & 511)])) + (0.00165670784f * fVec2[((IOTA - 200) & 511)])) + (0.00440932531f * fVec2[((IOTA - 201) & 511)])) + (0.00529387081f * fVec2[((IOTA - 202) & 511)])) + (0.00369481649f * fVec2[((IOTA - 203) & 511)])) + (0.000206793193f * fVec2[((IOTA - 218) & 511)])) + (0.000814920291f * fVec2[((IOTA - 219) & 511)])) + (0.000178090762f * fVec2[((IOTA - 248) & 511)])) + (0.00050379755f * fVec2[((IOTA - 249) & 511)])) + (0.00149282813f * fVec2[((IOTA - 358) & 511)]))))))))))))) + (0.00110928155f * fVec2[((IOTA - 368) & 511)])) + (0.00467016408f * fVec2[((IOTA - 369) & 511)])) + (0.0084596388f * fVec2[((IOTA - 370) & 511)])) + (0.0112470221f * fVec2[((IOTA - 371) & 511)])) + (0.0117470883f * fVec2[((IOTA - 372) & 511)])) + (0.0094874464f * fVec2[((IOTA - 373) & 511)])) + (0.0052046855f * fVec2[((IOTA - 374) & 511)])) + (0.00016854424f * fVec2[((IOTA - 375) & 511)])) + (5.54765575e-05f * fVec2[((IOTA - 381) & 511)])) + (0.000543601345f * fVec2[((IOTA - 382) & 511)])) + (0.000472918618f * fVec2[((IOTA - 383) & 511)])) + (0.00085145887f * fVec2[((IOTA - 389) & 511)])) + (0.00134409266f * fVec2[((IOTA - 390) & 511)])) + (0.000659032259f * fVec2[((IOTA - 391) & 511)])) + (0.00247514155f * fVec2[((IOTA - 396) & 511)])) + (0.00613463204f * fVec2[((IOTA - 397) & 511)])) + (0.00820131879f * fVec2[((IOTA - 398) & 511)])) + (0.00823530741f * fVec2[((IOTA - 399) & 511)])) + (0.00600237772f * fVec2[((IOTA - 400) & 511)])) + (0.00234254543f * fVec2[((IOTA - 401) & 511)])) + (0.000627873465f * fVec2[((IOTA - 405) & 511)])) + (0.00156982336f * fVec2[((IOTA - 406) & 511)])) + (0.00180914393f * fVec2[((IOTA - 407) & 511)])) + (0.0016817716f * fVec2[((IOTA - 408) & 511)])) + (0.000912221614f * fVec2[((IOTA - 409) & 511)])) + (0.000609028619f * fVec2[((IOTA - 410) & 511)])) + (0.00139941368f * fVec2[((IOTA - 411) & 511)])) + (0.00314611522f * fVec2[((IOTA - 412) & 511)])) + (0.00558453146f * fVec2[((IOTA - 413) & 511)])) + (0.00699604163f * fVec2[((IOTA - 414) & 511)])) + (0.00639506709f * fVec2[((IOTA - 415) & 511)])) + (0.00461988105f * fVec2[((IOTA - 416) & 511)])) + (0.00204227585f * fVec2[((IOTA - 417) & 511)])) + (0.00105850073f * fVec2[((IOTA - 421) & 511)])) + (0.0029066084f * fVec2[((IOTA - 422) & 511)])) + (0.00375327794f * fVec2[((IOTA - 423) & 511)])) + (0.00291310763f * fVec2[((IOTA - 424) & 511)])) + (0.00114208832f * fVec2[((IOTA - 425) & 511)])) + (0.00210459344f * fVec2[((IOTA - 430) & 511)])) + (0.00489238137f * fVec2[((IOTA - 431) & 511)])) + (0.00714166788f * fVec2[((IOTA - 432) & 511)])) + (0.00829681661f * fVec2[((IOTA - 433) & 511)])) + (0.00836205762f * fVec2[((IOTA - 434) & 511)])) + (0.00752605405f * fVec2[((IOTA - 435) & 511)])) + (0.00647392822f * fVec2[((IOTA - 436) & 511)])) + (0.00614072708f * fVec2[((IOTA - 437) & 511)])) + (0.0072281789f * fVec2[((IOTA - 438) & 511)])) + (0.00960586313f * fVec2[((IOTA - 439) & 511)])) + (0.0118202586f * fVec2[((IOTA - 440) & 511)])) + (0.0129349828f * fVec2[((IOTA - 441) & 511)])) + (0.0130369179f * fVec2[((IOTA - 442) & 511)])) + (0.0124686249f * fVec2[((IOTA - 443) & 511)])) + (0.0115384292f * fVec2[((IOTA - 444) & 511)])) + (0.00982652605f * fVec2[((IOTA - 445) & 511)])) + (0.00745185744f * fVec2[((IOTA - 446) & 511)])) + (0.00551210763f * fVec2[((IOTA - 447) & 511)])) + (0.00454624416f * fVec2[((IOTA - 448) & 511)])) + (0.0043531023f * fVec2[((IOTA - 449) & 511)])) + (0.00433854898f * fVec2[((IOTA - 450) & 511)])) + (0.00368017005f * fVec2[((IOTA - 451) & 511)])) + (0.0025971029f * fVec2[((IOTA - 452) & 511)])) + (0.00170263741f * fVec2[((IOTA - 453) & 511)])) + (0.00113359885f * fVec2[((IOTA - 454) & 511)])) + (0.00180062326f * fVec2[((IOTA - 455) & 511)])) + (0.0042739301f * fVec2[((IOTA - 456) & 511)])) + (0.00738291582f * fVec2[((IOTA - 457) & 511)])) + (0.00901599042f * fVec2[((IOTA - 458) & 511)])) + (0.00795966573f * fVec2[((IOTA - 459) & 511)])) + (0.00513565075f * fVec2[((IOTA - 460) & 511)])) + (0.00211106148f * fVec2[((IOTA - 461) & 511)])) + (9.51578841e-06f * fVec2[((IOTA - 462) & 511)])) + (0.00235538837f * fVec2[((IOTA - 464) & 511)])) + (0.00613245554f * fVec2[((IOTA - 465) & 511)])) + (0.00952970795f * fVec2[((IOTA - 466) & 511)])) + (0.0110239033f * fVec2[((IOTA - 467) & 511)])) + (0.0100518204f * fVec2[((IOTA - 468) & 511)])) + (0.00722015556f * fVec2[((IOTA - 469) & 511)])) + (0.00377401989f * fVec2[((IOTA - 470) & 511)])) + (0.00105125504f * fVec2[((IOTA - 471) & 511)])) + (0.000421733595f * fVec2[((IOTA - 474) & 511)])) + (0.00157109834f * fVec2[((IOTA - 475) & 511)])) + (0.00158164045f * fVec2[((IOTA - 476) & 511)])) + (0.00044673495f * fVec2[((IOTA - 477) & 511)])) + (0.00023024017f * fVec2[((IOTA - 478) & 511)])) + (0.00194662204f * fVec2[((IOTA - 479) & 511)])) + (0.00462653581f * fVec2[((IOTA - 480) & 511)])) + (0.00722889369f * fVec2[((IOTA - 481) & 511)])) + (0.00901026838f * fVec2[((IOTA - 482) & 511)])) + (0.00954796188f * fVec2[((IOTA - 483) & 511)])) + (0.00796703622f * fVec2[((IOTA - 484) & 511)])) + (0.00431833649f * fVec2[((IOTA - 485) & 511)])) + (0.000474846456f * fVec2[((IOTA - 486) & 511)])) + (0.00246149022f * fVec2[((IOTA - 489) & 511)])) + (0.00603534048f * fVec2[((IOTA - 490) & 511)])) + (0.00852021575f * fVec2[((IOTA - 491) & 511)])) + (0.00891763158f * fVec2[((IOTA - 492) & 511)])) + (0.00648366148f * fVec2[((IOTA - 493) & 511)])) + (0.00220363634f * fVec2[((IOTA - 494) & 511)])) + (0.000707201194f * fVec2[((IOTA - 500) & 511)])) + (0.00289709261f * fVec2[((IOTA - 501) & 511)])) + (0.00411673635f * fVec2[((IOTA - 502) & 511)])) + (0.00514880475f * fVec2[((IOTA - 503) & 511)])) + (0.00682466803f * fVec2[((IOTA - 504) & 511)])) + (0.00901222788f * fVec2[((IOTA - 505) & 511)])) + (0.0110035352f * fVec2[((IOTA - 506) & 511)])) + (0.0116403643f * fVec2[((IOTA - 507) & 511)])) + (0.0106173456f * fVec2[((IOTA - 508) & 511)])) + (0.00870085601f * fVec2[((IOTA - 509) & 511)])) + (0.00649725087f * fVec2[((IOTA - 510) & 511)])) + (0.00469616102f * fVec2[((IOTA - 511) & 511)]))) : ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00418897625f * fVec1[((IOTA - 20) & 511)]) + ((0.0169657543f * fVec1[((IOTA - 19) & 511)]) + ((0.0334376656f * fVec1[((IOTA - 18) & 511)]) + ((0.0358495414f * fVec1[((IOTA - 17) & 511)]) + ((0.0370058417f * fVec1[((IOTA - 16) & 511)]) + ((0.0455574654f * fVec1[((IOTA - 15) & 511)]) + ((0.0421108939f * fVec1[((IOTA - 14) & 511)]) + ((0.0252749454f * fVec1[((IOTA - 13) & 511)]) + ((0.0103768352f * fVec1[((IOTA - 12) & 511)]) + ((0.0216898136f * fVec1[((IOTA - 6) & 511)]) + ((0.112800464f * fVec1[((IOTA - 5) & 511)]) + ((0.185279459f * fVec1[((IOTA - 4) & 511)]) + ((0.238267645f * fVec1[((IOTA - 3) & 511)]) + ((0.262707233f * fVec1[((IOTA - 2) & 511)]) + ((0.208740115f * fVec1[((IOTA - 1) & 511)]) + ((fSlow12 * fTemp0) + ((0.0557483099f * fVec1[((IOTA - 28) & 511)]) + ((0.0151431039f * fVec1[((IOTA - 36) & 511)]) + ((0.0170514733f * fVec1[((IOTA - 29) & 511)]) + ((0.00413668342f * fVec1[((IOTA - 35) & 511)]) + ((0.00121118873f * fVec1[((IOTA - 37) & 511)]) + (((0.0420937128f * fVec1[((IOTA - 26) & 511)]) + ((0.0089501217f * fVec1[((IOTA - 25) & 511)]) + (0.0609558076f * fVec1[((IOTA - 27) & 511)]))) + (0.0116415164f * fVec1[((IOTA - 42) & 511)]))))))))))))))))))))))) + (0.0190409534f * fVec1[((IOTA - 43) & 511)])) + (0.00473067211f * fVec1[((IOTA - 44) & 511)])) + (0.0190426726f * fVec1[((IOTA - 53) & 511)])) + (0.0468192622f * fVec1[((IOTA - 54) & 511)])) + (0.0513633601f * fVec1[((IOTA - 55) & 511)])) + (0.0407225341f * fVec1[((IOTA - 56) & 511)])) + (0.0146027692f * fVec1[((IOTA - 57) & 511)])) + (0.00348106585f * fVec1[((IOTA - 66) & 511)])) + (0.00346411066f * fVec1[((IOTA - 67) & 511)])) + (0.00405061012f * fVec1[((IOTA - 77) & 511)])) + (0.0150977168f * fVec1[((IOTA - 78) & 511)])) + (0.0201174077f * fVec1[((IOTA - 79) & 511)])) + (0.0141411172f * fVec1[((IOTA - 80) & 511)])) + (0.000804714393f * fVec1[((IOTA - 87) & 511)])) + (0.00905853324f * fVec1[((IOTA - 88) & 511)])) + (0.00452146959f * fVec1[((IOTA - 89) & 511)])) + (0.00403777184f * fVec1[((IOTA - 101) & 511)])) + (0.0162193961f * fVec1[((IOTA - 102) & 511)])) + (0.0193686485f * fVec1[((IOTA - 103) & 511)])) + (0.0108396877f * fVec1[((IOTA - 104) & 511)])) + (0.00188058475f * fVec1[((IOTA - 115) & 511)])) + (0.00767480768f * fVec1[((IOTA - 127) & 511)])) + (0.0102759469f * fVec1[((IOTA - 128) & 511)])) + (0.00689855777f * fVec1[((IOTA - 129) & 511)])) + (0.0012917514f * fVec1[((IOTA - 130) & 511)])) + (0.00300531136f * fVec1[((IOTA - 134) & 511)])) + (0.00785548054f * fVec1[((IOTA - 135) & 511)])) + (0.0102487141f * fVec1[((IOTA - 136) & 511)])) + (0.00925324392f * fVec1[((IOTA - 137) & 511)])) + (0.00466281828f * fVec1[((IOTA - 138) & 511)])) + (4.30205837e-05f * fVec1[((IOTA - 146) & 511)])) + (0.00211196207f * fVec1[((IOTA - 147) & 511)])) + (0.00180063862f * fVec1[((IOTA - 148) & 511)])) + (0.00318750832f * fVec1[((IOTA - 154) & 511)])) + (0.00595314289f * fVec1[((IOTA - 155) & 511)])) + (0.00543423789f * fVec1[((IOTA - 156) & 511)])) + (0.00167913083f * fVec1[((IOTA - 157) & 511)])) + (0.00222799135f * fVec1[((IOTA - 169) & 511)])) + (0.00619645044f * fVec1[((IOTA - 170) & 511)])) + (0.00819624215f * fVec1[((IOTA - 171) & 511)])) + (0.00841286778f * fVec1[((IOTA - 172) & 511)])) + (0.00756182615f * fVec1[((IOTA - 173) & 511)])) + (0.00565708894f * fVec1[((IOTA - 174) & 511)])) + (0.00357800024f * fVec1[((IOTA - 175) & 511)])) + (1.98408961e-05f * fVec1[((IOTA - 176) & 511)])) + (0.00678538159f * fVec1[((IOTA - 182) & 511)])) + (0.0120371636f * fVec1[((IOTA - 183) & 511)])) + (0.014649421f * fVec1[((IOTA - 184) & 511)])) + (0.0143321007f * fVec1[((IOTA - 185) & 511)])) + (0.0107489778f * fVec1[((IOTA - 186) & 511)])) + (0.0051087793f * fVec1[((IOTA - 187) & 511)])) + (0.000572429504f * fVec1[((IOTA - 188) & 511)])) + (0.000137620606f * fVec1[((IOTA - 189) & 511)])) + (0.00448049139f * fVec1[((IOTA - 190) & 511)])) + (0.0102163274f * fVec1[((IOTA - 191) & 511)])) + (0.013597412f * fVec1[((IOTA - 192) & 511)])) + (0.0134204347f * fVec1[((IOTA - 193) & 511)])) + (0.0109723154f * fVec1[((IOTA - 194) & 511)])) + (0.00849835761f * fVec1[((IOTA - 195) & 511)])) + (0.00659777038f * fVec1[((IOTA - 196) & 511)])) + (0.0048379479f * fVec1[((IOTA - 197) & 511)])) + (0.0031838771f * fVec1[((IOTA - 198) & 511)])) + (0.00157882506f * fVec1[((IOTA - 199) & 511)])) + (0.000620280392f * fVec1[((IOTA - 200) & 511)])) + (0.000576611608f * fVec1[((IOTA - 201) & 511)])) + (0.00176569028f * fVec1[((IOTA - 202) & 511)])) + (0.00424230611f * fVec1[((IOTA - 203) & 511)])) + (0.00737800822f * fVec1[((IOTA - 204) & 511)])) + (0.010376025f * fVec1[((IOTA - 205) & 511)])) + (0.0114532895f * fVec1[((IOTA - 206) & 511)])) + (0.00936207548f * fVec1[((IOTA - 207) & 511)])) + (0.00511857029f * fVec1[((IOTA - 208) & 511)])) + (0.00150020793f * fVec1[((IOTA - 209) & 511)])) + (0.000229723752f * fVec1[((IOTA - 211) & 511)])) + (0.00319768814f * fVec1[((IOTA - 212) & 511)])) + (0.00821212679f * fVec1[((IOTA - 213) & 511)])) + (0.0138662979f * fVec1[((IOTA - 214) & 511)])) + (0.0190919172f * fVec1[((IOTA - 215) & 511)])) + (0.0221510772f * fVec1[((IOTA - 216) & 511)])) + (0.0213343669f * fVec1[((IOTA - 217) & 511)])) + (0.0157850087f * fVec1[((IOTA - 218) & 511)])) + (0.00726421596f * fVec1[((IOTA - 219) & 511)])) + (0.000295113772f * fVec1[((IOTA - 220) & 511)])) + (0.00114712818f * fVec1[((IOTA - 224) & 511)])) + (0.00376833417f * fVec1[((IOTA - 225) & 511)])) + (0.00517264567f * fVec1[((IOTA - 226) & 511)])) + (0.00581759727f * fVec1[((IOTA - 227) & 511)])) + (0.00768803479f * fVec1[((IOTA - 228) & 511)])) + (0.0122575499f * fVec1[((IOTA - 229) & 511)])) + (0.0185795929f * fVec1[((IOTA - 230) & 511)])) + (0.0236179568f * fVec1[((IOTA - 231) & 511)])) + (0.0250739455f * fVec1[((IOTA - 232) & 511)])) + (0.0225961637f * fVec1[((IOTA - 233) & 511)])) + (0.0172503646f * fVec1[((IOTA - 234) & 511)])) + (0.0115522332f * fVec1[((IOTA - 235) & 511)])) + (0.00789681636f * fVec1[((IOTA - 236) & 511)])) + (0.0070959595f * fVec1[((IOTA - 237) & 511)])) + (0.00835059024f * fVec1[((IOTA - 238) & 511)])) + (0.0105487239f * fVec1[((IOTA - 239) & 511)])) + (0.0126416869f * fVec1[((IOTA - 240) & 511)])) + (0.0131556969f * fVec1[((IOTA - 241) & 511)])) + (0.0111355465f * fVec1[((IOTA - 242) & 511)])) + (0.00750959851f * fVec1[((IOTA - 243) & 511)])) + (0.00386059983f * fVec1[((IOTA - 244) & 511)])) + (0.00230304198f * fVec1[((IOTA - 245) & 511)])) + (0.00385781191f * fVec1[((IOTA - 246) & 511)])) + (0.00679377792f * fVec1[((IOTA - 247) & 511)])) + (0.0089891227f * fVec1[((IOTA - 248) & 511)])) + (0.00917556696f * fVec1[((IOTA - 249) & 511)])) + (0.00695593981f * fVec1[((IOTA - 250) & 511)])) + (0.00401433278f * fVec1[((IOTA - 251) & 511)])) + (0.00212441105f * fVec1[((IOTA - 252) & 511)])) + (0.00256680651f * fVec1[((IOTA - 253) & 511)])) + (0.00603675237f * fVec1[((IOTA - 254) & 511)])) + (0.0109355841f * fVec1[((IOTA - 255) & 511)])) + (0.0149209984f * fVec1[((IOTA - 256) & 511)])) + (0.0167535059f * fVec1[((IOTA - 257) & 511)])) + (0.0156391859f * fVec1[((IOTA - 258) & 511)])) + (0.0127430633f * fVec1[((IOTA - 259) & 511)])) + (0.0107934251f * fVec1[((IOTA - 260) & 511)])) + (0.0103356633f * fVec1[((IOTA - 261) & 511)])) + (0.0104036462f * fVec1[((IOTA - 262) & 511)])) + (0.0107516684f * fVec1[((IOTA - 263) & 511)])) + (0.0114755938f * fVec1[((IOTA - 264) & 511)])) + (0.0123721845f * fVec1[((IOTA - 265) & 511)])) + (0.0126706706f * fVec1[((IOTA - 266) & 511)])) + (0.0114929061f * fVec1[((IOTA - 267) & 511)])) + (0.00987144932f * fVec1[((IOTA - 268) & 511)])) + (0.00959144346f * fVec1[((IOTA - 269) & 511)])) + (0.0111988951f * fVec1[((IOTA - 270) & 511)])) + (0.0142323133f * fVec1[((IOTA - 271) & 511)])) + (0.0169322975f * fVec1[((IOTA - 272) & 511)])) + (0.0177078675f * fVec1[((IOTA - 273) & 511)])) + (0.0161948539f * fVec1[((IOTA - 274) & 511)])) + (0.0122486996f * fVec1[((IOTA - 275) & 511)])) + (0.00789843686f * fVec1[((IOTA - 276) & 511)])) + (0.00561883394f * fVec1[((IOTA - 277) & 511)])) + (0.00547220092f * fVec1[((IOTA - 278) & 511)])) + (0.00658716913f * fVec1[((IOTA - 279) & 511)])) + (0.00791555457f * fVec1[((IOTA - 280) & 511)])) + (0.00826594327f * fVec1[((IOTA - 281) & 511)])) + (0.00742880953f * fVec1[((IOTA - 282) & 511)])) + (0.00562029285f * fVec1[((IOTA - 283) & 511)])) + (0.00378240459f * fVec1[((IOTA - 284) & 511)])) + (0.0030470998f * fVec1[((IOTA - 285) & 511)])) + (0.00329121808f * fVec1[((IOTA - 286) & 511)])) + (0.0044086501f * fVec1[((IOTA - 287) & 511)])) + (0.00591650885f * fVec1[((IOTA - 288) & 511)])) + (0.00678739138f * fVec1[((IOTA - 289) & 511)])) + (0.00725912629f * fVec1[((IOTA - 290) & 511)])) + (0.00795481354f * fVec1[((IOTA - 291) & 511)])) + (0.00932427496f * fVec1[((IOTA - 292) & 511)])) + (0.011505615f * fVec1[((IOTA - 293) & 511)])) + (0.0130572077f * fVec1[((IOTA - 294) & 511)])) + (0.0126914512f * fVec1[((IOTA - 295) & 511)])) + (0.0104130479f * fVec1[((IOTA - 296) & 511)])) + (0.00651558721f * fVec1[((IOTA - 297) & 511)])) + (0.00187286921f * fVec1[((IOTA - 298) & 511)])) + (0.000275176018f * fVec1[((IOTA - 300) & 511)])) + (0.00421889918f * fVec1[((IOTA - 301) & 511)])) + (0.00919835828f * fVec1[((IOTA - 302) & 511)])) + (0.0141724348f * fVec1[((IOTA - 303) & 511)])) + (0.0176396575f * fVec1[((IOTA - 304) & 511)])) + (0.0190034769f * fVec1[((IOTA - 305) & 511)])) + (0.0174438767f * fVec1[((IOTA - 306) & 511)])) + (0.0129654603f * fVec1[((IOTA - 307) & 511)])) + (0.00813720562f * fVec1[((IOTA - 308) & 511)])) + (0.00459353765f * fVec1[((IOTA - 309) & 511)])) + (0.00293120043f * fVec1[((IOTA - 310) & 511)])) + (0.00394605752f * fVec1[((IOTA - 311) & 511)])) + (0.0072657722f * fVec1[((IOTA - 312) & 511)])) + (0.0118001774f * fVec1[((IOTA - 313) & 511)])) + (0.0151042333f * fVec1[((IOTA - 314) & 511)])) + (0.0150356982f * fVec1[((IOTA - 315) & 511)])) + (0.0123819113f * fVec1[((IOTA - 316) & 511)])) + (0.00814190693f * fVec1[((IOTA - 317) & 511)])) + (0.00359479338f * fVec1[((IOTA - 318) & 511)])) + (0.000803514849f * fVec1[((IOTA - 319) & 511)])) + (9.10987146e-05f * fVec1[((IOTA - 320) & 511)])) + (0.000611916184f * fVec1[((IOTA - 321) & 511)])) + (0.00120318122f * fVec1[((IOTA - 322) & 511)])) + (0.000375125092f * fVec1[((IOTA - 323) & 511)])) + (0.000876102131f * fVec1[((IOTA - 327) & 511)])) + (0.00316008134f * fVec1[((IOTA - 328) & 511)])) + (0.00477051549f * fVec1[((IOTA - 329) & 511)])) + (0.0049077794f * fVec1[((IOTA - 330) & 511)])) + (0.00288004288f * fVec1[((IOTA - 331) & 511)])) + (0.00028457772f * fVec1[((IOTA - 332) & 511)])) + (0.00153807364f * fVec1[((IOTA - 334) & 511)])) + (0.00497589214f * fVec1[((IOTA - 335) & 511)])) + (0.00771980593f * fVec1[((IOTA - 336) & 511)])) + (0.00823011994f * fVec1[((IOTA - 337) & 511)])) + (0.00726402132f * fVec1[((IOTA - 338) & 511)])) + (0.00580248982f * fVec1[((IOTA - 339) & 511)])) + (0.00455223536f * fVec1[((IOTA - 340) & 511)])) + (0.00448862882f * fVec1[((IOTA - 341) & 511)])) + (0.00566713884f * fVec1[((IOTA - 342) & 511)])) + (0.00703997118f * fVec1[((IOTA - 343) & 511)])) + (0.00757035241f * fVec1[((IOTA - 344) & 511)])) + (0.00708895689f * fVec1[((IOTA - 345) & 511)])) + (0.00646566134f * fVec1[((IOTA - 346) & 511)])) + (0.00676262286f * fVec1[((IOTA - 347) & 511)])) + (0.00788167585f * fVec1[((IOTA - 348) & 511)])) + (0.00914846361f * fVec1[((IOTA - 349) & 511)])) + (0.0102552306f * fVec1[((IOTA - 350) & 511)])) + (0.0104446243f * fVec1[((IOTA - 351) & 511)])) + (0.00916548446f * fVec1[((IOTA - 352) & 511)])) + (0.00661527691f * fVec1[((IOTA - 353) & 511)])) + (0.00244247774f * fVec1[((IOTA - 354) & 511)])) + (0.000695817638f * fVec1[((IOTA - 359) & 511)])) + (0.00493718358f * fVec1[((IOTA - 360) & 511)])) + (0.00706940796f * fVec1[((IOTA - 361) & 511)])) + (0.00636720331f * fVec1[((IOTA - 362) & 511)])) + (0.00420327298f * fVec1[((IOTA - 363) & 511)])) + (0.00292448979f * fVec1[((IOTA - 364) & 511)])) + (0.00296553271f * fVec1[((IOTA - 365) & 511)])) + (0.00286850147f * fVec1[((IOTA - 366) & 511)])) + (0.00119770272f * fVec1[((IOTA - 367) & 511)])) + (0.000561860856f * fVec1[((IOTA - 376) & 511)])) + (0.00198452128f * fVec1[((IOTA - 377) & 511)])) + (0.00183801819f * fVec1[((IOTA - 378) & 511)])) + (0.000261008739f * fVec1[((IOTA - 379) & 511)])) + (0.000379015226f * fVec1[((IOTA - 383) & 511)])) + (0.0033721691f * fVec1[((IOTA - 384) & 511)])) + (0.00497692963f * fVec1[((IOTA - 385) & 511)])) + (0.00480659818f * fVec1[((IOTA - 386) & 511)])) + (0.00302058086f * fVec1[((IOTA - 387) & 511)])) + (0.000406312291f * fVec1[((IOTA - 388) & 511)])) + (0.00237579131f * fVec1[((IOTA - 392) & 511)])) + (0.00547648035f * fVec1[((IOTA - 393) & 511)])) + (0.0066043837f * fVec1[((IOTA - 394) & 511)])) + (0.00546211842f * fVec1[((IOTA - 395) & 511)])) + (0.00178793026f * fVec1[((IOTA - 396) & 511)])) + (0.000120826997f * fVec1[((IOTA - 409) & 511)])) + (0.001317719f * fVec1[((IOTA - 418) & 511)])) + (0.00414034724f * fVec1[((IOTA - 419) & 511)])) + (0.00499547366f * fVec1[((IOTA - 420) & 511)])) + (0.00382798584f * fVec1[((IOTA - 421) & 511)])) + (0.00136758015f * fVec1[((IOTA - 422) & 511)])) + (0.0012371568f * fVec1[((IOTA - 477) & 511)])) + (3.02796252e-05f * fVec1[((IOTA - 478) & 511)])) + (0.000836582854f * fVec1[((IOTA - 487) & 511)])) + (0.00116638513f * fVec1[((IOTA - 488) & 511)])) + (0.00126714492f * fVec1[((IOTA - 496) & 511)])) + (0.00291677378f * fVec1[((IOTA - 497) & 511)])) + (0.00288503524f * fVec1[((IOTA - 498) & 511)])) + (0.00221194373f * fVec1[((IOTA - 499) & 511)])) + (0.00119773485f * fVec1[((IOTA - 500) & 511)])) + (0.000128251035f * fVec1[((IOTA - 501) & 511)])) - ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.00416728761f * fVec1[((IOTA - 424) & 511)]) + ((0.00137980236f * fVec1[((IOTA - 423) & 511)]) + ((0.00298161246f * fVec1[((IOTA - 417) & 511)]) + ((0.00668066693f * fVec1[((IOTA - 416) & 511)]) + ((0.00870097987f * fVec1[((IOTA - 415) & 511)]) + ((0.00979066081f * fVec1[((IOTA - 414) & 511)]) + ((0.00915228948f * fVec1[((IOTA - 413) & 511)]) + ((0.00623292243f * fVec1[((IOTA - 412) & 511)]) + ((0.00265994715f * fVec1[((IOTA - 411) & 511)]) + ((0.00022045197f * fVec1[((IOTA - 410) & 511)]) + ((0.000536281615f * fVec1[((IOTA - 408) & 511)]) + ((0.000571456738f * fVec1[((IOTA - 407) & 511)]) + ((0.00088670291f * fVec1[((IOTA - 406) & 511)]) + ((0.00220225006f * fVec1[((IOTA - 405) & 511)]) + ((0.00309569668f * fVec1[((IOTA - 404) & 511)]) + ((0.00333132083f * fVec1[((IOTA - 403) & 511)]) + ((0.0043242625f * fVec1[((IOTA - 402) & 511)]) + ((0.00697604008f * fVec1[((IOTA - 401) & 511)]) + ((0.010189062f * fVec1[((IOTA - 400) & 511)]) + ((0.0111176837f * fVec1[((IOTA - 399) & 511)]) + ((0.00839270279f * fVec1[((IOTA - 398) & 511)]) + ((0.00341972848f * fVec1[((IOTA - 397) & 511)]) + ((0.00117650023f * fVec1[((IOTA - 391) & 511)]) + ((0.00251924712f * fVec1[((IOTA - 390) & 511)]) + ((0.00165854441f * fVec1[((IOTA - 389) & 511)]) + ((0.00219732244f * fVec1[((IOTA - 382) & 511)]) + ((0.00284580793f * fVec1[((IOTA - 381) & 511)]) + ((0.0017446829f * fVec1[((IOTA - 380) & 511)]) + ((0.00273768883f * fVec1[((IOTA - 375) & 511)]) + ((0.00738150952f * fVec1[((IOTA - 374) & 511)]) + ((0.0111262742f * fVec1[((IOTA - 373) & 511)]) + ((0.0102982186f * fVec1[((IOTA - 371) & 511)]) + ((0.00731686503f * fVec1[((IOTA - 370) & 511)]) + ((0.00463030161f * fVec1[((IOTA - 369) & 511)]) + ((0.00179318199f * fVec1[((IOTA - 368) & 511)]) + (((0.00389849814f * fVec1[((IOTA - 358) & 511)]) + ((0.00665119756f * fVec1[((IOTA - 357) & 511)]) + ((0.00605964055f * fVec1[((IOTA - 356) & 511)]) + ((0.00252099754f * fVec1[((IOTA - 355) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0338626504f * fVec1[((IOTA - 23) & 511)]) + ((0.0237636194f * fVec1[((IOTA - 22) & 511)]) + ((0.00650086859f * fVec1[((IOTA - 21) & 511)]) + ((0.00668491377f * fVec1[((IOTA - 11) & 511)]) + ((0.0365187414f * fVec1[((IOTA - 10) & 511)]) + ((0.0884655192f * fVec1[((IOTA - 9) & 511)]) + ((0.126075536f * fVec1[((IOTA - 8) & 511)]) + ((0.0804191232f * fVec1[((IOTA - 7) & 511)]) + ((0.103135012f * fVec1[((IOTA - 32) & 511)]) + ((0.0861127451f * fVec1[((IOTA - 33) & 511)]) + ((0.022048112f * fVec1[((IOTA - 24) & 511)]) + (((0.0199011713f * fVec1[((IOTA - 38) & 511)]) + ((0.0879630223f * fVec1[((IOTA - 31) & 511)]) + ((((0.0409066416f * fVec1[((IOTA - 30) & 511)]) + (0.0400995612f * fVec1[((IOTA - 34) & 511)])) + (0.0316053219f * fVec1[((IOTA - 39) & 511)])) + (0.0223043561f * fVec1[((IOTA - 40) & 511)])))) + (0.00654833065f * fVec1[((IOTA - 41) & 511)]))))))))))))) + (0.0165740326f * fVec1[((IOTA - 45) & 511)])) + (0.0431433246f * fVec1[((IOTA - 46) & 511)])) + (0.0665761977f * fVec1[((IOTA - 47) & 511)])) + (0.0723277926f * fVec1[((IOTA - 48) & 511)])) + (0.0709528178f * fVec1[((IOTA - 49) & 511)])) + (0.0654654428f * fVec1[((IOTA - 50) & 511)])) + (0.0475077517f * fVec1[((IOTA - 51) & 511)])) + (0.0175485276f * fVec1[((IOTA - 52) & 511)])) + (0.0216987934f * fVec1[((IOTA - 58) & 511)])) + (0.0531257093f * fVec1[((IOTA - 59) & 511)])) + (0.0692593604f * fVec1[((IOTA - 60) & 511)])) + (0.0708700195f * fVec1[((IOTA - 61) & 511)])) + (0.0600111708f * fVec1[((IOTA - 62) & 511)])) + (0.0414434113f * fVec1[((IOTA - 63) & 511)])) + (0.0235325973f * fVec1[((IOTA - 64) & 511)])) + (0.00975950528f * fVec1[((IOTA - 65) & 511)])) + (0.0117078461f * fVec1[((IOTA - 68) & 511)])) + (0.0235950053f * fVec1[((IOTA - 69) & 511)])) + (0.0288729481f * fVec1[((IOTA - 70) & 511)])) + (0.0331534781f * fVec1[((IOTA - 71) & 511)])) + (0.0370769054f * fVec1[((IOTA - 72) & 511)])) + (0.0376843177f * fVec1[((IOTA - 73) & 511)])) + (0.029194355f * fVec1[((IOTA - 74) & 511)])) + (0.0150516815f * fVec1[((IOTA - 75) & 511)])) + (0.00510923332f * fVec1[((IOTA - 76) & 511)])) + (0.00478659524f * fVec1[((IOTA - 81) & 511)])) + (0.0292824395f * fVec1[((IOTA - 82) & 511)])) + (0.0454318412f * fVec1[((IOTA - 83) & 511)])) + (0.0470556654f * fVec1[((IOTA - 84) & 511)])) + (0.0360488221f * fVec1[((IOTA - 85) & 511)])) + (0.016543135f * fVec1[((IOTA - 86) & 511)])) + (0.0114131216f * fVec1[((IOTA - 90) & 511)])) + (0.0238790959f * fVec1[((IOTA - 91) & 511)])) + (0.0277202129f * fVec1[((IOTA - 92) & 511)])) + (0.0268128905f * fVec1[((IOTA - 93) & 511)])) + (0.0197645556f * fVec1[((IOTA - 94) & 511)])) + (0.0122956429f * fVec1[((IOTA - 95) & 511)])) + (0.0127312951f * fVec1[((IOTA - 96) & 511)])) + (0.0204209182f * fVec1[((IOTA - 97) & 511)])) + (0.0276497006f * fVec1[((IOTA - 98) & 511)])) + (0.0257723257f * fVec1[((IOTA - 99) & 511)])) + (0.0130408676f * fVec1[((IOTA - 100) & 511)])) + (0.00507704075f * fVec1[((IOTA - 105) & 511)])) + (0.0191637259f * fVec1[((IOTA - 106) & 511)])) + (0.0284116212f * fVec1[((IOTA - 107) & 511)])) + (0.0309195854f * fVec1[((IOTA - 108) & 511)])) + (0.0264290441f * fVec1[((IOTA - 109) & 511)])) + (0.0193261467f * fVec1[((IOTA - 110) & 511)])) + (0.0135050807f * fVec1[((IOTA - 111) & 511)])) + (0.0110358577f * fVec1[((IOTA - 112) & 511)])) + (0.00714264344f * fVec1[((IOTA - 113) & 511)])) + (0.00104056578f * fVec1[((IOTA - 114) & 511)])) + (0.000231344718f * fVec1[((IOTA - 116) & 511)])) + (0.00602631364f * fVec1[((IOTA - 117) & 511)])) + (0.0148349898f * fVec1[((IOTA - 118) & 511)])) + (0.0244623218f * fVec1[((IOTA - 119) & 511)])) + (0.033608485f * fVec1[((IOTA - 120) & 511)])) + (0.0394472517f * fVec1[((IOTA - 121) & 511)])) + (0.0395902544f * fVec1[((IOTA - 122) & 511)])) + (0.033584103f * fVec1[((IOTA - 123) & 511)])) + (0.0247028731f * fVec1[((IOTA - 124) & 511)])) + (0.0126825031f * fVec1[((IOTA - 125) & 511)])) + (0.000422457233f * fVec1[((IOTA - 126) & 511)])) + (0.0026438348f * fVec1[((IOTA - 131) & 511)])) + (0.00432727719f * fVec1[((IOTA - 132) & 511)])) + (0.0021131942f * fVec1[((IOTA - 133) & 511)])) + (0.00142771797f * fVec1[((IOTA - 139) & 511)])) + (0.00532712415f * fVec1[((IOTA - 140) & 511)])) + (0.00983008184f * fVec1[((IOTA - 141) & 511)])) + (0.0142170116f * fVec1[((IOTA - 142) & 511)])) + (0.0149267046f * fVec1[((IOTA - 143) & 511)])) + (0.0113387834f * fVec1[((IOTA - 144) & 511)])) + (0.00508138491f * fVec1[((IOTA - 145) & 511)])) + (0.0021850355f * fVec1[((IOTA - 149) & 511)])) + (0.00696923165f * fVec1[((IOTA - 150) & 511)])) + (0.00850578211f * fVec1[((IOTA - 151) & 511)])) + (0.00615540752f * fVec1[((IOTA - 152) & 511)])) + (0.00154313119f * fVec1[((IOTA - 153) & 511)])) + (0.0040001655f * fVec1[((IOTA - 158) & 511)])) + (0.00792972185f * fVec1[((IOTA - 159) & 511)])) + (0.00839215145f * fVec1[((IOTA - 160) & 511)])) + (0.0061334921f * fVec1[((IOTA - 161) & 511)])) + (0.00417036749f * fVec1[((IOTA - 162) & 511)])) + (0.00399267673f * fVec1[((IOTA - 163) & 511)])) + (0.0044829878f * fVec1[((IOTA - 164) & 511)])) + (0.00396635197f * fVec1[((IOTA - 165) & 511)])) + (0.00329047255f * fVec1[((IOTA - 166) & 511)])) + (0.00279413117f * fVec1[((IOTA - 167) & 511)])) + (0.00131048961f * fVec1[((IOTA - 168) & 511)])) + (0.00542263174f * fVec1[((IOTA - 177) & 511)])) + (0.00950725004f * fVec1[((IOTA - 178) & 511)])) + (0.0103220139f * fVec1[((IOTA - 179) & 511)])) + (0.00731449854f * fVec1[((IOTA - 180) & 511)])) + (0.000656330958f * fVec1[((IOTA - 181) & 511)])) + (0.000113954302f * fVec1[((IOTA - 210) & 511)])) + (0.00286882557f * fVec1[((IOTA - 221) & 511)])) + (0.00311342999f * fVec1[((IOTA - 222) & 511)])) + (0.00155220879f * fVec1[((IOTA - 223) & 511)])) + (0.000875259284f * fVec1[((IOTA - 299) & 511)])) + (0.00133924559f * fVec1[((IOTA - 324) & 511)])) + (0.00220675627f * fVec1[((IOTA - 325) & 511)])) + (0.0013124994f * fVec1[((IOTA - 326) & 511)])) + (0.000359368976f * fVec1[((IOTA - 333) & 511)])) + (0.0121324109f * fVec1[((IOTA - 372) & 511)])))))) + (0.00561316079f * fVec1[((IOTA - 425) & 511)]))))))))))))))))))))))))))))))))))))) + (0.00477654533f * fVec1[((IOTA - 426) & 511)])) + (0.00279957755f * fVec1[((IOTA - 427) & 511)])) + (0.000892765354f * fVec1[((IOTA - 428) & 511)])) + (0.000181970187f * fVec1[((IOTA - 429) & 511)])) + (0.0014803349f * fVec1[((IOTA - 430) & 511)])) + (0.00428318698f * fVec1[((IOTA - 431) & 511)])) + (0.00747494213f * fVec1[((IOTA - 432) & 511)])) + (0.0103330687f * fVec1[((IOTA - 433) & 511)])) + (0.0123470593f * fVec1[((IOTA - 434) & 511)])) + (0.0129654929f * fVec1[((IOTA - 435) & 511)])) + (0.0120415725f * fVec1[((IOTA - 436) & 511)])) + (0.010604063f * fVec1[((IOTA - 437) & 511)])) + (0.00988778844f * fVec1[((IOTA - 438) & 511)])) + (0.00982103683f * fVec1[((IOTA - 439) & 511)])) + (0.0101598203f * fVec1[((IOTA - 440) & 511)])) + (0.0117572211f * fVec1[((IOTA - 441) & 511)])) + (0.0144222267f * fVec1[((IOTA - 442) & 511)])) + (0.0163728688f * fVec1[((IOTA - 443) & 511)])) + (0.0162056498f * fVec1[((IOTA - 444) & 511)])) + (0.0138811786f * fVec1[((IOTA - 445) & 511)])) + (0.0107412301f * fVec1[((IOTA - 446) & 511)])) + (0.00824266672f * fVec1[((IOTA - 447) & 511)])) + (0.00682914769f * fVec1[((IOTA - 448) & 511)])) + (0.00661028409f * fVec1[((IOTA - 449) & 511)])) + (0.00739269424f * fVec1[((IOTA - 450) & 511)])) + (0.00805388764f * fVec1[((IOTA - 451) & 511)])) + (0.0079289116f * fVec1[((IOTA - 452) & 511)])) + (0.0068219183f * fVec1[((IOTA - 453) & 511)])) + (0.00462025125f * fVec1[((IOTA - 454) & 511)])) + (0.00268374337f * fVec1[((IOTA - 455) & 511)])) + (0.00275055971f * fVec1[((IOTA - 456) & 511)])) + (0.00489309337f * fVec1[((IOTA - 457) & 511)])) + (0.00818174984f * fVec1[((IOTA - 458) & 511)])) + (0.0108604357f * fVec1[((IOTA - 459) & 511)])) + (0.0107367877f * fVec1[((IOTA - 460) & 511)])) + (0.00766741624f * fVec1[((IOTA - 461) & 511)])) + (0.00350654777f * fVec1[((IOTA - 462) & 511)])) + (0.000411207788f * fVec1[((IOTA - 463) & 511)])) + (0.000583905727f * fVec1[((IOTA - 464) & 511)])) + (0.00441756519f * fVec1[((IOTA - 465) & 511)])) + (0.00963232387f * fVec1[((IOTA - 466) & 511)])) + (0.0135808773f * fVec1[((IOTA - 467) & 511)])) + (0.0142358793f * fVec1[((IOTA - 468) & 511)])) + (0.0114046279f * fVec1[((IOTA - 469) & 511)])) + (0.00722067663f * fVec1[((IOTA - 470) & 511)])) + (0.00365162455f * fVec1[((IOTA - 471) & 511)])) + (0.00150027266f * fVec1[((IOTA - 472) & 511)])) + (0.00114579918f * fVec1[((IOTA - 473) & 511)])) + (0.00172775984f * fVec1[((IOTA - 474) & 511)])) + (0.00172480941f * fVec1[((IOTA - 475) & 511)])) + (0.000267233234f * fVec1[((IOTA - 476) & 511)])) + (0.00347412843f * fVec1[((IOTA - 479) & 511)])) + (0.00707968464f * fVec1[((IOTA - 480) & 511)])) + (0.0104475422f * fVec1[((IOTA - 481) & 511)])) + (0.0131076518f * fVec1[((IOTA - 482) & 511)])) + (0.0138229858f * fVec1[((IOTA - 483) & 511)])) + (0.0116409659f * fVec1[((IOTA - 484) & 511)])) + (0.00697458116f * fVec1[((IOTA - 485) & 511)])) + (0.00208038557f * fVec1[((IOTA - 486) & 511)])) + (0.000504835043f * fVec1[((IOTA - 489) & 511)])) + (0.00338497479f * fVec1[((IOTA - 490) & 511)])) + (0.00659362087f * fVec1[((IOTA - 491) & 511)])) + (0.00863740407f * fVec1[((IOTA - 492) & 511)])) + (0.00812213123f * fVec1[((IOTA - 493) & 511)])) + (0.00550899701f * fVec1[((IOTA - 494) & 511)])) + (0.00200799294f * fVec1[((IOTA - 495) & 511)])) + (0.00116998376f * fVec1[((IOTA - 502) & 511)])) + (0.00378084835f * fVec1[((IOTA - 503) & 511)])) + (0.00767830899f * fVec1[((IOTA - 504) & 511)])) + (0.0115385521f * fVec1[((IOTA - 505) & 511)])) + (0.0146359354f * fVec1[((IOTA - 506) & 511)])) + (0.0164308362f * fVec1[((IOTA - 507) & 511)])) + (0.015900908f * fVec1[((IOTA - 508) & 511)])) + (0.0130615514f * fVec1[((IOTA - 509) & 511)])) + (0.00910777785f * fVec1[((IOTA - 510) & 511)])) + (0.0058097518f * fVec1[((IOTA - 511) & 511)])))) : (iSlow6 ? (((0.00185384555f * (fVec0[((IOTA - 200) & 511)] - fVec0[((IOTA - 504) & 511)])) + ((0.000151251443f * fVec0[((IOTA - 496) & 511)]) + ((0.000401279889f * fVec0[((IOTA - 495) & 511)]) + ((0.00012733601f * fVec0[((IOTA - 494) & 511)]) + ((0.00137239182f * fVec0[((IOTA - 427) & 511)]) + ((0.00222872989f * fVec0[((IOTA - 426) & 511)]) + ((0.00163243851f * fVec0[((IOTA - 425) & 511)]) + ((0.000291340053f * fVec0[((IOTA - 424) & 511)]) + ((0.000399117358f * fVec0[((IOTA - 403) & 511)]) + ((0.00145049812f * fVec0[((IOTA - 402) & 511)]) + ((0.00231787143f * fVec0[((IOTA - 401) & 511)]) + ((0.00201635482f * fVec0[((IOTA - 400) & 511)]) + ((0.000578195788f * fVec0[((IOTA - 399) & 511)]) + ((0.000144222751f * fVec0[((IOTA - 392) & 511)]) + ((6.09965064e-05f * fVec0[((IOTA - 391) & 511)]) + ((0.000555711333f * fVec0[((IOTA - 387) & 511)]) + ((0.00144728599f * fVec0[((IOTA - 386) & 511)]) + ((0.00199348899f * fVec0[((IOTA - 385) & 511)]) + ((0.00176734338f * fVec0[((IOTA - 384) & 511)]) + ((0.000722959172f * fVec0[((IOTA - 383) & 511)]) + ((0.000649846159f * fVec0[((IOTA - 379) & 511)]) + ((0.00105513306f * fVec0[((IOTA - 378) & 511)]) + ((0.000788821839f * fVec0[((IOTA - 377) & 511)]) + ((0.00112115452f * fVec0[((IOTA - 370) & 511)]) + ((0.00158384489f * fVec0[((IOTA - 369) & 511)]) + ((0.00099270558f * fVec0[((IOTA - 368) & 511)]) + ((0.000800270587f * fVec0[((IOTA - 357) & 511)]) + ((0.00167037873f * fVec0[((IOTA - 356) & 511)]) + ((0.00186736137f * fVec0[((IOTA - 355) & 511)]) + ((0.00205512159f * fVec0[((IOTA - 354) & 511)]) + ((0.00235348986f * fVec0[((IOTA - 353) & 511)]) + ((0.00242981501f * fVec0[((IOTA - 352) & 511)]) + ((0.00267173443f * fVec0[((IOTA - 351) & 511)]) + ((0.00271743396f * fVec0[((IOTA - 350) & 511)]) + ((0.00229004445f * fVec0[((IOTA - 349) & 511)]) + ((0.00187416701f * fVec0[((IOTA - 348) & 511)]) + ((0.00157659361f * fVec0[((IOTA - 347) & 511)]) + ((0.00169359427f * fVec0[((IOTA - 346) & 511)]) + ((0.00254045473f * fVec0[((IOTA - 345) & 511)]) + ((0.00334244268f * fVec0[((IOTA - 344) & 511)]) + ((0.00364163751f * fVec0[((IOTA - 343) & 511)]) + ((0.00357151357f * fVec0[((IOTA - 342) & 511)]) + ((0.0030716788f * fVec0[((IOTA - 341) & 511)]) + ((0.00276208436f * fVec0[((IOTA - 340) & 511)]) + ((0.00307762576f * fVec0[((IOTA - 339) & 511)]) + ((0.00340973586f * fVec0[((IOTA - 338) & 511)]) + ((0.00373367313f * fVec0[((IOTA - 337) & 511)]) + ((0.00370972604f * fVec0[((IOTA - 336) & 511)]) + ((0.00277556852f * fVec0[((IOTA - 335) & 511)]) + ((0.00164328283f * fVec0[((IOTA - 334) & 511)]) + ((0.000599757768f * fVec0[((IOTA - 333) & 511)]) + ((0.000250092242f * fVec0[((IOTA - 332) & 511)]) + ((0.00145647675f * fVec0[((IOTA - 331) & 511)]) + ((0.00294939941f * fVec0[((IOTA - 330) & 511)]) + ((0.00330691971f * fVec0[((IOTA - 329) & 511)]) + ((0.00229529152f * fVec0[((IOTA - 328) & 511)]) + ((0.000452068169f * fVec0[((IOTA - 327) & 511)]) + ((0.000522605609f * fVec0[((IOTA - 324) & 511)]) + ((0.00130061433f * fVec0[((IOTA - 323) & 511)]) + ((0.00178636098f * fVec0[((IOTA - 322) & 511)]) + ((0.00136402808f * fVec0[((IOTA - 321) & 511)]) + ((0.000340347178f * fVec0[((IOTA - 320) & 511)]) + ((0.000909987837f * fVec0[((IOTA - 314) & 511)]) + ((0.00246835919f * fVec0[((IOTA - 313) & 511)]) + ((0.00376986386f * fVec0[((IOTA - 312) & 511)]) + ((0.00471143145f * fVec0[((IOTA - 311) & 511)]) + ((0.005091595f * fVec0[((IOTA - 310) & 511)]) + ((0.00516979676f * fVec0[((IOTA - 309) & 511)]) + ((0.00492062652f * fVec0[((IOTA - 308) & 511)]) + ((0.00462448457f * fVec0[((IOTA - 307) & 511)]) + ((0.00499825552f * fVec0[((IOTA - 306) & 511)]) + ((0.00561397802f * fVec0[((IOTA - 305) & 511)]) + ((0.00574891455f * fVec0[((IOTA - 304) & 511)]) + ((0.00545875123f * fVec0[((IOTA - 303) & 511)]) + ((0.00493401522f * fVec0[((IOTA - 302) & 511)]) + ((0.00445701415f * fVec0[((IOTA - 301) & 511)]) + ((0.00400516856f * fVec0[((IOTA - 300) & 511)]) + ((0.003471178f * fVec0[((IOTA - 299) & 511)]) + ((0.00339809619f * fVec0[((IOTA - 298) & 511)]) + ((0.00381088909f * fVec0[((IOTA - 297) & 511)]) + ((0.00428976631f * fVec0[((IOTA - 296) & 511)]) + ((0.00489772903f * fVec0[((IOTA - 295) & 511)]) + ((0.00526876515f * fVec0[((IOTA - 294) & 511)]) + ((0.0050304397f * fVec0[((IOTA - 293) & 511)]) + ((0.0044471873f * fVec0[((IOTA - 292) & 511)]) + ((0.00359199429f * fVec0[((IOTA - 291) & 511)]) + ((0.00263249036f * fVec0[((IOTA - 290) & 511)]) + ((0.00160620175f * fVec0[((IOTA - 289) & 511)]) + ((0.000495541841f * fVec0[((IOTA - 288) & 511)]) + ((7.79791735e-05f * fVec0[((IOTA - 287) & 511)]) + ((0.000781507231f * fVec0[((IOTA - 286) & 511)]) + ((0.00225143647f * fVec0[((IOTA - 285) & 511)]) + ((0.00398853607f * fVec0[((IOTA - 284) & 511)]) + ((0.00536499871f * fVec0[((IOTA - 283) & 511)]) + ((0.00579563202f * fVec0[((IOTA - 282) & 511)]) + ((0.00505216047f * fVec0[((IOTA - 281) & 511)]) + ((0.0032199407f * fVec0[((IOTA - 280) & 511)]) + ((0.00106448308f * fVec0[((IOTA - 279) & 511)]) + ((0.000437375624f * fVec0[((IOTA - 276) & 511)]) + ((0.00177583471f * fVec0[((IOTA - 275) & 511)]) + ((0.00278456835f * fVec0[((IOTA - 274) & 511)]) + ((0.00286906678f * fVec0[((IOTA - 273) & 511)]) + ((0.00257327454f * fVec0[((IOTA - 272) & 511)]) + ((0.00269860728f * fVec0[((IOTA - 271) & 511)]) + ((0.00377924554f * fVec0[((IOTA - 270) & 511)]) + ((0.0054305112f * fVec0[((IOTA - 269) & 511)]) + ((0.00660566567f * fVec0[((IOTA - 268) & 511)]) + ((0.0068458044f * fVec0[((IOTA - 267) & 511)]) + ((0.00594144501f * fVec0[((IOTA - 266) & 511)]) + ((0.00408111233f * fVec0[((IOTA - 265) & 511)]) + ((0.00243856059f * fVec0[((IOTA - 264) & 511)]) + ((0.00201253826f * fVec0[((IOTA - 263) & 511)]) + ((0.00316985184f * fVec0[((IOTA - 262) & 511)]) + ((0.00558211235f * fVec0[((IOTA - 261) & 511)]) + ((0.00775766838f * fVec0[((IOTA - 260) & 511)]) + ((0.00875578076f * fVec0[((IOTA - 259) & 511)]) + ((0.00860188901f * fVec0[((IOTA - 258) & 511)]) + ((0.00731730368f * fVec0[((IOTA - 257) & 511)]) + ((0.00577979442f * fVec0[((IOTA - 256) & 511)]) + ((0.00479704328f * fVec0[((IOTA - 255) & 511)]) + ((0.00395104103f * fVec0[((IOTA - 254) & 511)]) + ((0.00360786356f * fVec0[((IOTA - 253) & 511)]) + ((0.00407955376f * fVec0[((IOTA - 252) & 511)]) + ((0.00460794708f * fVec0[((IOTA - 251) & 511)]) + ((0.00495675392f * fVec0[((IOTA - 250) & 511)]) + ((0.00457334658f * fVec0[((IOTA - 249) & 511)]) + ((0.00321501121f * fVec0[((IOTA - 248) & 511)]) + ((0.00220777187f * fVec0[((IOTA - 247) & 511)]) + ((0.00181829045f * fVec0[((IOTA - 246) & 511)]) + ((0.00164433243f * fVec0[((IOTA - 245) & 511)]) + ((0.00206141826f * fVec0[((IOTA - 244) & 511)]) + ((0.00272722915f * fVec0[((IOTA - 243) & 511)]) + ((0.00319281314f * fVec0[((IOTA - 242) & 511)]) + ((0.00312898634f * fVec0[((IOTA - 241) & 511)]) + ((0.00192966172f * fVec0[((IOTA - 240) & 511)]) + ((0.00060500484f * fVec0[((IOTA - 239) & 511)]) + ((0.000446725637f * fVec0[((IOTA - 238) & 511)]) + ((0.00132036349f * fVec0[((IOTA - 237) & 511)]) + ((0.0032587708f * fVec0[((IOTA - 236) & 511)]) + ((0.00564069161f * fVec0[((IOTA - 235) & 511)]) + ((0.00723156473f * fVec0[((IOTA - 234) & 511)]) + ((0.00763306767f * fVec0[((IOTA - 233) & 511)]) + ((0.00662385672f * fVec0[((IOTA - 232) & 511)]) + ((0.0048312624f * fVec0[((IOTA - 231) & 511)]) + ((0.00376487104f * fVec0[((IOTA - 230) & 511)]) + ((0.00340452045f * fVec0[((IOTA - 229) & 511)]) + ((0.00328395842f * fVec0[((IOTA - 228) & 511)]) + ((0.00346173253f * fVec0[((IOTA - 227) & 511)]) + ((0.00353996595f * fVec0[((IOTA - 226) & 511)]) + ((0.00368571561f * fVec0[((IOTA - 225) & 511)]) + ((0.0042198333f * fVec0[((IOTA - 224) & 511)]) + ((0.00467892969f * fVec0[((IOTA - 223) & 511)]) + ((0.00545032369f * fVec0[((IOTA - 222) & 511)]) + ((0.00676661683f * fVec0[((IOTA - 221) & 511)]) + ((0.00754284486f * fVec0[((IOTA - 220) & 511)]) + ((0.0072786957f * fVec0[((IOTA - 219) & 511)]) + ((0.00554146897f * fVec0[((IOTA - 218) & 511)]) + ((0.00240418222f * fVec0[((IOTA - 217) & 511)]) + ((0.000987203792f * fVec0[((IOTA - 213) & 511)]) + ((0.00381079363f * fVec0[((IOTA - 212) & 511)]) + ((0.00642340723f * fVec0[((IOTA - 211) & 511)]) + ((0.00758924428f * fVec0[((IOTA - 210) & 511)]) + ((0.00591304572f * fVec0[((IOTA - 209) & 511)]) + ((0.00292716967f * fVec0[((IOTA - 208) & 511)]) + ((0.000582234468f * fVec0[((IOTA - 207) & 511)]) + ((0.000284566078f * fVec0[((IOTA - 204) & 511)]) + ((0.00124829961f * fVec0[((IOTA - 203) & 511)]) + ((0.00201838976f * fVec0[((IOTA - 202) & 511)]) + ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((fSlow9 * fTemp0) + (0.208459094f * fVec0[((IOTA - 1) & 511)])) + (0.257705778f * fVec0[((IOTA - 2) & 511)])) + (0.217905849f * fVec0[((IOTA - 3) & 511)])) + (0.113110229f * fVec0[((IOTA - 4) & 511)])) + (0.0610963739f * fVec0[((IOTA - 10) & 511)])) + (0.114339389f * fVec0[((IOTA - 11) & 511)])) + (0.102898739f * fVec0[((IOTA - 12) & 511)])) + (0.0291915219f * fVec0[((IOTA - 13) & 511)])) + (0.00673700869f * fVec0[((IOTA - 16) & 511)])) + (0.0309213698f * fVec0[((IOTA - 17) & 511)])) + (0.0361127928f * fVec0[((IOTA - 18) & 511)])) + (0.00934628397f * fVec0[((IOTA - 19) & 511)])) + (0.00968195591f * fVec0[((IOTA - 23) & 511)])) + (0.0335224085f * fVec0[((IOTA - 24) & 511)])) + (0.0347462818f * fVec0[((IOTA - 25) & 511)])) + (0.0131169744f * fVec0[((IOTA - 26) & 511)])) + (0.0323475078f * fVec0[((IOTA - 36) & 511)])) + (0.051153928f * fVec0[((IOTA - 37) & 511)])) + (0.0430648476f * fVec0[((IOTA - 38) & 511)])) + (0.0181146897f * fVec0[((IOTA - 39) & 511)])) + (0.0229419135f * fVec0[((IOTA - 49) & 511)])) + (0.0348782949f * fVec0[((IOTA - 50) & 511)])) + (0.0210948102f * fVec0[((IOTA - 51) & 511)])) + (0.00452662911f * fVec0[((IOTA - 60) & 511)])) + (0.0105941705f * fVec0[((IOTA - 61) & 511)])) + (0.0136083178f * fVec0[((IOTA - 62) & 511)])) + (0.0147955585f * fVec0[((IOTA - 63) & 511)])) + (0.0059160986f * fVec0[((IOTA - 64) & 511)])) + (0.000250632875f * fVec0[((IOTA - 72) & 511)])) + (0.00153321587f * fVec0[((IOTA - 73) & 511)])) + (0.00220020302f * fVec0[((IOTA - 74) & 511)])) + (0.00367922802f * fVec0[((IOTA - 75) & 511)])) + (0.00788942538f * fVec0[((IOTA - 76) & 511)])) + (0.0107560754f * fVec0[((IOTA - 77) & 511)])) + (0.0067856661f * fVec0[((IOTA - 78) & 511)])) + (0.00250330986f * fVec0[((IOTA - 95) & 511)])) + (0.0113677271f * fVec0[((IOTA - 96) & 511)])) + (0.0177218374f * fVec0[((IOTA - 97) & 511)])) + (0.0175200514f * fVec0[((IOTA - 98) & 511)])) + (0.011907028f * fVec0[((IOTA - 99) & 511)])) + (0.00233046478f * fVec0[((IOTA - 100) & 511)])) + (0.00300816959f * fVec0[((IOTA - 109) & 511)])) + (0.00550391059f * fVec0[((IOTA - 110) & 511)])) + (0.00530123524f * fVec0[((IOTA - 111) & 511)])) + (0.00384952873f * fVec0[((IOTA - 112) & 511)])) + (0.000739337411f * fVec0[((IOTA - 113) & 511)])) + (0.00156711694f * fVec0[((IOTA - 128) & 511)])) + (0.00458651269f * fVec0[((IOTA - 129) & 511)])) + (0.00505686691f * fVec0[((IOTA - 130) & 511)])) + (0.0030626785f * fVec0[((IOTA - 131) & 511)])) + (0.000415750314f * fVec0[((IOTA - 135) & 511)])) + (0.00271314057f * fVec0[((IOTA - 136) & 511)])) + (0.0031849579f * fVec0[((IOTA - 137) & 511)])) + (0.000658591744f * fVec0[((IOTA - 138) & 511)])) + (0.000880762003f * fVec0[((IOTA - 144) & 511)])) + (0.000174975488f * fVec0[((IOTA - 145) & 511)])) + (0.00183718093f * fVec0[((IOTA - 151) & 511)])) + (0.00346561242f * fVec0[((IOTA - 152) & 511)])) + (0.00506058801f * fVec0[((IOTA - 153) & 511)])) + (0.0059262435f * fVec0[((IOTA - 154) & 511)])) + (0.00537682883f * fVec0[((IOTA - 155) & 511)])) + (0.00311324419f * fVec0[((IOTA - 156) & 511)])) + (0.000639383215f * fVec0[((IOTA - 169) & 511)])) + (0.000645902473f * fVec0[((IOTA - 170) & 511)])) + (9.23853368e-05f * fVec0[((IOTA - 173) & 511)])) + (0.00159828272f * fVec0[((IOTA - 174) & 511)])) + (0.00278167427f * fVec0[((IOTA - 175) & 511)])) + (0.00292061828f * fVec0[((IOTA - 176) & 511)])) + (0.0022148001f * fVec0[((IOTA - 177) & 511)])) + (0.00115092145f * fVec0[((IOTA - 178) & 511)])) + (0.00230480032f * fVec0[((IOTA - 182) & 511)])) + (0.00582632143f * fVec0[((IOTA - 183) & 511)])) + (0.0067671258f * fVec0[((IOTA - 184) & 511)])) + (0.00441363594f * fVec0[((IOTA - 185) & 511)])) + (0.000970921014f * fVec0[((IOTA - 186) & 511)])) + (0.00014679879f * fVec0[((IOTA - 189) & 511)])) + (0.00300743803f * fVec0[((IOTA - 190) & 511)])) + (0.00563891092f * fVec0[((IOTA - 191) & 511)])) + (0.00779077457f * fVec0[((IOTA - 192) & 511)])) + (0.00844745804f * fVec0[((IOTA - 193) & 511)])) + (0.00686816126f * fVec0[((IOTA - 194) & 511)])) + (0.00448191538f * fVec0[((IOTA - 195) & 511)])) + (0.00213201903f * fVec0[((IOTA - 196) & 511)])) + (0.000421092845f * fVec0[((IOTA - 197) & 511)])) + (0.000392184593f * fVec0[((IOTA - 198) & 511)])) + (0.0012617521f * fVec0[((IOTA - 199) & 511)])) + (0.00219559157f * fVec0[((IOTA - 201) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) - ((((((((((((((((((((((((((0.0034213122f * fVec0[((IOTA - 482) & 511)]) + ((0.00235326728f * fVec0[((IOTA - 481) & 511)]) + ((0.0012840773f * fVec0[((IOTA - 480) & 511)]) + ((0.00102730654f * fVec0[((IOTA - 479) & 511)]) + ((0.00139287254f * fVec0[((IOTA - 478) & 511)]) + ((0.00219600508f * fVec0[((IOTA - 477) & 511)]) + ((0.00314479182f * fVec0[((IOTA - 476) & 511)]) + ((0.00334132928f * fVec0[((IOTA - 475) & 511)]) + ((0.00289918343f * fVec0[((IOTA - 474) & 511)]) + ((0.00234821066f * fVec0[((IOTA - 473) & 511)]) + ((0.00182096194f * fVec0[((IOTA - 472) & 511)]) + ((0.00137942005f * fVec0[((IOTA - 471) & 511)]) + ((0.000988221262f * fVec0[((IOTA - 470) & 511)]) + ((0.000909574796f * fVec0[((IOTA - 469) & 511)]) + ((0.00114239845f * fVec0[((IOTA - 468) & 511)]) + ((0.00120520778f * fVec0[((IOTA - 467) & 511)]) + ((0.0012554233f * fVec0[((IOTA - 466) & 511)]) + ((0.00151054049f * fVec0[((IOTA - 465) & 511)]) + ((0.00158371776f * fVec0[((IOTA - 464) & 511)]) + ((0.00166659383f * fVec0[((IOTA - 463) & 511)]) + ((0.00197005039f * fVec0[((IOTA - 462) & 511)]) + ((0.00226997724f * fVec0[((IOTA - 461) & 511)]) + ((0.00280387234f * fVec0[((IOTA - 460) & 511)]) + ((0.0034201988f * fVec0[((IOTA - 459) & 511)]) + ((0.00368199451f * fVec0[((IOTA - 458) & 511)]) + ((0.00382430945f * fVec0[((IOTA - 457) & 511)]) + ((0.0037427051f * fVec0[((IOTA - 456) & 511)]) + ((0.00320849149f * fVec0[((IOTA - 455) & 511)]) + ((0.00272067776f * fVec0[((IOTA - 454) & 511)]) + ((0.00231752126f * fVec0[((IOTA - 453) & 511)]) + ((0.0015927176f * fVec0[((IOTA - 452) & 511)]) + ((0.00119067403f * fVec0[((IOTA - 451) & 511)]) + ((0.00129791116f * fVec0[((IOTA - 450) & 511)]) + ((0.00153553719f * fVec0[((IOTA - 449) & 511)]) + ((0.00206844648f * fVec0[((IOTA - 448) & 511)]) + ((0.00252964208f * fVec0[((IOTA - 447) & 511)]) + ((0.00279334607f * fVec0[((IOTA - 446) & 511)]) + ((0.00310160452f * fVec0[((IOTA - 445) & 511)]) + ((0.00330020906f * fVec0[((IOTA - 444) & 511)]) + ((0.00383954262f * fVec0[((IOTA - 443) & 511)]) + ((0.0048407712f * fVec0[((IOTA - 442) & 511)]) + ((0.00570206996f * fVec0[((IOTA - 441) & 511)]) + ((0.00645654555f * fVec0[((IOTA - 440) & 511)]) + ((0.00689379359f * fVec0[((IOTA - 439) & 511)]) + ((0.00667747529f * fVec0[((IOTA - 438) & 511)]) + ((0.00607593684f * fVec0[((IOTA - 437) & 511)]) + ((0.00515475404f * fVec0[((IOTA - 436) & 511)]) + ((0.00423707021f * fVec0[((IOTA - 435) & 511)]) + ((0.004121501f * fVec0[((IOTA - 434) & 511)]) + ((0.00448019803f * fVec0[((IOTA - 433) & 511)]) + ((0.00469422666f * fVec0[((IOTA - 432) & 511)]) + ((0.00445090793f * fVec0[((IOTA - 431) & 511)]) + ((0.00328713842f * fVec0[((IOTA - 430) & 511)]) + ((0.00172390183f * fVec0[((IOTA - 429) & 511)]) + ((0.000219816808f * fVec0[((IOTA - 428) & 511)]) + ((0.0011220132f * fVec0[((IOTA - 423) & 511)]) + ((0.00206208602f * fVec0[((IOTA - 422) & 511)]) + ((0.00235034106f * fVec0[((IOTA - 421) & 511)]) + ((0.0027248119f * fVec0[((IOTA - 420) & 511)]) + ((0.00284203514f * fVec0[((IOTA - 419) & 511)]) + ((0.00239422824f * fVec0[((IOTA - 418) & 511)]) + ((0.00200541457f * fVec0[((IOTA - 417) & 511)]) + ((0.00134545565f * fVec0[((IOTA - 416) & 511)]) + ((0.000640941318f * fVec0[((IOTA - 415) & 511)]) + ((0.000673952047f * fVec0[((IOTA - 414) & 511)]) + ((0.00110048335f * fVec0[((IOTA - 413) & 511)]) + ((0.00184891606f * fVec0[((IOTA - 412) & 511)]) + ((0.00262466678f * fVec0[((IOTA - 411) & 511)]) + ((0.00268843025f * fVec0[((IOTA - 410) & 511)]) + ((0.00246193493f * fVec0[((IOTA - 409) & 511)]) + ((0.00216557039f * fVec0[((IOTA - 408) & 511)]) + ((0.0015799012f * fVec0[((IOTA - 407) & 511)]) + ((0.00116672693f * fVec0[((IOTA - 406) & 511)]) + ((0.000887694769f * fVec0[((IOTA - 405) & 511)]) + ((0.000352559146f * fVec0[((IOTA - 404) & 511)]) + ((0.00151744159f * fVec0[((IOTA - 398) & 511)]) + ((0.00350905443f * fVec0[((IOTA - 397) & 511)]) + ((0.00415104534f * fVec0[((IOTA - 396) & 511)]) + ((0.00351468334f * fVec0[((IOTA - 395) & 511)]) + ((0.0022530267f * fVec0[((IOTA - 394) & 511)]) + ((0.000680884812f * fVec0[((IOTA - 393) & 511)]) + ((0.000213138293f * fVec0[((IOTA - 390) & 511)]) + ((0.000583760906f * fVec0[((IOTA - 389) & 511)]) + ((0.000421474688f * fVec0[((IOTA - 388) & 511)]) + ((3.51094641e-05f * fVec0[((IOTA - 382) & 511)]) + ((0.000272131525f * fVec0[((IOTA - 381) & 511)]) + ((5.64171933e-05f * fVec0[((IOTA - 380) & 511)]) + ((0.0019731354f * fVec0[((IOTA - 375) & 511)]) + ((0.00316600408f * fVec0[((IOTA - 374) & 511)]) + ((0.0029968163f * fVec0[((IOTA - 373) & 511)]) + ((0.00199367944f * fVec0[((IOTA - 372) & 511)]) + ((0.000373803079f * fVec0[((IOTA - 371) & 511)]) + ((0.000532559585f * fVec0[((IOTA - 367) & 511)]) + ((0.00200824486f * fVec0[((IOTA - 366) & 511)]) + ((0.00235962728f * fVec0[((IOTA - 365) & 511)]) + ((0.00205623452f * fVec0[((IOTA - 364) & 511)]) + ((0.00164967543f * fVec0[((IOTA - 363) & 511)]) + ((0.0013515614f * fVec0[((IOTA - 362) & 511)]) + ((0.00145266065f * fVec0[((IOTA - 361) & 511)]) + ((0.00141570671f * fVec0[((IOTA - 360) & 511)]) + ((0.000950026792f * fVec0[((IOTA - 359) & 511)]) + ((0.000248407014f * fVec0[((IOTA - 358) & 511)]) + (((0.000454898458f * fVec0[((IOTA - 326) & 511)]) + ((7.48625025e-05f * fVec0[((IOTA - 325) & 511)]) + ((0.00116510503f * fVec0[((IOTA - 319) & 511)]) + ((0.00250340533f * fVec0[((IOTA - 318) & 511)]) + ((0.00280686188f * fVec0[((IOTA - 317) & 511)]) + ((0.00223121f * fVec0[((IOTA - 316) & 511)]) + ((0.000886263791f * fVec0[((IOTA - 315) & 511)]) + (((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((0.0619222783f * fVec0[((IOTA - 5) & 511)]) + (0.205279574f * fVec0[((IOTA - 6) & 511)])) + (0.25567323f * fVec0[((IOTA - 7) & 511)])) + (0.210651949f * fVec0[((IOTA - 8) & 511)])) + (0.0702744573f * fVec0[((IOTA - 9) & 511)])) + (0.0286961701f * fVec0[((IOTA - 14) & 511)])) + (0.0193237457f * fVec0[((IOTA - 15) & 511)])) + (0.0199804287f * fVec0[((IOTA - 20) & 511)])) + (0.03397616f * fVec0[((IOTA - 21) & 511)])) + (0.0225008167f * fVec0[((IOTA - 22) & 511)])) + (0.00615792256f * fVec0[((IOTA - 27) & 511)])) + (0.00427640928f * fVec0[((IOTA - 28) & 511)])) + (0.00430741673f * fVec0[((IOTA - 29) & 511)])) + (0.0206353627f * fVec0[((IOTA - 30) & 511)])) + (0.0443594828f * fVec0[((IOTA - 31) & 511)])) + (0.0618892983f * fVec0[((IOTA - 32) & 511)])) + (0.0565144084f * fVec0[((IOTA - 33) & 511)])) + (0.0336717181f * fVec0[((IOTA - 34) & 511)])) + (0.00207824167f * fVec0[((IOTA - 35) & 511)])) + (0.00230445061f * fVec0[((IOTA - 40) & 511)])) + (0.00664242916f * fVec0[((IOTA - 41) & 511)])) + (0.00479987357f * fVec0[((IOTA - 42) & 511)])) + (0.0116785299f * fVec0[((IOTA - 43) & 511)])) + (0.0302486904f * fVec0[((IOTA - 44) & 511)])) + (0.0490337685f * fVec0[((IOTA - 45) & 511)])) + (0.0502935499f * fVec0[((IOTA - 46) & 511)])) + (0.0341343768f * fVec0[((IOTA - 47) & 511)])) + (0.00762126874f * fVec0[((IOTA - 48) & 511)])) + (0.00105312979f * fVec0[((IOTA - 52) & 511)])) + (0.0227754917f * fVec0[((IOTA - 53) & 511)])) + (0.0325151682f * fVec0[((IOTA - 54) & 511)])) + (0.0277269352f * fVec0[((IOTA - 55) & 511)])) + (0.0210946184f * fVec0[((IOTA - 56) & 511)])) + (0.0141953863f * fVec0[((IOTA - 57) & 511)])) + (0.00749622285f * fVec0[((IOTA - 58) & 511)])) + (0.00283691473f * fVec0[((IOTA - 59) & 511)])) + (0.0144020058f * fVec0[((IOTA - 65) & 511)])) + (0.0325336456f * fVec0[((IOTA - 66) & 511)])) + (0.0389749892f * fVec0[((IOTA - 67) & 511)])) + (0.0345722288f * fVec0[((IOTA - 68) & 511)])) + (0.0229463018f * fVec0[((IOTA - 69) & 511)])) + (0.00947734062f * fVec0[((IOTA - 70) & 511)])) + (0.00193503639f * fVec0[((IOTA - 71) & 511)])) + (0.00117391441f * fVec0[((IOTA - 79) & 511)])) + (0.00692753587f * fVec0[((IOTA - 80) & 511)])) + (0.0108184703f * fVec0[((IOTA - 81) & 511)])) + (0.0136748487f * fVec0[((IOTA - 82) & 511)])) + (0.0134480987f * fVec0[((IOTA - 83) & 511)])) + (0.013269498f * fVec0[((IOTA - 84) & 511)])) + (0.0144870449f * fVec0[((IOTA - 85) & 511)])) + (0.0143067902f * fVec0[((IOTA - 86) & 511)])) + (0.0128905112f * fVec0[((IOTA - 87) & 511)])) + (0.0104989856f * fVec0[((IOTA - 88) & 511)])) + (0.00977532752f * fVec0[((IOTA - 89) & 511)])) + (0.0112102423f * fVec0[((IOTA - 90) & 511)])) + (0.0125766871f * fVec0[((IOTA - 91) & 511)])) + (0.0144605218f * fVec0[((IOTA - 92) & 511)])) + (0.0129733235f * fVec0[((IOTA - 93) & 511)])) + (0.00589774875f * fVec0[((IOTA - 94) & 511)])) + (0.00760912057f * fVec0[((IOTA - 101) & 511)])) + (0.0143465428f * fVec0[((IOTA - 102) & 511)])) + (0.0180050358f * fVec0[((IOTA - 103) & 511)])) + (0.0193199925f * fVec0[((IOTA - 104) & 511)])) + (0.0184785388f * fVec0[((IOTA - 105) & 511)])) + (0.0153908003f * fVec0[((IOTA - 106) & 511)])) + (0.0100465994f * fVec0[((IOTA - 107) & 511)])) + (0.00315802172f * fVec0[((IOTA - 108) & 511)])) + (0.00411781203f * fVec0[((IOTA - 114) & 511)])) + (0.00844211504f * fVec0[((IOTA - 115) & 511)])) + (0.0105677741f * fVec0[((IOTA - 116) & 511)])) + (0.0115595572f * fVec0[((IOTA - 117) & 511)])) + (0.0111376066f * fVec0[((IOTA - 118) & 511)])) + (0.00899830461f * fVec0[((IOTA - 119) & 511)])) + (0.00709999911f * fVec0[((IOTA - 120) & 511)])) + (0.00595251238f * fVec0[((IOTA - 121) & 511)])) + (0.00553778f * fVec0[((IOTA - 122) & 511)])) + (0.00630147802f * fVec0[((IOTA - 123) & 511)])) + (0.00761583075f * fVec0[((IOTA - 124) & 511)])) + (0.00845601317f * fVec0[((IOTA - 125) & 511)])) + (0.00707341265f * fVec0[((IOTA - 126) & 511)])) + (0.00305167492f * fVec0[((IOTA - 127) & 511)])) + (0.00010869978f * fVec0[((IOTA - 132) & 511)])) + (0.00203410024f * fVec0[((IOTA - 133) & 511)])) + (0.0015926538f * fVec0[((IOTA - 134) & 511)])) + (0.00319084153f * fVec0[((IOTA - 139) & 511)])) + (0.00643587392f * fVec0[((IOTA - 140) & 511)])) + (0.00735021895f * fVec0[((IOTA - 141) & 511)])) + (0.00474444218f * fVec0[((IOTA - 142) & 511)])) + (0.000922072679f * fVec0[((IOTA - 143) & 511)])) + (0.00192603655f * fVec0[((IOTA - 146) & 511)])) + (0.0035971147f * fVec0[((IOTA - 147) & 511)])) + (0.00336142862f * fVec0[((IOTA - 148) & 511)])) + (0.00204729801f * fVec0[((IOTA - 149) & 511)])) + (0.000165116973f * fVec0[((IOTA - 150) & 511)])) + (0.000540001318f * fVec0[((IOTA - 157) & 511)])) + (0.00420294655f * fVec0[((IOTA - 158) & 511)])) + (0.00679422123f * fVec0[((IOTA - 159) & 511)])) + (0.00740428269f * fVec0[((IOTA - 160) & 511)])) + (0.00559130311f * fVec0[((IOTA - 161) & 511)])) + (0.00296272431f * fVec0[((IOTA - 162) & 511)])) + (0.00103512965f * fVec0[((IOTA - 163) & 511)])) + (0.000387478154f * fVec0[((IOTA - 164) & 511)])) + (0.00134281581f * fVec0[((IOTA - 165) & 511)])) + (0.00240809424f * fVec0[((IOTA - 166) & 511)])) + (0.00198328029f * fVec0[((IOTA - 167) & 511)])) + (0.000604591332f * fVec0[((IOTA - 168) & 511)])) + (0.000537711661f * fVec0[((IOTA - 171) & 511)])) + (0.00095848646f * fVec0[((IOTA - 172) & 511)])) + (0.000535962172f * fVec0[((IOTA - 179) & 511)])) + (0.0018843119f * fVec0[((IOTA - 180) & 511)])) + (0.000976963434f * fVec0[((IOTA - 181) & 511)])) + (0.00133620109f * fVec0[((IOTA - 187) & 511)])) + (0.0016394034f * fVec0[((IOTA - 188) & 511)])) + (0.000609902665f * fVec0[((IOTA - 205) & 511)])) + (0.000688008498f * fVec0[((IOTA - 206) & 511)])) + (0.00116542308f * fVec0[((IOTA - 214) & 511)])) + (0.00157633936f * fVec0[((IOTA - 215) & 511)])) + (0.000326417852f * fVec0[((IOTA - 216) & 511)])) + (0.000312233809f * fVec0[((IOTA - 277) & 511)])) + (0.000204710755f * fVec0[((IOTA - 278) & 511)])) + (0.000205792021f * fVec0[((IOTA - 376) & 511)]))))))))) + (0.00376827409f * fVec0[((IOTA - 483) & 511)])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (0.00350994477f * fVec0[((IOTA - 484) & 511)])) + (0.0024432675f * fVec0[((IOTA - 485) & 511)])) + (0.0011532749f * fVec0[((IOTA - 486) & 511)])) + (0.000423605088f * fVec0[((IOTA - 487) & 511)])) + (0.000110830646f * fVec0[((IOTA - 488) & 511)])) + (0.000374820549f * fVec0[((IOTA - 489) & 511)])) + (0.00109243719f * fVec0[((IOTA - 490) & 511)])) + (0.00144804921f * fVec0[((IOTA - 491) & 511)])) + (0.0013021091f * fVec0[((IOTA - 492) & 511)])) + (0.000677037053f * fVec0[((IOTA - 493) & 511)])) + (0.000691093504f * fVec0[((IOTA - 497) & 511)])) + (0.00202735793f * fVec0[((IOTA - 498) & 511)])) + (0.00311105f * fVec0[((IOTA - 499) & 511)])) + (0.00382612227f * fVec0[((IOTA - 500) & 511)])) + (0.00401671277f * fVec0[((IOTA - 501) & 511)])) + (0.00336998329f * fVec0[((IOTA - 502) & 511)])) + (0.00250168797f * fVec0[((IOTA - 503) & 511)])) + (0.00189598324f * fVec0[((IOTA - 505) & 511)])) + (0.00320604304f * fVec0[((IOTA - 506) & 511)])) + (0.00480213156f * fVec0[((IOTA - 507) & 511)])) + (0.00567188999f * fVec0[((IOTA - 508) & 511)])) + (0.00580876647f * fVec0[((IOTA - 509) & 511)])) + (0.00477586268f * fVec0[((IOTA - 510) & 511)])) + (0.00299827941f * fVec0[((IOTA - 511) & 511)]))) : (fSlow7 * fTemp0))))))));
			IOTA = (IOTA + 1);
		}
	}

};

//----------------------------------------------------------------------------
//  LV2 interface
//----------------------------------------------------------------------------

#line 286 "lv2.cpp"

#include <assert.h>
#include <stdio.h>
#include <stdlib.h>

#include <bitset>
#include <boost/circular_buffer.hpp>

#include <lv2/lv2plug.in/ns/lv2core/lv2.h>
#include <lv2/lv2plug.in/ns/ext/dynmanifest/dynmanifest.h>
#include <lv2/lv2plug.in/ns/ext/atom/util.h>
#include <lv2/lv2plug.in/ns/ext/urid/urid.h>

// Set this to the proper shared library extension for your system
#ifndef DLLEXT
#define DLLEXT ".so"
#endif

#ifndef URI_PREFIX
#define URI_PREFIX "https://faustlv2.bitbucket.io"
#endif

#ifndef PLUGIN_URI
#define PLUGIN_URI URI_PREFIX "/gods_cab"
#endif

#define MIDI_EVENT_URI "http://lv2plug.in/ns/ext/midi#MidiEvent"

/* Setting NVOICES at compile time overrides meta data in the Faust source. If
   set, this must be an integer value >= 0. A nonzero value indicates an
   instrument (VSTi) plugin with the given maximum number of voices. Use 1 for
   a monophonic synthesizer, and 0 for a simple effect plugin. If NVOICES
   isn't defined at compile time then the number of voices of an instrument
   plugin can also be set with the global "nvoices" meta data key in the Faust
   source. This setting also adds a special "polyphony" control to the plugin
   which can be used to dynamically adjust the actual number of voices in the
   range 1..NVOICES. */
//#define NVOICES 16

/* This enables a special "tuning" control for instruments which lets you
   select the MTS tuning to be used for the synth. In order to use this, you
   just drop some sysex (.syx) files with MTS octave-based tunings in 1- or
   2-byte format into the ~/.fautvst/tuning directory (these can be generated
   with the author's sclsyx program, https://bitbucket.org/agraef/sclsyx).
   The control will only be shown if any .syx files were found at startup. 0
   selects the default tuning (standard 12-tone equal temperament), i>0 the
   tuning in the ith sysex file (in alphabetic order). */
#ifndef FAUST_MTS
#define FAUST_MTS 1
#endif

/* This allows various manifest data to be generated from the corresponding
   metadata (author, name, description, license) in the Faust source. */
#ifndef FAUST_META
#define FAUST_META 1
#endif

/* This enables automatic MIDI controller mapping based on the midi:ctrl
   attributes in the Faust source. We have this enabled by default, but you
   may have to disable it if the custom controller mapping gets in the way of
   the automation facilities that the host provides. (But then again if the
   host wants to do its own controller mapping then it probably won't, or at
   least shouldn't, send us the MIDI controllers in the first place.) */
#ifndef FAUST_MIDICC
#define FAUST_MIDICC 1
#endif

/* This enables or disables the plugin's custom Qt GUI (cf. lv2ui.cpp). Note
   that this only affects the plugin manifest, the GUI code itself is in a
   separate module created with the lv2ui.cpp architecture. Also, you'll have
   to use the alternative lv2ui manifest templates to tell the LV2 host about
   the GUI. */
#ifndef FAUST_UI
#define FAUST_UI 0
#endif

// You can define these for various debugging output items.
//#define DEBUG_META 1 // recognized MIDI controller metadata
//#define DEBUG_VOICES 1 // triggering of synth voices
//#define DEBUG_VOICE_ALLOC 1 // voice allocation
//#define DEBUG_MIDI 1 // incoming MIDI messages
//#define DEBUG_NOTES 1 // note messages
//#define DEBUG_MIDICC 1 // controller messages
//#define DEBUG_RPN 1 // RPN messages (pitch bend range, master tuning)
//#define DEBUG_MTS 1 // MTS messages (octave/scale tuning)

// Note and voice data structures.

struct NoteInfo {
  uint8_t ch;
  int8_t note;
};

struct VoiceData {
  // Octave tunings (offsets in semitones) per MIDI channel.
  float tuning[16][12];
  // Allocated voices per MIDI channel and note.
  int8_t notes[16][128];
  // Free and used voices.
  int n_free, n_used;
  boost::circular_buffer<int> free_voices;
  boost::circular_buffer<int> used_voices;
  NoteInfo *note_info;
  // Voices queued for note-offs (zero-length notes).
  set<int> queued;
  // Last gate value during run() for each voice. We need to keep track of
  // these so that we can force the Faust synth to retrigger a note when
  // needed.
  float *lastgate;
  // Current pitch bend and pitch bend range on each MIDI channel, in semitones.
  float bend[16], range[16];
  // Current coarse, fine and total master tuning on each MIDI channel (tuning
  // offset relative to A4 = 440 Hz, in semitones).
  float coarse[16], fine[16], tune[16];
  VoiceData(int n) : free_voices(n), used_voices(n) { }
};

#if FAUST_MTS

// Helper classes to read and store MTS tunings.

#include <sys/types.h>
#include <sys/stat.h>
#include <dirent.h>

#include <string>
#include <vector>

struct MTSTuning {
  char *name; // name of the tuning
  int len; // length of sysex data in bytes
  unsigned char *data; // sysex data
  MTSTuning() : name(0), len(0), data(0) {}
  MTSTuning& operator=(const MTSTuning &t)
  {
    if (this == &t) return *this;
    if (name) free(name); if (data) free(data);
    name = 0; data = 0; len = t.len;
    if (t.name) {
      name = strdup(t.name); assert(name);
    }
    if (t.data) {
      data = (unsigned char*)malloc(len); assert(data);
      memcpy(data, t.data, len);
    }
    return *this;
  }
  MTSTuning(const MTSTuning& t) : name(0), len(0), data(0)
  { *this = t; }
  MTSTuning(const char *filename);
  ~MTSTuning()
  { if (name) free(name); if (data) free(data); }
};

MTSTuning::MTSTuning(const char *filename)
{
  FILE *fp = fopen(filename, "rb");
  name = 0; len = 0; data = 0;
  if (!fp) return;
  struct stat st;
  if (fstat(fileno(fp), &st)) return;
  len = st.st_size;
  data = (unsigned char*)calloc(len, 1);
  if (!data) {
    len = 0; fclose(fp);
    return;
  }
  assert(len > 0);
  if (fread(data, 1, len, fp) < len) {
    free(data); len = 0; data = 0; fclose(fp);
    return;
  }
  fclose(fp);
  // Do some basic sanity checks.
  if (data[0] != 0xf0 || data[len-1] != 0xf7 || // not a sysex message
      (data[1] != 0x7e && data[1] != 0x7f) || data[3] != 8 || // not MTS
      !((len == 21 && data[4] == 8) ||
	(len == 33 && data[4] == 9))) { // no 1- or 2-byte tuning
    free(data); len = 0; data = 0;
    return;
  }
  // Name of the tuning is the basename of the file, without the trailing .syx
  // suffix.
  string nm = filename;
  size_t p = nm.rfind(".syx");
  if (p != string::npos) nm.erase(p);
  p = nm.rfind('/');
  if (p != string::npos) nm.erase(0, p+1);
  name = strdup(nm.c_str());
  assert(name);
}

struct MTSTunings {
  vector<MTSTuning> tuning;
  MTSTunings() {}
  MTSTunings(const char *path);
};

static bool compareByName(const MTSTuning &a, const MTSTuning &b)
{
  return strcmp(a.name, b.name) < 0;
}

MTSTunings::MTSTunings(const char *path)
{
  DIR *dp = opendir(path);
  if (!dp) return;
  struct dirent *d;
  while ((d = readdir(dp))) {
    string nm = d->d_name;
    if (nm.length() > 4 && nm.substr(nm.length()-4) == ".syx") {
      string pathname = path;
      pathname += "/";
      pathname += nm;
      MTSTuning t(pathname.c_str());
      if (t.data) tuning.push_back(t);
    }
  }
  closedir(dp);
  // sort found tunings by name
  sort(tuning.begin(), tuning.end(), compareByName);
}

#endif

#if FAUST_MIDICC
static float ctrlval(const ui_elem_t &el, uint8_t v)
{
  // Translate the given MIDI controller value to the range and stepsize
  // indicated by the Faust control.
  switch (el.type) {
  case UI_BUTTON: case UI_CHECK_BUTTON:
    return (float)(v>=64);
  default:
    /* Continuous controllers. The problem here is that the range 0..127 is
       not symmetric. We'd like to map 64 to the center of the range
       (max-min)/2 and at the same time retain the full control range
       min..max. So let's just pretend that there are 128 controller values
       and map value 127 to the max value anyway. */
    if (v==127)
      return el.max;
    else
      // XXXFIXME: We might want to add proper quantization according to
      // el.step here.
      return el.min+(el.max-el.min)*v/128;
  }
}
#endif

/***************************************************************************/

/* Polyphonic Faust plugin data structure. XXXTODO: At present this is just a
   big struct which exposes all requisite data. Some more work is needed to
   make the interface a bit more abstract and properly encapsulate the
   internal data structures, so that implementation details can be changed
   more easily. */

struct LV2Plugin {
  const int maxvoices;	// maximum number of voices (zero if not an instrument)
  const int ndsps;	// number of dsp instances (1 if maxvoices==0)
  bool active;		// activation status
  int rate;		// sampling rate
  int nvoices;		// current number of voices (<= maxvoices)
  int tuning_no;	// current tuning number (<= n_tunings)
  gods_cab **dsp;		// the dsps
  LV2UI **ui;		// their Faust interface descriptions
  int n_in, n_out;	// number of input and output control ports
  int *ctrls;		// Faust ui elements (indices into ui->elems)
  float **ports;	// corresponding LV2 data
  float *portvals;	// cached port data from the last run
  float *midivals[16];	// per-midi channel data
  int *inctrls, *outctrls;	// indices for active and passive controls
  float **inputs, **outputs;	// audio buffers
  int freq, gain, gate;	// indices of voice controls
  unsigned n_samples;	// current block size
  float **outbuf;	// audio buffers for mixing down the voices
  float **inbuf;	// dummy input buffer
  LV2_Atom_Sequence* event_port; // midi input
  float *poly, *tuning;	// polyphony and tuning ports
  std::map<uint8_t,int> ctrlmap; // MIDI controller map
  // Needed host features.
  LV2_URID_Map* map;	// the urid extension
  LV2_URID midi_event;	// midi event uri
  // Current RPN MSB and LSB numbers, as set with controllers 101 and 100.
  uint8_t rpn_msb[16], rpn_lsb[16];
  // Current data entry MSB and LSB numbers, as set with controllers 6 and 38.
  uint8_t data_msb[16], data_lsb[16];
  // Synth voice data (instruments only).
  VoiceData *vd;

  // Static methods. These all use static data so they can be invoked before
  // instantiating a plugin.

  // Global meta data (dsp name, author, etc.).
  static Meta *meta;
  static void init_meta()
  {
    if (!meta && (meta = new Meta)) {
      // We allocate the temporary dsp object on the heap here, to prevent
      // large dsp objects from running out of stack in environments where
      // stack space is precious (e.g., Reaper). Note that if any of these
      // allocations fail then no meta data will be available, but at least we
      // won't make the host crash and burn.
      gods_cab* tmp_dsp = new gods_cab();
      if (tmp_dsp) {
	tmp_dsp->metadata(meta);
	delete tmp_dsp;
      }
    }
  }
  static const char *meta_get(const char *key, const char *deflt)
  {
    init_meta();
    return meta?meta->get(key, deflt):deflt;
  }

  static const char *pluginName()
  {
    return meta_get("name", "gods_cab");
  }

  static const char *pluginAuthor()
  {
    return meta_get("author", "");
  }

  static const char *pluginDescription()
  {
    return meta_get("description", "");
  }

  static const char *pluginLicense()
  {
    return meta_get("license", "");
  }

  static const char *pluginVersion()
  {
    return meta_get("version", "");
  }

  // Load a collection of sysex files with MTS tunings in ~/.faust/tuning.
  static int n_tunings;
#if FAUST_MTS
  static MTSTunings *mts;

  static MTSTunings *load_sysex_data()
  {
    if (!mts) {
      string mts_path;
      // Look for FAUST_HOME. If that isn't set, try $HOME/.faust. If HOME
      // isn't set either, just assume a .faust subdir of the cwd.
      const char *home = getenv("FAUST_HOME");
      if (home)
	mts_path = home;
      else {
	home = getenv("HOME");
	if (home) {
	  mts_path = home;
	  mts_path += "/.faust";
	} else
	  mts_path = ".faust";
      }
      // MTS tunings are looked for in this subdir.
      mts_path += "/tuning";
      mts = new MTSTunings(mts_path.c_str());
#ifdef __APPLE__
      if (!mts || mts->tuning.size() == 0) {
	// Also check ~/Library/Faust/Tuning on the Mac.
	home = getenv("HOME");
	if (home) {
	  if (mts) delete mts;
	  mts_path = home;
	  mts_path += "/Library/Faust/Tuning";
	  mts = new MTSTunings(mts_path.c_str());
	}
      }
#endif
      n_tunings = mts->tuning.size();
    }
    return mts;
  }
#endif

  // The number of voices of an instrument plugin. We get this information
  // from the global meta data (nvoices key) of the dsp module if present, and
  // you can also override this setting at compile time by defining the
  // NVOICES macro. If neither is defined or the value is zero then the plugin
  // becomes a simple audio effect instead.
  static int numVoices()
  {
#ifdef NVOICES
    return NVOICES;
#else
    const char *numVoices = meta_get("nvoices", "0");
    int nvoices = atoi(numVoices);
    if (nvoices < 0 ) nvoices = 0;
    return nvoices;
#endif
  }

  // Instance methods.

  LV2Plugin(const int num_voices, const int sr)
    : maxvoices(num_voices), ndsps(num_voices<=0?1:num_voices),
      vd(num_voices>0?new VoiceData(num_voices):0)
  {
    // Initialize static data.
    init_meta();
#if FAUST_MTS
    // Synth: load tuning sysex data if present.
    if (num_voices>0) load_sysex_data();
#endif
    // Allocate data structures and set some reasonable defaults.
    dsp = (gods_cab**)calloc(ndsps, sizeof(gods_cab*));
    ui = (LV2UI**)calloc(ndsps, sizeof(LV2UI*));
    assert(dsp && ui);
    if (vd) {
      vd->note_info = (NoteInfo*)calloc(ndsps, sizeof(NoteInfo));
      vd->lastgate = (float*)calloc(ndsps, sizeof(float));
      assert(vd->note_info && vd->lastgate);
    }
    active = false;
    rate = sr;
    nvoices = maxvoices;
    tuning_no = 0;
    n_in = n_out = 0;
    map = NULL;
    midi_event = -1;
    event_port = NULL;
    poly = tuning = NULL;
    freq = gain = gate = -1;
    if (vd) {
      vd->n_free = maxvoices;
      for (int i = 0; i < maxvoices; i++) {
	vd->free_voices.push_back(i);
	vd->lastgate[i] = 0.0f;
      }
      for (int i = 0; i < 16; i++) {
	vd->bend[i] = 0.0f;
	vd->range[i] = 2.0f;
	vd->coarse[i] = vd->fine[i] = vd->tune[i] = 0.0f;
	for (int j = 0; j < 12; j++)
	  vd->tuning[i][j] = 0.0f;
      }
      vd->n_used = 0;
      memset(vd->notes, 0xff, sizeof(vd->notes));
    }
    n_samples = 0;
    ctrls = inctrls = outctrls = NULL;
    ports = inputs = outputs = inbuf = outbuf = NULL;
    portvals = NULL;
    memset(midivals, 0, sizeof(midivals));
    // Initialize the Faust DSPs.
    for (int i = 0; i < ndsps; i++) {
      dsp[i] = new gods_cab();
      ui[i] = new LV2UI(num_voices);
      dsp[i]->init(rate);
      dsp[i]->buildUserInterface(ui[i]);
    }
    // The ports are numbered as follows: 0..k-1 are the control ports, then
    // come the n audio input ports, then the m audio output ports, and
    // finally the midi input port and the polyphony and tuning controls.
    int k = ui[0]->nports, p = 0, q = 0;
    int n = dsp[0]->getNumInputs(), m = dsp[0]->getNumOutputs();
    // Allocate tables for the built-in control elements and their ports.
    ctrls = (int*)calloc(k, sizeof(int));
    inctrls = (int*)calloc(k, sizeof(int));
    outctrls = (int*)calloc(k, sizeof(int));
    ports = (float**)calloc(k, sizeof(float*));
    portvals = (float*)calloc(k, sizeof(float));
    assert(k == 0 || (ctrls && inctrls && outctrls && ports && portvals));
    for (int ch = 0; ch < 16; ch++) {
      midivals[ch] = (float*)calloc(k, sizeof(float));
      assert(k == 0 || midivals[ch]);
    }
    // Scan the Faust UI for active and passive controls which become the
    // input and output control ports of the plugin, respectively.
    for (int i = 0, j = 0; i < ui[0]->nelems; i++) {
      switch (ui[0]->elems[i].type) {
      case UI_T_GROUP: case UI_H_GROUP: case UI_V_GROUP: case UI_END_GROUP:
	// control groups (ignored right now)
	break;
      case UI_H_BARGRAPH: case UI_V_BARGRAPH:
	// passive controls (output ports)
	ctrls[j++] = i;
	outctrls[q++] = i;
	break;
      default:
	// active controls (input ports)
	if (maxvoices == 0)
	  goto noinstr;
	else if (freq == -1 &&
		 !strcmp(ui[0]->elems[i].label, "freq"))
	  freq = i;
	else if (gain == -1 &&
		 !strcmp(ui[0]->elems[i].label, "gain"))
	  gain = i;
	else if (gate == -1 &&
		 !strcmp(ui[0]->elems[i].label, "gate"))
	  gate = i;
	else {
	noinstr:
#if FAUST_MIDICC
	  std::map< int, list<strpair> >::iterator it =
	    ui[0]->metadata.find(i);
	  if (it != ui[0]->metadata.end()) {
	    // Scan for controller mappings.
	    for (std::list<strpair>::iterator jt = it->second.begin();
		 jt != it->second.end(); jt++) {
	      const char *key = jt->first, *val = jt->second;
#if DEBUG_META
	      fprintf(stderr, "ctrl '%s' meta: '%s' -> '%s'\n",
		      ui[0]->elems[i].label, key, val);
#endif
	      if (strcmp(key, "midi") == 0) {
		unsigned num;
		if (sscanf(val, "ctrl %u", &num) < 1) continue;
#if 0 // enable this to get feedback about controller assignments
		fprintf(stderr, "%s: cc %d -> %s\n", PLUGIN_URI, num,
			ui[0]->elems[i].label);
#endif
		ctrlmap.insert(std::pair<uint8_t,int>(num, p));
	      }
	    }
	  }
#endif
	  ctrls[j++] = i;
	  inctrls[p++] = i;
	  int p = ui[0]->elems[i].port;
	  float val = ui[0]->elems[i].init;
	  assert(p>=0);
	  portvals[p] = val;
	  for (int ch = 0; ch < 16; ch++)
	    midivals[ch][p] = val;
	}
	break;
      }
    }
    // Realloc the inctrls and outctrls vectors to their appropriate sizes.
    inctrls = (int*)realloc(inctrls, p*sizeof(int));
    assert(p == 0 || inctrls);
    outctrls = (int*)realloc(outctrls, q*sizeof(int));
    assert(q == 0 || outctrls);
    n_in = p; n_out = q;
    // Allocate vectors for the audio input and output ports. Like
    // ports, these will be initialized in the connect_port callback.
    inputs = (float**)calloc(n, sizeof(float*));
    assert(n == 0 || inputs);
    outputs = (float**)calloc(m, sizeof(float*));
    assert(m == 0 || outputs);
    if (maxvoices > 0) {
      // Initialize the mixdown buffer.
      outbuf = (float**)calloc(m, sizeof(float*));
      assert(m == 0 || outbuf);
      // We start out with a blocksize of 512 samples here. Hopefully this is
      // enough for most realtime hosts so that we can avoid reallocations
      // later when we know what the actual blocksize is.
      n_samples = 512;
      for (int i = 0; i < m; i++) {
	outbuf[i] = (float*)malloc(n_samples*sizeof(float));
	assert(outbuf[i]);
      }
      // Initialize a 1-sample dummy input buffer used for retriggering notes.
      inbuf = (float**)calloc(n, sizeof(float*));
      assert(n == 0 || inbuf);
      for (int i = 0; i < m; i++) {
	inbuf[i] = (float*)malloc(sizeof(float));
	assert(inbuf[i]);
	*inbuf[i] = 0.0f;
      }
    }
  }

  ~LV2Plugin()
  {
    const int n = dsp[0]->getNumInputs();
    const int m = dsp[0]->getNumOutputs();
    for (int i = 0; i < ndsps; i++) {
      delete dsp[i];
      delete ui[i];
    }
    free(ctrls); free(inctrls); free(outctrls);
    free(ports); free(portvals);
    free(inputs); free(outputs);
    for (int ch = 0; ch < 16; ch++)
      free(midivals[ch]);
    if (inbuf) {
      for (int i = 0; i < n; i++)
	free(inbuf[i]);
      free(inbuf);
    }
    if (outbuf) {
      for (int i = 0; i < m; i++)
	free(outbuf[i]);
      free(outbuf);
    }
    free(dsp); free(ui);
    if (vd) {
      free(vd->note_info);
      free(vd->lastgate);
      delete vd;
    }
  }
  // Voice allocation.

#if DEBUG_VOICE_ALLOC
  void print_voices(const char *msg)
  {
    fprintf(stderr, "%s: notes =", msg);
    for (uint8_t ch = 0; ch < 16; ch++)
      for (int note = 0; note < 128; note++)
	if (vd->notes[ch][note] >= 0)
	  fprintf(stderr, " [%d] %d(#%d)", ch, note, vd->notes[ch][note]);
    fprintf(stderr, "\nqueued (%d):", vd->queued.size());
    for (int i = 0; i < nvoices; i++)
      if (vd->queued.find(i) != vd->queued.end()) fprintf(stderr, " #%d", i);
    fprintf(stderr, "\nused (%d):", vd->n_used);
    for (boost::circular_buffer<int>::iterator it = vd->used_voices.begin();
	 it != vd->used_voices.end(); it++)
      fprintf(stderr, " #%d->%d", *it, vd->note_info[*it].note);
    fprintf(stderr, "\nfree (%d):", vd->n_free);
    for (boost::circular_buffer<int>::iterator it = vd->free_voices.begin();
	 it != vd->free_voices.end(); it++)
      fprintf(stderr, " #%d", *it);
    fprintf(stderr, "\n");
  }
#endif

  int alloc_voice(uint8_t ch, int8_t note, int8_t vel)
  {
    int i = vd->notes[ch][note];
    if (i >= 0) {
      // note already playing on same channel, retrigger it
      voice_off(i);
      voice_on(i, note, vel, ch);
      // move this voice to the end of the used list
      for (boost::circular_buffer<int>::iterator it =
	     vd->used_voices.begin();
	   it != vd->used_voices.end(); it++) {
	if (*it == i) {
	  vd->used_voices.erase(it);
	  vd->used_voices.push_back(i);
	  break;
	}
      }
#if DEBUG_VOICE_ALLOC
      print_voices("retrigger");
#endif
      return i;
    } else if (vd->n_free > 0) {
      // take voice from free list
      int i = vd->free_voices.front();
      vd->free_voices.pop_front();
      vd->n_free--;
      vd->used_voices.push_back(i);
      vd->note_info[i].ch = ch;
      vd->note_info[i].note = note;
      vd->n_used++;
      voice_on(i, note, vel, ch);
      vd->notes[ch][note] = i;
#if DEBUG_VOICE_ALLOC
      print_voices("alloc");
#endif
      return i;
    } else {
      // steal a voice
      assert(vd->n_used > 0);
      // FIXME: Maybe we should look for the oldest note on the *current*
      // channel here, but this is faster.
      int i = vd->used_voices.front();
      int oldch = vd->note_info[i].ch;
      int oldnote = vd->note_info[i].note;
      voice_off(i);
      vd->notes[oldch][oldnote] = -1;
      vd->queued.erase(i);
      vd->used_voices.pop_front();
      vd->used_voices.push_back(i);
      vd->note_info[i].ch = ch;
      vd->note_info[i].note = note;
      voice_on(i, note, vel, ch);
      vd->notes[ch][note] = i;
#if DEBUG_VOICE_ALLOC
      print_voices("steal");
#endif
      return i;
    }
  }

  int dealloc_voice(uint8_t ch, int8_t note, int8_t vel)
  {
    int i = vd->notes[ch][note];
    if (i >= 0) {
      if (vd->lastgate[i] == 0.0f && gate >= 0) {
	// zero-length note, queued for later
	vd->queued.insert(i);
	vd->notes[ch][note] = -1;
#if DEBUG_VOICE_ALLOC
	print_voices("dealloc (queued)");
#endif
	return i;
      }
      assert(vd->n_free < nvoices);
      vd->free_voices.push_back(i);
      vd->n_free++;
      voice_off(i);
      vd->notes[ch][note] = -1;
      // erase this voice from the used list
      for (boost::circular_buffer<int>::iterator it =
	     vd->used_voices.begin();
	   it != vd->used_voices.end(); it++) {
	if (*it == i) {
	  vd->used_voices.erase(it);
	  vd->n_used--;
	  break;
	}
      }
#if DEBUG_VOICE_ALLOC
      print_voices("dealloc");
#endif
      return i;
    }
    return -1;
  }


  float midicps(int8_t note, uint8_t chan)
  {
    float pitch = note + vd->tune[chan] +
      vd->tuning[chan][note%12] + vd->bend[chan];
    return 440.0*pow(2, (pitch-69.0)/12.0);
  }

  void voice_on(int i, int8_t note, int8_t vel, uint8_t ch)
  {
    if (vd->lastgate[i] == 1.0f && gate >= 0) {
      // Make sure that the synth sees the 0.0f gate so that the voice is
      // properly retriggered.
      *ui[i]->elems[gate].zone = 0.0f;
      dsp[i]->compute(1, inbuf, outbuf);
    }
#if DEBUG_VOICES
    fprintf(stderr, "voice on: %d %d (%g Hz) %d (%g)\n", i,
	    note, midicps(note, ch), vel, vel/127.0);
#endif
    if (freq >= 0)
      *ui[i]->elems[freq].zone = midicps(note, ch);
    if (gate >= 0)
      *ui[i]->elems[gate].zone = 1.0f;
    if (gain >= 0)
      *ui[i]->elems[gain].zone = vel/127.0;
    // reinitialize the per-channel control data for this voice
    for (int idx = 0; idx < n_in; idx++) {
      int j = inctrls[idx], k = ui[0]->elems[j].port;
      *ui[i]->elems[j].zone = midivals[ch][k];
    }
  }

  void voice_off(int i)
  {
#if DEBUG_VOICES
    fprintf(stderr, "voice off: %d\n", i);
#endif
    if (gate >= 0)
      *ui[i]->elems[gate].zone = 0.0f;
  }

  void update_voices(uint8_t chan)
  {
    // update running voices on the given channel after tuning or pitch bend
    // changes
    for (boost::circular_buffer<int>::iterator it =
	   vd->used_voices.begin();
	 it != vd->used_voices.end(); it++) {
      int i = *it;
      if (vd->note_info[i].ch == chan && freq >= 0) {
	int note = vd->note_info[i].note;
	*ui[i]->elems[freq].zone = midicps(note, chan);
      }
    }
  }

  void all_notes_off()
  {
    for (int i = 0; i < nvoices; i++)
      voice_off(i);
    for (int i = 0; i < 16; i++)
      vd->bend[i] = 0.0f;
    memset(vd->notes, 0xff, sizeof(vd->notes));
    vd->free_voices.clear();
    vd->n_free = nvoices;
    for (int i = 0; i < nvoices; i++)
      vd->free_voices.push_back(i);
    vd->queued.clear();
    vd->used_voices.clear();
    vd->n_used = 0;
  }

  void all_notes_off(uint8_t chan)
  {
    for (boost::circular_buffer<int>::iterator it =
	   vd->used_voices.begin();
	 it != vd->used_voices.end(); ) {
      int i = *it;
      if (vd->note_info[i].ch == chan) {
	assert(vd->n_free < nvoices);
	vd->free_voices.push_back(i);
	vd->n_free++;
	voice_off(i);
	vd->notes[vd->note_info[i].ch][vd->note_info[i].note] = -1;
	vd->queued.erase(i);
	// erase this voice from the used list
	it = vd->used_voices.erase(it);
	vd->n_used--;
#if DEBUG_VOICE_ALLOC
	print_voices("dealloc (all-notes-off)");
#endif
      } else
	it++;
    }
    vd->bend[chan] = 0.0f;
  }

  void queued_notes_off()
  {
    if (vd->queued.empty()) return;
    for (int i = 0; i < nvoices; i++)
      if (vd->queued.find(i) != vd->queued.end()) {
	assert(vd->n_free < nvoices);
	vd->free_voices.push_back(i);
	vd->n_free++;
	voice_off(i);
	vd->notes[vd->note_info[i].ch][vd->note_info[i].note] = -1;
	vd->queued.erase(i);
	// erase this voice from the used list
	for (boost::circular_buffer<int>::iterator it =
	       vd->used_voices.begin();
	     it != vd->used_voices.end(); it++) {
	  if (*it == i) {
	    vd->used_voices.erase(it);
	    vd->n_used--;
	    break;
	  }
	}
#if DEBUG_VOICE_ALLOC
	print_voices("dealloc (unqueued)");
#endif
      }
  }

  // Plugin activation status. suspend() deactivates a plugin (disables audio
  // processing), resume() reactivates it. Also, set_rate() changes the sample
  // rate. Note that the audio and MIDI process functions (see below) can
  // still be called in deactivated state, but this is optional. The plugin
  // tries to do some reasonable processing in either case, no matter whether
  // the host plugin architecture actually executes callbacks in suspended
  // state or not.

  void suspend()
  {
    active = false;
    if (maxvoices > 0) all_notes_off();
  }

  void resume()
  {
    for (int i = 0; i < ndsps; i++)
      dsp[i]->init(rate);
    for (int i = 0, j = 0; i < ui[0]->nelems; i++) {
      int p = ui[0]->elems[i].port;
      if (p >= 0) {
	float val = ui[0]->elems[i].init;
	portvals[p] = val;
      }
    }
    active = true;
  }

  void set_rate(int sr)
  {
    rate = sr;
    for (int i = 0; i < ndsps; i++)
      dsp[i]->init(rate);
  }

  // Audio and MIDI process functions. The plugin should run these in the
  // appropriate real-time callbacks.

  void process_audio(int blocksz, float **inputs, float **outputs)
  {
    int n = dsp[0]->getNumInputs(), m = dsp[0]->getNumOutputs();
    AVOIDDENORMALS;
    if (maxvoices > 0) queued_notes_off();
    if (!active) {
      // Depending on the plugin architecture and host, this code might never
      // be invoked, since the plugin is deactivitated at this point. But
      // let's do something reasonable here anyway.
      if (n == m) {
	// copy inputs to outputs
	for (int i = 0; i < m; i++)
	  for (unsigned j = 0; j < blocksz; j++)
	    outputs[i][j] = inputs[i][j];
      } else {
	// silence
	for (int i = 0; i < m; i++)
	  for (unsigned j = 0; j < blocksz; j++)
	    outputs[i][j] = 0.0f;
      }
      return;
    }
    // Handle changes in the polyphony and tuning controls.
    bool is_instr = maxvoices > 0;
    if (is_instr) {
      if (!poly)
	; // this shouldn't happen but...
      else if (nvoices != (int)*poly &&
	       (int)*poly > 0 && (int)*poly <= maxvoices) {
	for (int i = 0; i < nvoices; i++)
	  voice_off(i);
        nvoices = (int)*poly;
	// Reset the voice allocation.
	memset(vd->notes, 0xff, sizeof(vd->notes));
	vd->free_voices.clear();
	vd->n_free = nvoices;
	for (int i = 0; i < nvoices; i++)
	  vd->free_voices.push_back(i);
	vd->used_voices.clear();
	vd->n_used = 0;
      } else
	*poly = nvoices;
#if FAUST_MTS
      if (tuning && tuning_no != (int)*tuning) change_tuning((int)*tuning);
#endif
    }
    // Only update the controls (of all voices simultaneously) if a port value
    // actually changed. This is necessary to allow MIDI controllers to modify
    // the values for individual MIDI channels (see processEvents below). Also
    // note that this will be done *after* processing the MIDI controller data
    // for the current audio block, so manual inputs can still override these.
    for (int i = 0; i < n_in; i++) {
      int j = inctrls[i], k = ui[0]->elems[j].port;
      float &oldval = portvals[k], newval = *ports[k];
      if (newval != oldval) {
	if (is_instr) {
	  // instrument: update running voices
	  for (boost::circular_buffer<int>::iterator it =
		 vd->used_voices.begin();
	       it != vd->used_voices.end(); it++) {
	    int i = *it;
	    *ui[i]->elems[j].zone = newval;
	  }
	} else {
	  // simple effect: here we only have a single dsp instance
	  *ui[0]->elems[j].zone = newval;
	}
	// also update the MIDI controller data for all channels (manual
	// control input is always omni)
	for (int ch = 0; ch < 16; ch++)
	  midivals[ch][k] = newval;
	// record the new value
	oldval = newval;
      }
    }
    // Initialize the output buffers.
    if (n_samples < blocksz) {
      // We need to enlarge the buffers. We're not officially allowed to do
      // this here (presumably in the realtime thread), but since we usually
      // don't know the hosts's block size beforehand, there's really nothing
      // else that we can do. Let's just hope that doing this once suffices,
      // then hopefully noone will notice.
      if (outbuf) {
	for (int i = 0; i < m; i++) {
	  outbuf[i] = (float*)realloc(outbuf[i],
				      blocksz*sizeof(float));
	  assert(outbuf[i]);
	}
      }
      n_samples = blocksz;
    }
    if (outbuf) {
      // Polyphonic instrument: Mix the voices down to one signal.
      for (int i = 0; i < m; i++)
	for (unsigned j = 0; j < blocksz; j++)
	  outputs[i][j] = 0.0f;
      for (int l = 0; l < nvoices; l++) {
	// Let Faust do all the hard work.
	dsp[l]->compute(blocksz, inputs, outbuf);
	for (int i = 0; i < m; i++)
	  for (unsigned j = 0; j < blocksz; j++)
	    outputs[i][j] += outbuf[i][j];
      }
    } else {
      // Simple effect: We can write directly to the output buffer.
      dsp[0]->compute(blocksz, inputs, outputs);
    }
    // Finally grab the passive controls and write them back to the
    // corresponding control ports. NOTE: Depending on the plugin
    // architecture, this might require a host call to get the control GUI
    // updated in real-time (if the host supports this at all).
    // FIXME: It's not clear how to aggregate the data of the different
    // voices. We compute the maximum of each control for now.
    for (int i = 0; i < n_out; i++) {
      int j = outctrls[i], k = ui[0]->elems[j].port;
      float *z = ui[0]->elems[j].zone;
      *ports[k] = *z;
      for (int l = 1; l < nvoices; l++) {
	float *z = ui[l]->elems[j].zone;
	if (*ports[k] < *z)
	  *ports[k] = *z;
      }
    }
    // Keep track of the last gates set for each voice, so that voices can be
    // forcibly retriggered if needed.
    if (gate >= 0)
      for (int i = 0; i < nvoices; i++)
	vd->lastgate[i] =
	  *ui[i]->elems[gate].zone;
  }

  // This processes just a single MIDI message, so to process an entire series
  // of MIDI events you'll have to loop over the event data in the plugin's
  // MIDI callback. XXXTODO: Sample-accurate processing of MIDI events.
  
  void process_midi(unsigned char *data, int sz)
  {
#if DEBUG_MIDI
    fprintf(stderr, "midi ev (%d bytes):", sz);
    for (int i = 0; i < sz; i++)
      fprintf(stderr, " 0x%0x", data[i]);
    fprintf(stderr, "\n");
#endif
    uint8_t status = data[0] & 0xf0, chan = data[0] & 0x0f;
    bool is_instr = maxvoices > 0;
    switch (status) {
    case 0x90: {
      if (!is_instr) break;
      // note on
#if DEBUG_NOTES
      fprintf(stderr, "note-on  chan %d, note %d, vel %d\n", chan+1,
	      data[1], data[2]);
#endif
      if (data[2] == 0) goto note_off;
      alloc_voice(chan, data[1], data[2]);
      break;
    }
    case 0x80: {
      if (!is_instr) break;
      // note off
#if DEBUG_NOTES
      fprintf(stderr, "note-off chan %d, note %d, vel %d\n", chan+1,
	      data[1], data[2]);
#endif
      note_off:
      dealloc_voice(chan, data[1], data[2]);
      break;
    }
    case 0xe0: {
      if (!is_instr) break;
      // pitch bend
      // data[1] is LSB, data[2] MSB, range is 0..0x3fff (which maps to
      // -2..+2 semitones by default), center point is 0x2000 = 8192
      int val = data[1] | (data[2]<<7);
      vd->bend[chan] =
	(val-0x2000)/8192.0f*vd->range[chan];
#if DEBUG_MIDICC
      fprintf(stderr, "pitch-bend (chan %d): %g cent\n", chan+1,
	      vd->bend[chan]*100.0);
#endif
      update_voices(chan);
      break;
    }
    case 0xb0: {
      // controller change
      switch (data[1]) {
      case 120: case 123:
	if (!is_instr) break;
	// all-sound-off and all-notes-off controllers (these are treated
	// the same in the current implementation)
	all_notes_off(chan);
#if DEBUG_MIDICC
	fprintf(stderr, "all-notes-off (chan %d)\n", chan+1);
#endif
	break;
      case 121:
	// all-controllers-off (in the current implementation, this just
	// resets the RPN-related controllers)
	data_msb[chan] = data_lsb[chan] = 0;
	rpn_msb[chan] = rpn_lsb[chan] = 0x7f;
#if DEBUG_MIDICC
	fprintf(stderr, "all-controllers-off (chan %d)\n", chan+1);
#endif
	break;
      case 101: case 100:
	// RPN MSB/LSB
	if (data[1] == 101)
	  rpn_msb[chan] = data[2];
	else
	  rpn_lsb[chan] = data[2];
	break;
      case 6: case 38:
	// data entry coarse/fine
	if (data[1] == 6)
	  data_msb[chan] = data[2];
	else
	  data_lsb[chan] = data[2];
	goto rpn;
      case 96: case 97:
	// data increment/decrement
	/* NOTE: The specification of these controllers is a complete
	   mess. Originally, the MIDI specification didn't have anything
	   to say about their exact behaviour at all. Nowadays, the
	   behaviour depends on which RPN or NRPN is being modified, which
	   is also rather confusing. Fortunately, as we only handle RPNs
	   0..2 here anyway, it's sufficient to assume the MSB for RPN #2
	   (channel coarse tuning) and the LSB otherwise. */
	if (rpn_msb[chan] == 0 && rpn_lsb[chan] == 2) {
	  // modify the MSB
	  if (data[1] == 96 && data_msb[chan] < 0x7f)
	    data_msb[chan]++;
	  else if (data[1] == 97 && data_msb[chan] > 0)
	    data_msb[chan]--;
	} else {
	  // modify the LSB
	  if (data[1] == 96 && data_lsb[chan] < 0x7f)
	    data_lsb[chan]++;
	  else if (data[1] == 97 && data_lsb[chan] > 0)
	    data_lsb[chan]--;
	}
      rpn:
	if (!is_instr) break;
	if (rpn_msb[chan] == 0) {
	  switch (rpn_lsb[chan]) {
	  case 0:
	    // pitch bend range, coarse value is in semitones, fine value
	    // in cents
	    vd->range[chan] = data_msb[chan]+
	      data_lsb[chan]/100.0;
#if DEBUG_RPN
	    fprintf(stderr, "pitch-bend-range (chan %d): %g cent\n", chan+1,
		    vd->range[chan]*100.0);
#endif
	    break;
	  case 1:
	    {
	      // channel fine tuning (14 bit value, range -100..+100 cents)
	      int value = (data_msb[chan]<<7) |
		data_lsb[chan];
	      vd->fine[chan] = (value-8192)/8192.0f;
	    }
	    goto master_tune;
	  case 2:
	    // channel coarse tuning (only msb is used, range -64..+63
	    // semitones)
	    vd->coarse[chan] = data_msb[chan]-64;
	  master_tune:
	    vd->tune[chan] = vd->coarse[chan]+
	      vd->fine[chan];
#if DEBUG_RPN
	    fprintf(stderr, "master-tuning (chan %d): %g cent\n", chan+1,
		    vd->tune[chan]*100.0);
#endif
	    update_voices(chan);
	    break;
	  default:
	    break;
	  }
	}
	break;
      default: {
#if FAUST_MIDICC
	// interpret all other controller changes according to the MIDI
	// controller map defined in the Faust plugin itself
	std::map<uint8_t,int>::iterator it = ctrlmap.find(data[1]);
	if (it != ctrlmap.end()) {
	  // defined MIDI controller
	  int j = inctrls[it->second],
	    k = ui[0]->elems[j].port;
	  float val = ctrlval(ui[0]->elems[j], data[2]);
	  midivals[chan][k] = val;
	  if (is_instr) {
	    // instrument: update running voices on this channel
	    for (boost::circular_buffer<int>::iterator it =
		   vd->used_voices.begin();
		 it != vd->used_voices.end(); it++) {
	      int i = *it;
	      if (vd->note_info[i].ch == chan)
		*ui[i]->elems[j].zone = val;
	    }
	  } else {
	    // simple effect: here we only have a single dsp instance and
	    // we're operating in omni mode, so we just update the control no
	    // matter what the midi channel is
	    *ui[0]->elems[j].zone = val;
	  }
#if DEBUG_MIDICC
	  fprintf(stderr, "ctrl-change chan %d, ctrl %d, val %d\n", chan+1,
		  data[1], data[2]);
#endif
	}
#endif
	break;
      }
      }
      break;
    }
    default:
      break;
    }
  }

  // Process an MTS sysex message and update the control values accordingly.

  void process_sysex(uint8_t *data, int sz)
  {
    if (!data || sz < 2) return;
#if DEBUG_MIDI
    fprintf(stderr, "midi sysex (%d bytes):", sz);
    for (int i = 0; i < sz; i++)
      fprintf(stderr, " 0x%0x", data[i]);
    fprintf(stderr, "\n");
#endif
    if (data[0] == 0xf0) {
      // Skip over the f0 and f7 status bytes in case they are included in the
      // dump.
      data++; sz--;
      if (data[sz-1] == 0xf7) sz--;
    }
    if ((data[0] == 0x7e || data[0] == 0x7f) && data[2] == 8) {
      // MIDI tuning standard
      bool realtime = data[0] == 0x7f;
      if ((sz == 19 && data[3] == 8) ||
	  (sz == 31 && data[3] == 9)) {
	// MTS scale/octave tuning 1- or 2-byte form
	bool onebyte = data[3] == 8;
	unsigned chanmsk = (data[4]<<14) | (data[5]<<7) | data[6];
	for (int i = 0; i < 12; i++) {
	  float t;
	  if (onebyte)
	    t = (data[i+7]-64)/100.0;
	  else
	    t = (((data[2*i+7]<<7)|data[2*i+8])-8192)/8192.0;
	  for (uint8_t ch = 0; ch < 16; ch++)
	    if (chanmsk & (1<<ch))
	      vd->tuning[ch][i] = t;
	}
	if (realtime) {
	  for (uint8_t ch = 0; ch < 16; ch++)
	    if (chanmsk & (1<<ch)) {
	      // update running voices on this channel
	      update_voices(ch);
	    }
	}
#if DEBUG_MTS
	fprintf(stderr, "octave-tuning-%s (chan ",
		realtime?"realtime":"non-realtime");
	bool first = true;
	for (uint8_t i = 0; i < 16; )
	  if (chanmsk & (1<<i)) {
	    uint8_t j;
	    for (j = i+1; j < 16 && (chanmsk&(1<<j)); )
	      j++;
	    if (first)
	      first = false;
	    else
	      fprintf(stderr, ",");
	    if (j > i+1)
	      fprintf(stderr, "%u-%u", i+1, j);
	    else
	      fprintf(stderr, "%u", i+1);
	    i = j;
	  } else
	    i++;
	fprintf(stderr, "):");
	if (onebyte) {
	  for (int i = 7; i < 19; i++) {
	    int val = data[i];
	    fprintf(stderr, " %d", val-64);
	  }
	} else {
	  for (int i = 7; i < 31; i++) {
	    int val = data[i++] << 7;
	    val |= data[i];
	    fprintf(stderr, " %g", ((double)val-8192.0)/8192.0*100.0);
	  }
	}
	fprintf(stderr, "\n");
#endif
      }
    }
  }

  // Change to a given preloaded tuning. The given tuning number may be in the
  // range 1..PFaustPlugin::n_tunings, zero denotes the default tuning (equal
  // temperament). This is only supported if FAUST_MTS is defined at compile
  // time.

  void change_tuning(int num)
  {
#if FAUST_MTS
    if (!mts || num == tuning_no) return;
    if (num < 0) num = 0;
    if (num > mts->tuning.size())
      num = mts->tuning.size();
    tuning_no = num;
    if (tuning_no > 0) {
      process_sysex(mts->tuning[tuning_no-1].data,
		    mts->tuning[tuning_no-1].len);
    } else {
      memset(vd->tuning, 0, sizeof(vd->tuning));
#if DEBUG_MTS
      fprintf(stderr,
	      "octave-tuning-default (chan 1-16): equal temperament\n");
#endif
    }
#endif
  }

};

Meta *LV2Plugin::meta = 0;
int LV2Plugin::n_tunings = 0;
#if FAUST_MTS
MTSTunings *LV2Plugin::mts = 0;
#endif

/* LV2-specific part starts here. ********************************************/

static LV2_Handle
instantiate(const LV2_Descriptor*     descriptor,
            double                    rate,
            const char*               bundle_path,
            const LV2_Feature* const* features)
{
  LV2Plugin* plugin =
    new LV2Plugin(LV2Plugin::numVoices(), (int)rate);
  // Scan host features for URID map.
  for (int i = 0; features[i]; i++) {
    if (!strcmp(features[i]->URI, LV2_URID_URI "#map")) {
      plugin->map = (LV2_URID_Map*)features[i]->data;
      plugin->midi_event =
	plugin->map->map(plugin->map->handle, MIDI_EVENT_URI);
    }
  }
  if (!plugin->map) {
    fprintf
      (stderr, "%s: host doesn't support urid:map, giving up\n",
       PLUGIN_URI);
    delete plugin;
    return 0;
  }
  return (LV2_Handle)plugin;
}

static void
cleanup(LV2_Handle instance)
{
  LV2Plugin* plugin = (LV2Plugin*)instance;
  delete plugin;
}

static void
connect_port(LV2_Handle instance,
             uint32_t   port,
             void*      data)
{
  LV2Plugin* plugin = (LV2Plugin*)instance;
  int i = port, k = plugin->ui[0]->nports;
  int n = plugin->dsp[0]->getNumInputs(), m = plugin->dsp[0]->getNumOutputs();
  if (i < k)
    plugin->ports[i] = (float*)data;
  else {
    i -= k;
    if (i < n)
      plugin->inputs[i] = (float*)data;
    else {
      i -= n;
      if (i < m)
	plugin->outputs[i] = (float*)data;
      else if (i == m)
	plugin->event_port = (LV2_Atom_Sequence*)data;
      else if (i == m+1)
	plugin->poly = (float*)data;
      else if (i == m+2)
	plugin->tuning = (float*)data;
      else
	fprintf(stderr, "%s: bad port number %u\n", PLUGIN_URI, port);
    }
  }
}

static void
run(LV2_Handle instance, uint32_t n_samples)
{
  LV2Plugin* plugin = (LV2Plugin*)instance;
  // Process incoming MIDI events.
  if (plugin->event_port) {
    LV2_ATOM_SEQUENCE_FOREACH(plugin->event_port, ev) {
      if (ev->body.type == plugin->midi_event) {
	uint8_t *data = (uint8_t*)(ev+1);
#if 0
	// FIXME: Consider doing sample-accurate note onsets here. LV2 keeps
	// track of the exact onset in the frames and subframes fields
	// (http://lv2plug.in/ns/doc/html/structLV2__Atom__Event.html), but we
	// can't use that information at present, since our gate parameter is
	// a control variable which can only change at block boundaries. In
	// the future, the gate could be implemented as an audio signal to get
	// sample-accurate note onsets.
	uint32_t frames = ev->body.frames;
#endif
	if (data[0] == 0xf0)
	  plugin->process_sysex(data, ev->body.size);
	else
	  plugin->process_midi(data, ev->body.size);
      }
    }
  }
  // Process audio.
  plugin->process_audio(n_samples, plugin->inputs, plugin->outputs);
}

static void
activate(LV2_Handle instance)
{
  LV2Plugin* plugin = (LV2Plugin*)instance;
  plugin->resume();
}

static void
deactivate(LV2_Handle instance)
{
  LV2Plugin* plugin = (LV2Plugin*)instance;
  plugin->suspend();
}

const void*
extension_data(const char* uri)
{
  return NULL;
}

static const LV2_Descriptor descriptor = {
  PLUGIN_URI,
  instantiate,
  connect_port,
  activate,
  run,
  deactivate,
  cleanup,
  extension_data
};

extern "C"
LV2_SYMBOL_EXPORT
const LV2_Descriptor*
lv2_descriptor(uint32_t index)
{
  switch (index) {
  case 0:
    return &descriptor;
  default:
    return NULL;
  }
}

//----------------------------------------------------------------------------
//  Dynamic manifest
//----------------------------------------------------------------------------

// NOTE: If your LV2 host doesn't offer this extension then you'll have to
// create a static ttl file with the descriptions of the ports. You can do
// this by compiling this code to a standalone executable. Running the
// executable then prints the manifest on stdout.

extern "C"
LV2_SYMBOL_EXPORT
int lv2_dyn_manifest_open(LV2_Dyn_Manifest_Handle *handle,
			  const LV2_Feature *const *features)
{
  LV2Plugin* plugin =
    new LV2Plugin(LV2Plugin::numVoices(), 48000);
  *handle = (LV2_Dyn_Manifest_Handle)plugin;
  return 0;
}

extern "C"
LV2_SYMBOL_EXPORT
int lv2_dyn_manifest_get_subjects(LV2_Dyn_Manifest_Handle handle,
				  FILE *fp)
{
  fprintf(fp, "@prefix lv2:  <http://lv2plug.in/ns/lv2core#> .\n\
<%s> a lv2:Plugin .\n", PLUGIN_URI);
  return 0;
}

#include <string>
#include <ctype.h>

static string mangle(const string &s)
{
  string t = s;
  size_t n = s.size();
  for (size_t i = 0; i < n; i++)
    if ((i == 0 && !isalpha(t[i]) && t[i] != '_') ||
	(!isalnum(t[i]) && t[i] != '_'))
      t[i] = '_';
  return t;
}

static unsigned steps(float min, float max, float step)
{
  if (step == 0.0) return 1;
  int n = (max-min)/step;
  if (n < 0) n = -n;
  if (n == 0) n = 1;
  return n;
}

#if FAUST_META
static bool is_xmlstring(const char *s)
{
  // This is just a basic sanity check. The string must not contain any
  // (unescaped) newlines, carriage returns or double quotes.
  return !strchr(s, '\n') && !strchr(s, '\r') && !strchr(s, '"');
}
#endif

extern "C"
LV2_SYMBOL_EXPORT
int lv2_dyn_manifest_get_data(LV2_Dyn_Manifest_Handle handle,
			      FILE *fp,
			      const char *uri)
{
  LV2Plugin* plugin = (LV2Plugin*)handle;
  int k = plugin->ui[0]->nports;
  int n = plugin->dsp[0]->getNumInputs(), m = plugin->dsp[0]->getNumOutputs();
  bool is_instr = plugin->maxvoices > 0, have_midi = is_instr;
  // Scan the global metadata for plugin name, description, license etc.
  const char *plugin_name = NULL, *plugin_author = NULL, *plugin_descr = NULL,
    *plugin_version = NULL, *plugin_license = NULL;
#if FAUST_META
  plugin_name = plugin->pluginName();
  plugin_descr = plugin->pluginDescription();
  plugin_author = plugin->pluginAuthor();
  plugin_version = plugin->pluginVersion();
  plugin_license = plugin->pluginLicense();
#endif
  if (!plugin_name || !*plugin_name) plugin_name = "gods_cab";
  fprintf(fp, "@prefix doap:  <http://usefulinc.com/ns/doap#> .\n\
@prefix foaf:  <http://xmlns.com/foaf/0.1/> .\n\
@prefix lv2:   <http://lv2plug.in/ns/lv2core#> .\n\
@prefix ui:    <http://lv2plug.in/ns/extensions/ui#> .\n\
@prefix epp:   <http://lv2plug.in/ns/ext/port-props#> .\n\
@prefix atom:  <http://lv2plug.in/ns/ext/atom#> .\n\
@prefix rdf:   <http://www.w3.org/1999/02/22-rdf-syntax-ns#> .\n\
@prefix rdfs:  <http://www.w3.org/2000/01/rdf-schema#> .\n\
@prefix units: <http://lv2plug.in/ns/extensions/units#> .\n\
<%s>\n\
       a lv2:Plugin%s ;\n\
       doap:name \"%s\" ;\n\
       lv2:binary <gods_cab%s> ;\n\
       lv2:optionalFeature epp:supportsStrictBounds ;\n\
       lv2:optionalFeature lv2:hardRtCapable ;\n", PLUGIN_URI,
	  is_instr?", lv2:InstrumentPlugin":"",
	  plugin_name, DLLEXT);
  if (plugin_author && *plugin_author)
    fprintf(fp, "\
       doap:maintainer [ foaf:name \"%s\" ] ;\n", plugin_author);
  // doap:description just seems to be ignored by all LV2 hosts anyway, so we
  // rather use rdfs:comment now which works with Ardour at least.
  if (plugin_descr && *plugin_descr)
    fprintf(fp, "\
       rdfs:comment \"%s\" ;\n", plugin_descr);
  if (plugin_version && *plugin_version)
    fprintf(fp, "\
       doap:revision \"%s\" ;\n", plugin_version);
  if (plugin_license && *plugin_license)
    fprintf(fp, "\
       doap:license \"%s\" ;\n", plugin_license);
#if FAUST_UI
    fprintf(fp, "\
       ui:ui <%sui> ;\n", PLUGIN_URI);
#endif
  int idx = 0;
  // control ports
  for (int i = 0; i < k; i++, idx++) {
    int j = plugin->ctrls[i];
    assert(idx == plugin->ui[0]->elems[j].port);
    fprintf(fp, "%s [\n", idx==0?"    lv2:port":" ,");
    const char *label = plugin->ui[0]->elems[j].label;
    assert(label);
    string sym = mangle(plugin->ui[0]->elems[j].label);
    switch (plugin->ui[0]->elems[j].type) {
    // active controls (input ports)
    case UI_BUTTON: case UI_CHECK_BUTTON:
    fprintf(fp, "\
	a lv2:InputPort ;\n\
	a lv2:ControlPort ;\n\
	lv2:index %d ;\n\
	lv2:symbol \"%s_%d\" ;\n\
	lv2:name \"%s\" ;\n\
        lv2:portProperty epp:hasStrictBounds ;\n\
        lv2:portProperty lv2:toggled ;\n\
	lv2:default 0.00000 ;\n\
	lv2:minimum 0.00000 ;\n\
	lv2:maximum 1.00000 ;\n", idx, sym.c_str(), idx, label);
      break;
    case UI_NUM_ENTRY: case UI_H_SLIDER: case UI_V_SLIDER:
    fprintf(fp, "\
	a lv2:InputPort ;\n\
	a lv2:ControlPort ;\n\
	lv2:index %d ;\n\
	lv2:symbol \"%s_%d\" ;\n\
	lv2:name \"%s\" ;\n\
        lv2:portProperty epp:hasStrictBounds ;\n\
        epp:rangeSteps %u ;\n\
	lv2:default %g ;\n\
	lv2:minimum %g ;\n\
	lv2:maximum %g ;\n", idx, sym.c_str(), idx, label,
	    steps(plugin->ui[0]->elems[j].min,
		  plugin->ui[0]->elems[j].max,
		  plugin->ui[0]->elems[j].step),
	    plugin->ui[0]->elems[j].init,
	    plugin->ui[0]->elems[j].min,
	    plugin->ui[0]->elems[j].max);
      break;
    // passive controls (output ports)
    case UI_H_BARGRAPH: case UI_V_BARGRAPH:
    fprintf(fp, "\
	a lv2:OutputPort ;\n\
	a lv2:ControlPort ;\n\
	lv2:index %d ;\n\
	lv2:symbol \"%s_%d\" ;\n\
	lv2:name \"%s\" ;\n\
	lv2:default %g ;\n\
	lv2:minimum %g ;\n\
	lv2:maximum %g ;\n", idx, sym.c_str(), idx, label,
	    plugin->ui[0]->elems[j].min,
	    plugin->ui[0]->elems[j].min,
	    plugin->ui[0]->elems[j].max);
      break;
    default:
      assert(0 && "this can't happen");
      break;
    }
    // Scan for Faust control metadata we understand and add corresponding
    // hints to the LV2 description of the port.
    std::map< int, list<strpair> >::iterator it =
      plugin->ui[0]->metadata.find(j);
    if (it != plugin->ui[0]->metadata.end()) {
      for (std::list<strpair>::iterator jt = it->second.begin();
	   jt != it->second.end(); jt++) {
	const char *key = jt->first, *val = jt->second;
#if FAUST_MIDICC
	unsigned num;
	if (!strcmp(key, "midi") && sscanf(val, "ctrl %u", &num) == 1)
	  have_midi = true;
#endif
	if (!strcmp(key, "unit"))
	  fprintf(fp, "\
	units:unit [\n\
            a            units:Unit ;\n\
            units:name   \"%s\" ;\n\
            units:symbol \"%s\" ;\n\
            units:render \"%%f %s\"\n\
	] ;\n", val, val, val);
	if (strcmp(key, "lv2")) continue;
	if (!strcmp(val, "integer"))
	  fprintf(fp, "\
	lv2:portProperty lv2:integer ;\n");
	else if (!strcmp(val, "reportsLatency"))
	  fprintf(fp, "\
	lv2:portProperty lv2:reportsLatency ;\n\
	lv2:designation lv2:latency ;\n");
	else if (!strcmp(val, "hidden") || !strcmp(val, "notOnGUI"))
	  fprintf(fp, "\
	lv2:portProperty epp:notOnGUI ;\n");
	else if (!strncmp(val, "scalepoint", 10) ||
		 !strncmp(val, "scalePoint", 10)) {
	  val += 10;
	  if (!isspace(*val)) continue;
	  char *label = (char*)malloc(strlen(val)+1);
	  float point;
	  int pos;
	  while (sscanf(val, "%s %g%n", label, &point, &pos) == 2) {
	    fprintf(fp, "\
	lv2:scalePoint [ rdfs:label \"%s\"; rdf:value %g ] ;\n",
		    label, point);
	    val += pos;
	  }
	  free(label);
	} else
	  fprintf(stderr, "%s: bad port property '%s:%s'\n", PLUGIN_URI,
		  key, val);
      }
    }
    fprintf(fp, "    ]");
  }
  // audio inputs
  for (int i = 0; i < n; i++, idx++)
    fprintf(fp, "%s [\n\
	a lv2:InputPort ;\n\
	a lv2:AudioPort ;\n\
	lv2:index %d ;\n\
	lv2:symbol \"in%d\" ;\n\
	lv2:name \"in%d\" ;\n\
    ]", idx==0?"    lv2:port":" ,", idx, i, i);
  // audio outputs
  for (int i = 0; i < m; i++, idx++)
    fprintf(fp, "%s [\n\
	a lv2:OutputPort ;\n\
	a lv2:AudioPort ;\n\
	lv2:index %d ;\n\
	lv2:symbol \"out%d\" ;\n\
	lv2:name \"out%d\" ;\n\
    ]", idx==0?"    lv2:port":" ,", idx, i, i);
  if (have_midi) {
    // midi input
    fprintf(fp, "%s [\n\
	a lv2:InputPort ;\n\
	a atom:AtomPort ;\n\
	atom:bufferType atom:Sequence ;\n\
	atom:supports <http://lv2plug.in/ns/ext/midi#MidiEvent> ;\n\
	lv2:index %d ;\n\
	lv2:symbol \"midiin\" ;\n\
	lv2:name \"midiin\"\n\
    ]", idx==0?"    lv2:port":" ,", idx);
    idx++;
  }
  if (is_instr) {
    // polyphony control
    fprintf(fp, "%s [\n\
	a lv2:InputPort ;\n\
	a lv2:ControlPort ;\n\
	lv2:index %d ;\n\
	lv2:symbol \"polyphony\" ;\n\
	lv2:name \"polyphony\" ;\n\
        lv2:portProperty epp:hasStrictBounds ;\n\
#       lv2:portProperty epp:expensive ;\n\
        lv2:portProperty lv2:integer ;\n\
        epp:rangeSteps %d ;\n\
	lv2:default %d ;\n\
	lv2:minimum 1 ;\n\
	lv2:maximum %d ;\n\
    ]", idx==0?"    lv2:port":" ,", idx, plugin->maxvoices-1,
      plugin->maxvoices>1?plugin->maxvoices/2:1,
      plugin->maxvoices);
    idx++;
#if FAUST_MTS
    if (plugin->n_tunings > 0) {
      // tuning control
      fprintf(fp, "%s [\n\
	a lv2:InputPort ;\n\
	a lv2:ControlPort ;\n\
	lv2:index %d ;\n\
	lv2:symbol \"tuning\" ;\n\
	lv2:name \"tuning\" ;\n\
        lv2:portProperty epp:hasStrictBounds ;\n\
        lv2:portProperty lv2:integer ;\n\
        epp:rangeSteps %d ;\n\
	lv2:default 0 ;\n\
	lv2:minimum 0 ;\n\
	lv2:maximum %d ;\n",
	idx==0?"    lv2:port":" ,", idx, plugin->n_tunings, plugin->n_tunings);
      for (int i = 0; i <= plugin->n_tunings; i++)
	fprintf(fp, "\
	lv2:scalePoint [ rdfs:label \"%s\"; rdf:value %d ] ;\n",
		(i>0)?plugin->mts->tuning[i-1].name:"default", i);
      fprintf(fp, "    ]");
      idx++;
    }
#endif
  }
  fprintf(fp, "\n.\n");
  return 0;
}

extern "C"
LV2_SYMBOL_EXPORT
void lv2_dyn_manifest_close(LV2_Dyn_Manifest_Handle handle)
{
  LV2Plugin* plugin = (LV2Plugin*)handle;
  delete plugin;
}

int main()
{
  LV2_Dyn_Manifest_Handle handle;
  LV2_Feature **features = { NULL };
  int res = lv2_dyn_manifest_open(&handle, features);
  if (res) return res;
  res = lv2_dyn_manifest_get_data(handle, stdout, PLUGIN_URI);
  return res;
}

#endif
